# -*- coding: utf-8 -*-

"""Data containing all current emoji
   Extracted from https://unicode.org/Public/emoji/latest/emoji-test.txt
   and https://www.unicode.org/Public/UCD/latest/ucd/emoji/emoji-variation-sequences.txt
   See utils/get_codes_from_unicode_emoji_data_files.py

   +----------------+-------------+------------------+-------------------+
   | Emoji Version  |    Date     | Unicode Version  | Data File Comment |
   +----------------+-------------+------------------+-------------------+
   | N/A            | 2010-10-11  | Unicode 6.0      | E0.6              |
   | N/A            | 2014-06-16  | Unicode 7.0      | E0.7              |
   | Emoji 1.0      | 2015-06-09  | Unicode 8.0      | E1.0              |
   | Emoji 2.0      | 2015-11-12  | Unicode 8.0      | E2.0              |
   | Emoji 3.0      | 2016-06-03  | Unicode 9.0      | E3.0              |
   | Emoji 4.0      | 2016-11-22  | Unicode 9.0      | E4.0              |
   | Emoji 5.0      | 2017-06-20  | Unicode 10.0     | E5.0              |
   | Emoji 11.0     | 2018-05-21  | Unicode 11.0     | E11.0             |
   | Emoji 12.0     | 2019-03-05  | Unicode 12.0     | E12.0             |
   | Emoji 12.1     | 2019-10-21  | Unicode 12.1     | E12.1             |
   | Emoji 13.0     | 2020-03-10  | Unicode 13.0     | E13.0             |
   | Emoji 13.1     | 2020-09-15  | Unicode 13.0     | E13.1             |
   | Emoji 14.0     | 2021-09-14  | Unicode 14.0     | E14.0             |
   | Emoji 15.0     | 2022-09-13  | Unicode 15.0     | E15.0             |

                          http://www.unicode.org/reports/tr51/#Versioning

"""

__all__ = [
    'EMOJI_DATA', 'STATUS', 'LANGUAGES'
]

component = 1
fully_qualified = 2
minimally_qualified = 3
unqualified = 4

STATUS = {
    "component" : component,
    "fully_qualified" : fully_qualified,
    "minimally_qualified" : minimally_qualified,
    "unqualified" : unqualified
}

LANGUAGES = ['en', 'es', 'ja', 'ko', 'pt', 'it', 'fr', 'de', 'fa', 'id', 'zh']

EMOJI_DATA = {
    u'\U0001F947': { # 🥇
        'en' : ':1st_place_medal:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':goldmedaille:',
        'es': ':medalla_de_oro:',
        'fr': u':médaille_d’or:',
        'ja': u':金メダル:',
        'ko': u':금메달:',
        'pt': ':medalha_de_ouro:',
        'it': u':medaglia_d’oro:',
        'fa': u':مدال_طلا:',
        'id': ':medali_emas:',
        'zh': u':金牌:'
    },
    u'\U0001F948': { # 🥈
        'en' : ':2nd_place_medal:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':silbermedaille:',
        'es': ':medalla_de_plata:',
        'fr': u':médaille_d’argent:',
        'ja': u':銀メダル:',
        'ko': u':은메달:',
        'pt': ':medalha_de_prata:',
        'it': u':medaglia_d’argento:',
        'fa': u':مدال_نقره:',
        'id': ':medali_perak:',
        'zh': u':银牌:'
    },
    u'\U0001F949': { # 🥉
        'en' : ':3rd_place_medal:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':bronzemedaille:',
        'es': ':medalla_de_bronce:',
        'fr': u':médaille_de_bronze:',
        'ja': u':銅メダル:',
        'ko': u':동메달:',
        'pt': ':medalha_de_bronze:',
        'it': ':medaglia_di_bronzo:',
        'fa': u':مدال_برنز:',
        'id': ':medali_perunggu:',
        'zh': u':铜牌:'
    },
    u'\U0001F18E': { # 🆎
        'en' : ':AB_button_(blood_type):',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ab:'],
        'de': u':großbuchstaben_ab_in_rotem_quadrat:',
        'es': u':grupo_sanguíneo_ab:',
        'fr': ':groupe_sanguin_ab:',
        'ja': u':血液型ab型:',
        'ko': u':에이비형:',
        'pt': u':botão_ab_(tipo_sanguíneo):',
        'it': ':gruppo_sanguigno_ab:',
        'fa': u':دکمه_آ_ب_(گروه_خونی):',
        'id': ':tombol_ab_(golongan_darah):',
        'zh': u':AB型血:'
    },
    u'\U0001F3E7': { # 🏧
        'en' : ':ATM_sign:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':atm:'],
        'de': ':symbol_geldautomat:',
        'es': u':señal_de_cajero_automático:',
        'fr': ':distributeur_de_billets:',
        'ja': ':atm:',
        'ko': u':에이티엠:',
        'pt': u':símbolo_de_caixa_automático:',
        'it': ':simbolo_dello_sportello_bancomat:',
        'fa': u':نشان_عابربانک:',
        'id': ':tanda_atm:',
        'zh': u':取款机:'
    },
    u'\U0001F170\U0000FE0F': { # 🅰️
        'en' : ':A_button_(blood_type):',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':a:'],
        'variant': True,
        'de': u':großbuchstabe_a_in_rotem_quadrat:',
        'es': u':grupo_sanguíneo_a:',
        'fr': ':groupe_sanguin_a:',
        'ja': u':血液型a型:',
        'ko': u':에이형:',
        'pt': u':botão_a_(tipo_sanguíneo):',
        'it': ':gruppo_sanguigno_a:',
        'fa': u':دکمه_آ_(گروه_خونی):',
        'id': ':tombol_a_(golongan_darah):',
        'zh': u':A型血:'
    },
    u'\U0001F170': { # 🅰
        'en' : ':A_button_(blood_type):',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':a:'],
        'variant': True,
        'de': u':großbuchstabe_a_in_rotem_quadrat:',
        'es': u':grupo_sanguíneo_a:',
        'fr': ':groupe_sanguin_a:',
        'ja': u':血液型a型:',
        'ko': u':에이형:',
        'pt': u':botão_a_(tipo_sanguíneo):',
        'it': ':gruppo_sanguigno_a:',
        'fa': u':دکمه_آ_(گروه_خونی):',
        'id': ':tombol_a_(golongan_darah):',
        'zh': u':A型血:'
    },
    u'\U0001F1E6\U0001F1EB': { # 🇦🇫
        'en' : ':Afghanistan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Afghanistan:', ':afghanistan:'],
        'de': ':flagge_afghanistan:',
        'es': u':bandera_afganistán:',
        'fr': ':drapeau_afghanistan:',
        'ja': u':旗_アフガニスタン:',
        'ko': u':깃발_아프가니스탄:',
        'pt': u':bandeira_afeganistão:',
        'it': ':bandiera_afghanistan:',
        'fa': u':پرچم_افغانستان:',
        'id': ':bendera_afganistan:',
        'zh': u':阿富汗:'
    },
    u'\U0001F1E6\U0001F1F1': { # 🇦🇱
        'en' : ':Albania:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Albania:', ':albania:'],
        'de': ':flagge_albanien:',
        'es': ':bandera_albania:',
        'fr': ':drapeau_albanie:',
        'ja': u':旗_アルバニア:',
        'ko': u':깃발_알바니아:',
        'pt': u':bandeira_albânia:',
        'it': ':bandiera_albania:',
        'fa': u':پرچم_آلبانی:',
        'id': ':bendera_albania:',
        'zh': u':阿尔巴尼亚:'
    },
    u'\U0001F1E9\U0001F1FF': { # 🇩🇿
        'en' : ':Algeria:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Algeria:', ':algeria:'],
        'de': ':flagge_algerien:',
        'es': ':bandera_argelia:',
        'fr': u':drapeau_algérie:',
        'ja': u':旗_アルジェリア:',
        'ko': u':깃발_알제리:',
        'pt': u':bandeira_argélia:',
        'it': ':bandiera_algeria:',
        'fa': u':پرچم_الجزایر:',
        'id': ':bendera_aljazair:',
        'zh': u':阿尔及利亚:'
    },
    u'\U0001F1E6\U0001F1F8': { # 🇦🇸
        'en' : ':American_Samoa:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_American_Samoa:', ':american_samoa:'],
        'de': ':flagge_amerikanisch-samoa:',
        'es': ':bandera_samoa_americana:',
        'fr': u':drapeau_samoa_américaines:',
        'ja': u':旗_米領サモア:',
        'ko': u':깃발_아메리칸_사모아:',
        'pt': ':bandeira_samoa_americana:',
        'it': ':bandiera_samoa_americane:',
        'fa': u':پرچم_ساموآی_امریکا:',
        'id': ':bendera_samoa_amerika:',
        'zh': u':美属萨摩亚:'
    },
    u'\U0001F1E6\U0001F1E9': { # 🇦🇩
        'en' : ':Andorra:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Andorra:', ':andorra:'],
        'de': ':flagge_andorra:',
        'es': ':bandera_andorra:',
        'fr': ':drapeau_andorre:',
        'ja': u':旗_アンドラ:',
        'ko': u':깃발_안도라:',
        'pt': ':bandeira_andorra:',
        'it': ':bandiera_andorra:',
        'fa': u':پرچم_آندورا:',
        'id': ':bendera_andorra:',
        'zh': u':安道尔:'
    },
    u'\U0001F1E6\U0001F1F4': { # 🇦🇴
        'en' : ':Angola:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Angola:', ':angola:'],
        'de': ':flagge_angola:',
        'es': ':bandera_angola:',
        'fr': ':drapeau_angola:',
        'ja': u':旗_アンゴラ:',
        'ko': u':깃발_앙골라:',
        'pt': ':bandeira_angola:',
        'it': ':bandiera_angola:',
        'fa': u':پرچم_آنگولا:',
        'id': ':bendera_angola:',
        'zh': u':安哥拉:'
    },
    u'\U0001F1E6\U0001F1EE': { # 🇦🇮
        'en' : ':Anguilla:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Anguilla:', ':anguilla:'],
        'de': ':flagge_anguilla:',
        'es': ':bandera_anguila:',
        'fr': ':drapeau_anguilla:',
        'ja': u':旗_アンギラ:',
        'ko': u':깃발_앵귈라:',
        'pt': ':bandeira_anguila:',
        'it': ':bandiera_anguilla:',
        'fa': u':پرچم_آنگویلا:',
        'id': ':bendera_anguilla:',
        'zh': u':安圭拉:'
    },
    u'\U0001F1E6\U0001F1F6': { # 🇦🇶
        'en' : ':Antarctica:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Antarctica:', ':antarctica:'],
        'de': ':flagge_antarktis:',
        'es': u':bandera_antártida:',
        'fr': ':drapeau_antarctique:',
        'ja': u':旗_南極:',
        'ko': u':깃발_남극_대륙:',
        'pt': u':bandeira_antártida:',
        'it': ':bandiera_antartide:',
        'fa': u':پرچم_جنوبگان:',
        'id': ':bendera_antarktika:',
        'zh': u':南极洲:'
    },
    u'\U0001F1E6\U0001F1EC': { # 🇦🇬
        'en' : ':Antigua_&_Barbuda:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Antigua_&_Barbuda:', ':antigua_barbuda:'],
        'de': ':flagge_antigua_und_barbuda:',
        'es': ':bandera_antigua_y_barbuda:',
        'fr': ':drapeau_antigua-et-barbuda:',
        'ja': u':旗_アンティグア・バーブーダ:',
        'ko': u':깃발_앤티가_바부다:',
        'pt': u':bandeira_antígua_e_barbuda:',
        'it': ':bandiera_antigua_e_barbuda:',
        'fa': u':پرچم_آنتیگوا_و_باربودا:',
        'id': ':bendera_antigua_dan_barbuda:',
        'zh': u':安提瓜和巴布达:'
    },
    u'\U00002652': { # ♒
        'en' : ':Aquarius:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':aquarius:'],
        'variant': True,
        'de': ':wassermann_(sternzeichen):',
        'es': ':acuario:',
        'fr': ':verseau:',
        'ja': u':みずがめ座:',
        'ko': u':물병자리:',
        'pt': u':signo_de_aquário:',
        'it': u':segno_zodiacale_dell’acquario:',
        'fa': u':برج_دلو:',
        'id': ':aquarius:',
        'zh': u':水瓶座:'
    },
    u'\U0001F1E6\U0001F1F7': { # 🇦🇷
        'en' : ':Argentina:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Argentina:', ':argentina:'],
        'de': ':flagge_argentinien:',
        'es': ':bandera_argentina:',
        'fr': ':drapeau_argentine:',
        'ja': u':旗_アルゼンチン:',
        'ko': u':깃발_아르헨티나:',
        'pt': ':bandeira_argentina:',
        'it': ':bandiera_argentina:',
        'fa': u':پرچم_آرژانتین:',
        'id': ':bendera_argentina:',
        'zh': u':阿根廷:'
    },
    u'\U00002648': { # ♈
        'en' : ':Aries:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':aries:'],
        'variant': True,
        'de': ':widder_(sternzeichen):',
        'es': ':aries:',
        'fr': u':bélier_zodiaque:',
        'ja': u':おひつじ座:',
        'ko': u':양자리:',
        'pt': u':signo_de_áries:',
        'it': u':segno_zodiacale_dell’ariete:',
        'fa': u':برج_حمل:',
        'id': ':aries:',
        'zh': u':白羊座:'
    },
    u'\U0001F1E6\U0001F1F2': { # 🇦🇲
        'en' : ':Armenia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Armenia:', ':armenia:'],
        'de': ':flagge_armenien:',
        'es': ':bandera_armenia:',
        'fr': u':drapeau_arménie:',
        'ja': u':旗_アルメニア:',
        'ko': u':깃발_아르메니아:',
        'pt': u':bandeira_armênia:',
        'it': ':bandiera_armenia:',
        'fa': u':پرچم_ارمنستان:',
        'id': ':bendera_armenia:',
        'zh': u':亚美尼亚:'
    },
    u'\U0001F1E6\U0001F1FC': { # 🇦🇼
        'en' : ':Aruba:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Aruba:', ':aruba:'],
        'de': ':flagge_aruba:',
        'es': ':bandera_aruba:',
        'fr': ':drapeau_aruba:',
        'ja': u':旗_アルバ:',
        'ko': u':깃발_아루바:',
        'pt': ':bandeira_aruba:',
        'it': ':bandiera_aruba:',
        'fa': u':پرچم_آروبا:',
        'id': ':bendera_aruba:',
        'zh': u':阿鲁巴:'
    },
    u'\U0001F1E6\U0001F1E8': { # 🇦🇨
        'en' : ':Ascension_Island:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Ascension_Island:', ':ascension_island:'],
        'de': ':flagge_ascension:',
        'es': u':bandera_isla_de_la_ascensión:',
        'fr': u':drapeau_île_de_l’ascension:',
        'ja': u':旗_アセンション島:',
        'ko': u':깃발_어센션_섬:',
        'pt': u':bandeira_ilha_de_ascensão:',
        'it': ':bandiera_isola_ascensione:',
        'fa': u':پرچم_جزایر_آسنسیون:',
        'id': ':bendera_pulau_ascension:',
        'zh': u':阿森松岛:'
    },
    u'\U0001F1E6\U0001F1FA': { # 🇦🇺
        'en' : ':Australia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Australia:', ':australia:'],
        'de': ':flagge_australien:',
        'es': ':bandera_australia:',
        'fr': ':drapeau_australie:',
        'ja': u':旗_オーストラリア:',
        'ko': u':깃발_오스트레일리아:',
        'pt': u':bandeira_austrália:',
        'it': ':bandiera_australia:',
        'fa': u':پرچم_استرالیا:',
        'id': ':bendera_australia:',
        'zh': u':澳大利亚:'
    },
    u'\U0001F1E6\U0001F1F9': { # 🇦🇹
        'en' : ':Austria:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Austria:', ':austria:'],
        'de': u':flagge_österreich:',
        'es': ':bandera_austria:',
        'fr': ':drapeau_autriche:',
        'ja': u':旗_オーストリア:',
        'ko': u':깃발_오스트리아:',
        'pt': u':bandeira_áustria:',
        'it': ':bandiera_austria:',
        'fa': u':پرچم_اتریش:',
        'id': ':bendera_austria:',
        'zh': u':奥地利:'
    },
    u'\U0001F1E6\U0001F1FF': { # 🇦🇿
        'en' : ':Azerbaijan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Azerbaijan:', ':azerbaijan:'],
        'de': ':flagge_aserbaidschan:',
        'es': u':bandera_azerbaiyán:',
        'fr': u':drapeau_azerbaïdjan:',
        'ja': u':旗_アゼルバイジャン:',
        'ko': u':깃발_아제르바이잔:',
        'pt': u':bandeira_azerbaijão:',
        'it': ':bandiera_azerbaigian:',
        'fa': u':پرچم_جمهوری_آذربایجان:',
        'id': ':bendera_azerbaijan:',
        'zh': u':阿塞拜疆:'
    },
    u'\U0001F519': { # 🔙
        'en' : ':BACK_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':back:'],
        'de': ':back-pfeil:',
        'es': ':flecha_back:',
        'fr': u':flèche_retour:',
        'ja': u':back矢印:',
        'ko': u':뒤로:',
        'pt': ':seta_back:',
        'it': ':freccia_back:',
        'fa': u':پیکان_عقب:',
        'id': ':tanda_panah_back:',
        'zh': u':返回箭头:'
    },
    u'\U0001F171\U0000FE0F': { # 🅱️
        'en' : ':B_button_(blood_type):',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':b:'],
        'variant': True,
        'de': u':großbuchstabe_b_in_rotem_quadrat:',
        'es': u':grupo_sanguíneo_b:',
        'fr': ':groupe_sanguin_b:',
        'ja': u':血液型b型:',
        'ko': u':비형:',
        'pt': u':botão_b_(tipo_sanguíneo):',
        'it': ':gruppo_sanguigno_b:',
        'fa': u':دکمه_ب_(گروه_خونی):',
        'id': ':tombol_b_(golongan_darah):',
        'zh': u':B型血:'
    },
    u'\U0001F171': { # 🅱
        'en' : ':B_button_(blood_type):',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':b:'],
        'variant': True,
        'de': u':großbuchstabe_b_in_rotem_quadrat:',
        'es': u':grupo_sanguíneo_b:',
        'fr': ':groupe_sanguin_b:',
        'ja': u':血液型b型:',
        'ko': u':비형:',
        'pt': u':botão_b_(tipo_sanguíneo):',
        'it': ':gruppo_sanguigno_b:',
        'fa': u':دکمه_ب_(گروه_خونی):',
        'id': ':tombol_b_(golongan_darah):',
        'zh': u':B型血:'
    },
    u'\U0001F1E7\U0001F1F8': { # 🇧🇸
        'en' : ':Bahamas:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bahamas:', ':bahamas:'],
        'de': ':flagge_bahamas:',
        'es': ':bandera_bahamas:',
        'fr': ':drapeau_bahamas:',
        'ja': u':旗_バハマ:',
        'ko': u':깃발_바하마:',
        'pt': ':bandeira_bahamas:',
        'it': ':bandiera_bahamas:',
        'fa': u':پرچم_باهاما:',
        'id': ':bendera_bahama:',
        'zh': u':巴哈马:'
    },
    u'\U0001F1E7\U0001F1ED': { # 🇧🇭
        'en' : ':Bahrain:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bahrain:', ':bahrain:'],
        'de': ':flagge_bahrain:',
        'es': u':bandera_baréin:',
        'fr': u':drapeau_bahreïn:',
        'ja': u':旗_バーレーン:',
        'ko': u':깃발_바레인:',
        'pt': ':bandeira_bahrein:',
        'it': ':bandiera_bahrein:',
        'fa': u':پرچم_بحرین:',
        'id': ':bendera_bahrain:',
        'zh': u':巴林:'
    },
    u'\U0001F1E7\U0001F1E9': { # 🇧🇩
        'en' : ':Bangladesh:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bangladesh:', ':bangladesh:'],
        'de': ':flagge_bangladesch:',
        'es': u':bandera_bangladés:',
        'fr': ':drapeau_bangladesh:',
        'ja': u':旗_バングラデシュ:',
        'ko': u':깃발_방글라데시:',
        'pt': ':bandeira_bangladesh:',
        'it': ':bandiera_bangladesh:',
        'fa': u':پرچم_بنگلادش:',
        'id': ':bendera_bangladesh:',
        'zh': u':孟加拉国:'
    },
    u'\U0001F1E7\U0001F1E7': { # 🇧🇧
        'en' : ':Barbados:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Barbados:', ':barbados:'],
        'de': ':flagge_barbados:',
        'es': ':bandera_barbados:',
        'fr': ':drapeau_barbade:',
        'ja': u':旗_バルバドス:',
        'ko': u':깃발_바베이도스:',
        'pt': ':bandeira_barbados:',
        'it': ':bandiera_barbados:',
        'fa': u':پرچم_باربادوس:',
        'id': ':bendera_barbados:',
        'zh': u':巴巴多斯:'
    },
    u'\U0001F1E7\U0001F1FE': { # 🇧🇾
        'en' : ':Belarus:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Belarus:', ':belarus:'],
        'de': ':flagge_belarus:',
        'es': ':bandera_bielorrusia:',
        'fr': u':drapeau_biélorussie:',
        'ja': u':旗_ベラルーシ:',
        'ko': u':깃발_벨라루스:',
        'pt': u':bandeira_bielorrússia:',
        'it': ':bandiera_bielorussia:',
        'fa': u':پرچم_بلاروس:',
        'id': ':bendera_belarus:',
        'zh': u':白俄罗斯:'
    },
    u'\U0001F1E7\U0001F1EA': { # 🇧🇪
        'en' : ':Belgium:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Belgium:', ':belgium:'],
        'de': ':flagge_belgien:',
        'es': u':bandera_bélgica:',
        'fr': ':drapeau_belgique:',
        'ja': u':旗_ベルギー:',
        'ko': u':깃발_벨기에:',
        'pt': u':bandeira_bélgica:',
        'it': ':bandiera_belgio:',
        'fa': u':پرچم_بلژیک:',
        'id': ':bendera_belgia:',
        'zh': u':比利时:'
    },
    u'\U0001F1E7\U0001F1FF': { # 🇧🇿
        'en' : ':Belize:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Belize:', ':belize:'],
        'de': ':flagge_belize:',
        'es': ':bandera_belice:',
        'fr': ':drapeau_belize:',
        'ja': u':旗_ベリーズ:',
        'ko': u':깃발_벨리즈:',
        'pt': ':bandeira_belize:',
        'it': ':bandiera_belize:',
        'fa': u':پرچم_بلیز:',
        'id': ':bendera_belize:',
        'zh': u':伯利兹:'
    },
    u'\U0001F1E7\U0001F1EF': { # 🇧🇯
        'en' : ':Benin:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Benin:', ':benin:'],
        'de': ':flagge_benin:',
        'es': u':bandera_benín:',
        'fr': u':drapeau_bénin:',
        'ja': u':旗_ベナン:',
        'ko': u':깃발_베냉:',
        'pt': ':bandeira_benin:',
        'it': ':bandiera_benin:',
        'fa': u':پرچم_بنین:',
        'id': ':bendera_benin:',
        'zh': u':贝宁:'
    },
    u'\U0001F1E7\U0001F1F2': { # 🇧🇲
        'en' : ':Bermuda:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bermuda:', ':bermuda:'],
        'de': ':flagge_bermuda:',
        'es': ':bandera_bermudas:',
        'fr': ':drapeau_bermudes:',
        'ja': u':旗_バミューダ:',
        'ko': u':깃발_버뮤다:',
        'pt': ':bandeira_bermudas:',
        'it': ':bandiera_bermuda:',
        'fa': u':پرچم_برمودا:',
        'id': ':bendera_bermuda:',
        'zh': u':百慕大:'
    },
    u'\U0001F1E7\U0001F1F9': { # 🇧🇹
        'en' : ':Bhutan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bhutan:', ':bhutan:'],
        'de': ':flagge_bhutan:',
        'es': u':bandera_bután:',
        'fr': ':drapeau_bhoutan:',
        'ja': u':旗_ブータン:',
        'ko': u':깃발_부탄:',
        'pt': u':bandeira_butão:',
        'it': ':bandiera_bhutan:',
        'fa': u':پرچم_بوتان:',
        'id': ':bendera_bhutan:',
        'zh': u':不丹:'
    },
    u'\U0001F1E7\U0001F1F4': { # 🇧🇴
        'en' : ':Bolivia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bolivia:', ':bolivia:'],
        'de': ':flagge_bolivien:',
        'es': ':bandera_bolivia:',
        'fr': ':drapeau_bolivie:',
        'ja': u':旗_ボリビア:',
        'ko': u':깃발_볼리비아:',
        'pt': u':bandeira_bolívia:',
        'it': ':bandiera_bolivia:',
        'fa': u':پرچم_بولیوی:',
        'id': ':bendera_bolivia:',
        'zh': u':玻利维亚:'
    },
    u'\U0001F1E7\U0001F1E6': { # 🇧🇦
        'en' : ':Bosnia_&_Herzegovina:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bosnia_&_Herzegovina:', ':bosnia_herzegovina:'],
        'de': ':flagge_bosnien_und_herzegowina:',
        'es': ':bandera_bosnia_y_herzegovina:',
        'fr': u':drapeau_bosnie-herzégovine:',
        'ja': u':旗_ボスニア・ヘルツェゴビナ:',
        'ko': u':깃발_보스니아_헤르체고비나:',
        'pt': u':bandeira_bósnia_e_herzegovina:',
        'it': ':bandiera_bosnia_ed_erzegovina:',
        'fa': u':پرچم_بوسنی_و_هرزگوین:',
        'id': ':bendera_bosnia_dan_herzegovina:',
        'zh': u':波斯尼亚和黑塞哥维那:'
    },
    u'\U0001F1E7\U0001F1FC': { # 🇧🇼
        'en' : ':Botswana:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Botswana:', ':botswana:'],
        'de': ':flagge_botsuana:',
        'es': ':bandera_botsuana:',
        'fr': ':drapeau_botswana:',
        'ja': u':旗_ボツワナ:',
        'ko': u':깃발_보츠와나:',
        'pt': ':bandeira_botsuana:',
        'it': ':bandiera_botswana:',
        'fa': u':پرچم_بوتسوانا:',
        'id': ':bendera_botswana:',
        'zh': u':博茨瓦纳:'
    },
    u'\U0001F1E7\U0001F1FB': { # 🇧🇻
        'en' : ':Bouvet_Island:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bouvet_Island:', ':bouvet_island:'],
        'de': ':flagge_bouvetinsel:',
        'es': ':bandera_isla_bouvet:',
        'fr': u':drapeau_île_bouvet:',
        'ja': u':旗_ブーベ島:',
        'ko': u':깃발_부베섬:',
        'pt': ':bandeira_ilha_bouvet:',
        'it': ':bandiera_isola_bouvet:',
        'fa': u':پرچم_جزیرهٔ_بووه:',
        'id': ':bendera_pulau_bouvet:',
        'zh': u':布韦岛:'
    },
    u'\U0001F1E7\U0001F1F7': { # 🇧🇷
        'en' : ':Brazil:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Brazil:', ':brazil:'],
        'de': ':flagge_brasilien:',
        'es': ':bandera_brasil:',
        'fr': u':drapeau_brésil:',
        'ja': u':旗_ブラジル:',
        'ko': u':깃발_브라질:',
        'pt': ':bandeira_brasil:',
        'it': ':bandiera_brasile:',
        'fa': u':پرچم_برزیل:',
        'id': ':bendera_brasil:',
        'zh': u':巴西:'
    },
    u'\U0001F1EE\U0001F1F4': { # 🇮🇴
        'en' : ':British_Indian_Ocean_Territory:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_British_Indian_Ocean_Territory:', ':british_indian_ocean_territory:'],
        'de': ':flagge_britisches_territorium_im_indischen_ozean:',
        'es': u':bandera_territorio_británico_del_océano_índico:',
        'fr': u':drapeau_territoire_britannique_de_l’océan_indien:',
        'ja': u':旗_英領インド洋地域:',
        'ko': u':깃발_영국령_인도양_식민지:',
        'pt': u':bandeira_território_britânico_do_oceano_índico:',
        'it': u':bandiera_territorio_britannico_dell’oceano_indiano:',
        'fa': u':پرچم_قلمرو_بریتانیا_در_اقیانوس_هند:',
        'id': ':bendera_wilayah_inggris_di_samudra_hindia:',
        'zh': u':英属印度洋领地:'
    },
    u'\U0001F1FB\U0001F1EC': { # 🇻🇬
        'en' : ':British_Virgin_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_British_Virgin_Islands:', ':british_virgin_islands:'],
        'de': ':flagge_britische_jungferninseln:',
        'es': u':bandera_islas_vírgenes_británicas:',
        'fr': u':drapeau_îles_vierges_britanniques:',
        'ja': u':旗_英領ヴァージン諸島:',
        'ko': u':깃발_영국령_버진아일랜드:',
        'pt': u':bandeira_ilhas_virgens_britânicas:',
        'it': ':bandiera_isole_vergini_britanniche:',
        'fa': u':پرچم_جزایر_ویرجین_بریتانیا:',
        'id': ':bendera_kepulauan_virgin_britania_raya:',
        'zh': u':英属维尔京群岛:'
    },
    u'\U0001F1E7\U0001F1F3': { # 🇧🇳
        'en' : ':Brunei:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Brunei:', ':brunei:'],
        'de': ':flagge_brunei_darussalam:',
        'es': u':bandera_brunéi:',
        'fr': u':drapeau_brunéi_darussalam:',
        'ja': u':旗_ブルネイ:',
        'ko': u':깃발_브루나이:',
        'pt': ':bandeira_brunei:',
        'it': ':bandiera_brunei:',
        'fa': u':پرچم_برونئی:',
        'id': ':bendera_brunei:',
        'zh': u':文莱:'
    },
    u'\U0001F1E7\U0001F1EC': { # 🇧🇬
        'en' : ':Bulgaria:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Bulgaria:', ':bulgaria:'],
        'de': ':flagge_bulgarien:',
        'es': ':bandera_bulgaria:',
        'fr': ':drapeau_bulgarie:',
        'ja': u':旗_ブルガリア:',
        'ko': u':깃발_불가리아:',
        'pt': u':bandeira_bulgária:',
        'it': ':bandiera_bulgaria:',
        'fa': u':پرچم_بلغارستان:',
        'id': ':bendera_bulgaria:',
        'zh': u':保加利亚:'
    },
    u'\U0001F1E7\U0001F1EB': { # 🇧🇫
        'en' : ':Burkina_Faso:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Burkina_Faso:', ':burkina_faso:'],
        'de': ':flagge_burkina_faso:',
        'es': ':bandera_burkina_faso:',
        'fr': ':drapeau_burkina_faso:',
        'ja': u':旗_ブルキナファソ:',
        'ko': u':깃발_부르키나파소:',
        'pt': ':bandeira_burquina_faso:',
        'it': ':bandiera_burkina_faso:',
        'fa': u':پرچم_بورکینافاسو:',
        'id': ':bendera_burkina_faso:',
        'zh': u':布基纳法索:'
    },
    u'\U0001F1E7\U0001F1EE': { # 🇧🇮
        'en' : ':Burundi:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Burundi:', ':burundi:'],
        'de': ':flagge_burundi:',
        'es': ':bandera_burundi:',
        'fr': ':drapeau_burundi:',
        'ja': u':旗_ブルンジ:',
        'ko': u':깃발_부룬디:',
        'pt': ':bandeira_burundi:',
        'it': ':bandiera_burundi:',
        'fa': u':پرچم_بوروندی:',
        'id': ':bendera_burundi:',
        'zh': u':布隆迪:'
    },
    u'\U0001F191': { # 🆑
        'en' : ':CL_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cl:'],
        'de': u':großbuchstaben_cl_in_rotem_quadrat:',
        'es': ':borrar:',
        'fr': ':bouton_effacer:',
        'ja': u':clマーク:',
        'ko': u':씨엘:',
        'pt': u':botão_cl:',
        'it': ':pulsante_cl:',
        'fa': u':دکمهٔ_cl:',
        'id': ':tombol_cl:',
        'zh': u':CL按钮:'
    },
    u'\U0001F192': { # 🆒
        'en' : ':COOL_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cool:'],
        'de': ':wort_cool_in_blauem_quadrat:',
        'es': u':botón_cool:',
        'fr': ':bouton_cool:',
        'ja': u':coolマーク:',
        'ko': u':쿨:',
        'pt': u':botão_cool:',
        'it': ':pulsante_cool:',
        'fa': u':دکمهٔ_cool:',
        'id': ':tombol_cool:',
        'zh': u':cool按钮:'
    },
    u'\U0001F1F0\U0001F1ED': { # 🇰🇭
        'en' : ':Cambodia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cambodia:', ':cambodia:'],
        'de': ':flagge_kambodscha:',
        'es': ':bandera_camboya:',
        'fr': ':drapeau_cambodge:',
        'ja': u':旗_カンボジア:',
        'ko': u':깃발_캄보디아:',
        'pt': ':bandeira_camboja:',
        'it': ':bandiera_cambogia:',
        'fa': u':پرچم_کامبوج:',
        'id': ':bendera_kamboja:',
        'zh': u':柬埔寨:'
    },
    u'\U0001F1E8\U0001F1F2': { # 🇨🇲
        'en' : ':Cameroon:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cameroon:', ':cameroon:'],
        'de': ':flagge_kamerun:',
        'es': u':bandera_camerún:',
        'fr': ':drapeau_cameroun:',
        'ja': u':旗_カメルーン:',
        'ko': u':깃발_카메룬:',
        'pt': u':bandeira_camarões:',
        'it': ':bandiera_camerun:',
        'fa': u':پرچم_کامرون:',
        'id': ':bendera_kamerun:',
        'zh': u':喀麦隆:'
    },
    u'\U0001F1E8\U0001F1E6': { # 🇨🇦
        'en' : ':Canada:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Canada:', ':canada:'],
        'de': ':flagge_kanada:',
        'es': u':bandera_canadá:',
        'fr': ':drapeau_canada:',
        'ja': u':旗_カナダ:',
        'ko': u':깃발_캐나다:',
        'pt': u':bandeira_canadá:',
        'it': ':bandiera_canada:',
        'fa': u':پرچم_کانادا:',
        'id': ':bendera_kanada:',
        'zh': u':加拿大:'
    },
    u'\U0001F1EE\U0001F1E8': { # 🇮🇨
        'en' : ':Canary_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Canary_Islands:', ':canary_islands:'],
        'de': ':flagge_kanarische_inseln:',
        'es': ':bandera_canarias:',
        'fr': u':drapeau_îles_canaries:',
        'ja': u':旗_カナリア諸島:',
        'ko': u':깃발_카나리아_제도:',
        'pt': u':bandeira_ilhas_canárias:',
        'it': ':bandiera_isole_canarie:',
        'fa': u':پرچم_جزایر_قناری:',
        'id': ':bendera_kepulauan_canaria:',
        'zh': u':加纳利群岛:'
    },
    u'\U0000264B': { # ♋
        'en' : ':Cancer:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cancer:'],
        'variant': True,
        'de': ':krebs_(sternzeichen):',
        'es': u':cáncer:',
        'fr': ':cancer:',
        'ja': u':かに座:',
        'ko': u':게자리:',
        'pt': u':signo_de_câncer:',
        'it': ':segno_zodiacale_del_cancro:',
        'fa': u':برج_سرطان:',
        'id': ':cancer:',
        'zh': u':巨蟹座:'
    },
    u'\U0001F1E8\U0001F1FB': { # 🇨🇻
        'en' : ':Cape_Verde:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cape_Verde:', ':cape_verde:'],
        'de': ':flagge_cabo_verde:',
        'es': ':bandera_cabo_verde:',
        'fr': ':drapeau_cap-vert:',
        'ja': u':旗_カーボベルデ:',
        'ko': u':깃발_카보베르데:',
        'pt': ':bandeira_cabo_verde:',
        'it': ':bandiera_capo_verde:',
        'fa': u':پرچم_کیپ_ورد:',
        'id': ':bendera_tanjung_verde:',
        'zh': u':佛得角:'
    },
    u'\U00002651': { # ♑
        'en' : ':Capricorn:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':capricorn:'],
        'variant': True,
        'de': ':steinbock_(sternzeichen):',
        'es': ':capricornio:',
        'fr': ':capricorne:',
        'ja': u':やぎ座:',
        'ko': u':염소자리:',
        'pt': u':signo_de_capricórnio:',
        'it': ':segno_zodiacale_del_capricorno:',
        'fa': u':برج_جدی:',
        'id': ':capricorn:',
        'zh': u':摩羯座:'
    },
    u'\U0001F1E7\U0001F1F6': { # 🇧🇶
        'en' : ':Caribbean_Netherlands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Caribbean_Netherlands:', ':caribbean_netherlands:'],
        'de': ':flagge_bonaire,_sint_eustatius_und_saba:',
        'es': u':bandera_caribe_neerlandés:',
        'fr': u':drapeau_pays-bas_caribéens:',
        'ja': u':旗_オランダ領カリブ:',
        'ko': u':깃발_네덜란드령_카리브:',
        'pt': u':bandeira_países_baixos_caribenhos:',
        'it': ':bandiera_caraibi_olandesi:',
        'fa': u':پرچم_جزایر_کارائیب_هلند:',
        'id': ':bendera_belanda_karibia:',
        'zh': u':荷属加勒比区:'
    },
    u'\U0001F1F0\U0001F1FE': { # 🇰🇾
        'en' : ':Cayman_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cayman_Islands:', ':cayman_islands:'],
        'de': ':flagge_kaimaninseln:',
        'es': u':bandera_islas_caimán:',
        'fr': u':drapeau_îles_caïmans:',
        'ja': u':旗_ケイマン諸島:',
        'ko': u':깃발_케이맨_제도:',
        'pt': ':bandeira_ilhas_cayman:',
        'it': ':bandiera_isole_cayman:',
        'fa': u':پرچم_جزایر_کِیمن:',
        'id': ':bendera_kepulauan_cayman:',
        'zh': u':开曼群岛:'
    },
    u'\U0001F1E8\U0001F1EB': { # 🇨🇫
        'en' : ':Central_African_Republic:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Central_African_Republic:', ':central_african_republic:'],
        'de': ':flagge_zentralafrikanische_republik:',
        'es': u':bandera_república_centroafricana:',
        'fr': u':drapeau_république_centrafricaine:',
        'ja': u':旗_中央アフリカ共和国:',
        'ko': u':깃발_중앙_아프리카_공화국:',
        'pt': u':bandeira_república_centro-africana:',
        'it': ':bandiera_repubblica_centrafricana:',
        'fa': u':پرچم_جمهوری_افریقای_مرکزی:',
        'id': ':bendera_republik_afrika_tengah:',
        'zh': u':中非共和国:'
    },
    u'\U0001F1EA\U0001F1E6': { # 🇪🇦
        'en' : ':Ceuta_&_Melilla:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Ceuta_&_Melilla:', ':ceuta_melilla:'],
        'de': ':flagge_ceuta_und_melilla:',
        'es': ':bandera_ceuta_y_melilla:',
        'fr': ':drapeau_ceuta_et_melilla:',
        'ja': u':旗_セウタ・メリリャ:',
        'ko': u':깃발_세우타_및_멜리야:',
        'pt': ':bandeira_ceuta_e_melilla:',
        'it': ':bandiera_ceuta_e_melilla:',
        'fa': u':پرچم_سبته_و_ملیله:',
        'id': ':bendera_ceuta_dan_melilla:',
        'zh': u':休达及梅利利亚:'
    },
    u'\U0001F1F9\U0001F1E9': { # 🇹🇩
        'en' : ':Chad:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Chad:', ':chad:'],
        'de': ':flagge_tschad:',
        'es': ':bandera_chad:',
        'fr': ':drapeau_tchad:',
        'ja': u':旗_チャド:',
        'ko': u':깃발_차드:',
        'pt': ':bandeira_chade:',
        'it': ':bandiera_ciad:',
        'fa': u':پرچم_چاد:',
        'id': ':bendera_chad:',
        'zh': u':乍得:'
    },
    u'\U0001F1E8\U0001F1F1': { # 🇨🇱
        'en' : ':Chile:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Chile:', ':chile:'],
        'de': ':flagge_chile:',
        'es': ':bandera_chile:',
        'fr': ':drapeau_chili:',
        'ja': u':旗_チリ:',
        'ko': u':깃발_칠레:',
        'pt': ':bandeira_chile:',
        'it': ':bandiera_cile:',
        'fa': u':پرچم_شیلی:',
        'id': ':bendera_cile:',
        'zh': u':智利:'
    },
    u'\U0001F1E8\U0001F1F3': { # 🇨🇳
        'en' : ':China:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_China:', ':cn:'],
        'de': ':flagge_china:',
        'es': ':bandera_china:',
        'fr': ':drapeau_chine:',
        'ja': u':旗_中国:',
        'ko': u':깃발_중국:',
        'pt': ':bandeira_china:',
        'it': ':bandiera_cina:',
        'fa': u':پرچم_چین:',
        'id': ':bendera_tiongkok:',
        'zh': u':中国:'
    },
    u'\U0001F1E8\U0001F1FD': { # 🇨🇽
        'en' : ':Christmas_Island:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Christmas_Island:', ':christmas_island:'],
        'de': ':flagge_weihnachtsinsel:',
        'es': ':bandera_isla_de_navidad:',
        'fr': u':drapeau_île_christmas:',
        'ja': u':旗_クリスマス島:',
        'ko': u':깃발_크리스마스섬:',
        'pt': ':bandeira_ilha_christmas:',
        'it': ':bandiera_isola_christmas:',
        'fa': u':پرچم_جزیرهٔ_کریسمس:',
        'id': ':bendera_pulau_natal:',
        'zh': u':圣诞岛:'
    },
    u'\U0001F384': { # 🎄
        'en' : ':Christmas_tree:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':christmas_tree:'],
        'de': ':weihnachtsbaum:',
        'es': u':árbol_de_navidad:',
        'fr': u':sapin_de_noël:',
        'ja': u':クリスマスツリー:',
        'ko': u':크리스마스_트리:',
        'pt': u':árvore_de_natal:',
        'it': ':albero_di_natale:',
        'fa': u':درخت_کریسمس:',
        'id': ':pohon_natal:',
        'zh': u':圣诞树:'
    },
    u'\U0001F1E8\U0001F1F5': { # 🇨🇵
        'en' : ':Clipperton_Island:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Clipperton_Island:', ':clipperton_island:'],
        'de': ':flagge_clipperton-insel:',
        'es': ':bandera_isla_clipperton:',
        'fr': u':drapeau_île_clipperton:',
        'ja': u':旗_クリッパートン島:',
        'ko': u':깃발_클리퍼턴섬:',
        'pt': ':bandeira_ilha_de_clipperton:',
        'it': ':bandiera_isola_di_clipperton:',
        'fa': u':پرچم_جزایر_کلیپرتون:',
        'id': ':bendera_pulau_clipperton:',
        'zh': u':克利珀顿岛:'
    },
    u'\U0001F1E8\U0001F1E8': { # 🇨🇨
        'en' : ':Cocos_(Keeling)_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cocos__Islands:', ':cocos_islands:'],
        'de': ':flagge_kokosinseln:',
        'es': ':bandera_islas_cocos:',
        'fr': u':drapeau_îles_cocos:',
        'ja': u':旗_ココス(キーリング)諸島:',
        'ko': u':깃발_코코스_제도:',
        'pt': ':bandeira_ilhas_cocos_(keeling):',
        'it': ':bandiera_isole_cocos_(keeling):',
        'fa': u':پرچم_جزایر_کوکوس:',
        'id': ':bendera_kepulauan_cocos_(keeling):',
        'zh': u':科科斯(基林)群岛:'
    },
    u'\U0001F1E8\U0001F1F4': { # 🇨🇴
        'en' : ':Colombia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Colombia:', ':colombia:'],
        'de': ':flagge_kolumbien:',
        'es': ':bandera_colombia:',
        'fr': ':drapeau_colombie:',
        'ja': u':旗_コロンビア:',
        'ko': u':깃발_콜롬비아:',
        'pt': u':bandeira_colômbia:',
        'it': ':bandiera_colombia:',
        'fa': u':پرچم_کلمبیا:',
        'id': ':bendera_kolombia:',
        'zh': u':哥伦比亚:'
    },
    u'\U0001F1F0\U0001F1F2': { # 🇰🇲
        'en' : ':Comoros:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Comoros:', ':comoros:'],
        'de': ':flagge_komoren:',
        'es': ':bandera_comoras:',
        'fr': ':drapeau_comores:',
        'ja': u':旗_コモロ:',
        'ko': u':깃발_코모로:',
        'pt': ':bandeira_comores:',
        'it': ':bandiera_comore:',
        'fa': u':پرچم_کومور:',
        'id': ':bendera_komoro:',
        'zh': u':科摩罗:'
    },
    u'\U0001F1E8\U0001F1EC': { # 🇨🇬
        'en' : ':Congo_-_Brazzaville:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Congo____Brazzaville:', ':congo_brazzaville:'],
        'de': ':flagge_kongo-brazzaville:',
        'es': ':bandera_congo:',
        'fr': ':drapeau_congo-brazzaville:',
        'ja': u':旗_コンゴ共和国(ブラザビル):',
        'ko': u':깃발_콩고-브라자빌:',
        'pt': u':bandeira_república_do_congo:',
        'it': ':bandiera_congo-brazzaville:',
        'fa': u':پرچم_کنگو_-_برازویل:',
        'id': ':bendera_kongo_-_brazzaville:',
        'zh': u':刚果_布:'
    },
    u'\U0001F1E8\U0001F1E9': { # 🇨🇩
        'en' : ':Congo_-_Kinshasa:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Congo____Kinshasa:', ':congo_kinshasa:'],
        'de': ':flagge_kongo-kinshasa:',
        'es': u':bandera_república_democrática_del_congo:',
        'fr': ':drapeau_congo-kinshasa:',
        'ja': u':旗_コンゴ民主共和国(キンシャサ):',
        'ko': u':깃발_콩고-킨샤사:',
        'pt': u':bandeira_congo_–_kinshasa:',
        'it': u':bandiera_congo_–_kinshasa:',
        'fa': u':پرچم_کنگو_-_کینشاسا:',
        'id': ':bendera_kongo_-_kinshasa:',
        'zh': u':刚果_金:'
    },
    u'\U0001F1E8\U0001F1F0': { # 🇨🇰
        'en' : ':Cook_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cook_Islands:', ':cook_islands:'],
        'de': ':flagge_cookinseln:',
        'es': ':bandera_islas_cook:',
        'fr': u':drapeau_îles_cook:',
        'ja': u':旗_クック諸島:',
        'ko': u':깃발_쿡_제도:',
        'pt': ':bandeira_ilhas_cook:',
        'it': ':bandiera_isole_cook:',
        'fa': u':پرچم_جزایر_کوک:',
        'id': ':bendera_kepulauan_cook:',
        'zh': u':库克群岛:'
    },
    u'\U0001F1E8\U0001F1F7': { # 🇨🇷
        'en' : ':Costa_Rica:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Costa_Rica:', ':costa_rica:'],
        'de': ':flagge_costa_rica:',
        'es': ':bandera_costa_rica:',
        'fr': ':drapeau_costa_rica:',
        'ja': u':旗_コスタリカ:',
        'ko': u':깃발_코스타리카:',
        'pt': ':bandeira_costa_rica:',
        'it': ':bandiera_costa_rica:',
        'fa': u':پرچم_کاستاریکا:',
        'id': ':bendera_kosta_rika:',
        'zh': u':哥斯达黎加:'
    },
    u'\U0001F1ED\U0001F1F7': { # 🇭🇷
        'en' : ':Croatia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Croatia:', ':croatia:'],
        'de': ':flagge_kroatien:',
        'es': ':bandera_croacia:',
        'fr': ':drapeau_croatie:',
        'ja': u':旗_クロアチア:',
        'ko': u':깃발_크로아티아:',
        'pt': u':bandeira_croácia:',
        'it': ':bandiera_croazia:',
        'fa': u':پرچم_کرواسی:',
        'id': ':bendera_kroasia:',
        'zh': u':克罗地亚:'
    },
    u'\U0001F1E8\U0001F1FA': { # 🇨🇺
        'en' : ':Cuba:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cuba:', ':cuba:'],
        'de': ':flagge_kuba:',
        'es': ':bandera_cuba:',
        'fr': ':drapeau_cuba:',
        'ja': u':旗_キューバ:',
        'ko': u':깃발_쿠바:',
        'pt': ':bandeira_cuba:',
        'it': ':bandiera_cuba:',
        'fa': u':پرچم_کوبا:',
        'id': ':bendera_kuba:',
        'zh': u':古巴:'
    },
    u'\U0001F1E8\U0001F1FC': { # 🇨🇼
        'en' : u':Curaçao:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [u':flag_for_Curaçao:', ':curacao:'],
        'de': u':flagge_curaçao:',
        'es': ':bandera_curazao:',
        'fr': u':drapeau_curaçao:',
        'ja': u':旗_キュラソー:',
        'ko': u':깃발_퀴라소:',
        'pt': u':bandeira_curaçao:',
        'it': u':bandiera_curaçao:',
        'fa': u':پرچم_کوراسائو:',
        'id': u':bendera_curaçao:',
        'zh': u':库拉索:'
    },
    u'\U0001F1E8\U0001F1FE': { # 🇨🇾
        'en' : ':Cyprus:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Cyprus:', ':cyprus:'],
        'de': ':flagge_zypern:',
        'es': ':bandera_chipre:',
        'fr': ':drapeau_chypre:',
        'ja': u':旗_キプロス:',
        'ko': u':깃발_키프로스:',
        'pt': ':bandeira_chipre:',
        'it': ':bandiera_cipro:',
        'fa': u':پرچم_قبرس:',
        'id': ':bendera_siprus:',
        'zh': u':塞浦路斯:'
    },
    u'\U0001F1E8\U0001F1FF': { # 🇨🇿
        'en' : ':Czechia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Czech_Republic:', ':czech_republic:'],
        'de': ':flagge_tschechien:',
        'es': ':bandera_chequia:',
        'fr': u':drapeau_tchéquie:',
        'ja': u':旗_チェコ:',
        'ko': u':깃발_체코:',
        'pt': u':bandeira_tchéquia:',
        'it': ':bandiera_cechia:',
        'fa': u':پرچم_چک:',
        'id': ':bendera_ceko:',
        'zh': u':捷克:'
    },
    u'\U0001F1E8\U0001F1EE': { # 🇨🇮
        'en' : u':Côte_d’Ivoire:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [u':flag_for_Côte_d’Ivoire:', ':cote_divoire:'],
        'de': u':flagge_côte_d’ivoire:',
        'es': u':bandera_côte_d’ivoire:',
        'fr': u':drapeau_côte_d’ivoire:',
        'ja': u':旗_コートジボワール:',
        'ko': u':깃발_코트디부아르:',
        'pt': ':bandeira_costa_do_marfim:',
        'it': u':bandiera_costa_d’avorio:',
        'fa': u':پرچم_ساحل_عاج:',
        'id': u':bendera_côte_d’ivoire:',
        'zh': u':科特迪瓦:'
    },
    u'\U0001F1E9\U0001F1F0': { # 🇩🇰
        'en' : ':Denmark:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Denmark:', ':denmark:'],
        'de': u':flagge_dänemark:',
        'es': ':bandera_dinamarca:',
        'fr': ':drapeau_danemark:',
        'ja': u':旗_デンマーク:',
        'ko': u':깃발_덴마크:',
        'pt': ':bandeira_dinamarca:',
        'it': ':bandiera_danimarca:',
        'fa': u':پرچم_دانمارک:',
        'id': ':bendera_denmark:',
        'zh': u':丹麦:'
    },
    u'\U0001F1E9\U0001F1EC': { # 🇩🇬
        'en' : ':Diego_Garcia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Diego_Garcia:', ':diego_garcia:'],
        'de': ':flagge_diego_garcia:',
        'es': u':bandera_diego_garcía:',
        'fr': ':drapeau_diego_garcia:',
        'ja': u':旗_ディエゴガルシア島:',
        'ko': u':깃발_디에고_가르시아:',
        'pt': ':bandeira_diego_garcia:',
        'it': ':bandiera_diego_garcia:',
        'fa': u':پرچم_دیه_گو_گارسیا:',
        'id': ':bendera_diego_garcia:',
        'zh': u':迪戈加西亚岛:'
    },
    u'\U0001F1E9\U0001F1EF': { # 🇩🇯
        'en' : ':Djibouti:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Djibouti:', ':djibouti:'],
        'de': ':flagge_dschibuti:',
        'es': ':bandera_yibuti:',
        'fr': ':drapeau_djibouti:',
        'ja': u':旗_ジブチ:',
        'ko': u':깃발_지부티:',
        'pt': ':bandeira_djibuti:',
        'it': ':bandiera_gibuti:',
        'fa': u':پرچم_جیبوتی:',
        'id': ':bendera_jibuti:',
        'zh': u':吉布提:'
    },
    u'\U0001F1E9\U0001F1F2': { # 🇩🇲
        'en' : ':Dominica:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Dominica:', ':dominica:'],
        'de': ':flagge_dominica:',
        'es': ':bandera_dominica:',
        'fr': ':drapeau_dominique:',
        'ja': u':旗_ドミニカ国:',
        'ko': u':깃발_도미니카:',
        'pt': ':bandeira_dominica:',
        'it': ':bandiera_dominica:',
        'fa': u':پرچم_دومینیکا:',
        'id': ':bendera_dominika:',
        'zh': u':多米尼克:'
    },
    u'\U0001F1E9\U0001F1F4': { # 🇩🇴
        'en' : ':Dominican_Republic:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Dominican_Republic:', ':dominican_republic:'],
        'de': ':flagge_dominikanische_republik:',
        'es': u':bandera_república_dominicana:',
        'fr': u':drapeau_république_dominicaine:',
        'ja': u':旗_ドミニカ共和国:',
        'ko': u':깃발_도미니카_공화국:',
        'pt': u':bandeira_república_dominicana:',
        'it': ':bandiera_repubblica_dominicana:',
        'fa': u':پرچم_جمهوری_دومینیکن:',
        'id': ':bendera_republik_dominika:',
        'zh': u':多米尼加共和国:'
    },
    u'\U0001F51A': { # 🔚
        'en' : ':END_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':end:'],
        'de': ':end-pfeil:',
        'es': ':flecha_end:',
        'fr': u':flèche_fin:',
        'ja': u':end矢印:',
        'ko': u':종료:',
        'pt': ':seta_end:',
        'it': ':freccia_end:',
        'fa': u':پیکان_پایان:',
        'id': ':tanda_panah_end:',
        'zh': u':结束箭头:'
    },
    u'\U0001F1EA\U0001F1E8': { # 🇪🇨
        'en' : ':Ecuador:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Ecuador:', ':ecuador:'],
        'de': ':flagge_ecuador:',
        'es': ':bandera_ecuador:',
        'fr': u':drapeau_équateur:',
        'ja': u':旗_エクアドル:',
        'ko': u':깃발_에콰도르:',
        'pt': ':bandeira_equador:',
        'it': ':bandiera_ecuador:',
        'fa': u':پرچم_اکوادور:',
        'id': ':bendera_ekuador:',
        'zh': u':厄瓜多尔:'
    },
    u'\U0001F1EA\U0001F1EC': { # 🇪🇬
        'en' : ':Egypt:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Egypt:', ':egypt:'],
        'de': u':flagge_ägypten:',
        'es': ':bandera_egipto:',
        'fr': u':drapeau_égypte:',
        'ja': u':旗_エジプト:',
        'ko': u':깃발_이집트:',
        'pt': ':bandeira_egito:',
        'it': ':bandiera_egitto:',
        'fa': u':پرچم_مصر:',
        'id': ':bendera_mesir:',
        'zh': u':埃及:'
    },
    u'\U0001F1F8\U0001F1FB': { # 🇸🇻
        'en' : ':El_Salvador:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_El_Salvador:', ':el_salvador:'],
        'de': ':flagge_el_salvador:',
        'es': ':bandera_el_salvador:',
        'fr': ':drapeau_salvador:',
        'ja': u':旗_エルサルバドル:',
        'ko': u':깃발_엘살바도르:',
        'pt': ':bandeira_el_salvador:',
        'it': ':bandiera_el_salvador:',
        'fa': u':پرچم_السالوادور:',
        'id': ':bendera_el_salvador:',
        'zh': u':萨尔瓦多:'
    },
    u'\U0001F3F4\U000E0067\U000E0062\U000E0065\U000E006E\U000E0067\U000E007F': { # 🏴󠁧󠁢󠁥󠁮󠁧󠁿
        'en' : ':England:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':england:'],
        'de': ':flagge_england:',
        'es': ':bandera_inglaterra:',
        'fr': ':drapeau_angleterre:',
        'ja': u':旗_イングランド:',
        'ko': u':깃발_잉글랜드:',
        'pt': ':bandeira_inglaterra:',
        'it': ':bandiera_inghilterra:',
        'fa': u':پرچم_انگلستان:',
        'id': ':bendera_inggris:',
        'zh': u':英格兰:'
    },
    u'\U0001F1EC\U0001F1F6': { # 🇬🇶
        'en' : ':Equatorial_Guinea:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Equatorial_Guinea:', ':equatorial_guinea:'],
        'de': u':flagge_äquatorialguinea:',
        'es': ':bandera_guinea_ecuatorial:',
        'fr': u':drapeau_guinée_équatoriale:',
        'ja': u':旗_赤道ギニア:',
        'ko': u':깃발_적도_기니:',
        'pt': u':bandeira_guiné_equatorial:',
        'it': ':bandiera_guinea_equatoriale:',
        'fa': u':پرچم_گینهٔ_استوایی:',
        'id': ':bendera_guinea_ekuatorial:',
        'zh': u':赤道几内亚:'
    },
    u'\U0001F1EA\U0001F1F7': { # 🇪🇷
        'en' : ':Eritrea:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Eritrea:', ':eritrea:'],
        'de': ':flagge_eritrea:',
        'es': ':bandera_eritrea:',
        'fr': u':drapeau_érythrée:',
        'ja': u':旗_エリトリア:',
        'ko': u':깃발_에리트리아:',
        'pt': ':bandeira_eritreia:',
        'it': ':bandiera_eritrea:',
        'fa': u':پرچم_اریتره:',
        'id': ':bendera_eritrea:',
        'zh': u':厄立特里亚:'
    },
    u'\U0001F1EA\U0001F1EA': { # 🇪🇪
        'en' : ':Estonia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Estonia:', ':estonia:'],
        'de': ':flagge_estland:',
        'es': ':bandera_estonia:',
        'fr': ':drapeau_estonie:',
        'ja': u':旗_エストニア:',
        'ko': u':깃발_에스토니아:',
        'pt': u':bandeira_estônia:',
        'it': ':bandiera_estonia:',
        'fa': u':پرچم_استونی:',
        'id': ':bendera_estonia:',
        'zh': u':爱沙尼亚:'
    },
    u'\U0001F1F8\U0001F1FF': { # 🇸🇿
        'en' : ':Eswatini:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Swaziland:', ':swaziland:'],
        'de': ':flagge_eswatini:',
        'es': ':bandera_esuatini:',
        'fr': ':drapeau_eswatini:',
        'ja': u':旗_エスワティニ:',
        'ko': u':깃발_에스와티니:',
        'pt': u':bandeira_essuatíni:',
        'it': ':bandiera_swaziland:',
        'fa': u':پرچم_اسواتینی:',
        'id': ':bendera_eswatini:',
        'zh': u':斯威士兰:'
    },
    u'\U0001F1EA\U0001F1F9': { # 🇪🇹
        'en' : ':Ethiopia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Ethiopia:', ':ethiopia:'],
        'de': u':flagge_äthiopien:',
        'es': u':bandera_etiopía:',
        'fr': u':drapeau_éthiopie:',
        'ja': u':旗_エチオピア:',
        'ko': u':깃발_에티오피아:',
        'pt': u':bandeira_etiópia:',
        'it': ':bandiera_etiopia:',
        'fa': u':پرچم_اتیوپی:',
        'id': ':bendera_etiopia:',
        'zh': u':埃塞俄比亚:'
    },
    u'\U0001F1EA\U0001F1FA': { # 🇪🇺
        'en' : ':European_Union:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_European_Union:', ':eu:', ':european_union:'],
        'de': u':flagge_europäische_union:',
        'es': u':bandera_unión_europea:',
        'fr': u':drapeau_union_européenne:',
        'ja': u':旗_欧州連合:',
        'ko': u':깃발_유럽_연합:',
        'pt': u':bandeira_união_europeia:',
        'it': ':bandiera_unione_europea:',
        'fa': u':پرچم_اتحادیهٔ_اروپا:',
        'id': ':bendera_uni_eropa:',
        'zh': u':欧盟:'
    },
    u'\U0001F193': { # 🆓
        'en' : ':FREE_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':free:'],
        'de': ':wort_free_in_blauem_quadrat:',
        'es': u':botón_free:',
        'fr': ':bouton_gratuit:',
        'ja': u':freeマーク:',
        'ko': u':프리:',
        'pt': u':botão_free:',
        'it': ':pulsante_free:',
        'fa': u':دکمهٔ_free:',
        'id': ':tombol_free:',
        'zh': u':FREE按钮:'
    },
    u'\U0001F1EB\U0001F1F0': { # 🇫🇰
        'en' : ':Falkland_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Falkland_Islands:', ':falkland_islands:'],
        'de': ':flagge_falklandinseln:',
        'es': ':bandera_islas_malvinas:',
        'fr': u':drapeau_îles_malouines:',
        'ja': u':旗_フォークランド諸島:',
        'ko': u':깃발_포클랜드_제도:',
        'pt': ':bandeira_ilhas_malvinas:',
        'it': ':bandiera_isole_falkland:',
        'fa': u':پرچم_جزایر_فالکلند:',
        'id': ':bendera_kepulauan_falkland:',
        'zh': u':福克兰群岛:'
    },
    u'\U0001F1EB\U0001F1F4': { # 🇫🇴
        'en' : ':Faroe_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Faroe_Islands:', ':faroe_islands:'],
        'de': u':flagge_färöer:',
        'es': ':bandera_islas_feroe:',
        'fr': u':drapeau_îles_féroé:',
        'ja': u':旗_フェロー諸島:',
        'ko': u':깃발_페로_제도:',
        'pt': ':bandeira_ilhas_faroe:',
        'it': u':bandiera_isole_fær_øer:',
        'fa': u':پرچم_جزایر_فارو:',
        'id': ':bendera_kepulauan_faroe:',
        'zh': u':法罗群岛:'
    },
    u'\U0001F1EB\U0001F1EF': { # 🇫🇯
        'en' : ':Fiji:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Fiji:', ':fiji:'],
        'de': ':flagge_fidschi:',
        'es': ':bandera_fiyi:',
        'fr': ':drapeau_fidji:',
        'ja': u':旗_フィジー:',
        'ko': u':깃발_피지:',
        'pt': ':bandeira_fiji:',
        'it': ':bandiera_figi:',
        'fa': u':پرچم_فیجی:',
        'id': ':bendera_fiji:',
        'zh': u':斐济:'
    },
    u'\U0001F1EB\U0001F1EE': { # 🇫🇮
        'en' : ':Finland:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Finland:', ':finland:'],
        'de': ':flagge_finnland:',
        'es': ':bandera_finlandia:',
        'fr': ':drapeau_finlande:',
        'ja': u':旗_フィンランド:',
        'ko': u':깃발_핀란드:',
        'pt': u':bandeira_finlândia:',
        'it': ':bandiera_finlandia:',
        'fa': u':پرچم_فنلاند:',
        'id': ':bendera_finlandia:',
        'zh': u':芬兰:'
    },
    u'\U0001F1EB\U0001F1F7': { # 🇫🇷
        'en' : ':France:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_France:', ':fr:'],
        'de': ':flagge_frankreich:',
        'es': ':bandera_francia:',
        'fr': ':drapeau_france:',
        'ja': u':旗_フランス:',
        'ko': u':깃발_프랑스:',
        'pt': u':bandeira_frança:',
        'it': ':bandiera_francia:',
        'fa': u':پرچم_فرانسه:',
        'id': ':bendera_prancis:',
        'zh': u':法国:'
    },
    u'\U0001F1EC\U0001F1EB': { # 🇬🇫
        'en' : ':French_Guiana:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_French_Guiana:', ':french_guiana:'],
        'de': u':flagge_französisch-guayana:',
        'es': ':bandera_guayana_francesa:',
        'fr': u':drapeau_guyane_française:',
        'ja': u':旗_仏領ギアナ:',
        'ko': u':깃발_프랑스령_기아나:',
        'pt': ':bandeira_guiana_francesa:',
        'it': ':bandiera_guyana_francese:',
        'fa': u':پرچم_گویان_فرانسه:',
        'id': ':bendera_guyana_prancis:',
        'zh': u':法属圭亚那:'
    },
    u'\U0001F1F5\U0001F1EB': { # 🇵🇫
        'en' : ':French_Polynesia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_French_Polynesia:', ':french_polynesia:'],
        'de': u':flagge_französisch-polynesien:',
        'es': ':bandera_polinesia_francesa:',
        'fr': u':drapeau_polynésie_française:',
        'ja': u':旗_仏領ポリネシア:',
        'ko': u':깃발_프랑스령_폴리네시아:',
        'pt': u':bandeira_polinésia_francesa:',
        'it': ':bandiera_polinesia_francese:',
        'fa': u':پرچم_پلی_نزی_فرانسه:',
        'id': ':bendera_polinesia_prancis:',
        'zh': u':法属波利尼西亚:'
    },
    u'\U0001F1F9\U0001F1EB': { # 🇹🇫
        'en' : ':French_Southern_Territories:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_French_Southern_Territories:', ':french_southern_territories:'],
        'de': u':flagge_französische_süd-_und_antarktisgebiete:',
        'es': ':bandera_territorios_australes_franceses:',
        'fr': u':drapeau_terres_australes_françaises:',
        'ja': u':旗_仏領極南諸島:',
        'ko': u':깃발_프랑스_남부_지방:',
        'pt': u':bandeira_territórios_franceses_do_sul:',
        'it': ':bandiera_terre_australi_francesi:',
        'fa': u':پرچم_سرزمین_های_جنوب_فرانسه:',
        'id': ':bendera_wilayah_selatan_prancis:',
        'zh': u':法属南部领地:'
    },
    u'\U0001F1EC\U0001F1E6': { # 🇬🇦
        'en' : ':Gabon:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Gabon:', ':gabon:'],
        'de': ':flagge_gabun:',
        'es': u':bandera_gabón:',
        'fr': ':drapeau_gabon:',
        'ja': u':旗_ガボン:',
        'ko': u':깃발_가봉:',
        'pt': u':bandeira_gabão:',
        'it': ':bandiera_gabon:',
        'fa': u':پرچم_گابن:',
        'id': ':bendera_gabon:',
        'zh': u':加蓬:'
    },
    u'\U0001F1EC\U0001F1F2': { # 🇬🇲
        'en' : ':Gambia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Gambia:', ':gambia:'],
        'de': ':flagge_gambia:',
        'es': ':bandera_gambia:',
        'fr': ':drapeau_gambie:',
        'ja': u':旗_ガンビア:',
        'ko': u':깃발_감비아:',
        'pt': u':bandeira_gâmbia:',
        'it': ':bandiera_gambia:',
        'fa': u':پرچم_گامبیا:',
        'id': ':bendera_gambia:',
        'zh': u':冈比亚:'
    },
    u'\U0000264A': { # ♊
        'en' : ':Gemini:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':gemini:'],
        'variant': True,
        'de': ':zwillinge_(sternzeichen):',
        'es': u':géminis:',
        'fr': u':gémeaux:',
        'ja': u':ふたご座:',
        'ko': u':쌍둥이_자리:',
        'pt': u':signo_de_gêmeos:',
        'it': ':segno_zodiacale_dei_gemelli:',
        'fa': u':برج_جوزا:',
        'id': ':gemini:',
        'zh': u':双子座:'
    },
    u'\U0001F1EC\U0001F1EA': { # 🇬🇪
        'en' : ':Georgia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Georgia:', ':georgia:'],
        'de': ':flagge_georgien:',
        'es': ':bandera_georgia:',
        'fr': u':drapeau_géorgie:',
        'ja': u':旗_ジョージア:',
        'ko': u':깃발_조지아:',
        'pt': u':bandeira_geórgia:',
        'it': ':bandiera_georgia:',
        'fa': u':پرچم_گرجستان:',
        'id': ':bendera_georgia:',
        'zh': u':格鲁吉亚:'
    },
    u'\U0001F1E9\U0001F1EA': { # 🇩🇪
        'en' : ':Germany:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_Germany:', ':de:'],
        'de': ':flagge_deutschland:',
        'es': ':bandera_alemania:',
        'fr': ':drapeau_allemagne:',
        'ja': u':旗_ドイツ:',
        'ko': u':깃발_독일:',
        'pt': ':bandeira_alemanha:',
        'it': ':bandiera_germania:',
        'fa': u':پرچم_آلمان:',
        'id': ':bendera_jerman:',
        'zh': u':德国:'
    },
    u'\U0001F1EC\U0001F1ED': { # 🇬🇭
        'en' : ':Ghana:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Ghana:', ':ghana:'],
        'de': ':flagge_ghana:',
        'es': ':bandera_ghana:',
        'fr': ':drapeau_ghana:',
        'ja': u':旗_ガーナ:',
        'ko': u':깃발_가나:',
        'pt': ':bandeira_gana:',
        'it': ':bandiera_ghana:',
        'fa': u':پرچم_غنا:',
        'id': ':bendera_ghana:',
        'zh': u':加纳:'
    },
    u'\U0001F1EC\U0001F1EE': { # 🇬🇮
        'en' : ':Gibraltar:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Gibraltar:', ':gibraltar:'],
        'de': ':flagge_gibraltar:',
        'es': ':bandera_gibraltar:',
        'fr': ':drapeau_gibraltar:',
        'ja': u':旗_ジブラルタル:',
        'ko': u':깃발_지브롤터:',
        'pt': ':bandeira_gibraltar:',
        'it': ':bandiera_gibilterra:',
        'fa': u':پرچم_جبل_الطارق:',
        'id': ':bendera_gibraltar:',
        'zh': u':直布罗陀:'
    },
    u'\U0001F1EC\U0001F1F7': { # 🇬🇷
        'en' : ':Greece:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Greece:', ':greece:'],
        'de': ':flagge_griechenland:',
        'es': ':bandera_grecia:',
        'fr': u':drapeau_grèce:',
        'ja': u':旗_ギリシャ:',
        'ko': u':깃발_그리스:',
        'pt': u':bandeira_grécia:',
        'it': ':bandiera_grecia:',
        'fa': u':پرچم_یونان:',
        'id': ':bendera_yunani:',
        'zh': u':希腊:'
    },
    u'\U0001F1EC\U0001F1F1': { # 🇬🇱
        'en' : ':Greenland:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Greenland:', ':greenland:'],
        'de': u':flagge_grönland:',
        'es': ':bandera_groenlandia:',
        'fr': ':drapeau_groenland:',
        'ja': u':旗_グリーンランド:',
        'ko': u':깃발_그린란드:',
        'pt': u':bandeira_groenlândia:',
        'it': ':bandiera_groenlandia:',
        'fa': u':پرچم_گرینلند:',
        'id': ':bendera_greenland:',
        'zh': u':格陵兰:'
    },
    u'\U0001F1EC\U0001F1E9': { # 🇬🇩
        'en' : ':Grenada:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Grenada:', ':grenada:'],
        'de': ':flagge_grenada:',
        'es': ':bandera_granada:',
        'fr': ':drapeau_grenade:',
        'ja': u':旗_グレナダ:',
        'ko': u':깃발_그레나다:',
        'pt': ':bandeira_granada:',
        'it': ':bandiera_grenada:',
        'fa': u':پرچم_گرنادا:',
        'id': ':bendera_grenada:',
        'zh': u':格林纳达:'
    },
    u'\U0001F1EC\U0001F1F5': { # 🇬🇵
        'en' : ':Guadeloupe:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Guadeloupe:', ':guadeloupe:'],
        'de': ':flagge_guadeloupe:',
        'es': ':bandera_guadalupe:',
        'fr': ':drapeau_guadeloupe:',
        'ja': u':旗_グアドループ:',
        'ko': u':깃발_과들루프:',
        'pt': ':bandeira_guadalupe:',
        'it': ':bandiera_guadalupa:',
        'fa': u':پرچم_گوادلوپ:',
        'id': ':bendera_guadeloupe:',
        'zh': u':瓜德罗普:'
    },
    u'\U0001F1EC\U0001F1FA': { # 🇬🇺
        'en' : ':Guam:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Guam:', ':guam:'],
        'de': ':flagge_guam:',
        'es': ':bandera_guam:',
        'fr': ':drapeau_guam:',
        'ja': u':旗_グアム:',
        'ko': u':깃발_괌:',
        'pt': ':bandeira_guam:',
        'it': ':bandiera_guam:',
        'fa': u':پرچم_گوام:',
        'id': ':bendera_guam:',
        'zh': u':关岛:'
    },
    u'\U0001F1EC\U0001F1F9': { # 🇬🇹
        'en' : ':Guatemala:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Guatemala:', ':guatemala:'],
        'de': ':flagge_guatemala:',
        'es': ':bandera_guatemala:',
        'fr': ':drapeau_guatemala:',
        'ja': u':旗_グアテマラ:',
        'ko': u':깃발_과테말라:',
        'pt': ':bandeira_guatemala:',
        'it': ':bandiera_guatemala:',
        'fa': u':پرچم_گواتمالا:',
        'id': ':bendera_guatemala:',
        'zh': u':危地马拉:'
    },
    u'\U0001F1EC\U0001F1EC': { # 🇬🇬
        'en' : ':Guernsey:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Guernsey:', ':guernsey:'],
        'de': ':flagge_guernsey:',
        'es': ':bandera_guernsey:',
        'fr': ':drapeau_guernesey:',
        'ja': u':旗_ガーンジー:',
        'ko': u':깃발_건지:',
        'pt': ':bandeira_guernsey:',
        'it': ':bandiera_guernsey:',
        'fa': u':پرچم_گرنزی:',
        'id': ':bendera_guernsey:',
        'zh': u':根西岛:'
    },
    u'\U0001F1EC\U0001F1F3': { # 🇬🇳
        'en' : ':Guinea:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Guinea:', ':guinea:'],
        'de': ':flagge_guinea:',
        'es': ':bandera_guinea:',
        'fr': u':drapeau_guinée:',
        'ja': u':旗_ギニア:',
        'ko': u':깃발_기니:',
        'pt': u':bandeira_guiné:',
        'it': ':bandiera_guinea:',
        'fa': u':پرچم_گینه:',
        'id': ':bendera_guinea:',
        'zh': u':几内亚:'
    },
    u'\U0001F1EC\U0001F1FC': { # 🇬🇼
        'en' : ':Guinea-Bissau:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Guinea__Bissau:', ':guinea_bissau:'],
        'de': ':flagge_guinea-bissau:',
        'es': u':bandera_guinea-bisáu:',
        'fr': u':drapeau_guinée-bissau:',
        'ja': u':旗_ギニアビサウ:',
        'ko': u':깃발_기니비사우:',
        'pt': u':bandeira_guiné-bissau:',
        'it': ':bandiera_guinea-bissau:',
        'fa': u':پرچم_گینهٔ_بیسائو:',
        'id': ':bendera_guinea-bissau:',
        'zh': u':几内亚比绍:'
    },
    u'\U0001F1EC\U0001F1FE': { # 🇬🇾
        'en' : ':Guyana:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Guyana:', ':guyana:'],
        'de': ':flagge_guyana:',
        'es': ':bandera_guyana:',
        'fr': ':drapeau_guyana:',
        'ja': u':旗_ガイアナ:',
        'ko': u':깃발_가이아나:',
        'pt': ':bandeira_guiana:',
        'it': ':bandiera_guyana:',
        'fa': u':پرچم_گویان:',
        'id': ':bendera_guyana:',
        'zh': u':圭亚那:'
    },
    u'\U0001F1ED\U0001F1F9': { # 🇭🇹
        'en' : ':Haiti:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Haiti:', ':haiti:'],
        'de': ':flagge_haiti:',
        'es': u':bandera_haití:',
        'fr': u':drapeau_haïti:',
        'ja': u':旗_ハイチ:',
        'ko': u':깃발_아이티:',
        'pt': ':bandeira_haiti:',
        'it': ':bandiera_haiti:',
        'fa': u':پرچم_هائیتی:',
        'id': ':bendera_haiti:',
        'zh': u':海地:'
    },
    u'\U0001F1ED\U0001F1F2': { # 🇭🇲
        'en' : ':Heard_&_McDonald_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Heard_&_McDonald_Islands:', ':heard_mcdonald_islands:'],
        'de': ':flagge_heard_und_mcdonaldinseln:',
        'es': ':bandera_islas_heard_y_mcdonald:',
        'fr': u':drapeau_îles_heard_et_mcdonald:',
        'ja': u':旗_ハード島・マクドナルド諸島:',
        'ko': u':깃발_허드_맥도널드_제도:',
        'pt': ':bandeira_ilhas_heard_e_mcdonald:',
        'it': ':bandiera_isole_heard_e_mcdonald:',
        'fa': u':پرچم_هرد_و_جزایر_مک_دونالد:',
        'id': ':bendera_pulau_heard_dan_kepulauan_mcdonald:',
        'zh': u':赫德岛和麦克唐纳群岛:'
    },
    u'\U0001F1ED\U0001F1F3': { # 🇭🇳
        'en' : ':Honduras:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Honduras:', ':honduras:'],
        'de': ':flagge_honduras:',
        'es': ':bandera_honduras:',
        'fr': ':drapeau_honduras:',
        'ja': u':旗_ホンジュラス:',
        'ko': u':깃발_온두라스:',
        'pt': ':bandeira_honduras:',
        'it': ':bandiera_honduras:',
        'fa': u':پرچم_هندوراس:',
        'id': ':bendera_honduras:',
        'zh': u':洪都拉斯:'
    },
    u'\U0001F1ED\U0001F1F0': { # 🇭🇰
        'en' : ':Hong_Kong_SAR_China:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Hong_Kong:', ':hong_kong:'],
        'de': ':flagge_sonderverwaltungsregion_hongkong:',
        'es': ':bandera_rae_de_hong_kong_(china):',
        'fr': ':drapeau_r.a.s._chinoise_de_hong_kong:',
        'ja': u':旗_中華人民共和国香港特別行政区:',
        'ko': u':깃발_홍콩(중국_특별행정구):',
        'pt': ':bandeira_hong_kong_rae_da_china:',
        'it': ':bandiera_ras_di_hong_kong:',
        'fa': u':پرچم_هنگ_کنگ:',
        'id': ':bendera_hong_kong_dak_tiongkok:',
        'zh': u':香港:'
    },
    u'\U0001F1ED\U0001F1FA': { # 🇭🇺
        'en' : ':Hungary:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Hungary:', ':hungary:'],
        'de': ':flagge_ungarn:',
        'es': u':bandera_hungría:',
        'fr': ':drapeau_hongrie:',
        'ja': u':旗_ハンガリー:',
        'ko': u':깃발_헝가리:',
        'pt': ':bandeira_hungria:',
        'it': ':bandiera_ungheria:',
        'fa': u':پرچم_مجارستان:',
        'id': ':bendera_hungaria:',
        'zh': u':匈牙利:'
    },
    u'\U0001F194': { # 🆔
        'en' : ':ID_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':id:'],
        'de': u':großbuchstaben_id_in_lila_quadrat:',
        'es': u':símbolo_de_identificación:',
        'fr': ':bouton_identifiant:',
        'ja': u':idマーク:',
        'ko': u':아이디:',
        'pt': u':botão_id:',
        'it': ':pulsante_id:',
        'fa': u':دکمهٔ_شناسایی:',
        'id': ':tombol_id:',
        'zh': u':ID按钮:'
    },
    u'\U0001F1EE\U0001F1F8': { # 🇮🇸
        'en' : ':Iceland:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Iceland:', ':iceland:'],
        'de': ':flagge_island:',
        'es': ':bandera_islandia:',
        'fr': ':drapeau_islande:',
        'ja': u':旗_アイスランド:',
        'ko': u':깃발_아이슬란드:',
        'pt': u':bandeira_islândia:',
        'it': ':bandiera_islanda:',
        'fa': u':پرچم_ایسلند:',
        'id': ':bendera_islandia:',
        'zh': u':冰岛:'
    },
    u'\U0001F1EE\U0001F1F3': { # 🇮🇳
        'en' : ':India:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_India:', ':india:'],
        'de': ':flagge_indien:',
        'es': ':bandera_india:',
        'fr': ':drapeau_inde:',
        'ja': u':旗_インド:',
        'ko': u':깃발_인도:',
        'pt': u':bandeira_índia:',
        'it': ':bandiera_india:',
        'fa': u':پرچم_هند:',
        'id': ':bendera_india:',
        'zh': u':印度:'
    },
    u'\U0001F1EE\U0001F1E9': { # 🇮🇩
        'en' : ':Indonesia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Indonesia:', ':indonesia:'],
        'de': ':flagge_indonesien:',
        'es': ':bandera_indonesia:',
        'fr': u':drapeau_indonésie:',
        'ja': u':旗_インドネシア:',
        'ko': u':깃발_인도네시아:',
        'pt': u':bandeira_indonésia:',
        'it': ':bandiera_indonesia:',
        'fa': u':پرچم_اندونزی:',
        'id': ':bendera_indonesia:',
        'zh': u':印度尼西亞:'
    },
    u'\U0001F1EE\U0001F1F7': { # 🇮🇷
        'en' : ':Iran:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Iran:', ':iran:'],
        'de': ':flagge_iran:',
        'es': u':bandera_irán:',
        'fr': ':drapeau_iran:',
        'ja': u':旗_イラン:',
        'ko': u':깃발_이란:',
        'pt': u':bandeira_irã:',
        'it': ':bandiera_iran:',
        'fa': u':پرچم_ایران:',
        'id': ':bendera_iran:',
        'zh': u':伊朗:'
    },
    u'\U0001F1EE\U0001F1F6': { # 🇮🇶
        'en' : ':Iraq:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Iraq:', ':iraq:'],
        'de': ':flagge_irak:',
        'es': ':bandera_irak:',
        'fr': ':drapeau_irak:',
        'ja': u':旗_イラク:',
        'ko': u':깃발_이라크:',
        'pt': ':bandeira_iraque:',
        'it': ':bandiera_iraq:',
        'fa': u':پرچم_عراق:',
        'id': ':bendera_irak:',
        'zh': u':伊拉克:'
    },
    u'\U0001F1EE\U0001F1EA': { # 🇮🇪
        'en' : ':Ireland:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Ireland:', ':ireland:'],
        'de': ':flagge_irland:',
        'es': ':bandera_irlanda:',
        'fr': ':drapeau_irlande:',
        'ja': u':旗_アイルランド:',
        'ko': u':깃발_아일랜드:',
        'pt': ':bandeira_irlanda:',
        'it': ':bandiera_irlanda:',
        'fa': u':پرچم_ایرلند:',
        'id': ':bendera_irlandia:',
        'zh': u':爱尔兰:'
    },
    u'\U0001F1EE\U0001F1F2': { # 🇮🇲
        'en' : ':Isle_of_Man:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Isle_of_Man:', ':isle_of_man:'],
        'de': ':flagge_isle_of_man:',
        'es': ':bandera_isla_de_man:',
        'fr': u':drapeau_île_de_man:',
        'ja': u':旗_マン島:',
        'ko': u':깃발_맨섬:',
        'pt': ':bandeira_ilha_de_man:',
        'it': ':bandiera_isola_di_man:',
        'fa': u':پرچم_جزیرهٔ_من:',
        'id': ':bendera_pulau_man:',
        'zh': u':马恩岛:'
    },
    u'\U0001F1EE\U0001F1F1': { # 🇮🇱
        'en' : ':Israel:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Israel:', ':israel:'],
        'de': ':flagge_israel:',
        'es': ':bandera_israel:',
        'fr': u':drapeau_israël:',
        'ja': u':旗_イスラエル:',
        'ko': u':깃발_이스라엘:',
        'pt': ':bandeira_israel:',
        'it': ':bandiera_israele:',
        'fa': u':پرچم_اسرائیل:',
        'id': ':bendera_israel:',
        'zh': u':以色列:'
    },
    u'\U0001F1EE\U0001F1F9': { # 🇮🇹
        'en' : ':Italy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_Italy:', ':it:'],
        'de': ':flagge_italien:',
        'es': ':bandera_italia:',
        'fr': ':drapeau_italie:',
        'ja': u':旗_イタリア:',
        'ko': u':깃발_이탈리아:',
        'pt': u':bandeira_itália:',
        'it': ':bandiera_italia:',
        'fa': u':پرچم_ایتالیا:',
        'id': ':bendera_italia:',
        'zh': u':意大利:'
    },
    u'\U0001F1EF\U0001F1F2': { # 🇯🇲
        'en' : ':Jamaica:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Jamaica:', ':jamaica:'],
        'de': ':flagge_jamaika:',
        'es': ':bandera_jamaica:',
        'fr': u':drapeau_jamaïque:',
        'ja': u':旗_ジャマイカ:',
        'ko': u':깃발_자메이카:',
        'pt': ':bandeira_jamaica:',
        'it': ':bandiera_giamaica:',
        'fa': u':پرچم_جامائیکا:',
        'id': ':bendera_jamaika:',
        'zh': u':牙买加:'
    },
    u'\U0001F1EF\U0001F1F5': { # 🇯🇵
        'en' : ':Japan:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_Japan:', ':jp:'],
        'de': ':flagge_japan:',
        'es': u':bandera_japón:',
        'fr': ':drapeau_japon:',
        'ja': u':旗_日本:',
        'ko': u':깃발_일본:',
        'pt': u':bandeira_japão:',
        'it': ':bandiera_giappone:',
        'fa': u':پرچم_ژاپن:',
        'id': ':bendera_jepang:',
        'zh': u':日本:'
    },
    u'\U0001F251': { # 🉑
        'en' : ':Japanese_acceptable_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':accept:'],
        'de': u':schriftzeichen_für_akzeptieren:',
        'es': u':ideograma_japonés_para_aceptable:',
        'fr': ':bouton_accepter_en_japonais:',
        'ja': u':可マーク:',
        'ko': u':옳을_가:',
        'pt': u':botão_japonês_de_“aceitável”:',
        'it': u':ideogramma_giapponese_di_“accettabile”:',
        'fa': u':دکمۀ_«قابل_قبول»_به_ژاپنی:',
        'id': ':tombol_jepang_dapat_diterima:',
        'zh': u':可:'
    },
    u'\U0001F238': { # 🈸
        'en' : ':Japanese_application_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u7533:'],
        'de': u':schriftzeichen_für_anwenden:',
        'es': u':ideograma_japonés_para_aplicación:',
        'fr': ':bouton_application_en_japonais:',
        'ja': u':申マーク:',
        'ko': u':거듭_신:',
        'pt': u':botão_japonês_de_“aplicação”:',
        'it': u':ideogramma_giapponese_di_“candidatura”:',
        'fa': u':دکمۀ_«تقاضانامه»_به_ژاپنی:',
        'id': ':tombol_jepang_lamaran_kerja:',
        'zh': u':申:'
    },
    u'\U0001F250': { # 🉐
        'en' : ':Japanese_bargain_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ideograph_advantage:'],
        'de': u':schriftzeichen_für_schnäppchen:',
        'es': u':ideograma_japonés_para_ganga:',
        'fr': ':bouton_bonne_affaire_en_japonais:',
        'ja': u':マル得:',
        'ko': u':얻을_득:',
        'pt': u':botão_japonês_de_“barganha”:',
        'it': u':ideogramma_giapponese_di_“occasione”:',
        'fa': u':دکمهٔ_«قیمت_مناسب»_به_ژاپنی:',
        'id': ':karakter_keunggulan_dalam_lingkaran:',
        'zh': u':得:'
    },
    u'\U0001F3EF': { # 🏯
        'en' : ':Japanese_castle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':japanese_castle:'],
        'de': ':japanisches_schloss:',
        'es': u':castillo_japonés:',
        'fr': u':château_japonais:',
        'ja': u':城:',
        'ko': u':일본_성:',
        'pt': u':castelo_japonês:',
        'it': ':castello_giapponese:',
        'fa': u':قلعهٔ_ژاپنی:',
        'id': ':kastel_jepang:',
        'zh': u':日本城堡:'
    },
    u'\U00003297\U0000FE0F': { # ㊗️
        'en' : ':Japanese_congratulations_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':congratulations:'],
        'variant': True,
        'de': u':schriftzeichen_für_gratulation:',
        'es': u':ideograma_japonés_para_enhorabuena:',
        'fr': u':bouton_félicitations_en_japonais:',
        'ja': u':祝マーク:',
        'ko': u':원_안의_축하_표의문자:',
        'pt': u':botão_japonês_de_“parabéns”:',
        'it': u':ideogramma_giapponese_di_“congratulazioni”:',
        'fa': u':دکمه_تبریک_به_ژاپنی:',
        'id': ':tombol_jepang_selamat:',
        'zh': u':祝:'
    },
    u'\U00003297': { # ㊗
        'en' : ':Japanese_congratulations_button:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':congratulations:'],
        'variant': True,
        'de': u':schriftzeichen_für_gratulation:',
        'es': u':ideograma_japonés_para_enhorabuena:',
        'fr': u':bouton_félicitations_en_japonais:',
        'ja': u':祝マーク:',
        'ko': u':원_안의_축하_표의문자:',
        'pt': u':botão_japonês_de_“parabéns”:',
        'it': u':ideogramma_giapponese_di_“congratulazioni”:',
        'fa': u':دکمهٔ_«تبریک»_به_ژاپنی:',
        'id': ':tombol_jepang_selamat:',
        'zh': u':祝:'
    },
    u'\U0001F239': { # 🈹
        'en' : ':Japanese_discount_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u5272:'],
        'de': u':schriftzeichen_für_rabatt:',
        'es': u':ideograma_japonés_para_descuento:',
        'fr': u':bouton_réduction_en_japonais:',
        'ja': u':割マーク:',
        'ko': u':나눌_할:',
        'pt': u':botão_japonês_de_“desconto”:',
        'it': u':ideogramma_giapponese_di_“sconto”:',
        'fa': u':دکمۀ_«تخفیف»_به_ژاپنی:',
        'id': ':tombol_jepang_diskon:',
        'zh': u':割:'
    },
    u'\U0001F38E': { # 🎎
        'en' : ':Japanese_dolls:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dolls:'],
        'de': ':japanische_puppen:',
        'es': u':muñecas_japonesas:',
        'fr': u':poupées_japonaises:',
        'ja': u':ひな祭り:',
        'ko': u':일본_인형:',
        'pt': ':bonecas_japonesas:',
        'it': ':bambole_giapponesi:',
        'fa': u':عروسک_های_ژاپنی:',
        'id': ':boneka_jepang:',
        'zh': u':日本人形:'
    },
    u'\U0001F21A': { # 🈚
        'en' : ':Japanese_free_of_charge_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u7121:'],
        'variant': True,
        'de': u':schriftzeichen_für_gratis:',
        'es': u':ideograma_japonés_para_gratis:',
        'fr': ':bouton_gratuit_en_japonais:',
        'ja': u':無マーク:',
        'ko': u':없을_무:',
        'pt': u':botão_japonês_de_“gratuito”:',
        'it': u':ideogramma_giapponese_di_“gratis”:',
        'fa': u':دکمۀ_«رایگان»_به_ژاپنی:',
        'id': ':tombol_jepang_gratis:',
        'zh': u':无:'
    },
    u'\U0001F201': { # 🈁
        'en' : ':Japanese_here_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':koko:'],
        'de': ':schriftzeichen_koko:',
        'es': u':ideograma_japonés_para_aquí:',
        'fr': ':bouton_ici_en_japonais:',
        'ja': u':ココのマーク:',
        'ko': u':일본어_여기_버튼:',
        'pt': u':botão_japonês_de_“aqui”:',
        'it': u':ideogramma_giapponese_per_“qui”:',
        'fa': u':دکمهٔ_«اینجا»_به_ژاپنی:',
        'id': ':tombol_jepang_di_sini:',
        'zh': u':这里:'
    },
    u'\U0001F237\U0000FE0F': { # 🈷️
        'en' : ':Japanese_monthly_amount_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u6708:'],
        'variant': True,
        'de': u':schriftzeichen_für_monatsbetrag:',
        'es': u':ideograma_japonés_para_cantidad_mensual:',
        'fr': ':bouton_montant_mensuel_en_japonais:',
        'ja': u':月マーク:',
        'ko': u':달_월:',
        'pt': u':botão_japonês_de_“quantidade_mensal”:',
        'it': u':ideogramma_giapponese_di_“importo_mensile”:',
        'fa': u':دکمه_مقدار_ماهانه_به_ژاپنی:',
        'id': ':tombol_jepang_jumlah_bulanan:',
        'zh': u':月:'
    },
    u'\U0001F237': { # 🈷
        'en' : ':Japanese_monthly_amount_button:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':u6708:'],
        'variant': True,
        'de': u':schriftzeichen_für_monatsbetrag:',
        'es': u':ideograma_japonés_para_cantidad_mensual:',
        'fr': ':bouton_montant_mensuel_en_japonais:',
        'ja': u':月マーク:',
        'ko': u':달_월:',
        'pt': u':botão_japonês_de_“quantidade_mensal”:',
        'it': u':ideogramma_giapponese_di_“importo_mensile”:',
        'fa': u':دکمهٔ_«مقدار_ماهانه»_به_ژاپنی:',
        'id': ':tombol_jepang_jumlah_bulanan:',
        'zh': u':月:'
    },
    u'\U0001F235': { # 🈵
        'en' : ':Japanese_no_vacancy_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u6e80:'],
        'de': u':schriftzeichen_für_kein_zimmer_frei:',
        'es': u':ideograma_japonés_para_completo:',
        'fr': ':bouton_complet_en_japonais:',
        'ja': u':満マーク:',
        'ko': u':찰_만:',
        'pt': u':botão_japonês_de_“sem_vagas”:',
        'it': u':ideogramma_giapponese_di_“nessun_posto_libero”:',
        'fa': u':دکمهٔ_«پُر»_به_ژاپنی:',
        'id': ':tombol_jepang_tidak_ada_lowongan:',
        'zh': u':满:'
    },
    u'\U0001F236': { # 🈶
        'en' : ':Japanese_not_free_of_charge_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u6709:'],
        'de': u':schriftzeichen_für_nicht_gratis:',
        'es': u':ideograma_japonés_para_de_pago:',
        'fr': ':bouton_pas_gratuit_en_japonais:',
        'ja': u':有マーク:',
        'ko': u':있을_유:',
        'pt': u':botão_japonês_de_“não_gratuito”:',
        'it': u':ideogramma_giapponese_di_“a_pagamento”:',
        'fa': u':دکمهٔ_غیرمجانی_به_ژاپنی:',
        'id': ':tombol_jepang_tidak_gratis:',
        'zh': u':有:'
    },
    u'\U0001F23A': { # 🈺
        'en' : ':Japanese_open_for_business_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u55b6:'],
        'de': u':schriftzeichen_für_geöffnet:',
        'es': u':ideograma_japonés_para_abierto:',
        'fr': ':bouton_ouvert_pour_affaires_en_japonais:',
        'ja': u':営マーク:',
        'ko': u':벼슬_관:',
        'pt': u':botão_japonês_de_“aberto_para_negócios”:',
        'it': u':ideogramma_giapponese_di_“aperto_al_pubblico”:',
        'fa': u':دکمۀ_«آماده_برای_کسب_وکار»_به_ژاپنی:',
        'id': ':tombol_jepang_siap_berbisnis:',
        'zh': u':营:'
    },
    u'\U0001F234': { # 🈴
        'en' : ':Japanese_passing_grade_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u5408:'],
        'de': u':schriftzeichen_für_note_zum_bestehen:',
        'es': u':ideograma_japonés_para_aprobado:',
        'fr': u':bouton_note_pour_réussir_en_japonais:',
        'ja': u':合マーク:',
        'ko': u':합할_합:',
        'pt': u':botão_japonês_de_“nota_mínima”:',
        'it': u':ideogramma_giapponese_di_“voto_di_sufficienza”:',
        'fa': u':دکمۀ_«نمرهٔ_قبولی»_به_ژاپنی:',
        'id': ':tombol_jepang_nilai_kelulusan:',
        'zh': u':合:'
    },
    u'\U0001F3E3': { # 🏣
        'en' : ':Japanese_post_office:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':post_office:'],
        'de': u':japanisches_postgebäude:',
        'es': ':oficina_de_correos_japonesa:',
        'fr': ':bureau_de_poste_japonais:',
        'ja': u':郵便局:',
        'ko': u':일본_우체국:',
        'pt': u':correio_japonês:',
        'it': ':ufficio_postale_giapponese:',
        'fa': u':پست_خانهٔ_ژاپنی:',
        'id': ':kantor_pos_jepang:',
        'zh': u':日本邮局:'
    },
    u'\U0001F232': { # 🈲
        'en' : ':Japanese_prohibited_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u7981:'],
        'de': u':schriftzeichen_für_verbieten:',
        'es': u':ideograma_japonés_para_prohibido:',
        'fr': ':bouton_interdit_en_japonais:',
        'ja': u':禁マーク:',
        'ko': u':금할_금:',
        'pt': u':botão_japonês_de_“proibido”:',
        'it': u':ideogramma_giapponese_di_“proibito”:',
        'fa': u':دکمۀ_«ممنوع»_به_ژاپنی:',
        'id': ':tombol_jepang_dilarang:',
        'zh': u':禁:'
    },
    u'\U0001F22F': { # 🈯
        'en' : ':Japanese_reserved_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u6307:'],
        'variant': True,
        'de': u':schriftzeichen_für_reserviert:',
        'es': u':ideograma_japonés_para_reservado:',
        'fr': u':bouton_réservé_en_japonais:',
        'ja': u':指マーク:',
        'ko': u':가리킬_지:',
        'pt': u':botão_japonês_de_“reservado”:',
        'it': u':ideogramma_giapponese_di_“riservato”:',
        'fa': u':دکمۀ_«رزروشده»_به_ژاپنی:',
        'id': ':tombol_jepang_sudah_dipesan:',
        'zh': u':指:'
    },
    u'\U00003299\U0000FE0F': { # ㊙️
        'en' : ':Japanese_secret_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':secret:'],
        'variant': True,
        'de': u':schriftzeichen_für_geheimnis:',
        'es': u':ideograma_japonés_para_secreto:',
        'fr': ':bouton_secret_en_japonais:',
        'ja': u':マル秘:',
        'ko': u':원_표시된_비밀_표의문자:',
        'pt': u':botão_japonês_de_“segredo”:',
        'it': u':ideogramma_giapponese_di_“segreto”:',
        'fa': u':دکمه_راز_به_ژاپنی:',
        'id': ':tombol_jepang_rahasia:',
        'zh': u':秘:'
    },
    u'\U00003299': { # ㊙
        'en' : ':Japanese_secret_button:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':secret:'],
        'variant': True,
        'de': u':schriftzeichen_für_geheimnis:',
        'es': u':ideograma_japonés_para_secreto:',
        'fr': ':bouton_secret_en_japonais:',
        'ja': u':マル秘:',
        'ko': u':원_표시된_비밀_표의문자:',
        'pt': u':botão_japonês_de_“segredo”:',
        'it': u':ideogramma_giapponese_di_“segreto”:',
        'fa': u':دکمهٔ_«راز»_به_ژاپنی:',
        'id': ':tombol_jepang_rahasia:',
        'zh': u':秘:'
    },
    u'\U0001F202\U0000FE0F': { # 🈂️
        'en' : ':Japanese_service_charge_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sa:'],
        'variant': True,
        'de': ':schriftzeichen_sa:',
        'es': u':ideograma_japonés_para_de_cortesía:',
        'fr': ':bouton_frais_de_service_en_japonais:',
        'ja': u':サのマーク:',
        'ko': u':일본어_봉사료_버튼:',
        'pt': u':botão_japonês_de_“taxa_de_serviço”:',
        'it': u':ideogramma_giapponese_di_“costo_del_servizio”:',
        'fa': u':دکمه_هزینه_خدمات_به_ژاپنی:',
        'id': ':tombol_jepang_biaya_layanan:',
        'zh': u':服务费:'
    },
    u'\U0001F202': { # 🈂
        'en' : ':Japanese_service_charge_button:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':sa:'],
        'variant': True,
        'de': ':schriftzeichen_sa:',
        'es': u':ideograma_japonés_para_de_cortesía:',
        'fr': ':bouton_frais_de_service_en_japonais:',
        'ja': u':サのマーク:',
        'ko': u':일본어_봉사료_버튼:',
        'pt': u':botão_japonês_de_“taxa_de_serviço”:',
        'it': u':ideogramma_giapponese_di_“costo_del_servizio”:',
        'fa': u':دکمهٔ_«هزینهٔ_خدمات»_به_ژاپنی:',
        'id': ':tombol_jepang_biaya_layanan:',
        'zh': u':服务:'
    },
    u'\U0001F530': { # 🔰
        'en' : ':Japanese_symbol_for_beginner:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':beginner:'],
        'de': u':japanisches_anfänger-zeichen:',
        'es': u':símbolo_japonés_para_principiante:',
        'fr': u':symbole_japonais_de_débutant:',
        'ja': u':初心者マーク:',
        'ko': u':노란색_초록색_이파리_모양:',
        'pt': u':símbolo_japonês_de_principiante:',
        'it': u':ideogramma_giapponese_di_“principiante”:',
        'fa': u':نماد_ژاپنی_سطح_مبتدی:',
        'id': ':simbol_jepang_untuk_pemula:',
        'zh': u':日本新手驾驶标志:'
    },
    u'\U0001F233': { # 🈳
        'en' : ':Japanese_vacancy_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':u7a7a:'],
        'de': u':schriftzeichen_für_zimmer_frei:',
        'es': u':ideograma_japonés_para_vacante:',
        'fr': ':bouton_chambres_disponibles_en_japonais:',
        'ja': u':空マーク:',
        'ko': u':빌_공:',
        'pt': u':botão_japonês_de_“vago”:',
        'it': u':ideogramma_giapponese_di_“posto_libero”:',
        'fa': u':دکمۀ_«پست_خالی»_به_ژاپنی:',
        'id': ':tombol_jepang_ada_lowongan:',
        'zh': u':空:'
    },
    u'\U0001F1EF\U0001F1EA': { # 🇯🇪
        'en' : ':Jersey:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Jersey:', ':jersey:'],
        'de': ':flagge_jersey:',
        'es': ':bandera_jersey:',
        'fr': ':drapeau_jersey:',
        'ja': u':旗_ジャージー:',
        'ko': u':깃발_저지:',
        'pt': ':bandeira_jersey:',
        'it': ':bandiera_jersey:',
        'fa': u':پرچم_جرزی:',
        'id': ':bendera_jersey:',
        'zh': u':泽西岛:'
    },
    u'\U0001F1EF\U0001F1F4': { # 🇯🇴
        'en' : ':Jordan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Jordan:', ':jordan:'],
        'de': ':flagge_jordanien:',
        'es': ':bandera_jordania:',
        'fr': ':drapeau_jordanie:',
        'ja': u':旗_ヨルダン:',
        'ko': u':깃발_요르단:',
        'pt': u':bandeira_jordânia:',
        'it': ':bandiera_giordania:',
        'fa': u':پرچم_اردن:',
        'id': ':bendera_yordania:',
        'zh': u':约旦:'
    },
    u'\U0001F1F0\U0001F1FF': { # 🇰🇿
        'en' : ':Kazakhstan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Kazakhstan:', ':kazakhstan:'],
        'de': ':flagge_kasachstan:',
        'es': u':bandera_kazajistán:',
        'fr': ':drapeau_kazakhstan:',
        'ja': u':旗_カザフスタン:',
        'ko': u':깃발_카자흐스탄:',
        'pt': u':bandeira_cazaquistão:',
        'it': ':bandiera_kazakistan:',
        'fa': u':پرچم_قزاقستان:',
        'id': ':bendera_kazakhstan:',
        'zh': u':哈薩克:'
    },
    u'\U0001F1F0\U0001F1EA': { # 🇰🇪
        'en' : ':Kenya:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Kenya:', ':kenya:'],
        'de': ':flagge_kenia:',
        'es': ':bandera_kenia:',
        'fr': ':drapeau_kenya:',
        'ja': u':旗_ケニア:',
        'ko': u':깃발_케냐:',
        'pt': u':bandeira_quênia:',
        'it': ':bandiera_kenya:',
        'fa': u':پرچم_کنیا:',
        'id': ':bendera_kenya:',
        'zh': u':肯尼亚:'
    },
    u'\U0001F1F0\U0001F1EE': { # 🇰🇮
        'en' : ':Kiribati:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Kiribati:', ':kiribati:'],
        'de': ':flagge_kiribati:',
        'es': ':bandera_kiribati:',
        'fr': ':drapeau_kiribati:',
        'ja': u':旗_キリバス:',
        'ko': u':깃발_키리바시:',
        'pt': ':bandeira_quiribati:',
        'it': ':bandiera_kiribati:',
        'fa': u':پرچم_کیریباتی:',
        'id': ':bendera_kiribati:',
        'zh': u':基里巴斯:'
    },
    u'\U0001F1FD\U0001F1F0': { # 🇽🇰
        'en' : ':Kosovo:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Kosovo:', ':kosovo:'],
        'de': ':flagge_kosovo:',
        'es': ':bandera_kosovo:',
        'fr': ':drapeau_kosovo:',
        'ja': u':旗_コソボ:',
        'ko': u':깃발_코소보:',
        'pt': ':bandeira_kosovo:',
        'it': ':bandiera_kosovo:',
        'fa': u':پرچم_کوزوو:',
        'id': ':bendera_kosovo:',
        'zh': u':科索沃:'
    },
    u'\U0001F1F0\U0001F1FC': { # 🇰🇼
        'en' : ':Kuwait:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Kuwait:', ':kuwait:'],
        'de': ':flagge_kuwait:',
        'es': ':bandera_kuwait:',
        'fr': u':drapeau_koweït:',
        'ja': u':旗_クウェート:',
        'ko': u':깃발_쿠웨이트:',
        'pt': ':bandeira_kuwait:',
        'it': ':bandiera_kuwait:',
        'fa': u':پرچم_کویت:',
        'id': ':bendera_kuwait:',
        'zh': u':科威特:'
    },
    u'\U0001F1F0\U0001F1EC': { # 🇰🇬
        'en' : ':Kyrgyzstan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Kyrgyzstan:', ':kyrgyzstan:'],
        'de': ':flagge_kirgisistan:',
        'es': u':bandera_kirguistán:',
        'fr': ':drapeau_kirghizistan:',
        'ja': u':旗_キルギス:',
        'ko': u':깃발_키르기스스탄:',
        'pt': u':bandeira_quirguistão:',
        'it': ':bandiera_kirghizistan:',
        'fa': u':پرچم_قرقیزستان:',
        'id': ':bendera_kirgizstan:',
        'zh': u':吉尔吉斯斯坦:'
    },
    u'\U0001F1F1\U0001F1E6': { # 🇱🇦
        'en' : ':Laos:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Laos:', ':laos:'],
        'de': ':flagge_laos:',
        'es': ':bandera_laos:',
        'fr': ':drapeau_laos:',
        'ja': u':旗_ラオス:',
        'ko': u':깃발_라오스:',
        'pt': ':bandeira_laos:',
        'it': ':bandiera_laos:',
        'fa': u':پرچم_لائوس:',
        'id': ':bendera_laos:',
        'zh': u':老挝:'
    },
    u'\U0001F1F1\U0001F1FB': { # 🇱🇻
        'en' : ':Latvia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Latvia:', ':latvia:'],
        'de': ':flagge_lettland:',
        'es': ':bandera_letonia:',
        'fr': ':drapeau_lettonie:',
        'ja': u':旗_ラトビア:',
        'ko': u':깃발_라트비아:',
        'pt': u':bandeira_letônia:',
        'it': ':bandiera_lettonia:',
        'fa': u':پرچم_لتونی:',
        'id': ':bendera_latvia:',
        'zh': u':拉脱维亚:'
    },
    u'\U0001F1F1\U0001F1E7': { # 🇱🇧
        'en' : ':Lebanon:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Lebanon:', ':lebanon:'],
        'de': ':flagge_libanon:',
        'es': u':bandera_líbano:',
        'fr': ':drapeau_liban:',
        'ja': u':旗_レバノン:',
        'ko': u':깃발_레바논:',
        'pt': u':bandeira_líbano:',
        'it': ':bandiera_libano:',
        'fa': u':پرچم_لبنان:',
        'id': ':bendera_lebanon:',
        'zh': u':黎巴嫩:'
    },
    u'\U0000264C': { # ♌
        'en' : ':Leo:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':leo:'],
        'variant': True,
        'de': u':löwe_(sternzeichen):',
        'es': ':leo:',
        'fr': ':lion:',
        'ja': u':しし座:',
        'ko': u':사자자리:',
        'pt': u':signo_de_leão:',
        'it': ':segno_zodiacale_del_leone:',
        'fa': u':برج_اسد:',
        'id': ':leo:',
        'zh': u':狮子座:'
    },
    u'\U0001F1F1\U0001F1F8': { # 🇱🇸
        'en' : ':Lesotho:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Lesotho:', ':lesotho:'],
        'de': ':flagge_lesotho:',
        'es': ':bandera_lesoto:',
        'fr': ':drapeau_lesotho:',
        'ja': u':旗_レソト:',
        'ko': u':깃발_레소토:',
        'pt': ':bandeira_lesoto:',
        'it': ':bandiera_lesotho:',
        'fa': u':پرچم_لسوتو:',
        'id': ':bendera_lesotho:',
        'zh': u':莱索托:'
    },
    u'\U0001F1F1\U0001F1F7': { # 🇱🇷
        'en' : ':Liberia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Liberia:', ':liberia:'],
        'de': ':flagge_liberia:',
        'es': ':bandera_liberia:',
        'fr': u':drapeau_libéria:',
        'ja': u':旗_リベリア:',
        'ko': u':깃발_라이베리아:',
        'pt': u':bandeira_libéria:',
        'it': ':bandiera_liberia:',
        'fa': u':پرچم_لیبریا:',
        'id': ':bendera_liberia:',
        'zh': u':利比里亚:'
    },
    u'\U0000264E': { # ♎
        'en' : ':Libra:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':libra:'],
        'variant': True,
        'de': ':waage_(sternzeichen):',
        'es': ':libra:',
        'fr': ':balance:',
        'ja': u':てんびん座:',
        'ko': u':천칭자리:',
        'pt': ':signo_de_libra:',
        'it': ':segno_zodiacale_della_bilancia:',
        'fa': u':برج_میزان:',
        'id': ':libra:',
        'zh': u':天秤座:'
    },
    u'\U0001F1F1\U0001F1FE': { # 🇱🇾
        'en' : ':Libya:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Libya:', ':libya:'],
        'de': ':flagge_libyen:',
        'es': ':bandera_libia:',
        'fr': ':drapeau_libye:',
        'ja': u':旗_リビア:',
        'ko': u':깃발_리비아:',
        'pt': u':bandeira_líbia:',
        'it': ':bandiera_libia:',
        'fa': u':پرچم_لیبی:',
        'id': ':bendera_libya:',
        'zh': u':利比亚:'
    },
    u'\U0001F1F1\U0001F1EE': { # 🇱🇮
        'en' : ':Liechtenstein:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Liechtenstein:', ':liechtenstein:'],
        'de': ':flagge_liechtenstein:',
        'es': ':bandera_liechtenstein:',
        'fr': ':drapeau_liechtenstein:',
        'ja': u':旗_リヒテンシュタイン:',
        'ko': u':깃발_리히텐슈타인:',
        'pt': ':bandeira_liechtenstein:',
        'it': ':bandiera_liechtenstein:',
        'fa': u':پرچم_لیختن_اشتاین:',
        'id': ':bendera_liechtenstein:',
        'zh': u':列支敦士登:'
    },
    u'\U0001F1F1\U0001F1F9': { # 🇱🇹
        'en' : ':Lithuania:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Lithuania:', ':lithuania:'],
        'de': ':flagge_litauen:',
        'es': ':bandera_lituania:',
        'fr': ':drapeau_lituanie:',
        'ja': u':旗_リトアニア:',
        'ko': u':깃발_리투아니아:',
        'pt': u':bandeira_lituânia:',
        'it': ':bandiera_lituania:',
        'fa': u':پرچم_لیتوانی:',
        'id': ':bendera_lituania:',
        'zh': u':立陶宛:'
    },
    u'\U0001F1F1\U0001F1FA': { # 🇱🇺
        'en' : ':Luxembourg:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Luxembourg:', ':luxembourg:'],
        'de': ':flagge_luxemburg:',
        'es': ':bandera_luxemburgo:',
        'fr': ':drapeau_luxembourg:',
        'ja': u':旗_ルクセンブルク:',
        'ko': u':깃발_룩셈부르크:',
        'pt': ':bandeira_luxemburgo:',
        'it': ':bandiera_lussemburgo:',
        'fa': u':پرچم_لوکزامبورگ:',
        'id': ':bendera_luksemburg:',
        'zh': u':卢森堡:'
    },
    u'\U0001F1F2\U0001F1F4': { # 🇲🇴
        'en' : ':Macao_SAR_China:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Macau:', ':macau:'],
        'de': ':flagge_sonderverwaltungsregion_macau:',
        'es': ':bandera_rae_de_macao_(china):',
        'fr': ':drapeau_r.a.s._chinoise_de_macao:',
        'ja': u':旗_中華人民共和国マカオ特別行政区:',
        'ko': u':깃발_마카오(중국_특별행정구):',
        'pt': ':bandeira_macau_rae_da_china:',
        'it': ':bandiera_ras_di_macao:',
        'fa': u':پرچم_ماکائو:',
        'id': ':bendera_makau_dak_tiongkok:',
        'zh': u':澳門:'
    },
    u'\U0001F1F2\U0001F1EC': { # 🇲🇬
        'en' : ':Madagascar:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Madagascar:', ':madagascar:'],
        'de': ':flagge_madagaskar:',
        'es': ':bandera_madagascar:',
        'fr': ':drapeau_madagascar:',
        'ja': u':旗_マダガスカル:',
        'ko': u':깃발_마다가스카르:',
        'pt': ':bandeira_madagascar:',
        'it': ':bandiera_madagascar:',
        'fa': u':پرچم_ماداگاسکار:',
        'id': ':bendera_madagaskar:',
        'zh': u':马达加斯加:'
    },
    u'\U0001F1F2\U0001F1FC': { # 🇲🇼
        'en' : ':Malawi:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Malawi:', ':malawi:'],
        'de': ':flagge_malawi:',
        'es': ':bandera_malaui:',
        'fr': ':drapeau_malawi:',
        'ja': u':旗_マラウイ:',
        'ko': u':깃발_말라위:',
        'pt': ':bandeira_malaui:',
        'it': ':bandiera_malawi:',
        'fa': u':پرچم_مالاوی:',
        'id': ':bendera_malawi:',
        'zh': u':马拉维:'
    },
    u'\U0001F1F2\U0001F1FE': { # 🇲🇾
        'en' : ':Malaysia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Malaysia:', ':malaysia:'],
        'de': ':flagge_malaysia:',
        'es': ':bandera_malasia:',
        'fr': ':drapeau_malaisie:',
        'ja': u':旗_マレーシア:',
        'ko': u':깃발_말레이시아:',
        'pt': u':bandeira_malásia:',
        'it': ':bandiera_malaysia:',
        'fa': u':پرچم_مالزی:',
        'id': ':bendera_malaysia:',
        'zh': u':马来西亚:'
    },
    u'\U0001F1F2\U0001F1FB': { # 🇲🇻
        'en' : ':Maldives:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Maldives:', ':maldives:'],
        'de': ':flagge_malediven:',
        'es': ':bandera_maldivas:',
        'fr': ':drapeau_maldives:',
        'ja': u':旗_モルディブ:',
        'ko': u':깃발_몰디브:',
        'pt': ':bandeira_maldivas:',
        'it': ':bandiera_maldive:',
        'fa': u':پرچم_مالدیو:',
        'id': ':bendera_maladewa:',
        'zh': u':马尔代夫:'
    },
    u'\U0001F1F2\U0001F1F1': { # 🇲🇱
        'en' : ':Mali:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Mali:', ':mali:'],
        'de': ':flagge_mali:',
        'es': ':bandera_mali:',
        'fr': ':drapeau_mali:',
        'ja': u':旗_マリ:',
        'ko': u':깃발_말리:',
        'pt': ':bandeira_mali:',
        'it': ':bandiera_mali:',
        'fa': u':پرچم_مالی:',
        'id': ':bendera_mali:',
        'zh': u':马里:'
    },
    u'\U0001F1F2\U0001F1F9': { # 🇲🇹
        'en' : ':Malta:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Malta:', ':malta:'],
        'de': ':flagge_malta:',
        'es': ':bandera_malta:',
        'fr': ':drapeau_malte:',
        'ja': u':旗_マルタ:',
        'ko': u':깃발_몰타:',
        'pt': ':bandeira_malta:',
        'it': ':bandiera_malta:',
        'fa': u':پرچم_مالت:',
        'id': ':bendera_malta:',
        'zh': u':马耳他:'
    },
    u'\U0001F1F2\U0001F1ED': { # 🇲🇭
        'en' : ':Marshall_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Marshall_Islands:', ':marshall_islands:'],
        'de': ':flagge_marshallinseln:',
        'es': ':bandera_islas_marshall:',
        'fr': u':drapeau_îles_marshall:',
        'ja': u':旗_マーシャル諸島:',
        'ko': u':깃발_마셜_제도:',
        'pt': ':bandeira_ilhas_marshall:',
        'it': ':bandiera_isole_marshall:',
        'fa': u':پرچم_جزایر_مارشال:',
        'id': ':bendera_kepulauan_marshall:',
        'zh': u':马绍尔群岛:'
    },
    u'\U0001F1F2\U0001F1F6': { # 🇲🇶
        'en' : ':Martinique:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Martinique:', ':martinique:'],
        'de': ':flagge_martinique:',
        'es': ':bandera_martinica:',
        'fr': ':drapeau_martinique:',
        'ja': u':旗_マルティニーク:',
        'ko': u':깃발_마르티니크:',
        'pt': ':bandeira_martinica:',
        'it': ':bandiera_martinica:',
        'fa': u':پرچم_مارتینیک:',
        'id': ':bendera_martinik:',
        'zh': u':马提尼克:'
    },
    u'\U0001F1F2\U0001F1F7': { # 🇲🇷
        'en' : ':Mauritania:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Mauritania:', ':mauritania:'],
        'de': ':flagge_mauretanien:',
        'es': ':bandera_mauritania:',
        'fr': ':drapeau_mauritanie:',
        'ja': u':旗_モーリタニア:',
        'ko': u':깃발_모리타니:',
        'pt': u':bandeira_mauritânia:',
        'it': ':bandiera_mauritania:',
        'fa': u':پرچم_موریتانی:',
        'id': ':bendera_mauritania:',
        'zh': u':毛里塔尼亚:'
    },
    u'\U0001F1F2\U0001F1FA': { # 🇲🇺
        'en' : ':Mauritius:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Mauritius:', ':mauritius:'],
        'de': ':flagge_mauritius:',
        'es': ':bandera_mauricio:',
        'fr': ':drapeau_maurice:',
        'ja': u':旗_モーリシャス:',
        'ko': u':깃발_모리셔스:',
        'pt': u':bandeira_maurício:',
        'it': ':bandiera_mauritius:',
        'fa': u':پرچم_موریس:',
        'id': ':bendera_mauritius:',
        'zh': u':毛里求斯:'
    },
    u'\U0001F1FE\U0001F1F9': { # 🇾🇹
        'en' : ':Mayotte:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Mayotte:', ':mayotte:'],
        'de': ':flagge_mayotte:',
        'es': ':bandera_mayotte:',
        'fr': ':drapeau_mayotte:',
        'ja': u':旗_マヨット:',
        'ko': u':깃발_마요트:',
        'pt': ':bandeira_mayotte:',
        'it': ':bandiera_mayotte:',
        'fa': u':پرچم_مایوت:',
        'id': ':bendera_mayotte:',
        'zh': u':马约特:'
    },
    u'\U0001F1F2\U0001F1FD': { # 🇲🇽
        'en' : ':Mexico:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Mexico:', ':mexico:'],
        'de': ':flagge_mexiko:',
        'es': u':bandera_méxico:',
        'fr': ':drapeau_mexique:',
        'ja': u':旗_メキシコ:',
        'ko': u':깃발_멕시코:',
        'pt': u':bandeira_méxico:',
        'it': ':bandiera_messico:',
        'fa': u':پرچم_مکزیک:',
        'id': ':bendera_meksiko:',
        'zh': u':墨西哥:'
    },
    u'\U0001F1EB\U0001F1F2': { # 🇫🇲
        'en' : ':Micronesia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Micronesia:', ':micronesia:'],
        'de': ':flagge_mikronesien:',
        'es': ':bandera_micronesia:',
        'fr': u':drapeau_états_fédérés_de_micronésie:',
        'ja': u':旗_ミクロネシア連邦:',
        'ko': u':깃발_미크로네시아:',
        'pt': u':bandeira_micronésia:',
        'it': ':bandiera_micronesia:',
        'fa': u':پرچم_میکرونزی:',
        'id': ':bendera_mikronesia:',
        'zh': u':密克罗尼西亚:'
    },
    u'\U0001F1F2\U0001F1E9': { # 🇲🇩
        'en' : ':Moldova:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Moldova:', ':moldova:'],
        'de': ':flagge_republik_moldau:',
        'es': ':bandera_moldavia:',
        'fr': ':drapeau_moldavie:',
        'ja': u':旗_モルドバ:',
        'ko': u':깃발_몰도바:',
        'pt': ':bandeira_moldova:',
        'it': ':bandiera_moldavia:',
        'fa': u':پرچم_مولداوی:',
        'id': ':bendera_moldova:',
        'zh': u':摩尔多瓦:'
    },
    u'\U0001F1F2\U0001F1E8': { # 🇲🇨
        'en' : ':Monaco:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Monaco:', ':monaco:'],
        'de': ':flagge_monaco:',
        'es': u':bandera_mónaco:',
        'fr': ':drapeau_monaco:',
        'ja': u':旗_モナコ:',
        'ko': u':깃발_모나코:',
        'pt': u':bandeira_mônaco:',
        'it': ':bandiera_monaco:',
        'fa': u':پرچم_موناکو:',
        'id': ':bendera_monako:',
        'zh': u':摩纳哥:'
    },
    u'\U0001F1F2\U0001F1F3': { # 🇲🇳
        'en' : ':Mongolia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Mongolia:', ':mongolia:'],
        'de': ':flagge_mongolei:',
        'es': ':bandera_mongolia:',
        'fr': ':drapeau_mongolie:',
        'ja': u':旗_モンゴル:',
        'ko': u':깃발_몽골:',
        'pt': u':bandeira_mongólia:',
        'it': ':bandiera_mongolia:',
        'fa': u':پرچم_مغولستان:',
        'id': ':bendera_mongolia:',
        'zh': u':蒙古:'
    },
    u'\U0001F1F2\U0001F1EA': { # 🇲🇪
        'en' : ':Montenegro:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Montenegro:', ':montenegro:'],
        'de': ':flagge_montenegro:',
        'es': ':bandera_montenegro:',
        'fr': u':drapeau_monténégro:',
        'ja': u':旗_モンテネグロ:',
        'ko': u':깃발_몬테네그로:',
        'pt': ':bandeira_montenegro:',
        'it': ':bandiera_montenegro:',
        'fa': u':پرچم_مونته_نگرو:',
        'id': ':bendera_montenegro:',
        'zh': u':黑山:'
    },
    u'\U0001F1F2\U0001F1F8': { # 🇲🇸
        'en' : ':Montserrat:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Montserrat:', ':montserrat:'],
        'de': ':flagge_montserrat:',
        'es': ':bandera_montserrat:',
        'fr': ':drapeau_montserrat:',
        'ja': u':旗_モントセラト:',
        'ko': u':깃발_몬트세라트:',
        'pt': ':bandeira_montserrat:',
        'it': ':bandiera_montserrat:',
        'fa': u':پرچم_مونت_سرات:',
        'id': ':bendera_montserrat:',
        'zh': u':蒙特塞拉特:'
    },
    u'\U0001F1F2\U0001F1E6': { # 🇲🇦
        'en' : ':Morocco:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Morocco:', ':morocco:'],
        'de': ':flagge_marokko:',
        'es': ':bandera_marruecos:',
        'fr': ':drapeau_maroc:',
        'ja': u':旗_モロッコ:',
        'ko': u':깃발_모로코:',
        'pt': ':bandeira_marrocos:',
        'it': ':bandiera_marocco:',
        'fa': u':پرچم_مراکش:',
        'id': ':bendera_maroko:',
        'zh': u':摩洛哥:'
    },
    u'\U0001F1F2\U0001F1FF': { # 🇲🇿
        'en' : ':Mozambique:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Mozambique:', ':mozambique:'],
        'de': ':flagge_mosambik:',
        'es': ':bandera_mozambique:',
        'fr': ':drapeau_mozambique:',
        'ja': u':旗_モザンビーク:',
        'ko': u':깃발_모잠비크:',
        'pt': u':bandeira_moçambique:',
        'it': ':bandiera_mozambico:',
        'fa': u':پرچم_موزامبیک:',
        'id': ':bendera_mozambik:',
        'zh': u':莫桑比克:'
    },
    u'\U0001F936': { # 🤶
        'en' : ':Mrs._Claus:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':mrs_claus:'],
        'de': ':weihnachtsfrau:',
        'es': u':mamá_noel:',
        'fr': u':mère_noël:',
        'ja': u':女性のサンタ:',
        'ko': u':산타할머니:',
        'pt': u':mamãe_noel:',
        'it': ':mamma_natale:',
        'fa': u':مامان_نوئل:',
        'id': ':nyonya_sinterklas:',
        'zh': u':圣诞奶奶:'
    },
    u'\U0001F936\U0001F3FF': { # 🤶🏿
        'en' : ':Mrs._Claus_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':weihnachtsfrau_dunkle_hautfarbe:',
        'es': u':mamá_noel_tono_de_piel_oscuro:',
        'fr': u':mère_noël_peau_foncée:',
        'ja': u':女性のサンタ_濃い肌色:',
        'ko': u':산타할머니_검은색_피부:',
        'pt': u':mamãe_noel_pele_escura:',
        'it': ':mamma_natale_carnagione_scura:',
        'fa': u':مامان_نوئل_پوست_آبنوسی:',
        'id': ':nyonya_sinterklas_warna_kulit_gelap:',
        'zh': u':圣诞奶奶_较深肤色:'
    },
    u'\U0001F936\U0001F3FB': { # 🤶🏻
        'en' : ':Mrs._Claus_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':weihnachtsfrau_helle_hautfarbe:',
        'es': u':mamá_noel_tono_de_piel_claro:',
        'fr': u':mère_noël_peau_claire:',
        'ja': u':女性のサンタ_薄い肌色:',
        'ko': u':산타할머니_하얀_피부:',
        'pt': u':mamãe_noel_pele_clara:',
        'it': ':mamma_natale_carnagione_chiara:',
        'fa': u':مامان_نوئل_پوست_سفید:',
        'id': ':nyonya_sinterklas_warna_kulit_cerah:',
        'zh': u':圣诞奶奶_较浅肤色:'
    },
    u'\U0001F936\U0001F3FE': { # 🤶🏾
        'en' : ':Mrs._Claus_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':weihnachtsfrau_mitteldunkle_hautfarbe:',
        'es': u':mamá_noel_tono_de_piel_oscuro_medio:',
        'fr': u':mère_noël_peau_mate:',
        'ja': u':女性のサンタ_やや濃い肌色:',
        'ko': u':산타할머니_진한_갈색_피부:',
        'pt': u':mamãe_noel_pele_morena_escura:',
        'it': ':mamma_natale_carnagione_abbastanza_scura:',
        'fa': u':مامان_نوئل_پوست_گندمی:',
        'id': ':nyonya_sinterklas_warna_kulit_gelap-sedang:',
        'zh': u':圣诞奶奶_中等深肤色:'
    },
    u'\U0001F936\U0001F3FC': { # 🤶🏼
        'en' : ':Mrs._Claus_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':weihnachtsfrau_mittelhelle_hautfarbe:',
        'es': u':mamá_noel_tono_de_piel_claro_medio:',
        'fr': u':mère_noël_peau_moyennement_claire:',
        'ja': u':女性のサンタ_やや薄い肌色:',
        'ko': u':산타할머니_연한_갈색_피부:',
        'pt': u':mamãe_noel_pele_morena_clara:',
        'it': ':mamma_natale_carnagione_abbastanza_chiara:',
        'fa': u':مامان_نوئل_پوست_روشن:',
        'id': ':nyonya_sinterklas_warna_kulit_cerah-sedang:',
        'zh': u':圣诞奶奶_中等浅肤色:'
    },
    u'\U0001F936\U0001F3FD': { # 🤶🏽
        'en' : ':Mrs._Claus_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':weihnachtsfrau_mittlere_hautfarbe:',
        'es': u':mamá_noel_tono_de_piel_medio:',
        'fr': u':mère_noël_peau_légèrement_mate:',
        'ja': u':女性のサンタ_中間の肌色:',
        'ko': u':산타할머니_갈색_피부:',
        'pt': u':mamãe_noel_pele_morena:',
        'it': ':mamma_natale_carnagione_olivastra:',
        'fa': u':مامان_نوئل_پوست_طلایی:',
        'id': ':nyonya_sinterklas_warna_kulit_sedang:',
        'zh': u':圣诞奶奶_中等肤色:'
    },
    u'\U0001F1F2\U0001F1F2': { # 🇲🇲
        'en' : ':Myanmar_(Burma):',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Myanmar:', ':myanmar:'],
        'de': ':flagge_myanmar:',
        'es': ':bandera_myanmar_(birmania):',
        'fr': ':drapeau_myanmar_(birmanie):',
        'ja': u':旗_ミャンマー_(ビルマ):',
        'ko': u':깃발_미얀마:',
        'pt': u':bandeira_mianmar_(birmânia):',
        'it': ':bandiera_myanmar_(birmania):',
        'fa': u':پرچم_میانمار_(برمه):',
        'id': ':bendera_myanmar_(burma):',
        'zh': u':缅甸:'
    },
    u'\U0001F195': { # 🆕
        'en' : ':NEW_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':new:'],
        'de': ':wort_new_in_blauem_quadrat:',
        'es': u':botón_new:',
        'fr': ':bouton_nouveau:',
        'ja': u':newマーク:',
        'ko': u':뉴:',
        'pt': u':botão_new:',
        'it': ':pulsante_new:',
        'fa': u':دکمهٔ_new:',
        'id': ':tombol_new:',
        'zh': u':new按钮:'
    },
    u'\U0001F196': { # 🆖
        'en' : ':NG_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ng:'],
        'de': u':großbuchstaben_ng_in_blauem_quadrat:',
        'es': u':botón_ng:',
        'fr': ':bouton_pas_bien:',
        'ja': u':ngマーク:',
        'ko': u':엔지:',
        'pt': u':botão_ng:',
        'it': ':pulsante_ng:',
        'fa': u':دکمهٔ_ng:',
        'id': ':tombol_ng:',
        'zh': u':NG按钮:'
    },
    u'\U0001F1F3\U0001F1E6': { # 🇳🇦
        'en' : ':Namibia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Namibia:', ':namibia:'],
        'de': ':flagge_namibia:',
        'es': ':bandera_namibia:',
        'fr': ':drapeau_namibie:',
        'ja': u':旗_ナミビア:',
        'ko': u':깃발_나미비아:',
        'pt': u':bandeira_namíbia:',
        'it': ':bandiera_namibia:',
        'fa': u':پرچم_نامیبیا:',
        'id': ':bendera_namibia:',
        'zh': u':纳米比亚:'
    },
    u'\U0001F1F3\U0001F1F7': { # 🇳🇷
        'en' : ':Nauru:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Nauru:', ':nauru:'],
        'de': ':flagge_nauru:',
        'es': ':bandera_nauru:',
        'fr': ':drapeau_nauru:',
        'ja': u':旗_ナウル:',
        'ko': u':깃발_나우루:',
        'pt': ':bandeira_nauru:',
        'it': ':bandiera_nauru:',
        'fa': u':پرچم_نائورو:',
        'id': ':bendera_nauru:',
        'zh': u':瑙鲁:'
    },
    u'\U0001F1F3\U0001F1F5': { # 🇳🇵
        'en' : ':Nepal:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Nepal:', ':nepal:'],
        'de': ':flagge_nepal:',
        'es': ':bandera_nepal:',
        'fr': u':drapeau_népal:',
        'ja': u':旗_ネパール:',
        'ko': u':깃발_네팔:',
        'pt': ':bandeira_nepal:',
        'it': ':bandiera_nepal:',
        'fa': u':پرچم_نپال:',
        'id': ':bendera_nepal:',
        'zh': u':尼泊尔:'
    },
    u'\U0001F1F3\U0001F1F1': { # 🇳🇱
        'en' : ':Netherlands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Netherlands:', ':netherlands:'],
        'de': ':flagge_niederlande:',
        'es': u':bandera_países_bajos:',
        'fr': ':drapeau_pays-bas:',
        'ja': u':旗_オランダ:',
        'ko': u':깃발_네덜란드:',
        'pt': u':bandeira_países_baixos:',
        'it': ':bandiera_paesi_bassi:',
        'fa': u':پرچم_هلند:',
        'id': ':bendera_belanda:',
        'zh': u':荷兰:'
    },
    u'\U0001F1F3\U0001F1E8': { # 🇳🇨
        'en' : ':New_Caledonia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_New_Caledonia:', ':new_caledonia:'],
        'de': ':flagge_neukaledonien:',
        'es': ':bandera_nueva_caledonia:',
        'fr': u':drapeau_nouvelle-calédonie:',
        'ja': u':旗_ニューカレドニア:',
        'ko': u':깃발_뉴칼레도니아:',
        'pt': u':bandeira_nova_caledônia:',
        'it': ':bandiera_nuova_caledonia:',
        'fa': u':پرچم_کالدونیای_جدید:',
        'id': ':bendera_kaledonia_baru:',
        'zh': u':新喀里多尼亚:'
    },
    u'\U0001F1F3\U0001F1FF': { # 🇳🇿
        'en' : ':New_Zealand:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_New_Zealand:', ':new_zealand:'],
        'de': ':flagge_neuseeland:',
        'es': ':bandera_nueva_zelanda:',
        'fr': u':drapeau_nouvelle-zélande:',
        'ja': u':旗_ニュージーランド:',
        'ko': u':깃발_뉴질랜드:',
        'pt': u':bandeira_nova_zelândia:',
        'it': ':bandiera_nuova_zelanda:',
        'fa': u':پرچم_نیوزیلند:',
        'id': ':bendera_selandia_baru:',
        'zh': u':新西兰:'
    },
    u'\U0001F1F3\U0001F1EE': { # 🇳🇮
        'en' : ':Nicaragua:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Nicaragua:', ':nicaragua:'],
        'de': ':flagge_nicaragua:',
        'es': ':bandera_nicaragua:',
        'fr': ':drapeau_nicaragua:',
        'ja': u':旗_ニカラグア:',
        'ko': u':깃발_니카라과:',
        'pt': u':bandeira_nicarágua:',
        'it': ':bandiera_nicaragua:',
        'fa': u':پرچم_نیکاراگوئه:',
        'id': ':bendera_nikaragua:',
        'zh': u':尼加拉瓜:'
    },
    u'\U0001F1F3\U0001F1EA': { # 🇳🇪
        'en' : ':Niger:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Niger:', ':niger:'],
        'de': ':flagge_niger:',
        'es': u':bandera_níger:',
        'fr': ':drapeau_niger:',
        'ja': u':旗_ニジェール:',
        'ko': u':깃발_니제르:',
        'pt': u':bandeira_níger:',
        'it': ':bandiera_niger:',
        'fa': u':پرچم_نیجر:',
        'id': ':bendera_niger:',
        'zh': u':尼日尔:'
    },
    u'\U0001F1F3\U0001F1EC': { # 🇳🇬
        'en' : ':Nigeria:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Nigeria:', ':nigeria:'],
        'de': ':flagge_nigeria:',
        'es': ':bandera_nigeria:',
        'fr': u':drapeau_nigéria:',
        'ja': u':旗_ナイジェリア:',
        'ko': u':깃발_나이지리아:',
        'pt': u':bandeira_nigéria:',
        'it': ':bandiera_nigeria:',
        'fa': u':پرچم_نیجریه:',
        'id': ':bendera_nigeria:',
        'zh': u':尼日利亚:'
    },
    u'\U0001F1F3\U0001F1FA': { # 🇳🇺
        'en' : ':Niue:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Niue:', ':niue:'],
        'de': ':flagge_niue:',
        'es': ':bandera_niue:',
        'fr': ':drapeau_niue:',
        'ja': u':旗_ニウエ:',
        'ko': u':깃발_니우에:',
        'pt': ':bandeira_niue:',
        'it': ':bandiera_niue:',
        'fa': u':پرچم_نیوئه:',
        'id': ':bendera_niue:',
        'zh': u':纽埃:'
    },
    u'\U0001F1F3\U0001F1EB': { # 🇳🇫
        'en' : ':Norfolk_Island:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Norfolk_Island:', ':norfolk_island:'],
        'de': ':flagge_norfolkinsel:',
        'es': ':bandera_isla_norfolk:',
        'fr': u':drapeau_île_norfolk:',
        'ja': u':旗_ノーフォーク島:',
        'ko': u':깃발_노퍽섬:',
        'pt': ':bandeira_ilha_norfolk:',
        'it': ':bandiera_isola_norfolk:',
        'fa': u':پرچم_جزیرهٔ_نورفولک:',
        'id': ':bendera_kepulauan_norfolk:',
        'zh': u':诺福克岛:'
    },
    u'\U0001F1F0\U0001F1F5': { # 🇰🇵
        'en' : ':North_Korea:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_North_Korea:', ':north_korea:'],
        'de': ':flagge_nordkorea:',
        'es': ':bandera_corea_del_norte:',
        'fr': u':drapeau_corée_du_nord:',
        'ja': u':旗_北朝鮮:',
        'ko': u':깃발_북한:',
        'pt': ':bandeira_coreia_do_norte:',
        'it': ':bandiera_corea_del_nord:',
        'fa': u':پرچم_کرهٔ_شمالی:',
        'id': ':bendera_korea_utara:',
        'zh': u':朝鲜:'
    },
    u'\U0001F1F2\U0001F1F0': { # 🇲🇰
        'en' : ':North_Macedonia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Macedonia:', ':macedonia:'],
        'de': ':flagge_nordmazedonien:',
        'es': ':bandera_macedonia_del_norte:',
        'fr': u':drapeau_macédoine_du_nord:',
        'ja': u':旗_北マケドニア:',
        'ko': u':깃발_북마케도니아:',
        'pt': u':bandeira_macedônia_do_norte:',
        'it': ':bandiera_macedonia_del_nord:',
        'fa': u':پرچم_مقدونیهٔ_شمالی:',
        'id': ':bendera_makedonia_utara:',
        'zh': u':北马其顿:'
    },
    u'\U0001F1F2\U0001F1F5': { # 🇲🇵
        'en' : ':Northern_Mariana_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Northern_Mariana_Islands:', ':northern_mariana_islands:'],
        'de': u':flagge_nördliche_marianen:',
        'es': ':bandera_islas_marianas_del_norte:',
        'fr': u':drapeau_îles_mariannes_du_nord:',
        'ja': u':旗_北マリアナ諸島:',
        'ko': u':깃발_북마리아나제도:',
        'pt': ':bandeira_ilhas_marianas_do_norte:',
        'it': ':bandiera_isole_marianne_settentrionali:',
        'fa': u':پرچم_جزایر_ماریانای_شمالی:',
        'id': ':bendera_kepulauan_mariana_utara:',
        'zh': u':北马里亚纳群岛:'
    },
    u'\U0001F1F3\U0001F1F4': { # 🇳🇴
        'en' : ':Norway:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Norway:', ':norway:'],
        'de': ':flagge_norwegen:',
        'es': ':bandera_noruega:',
        'fr': u':drapeau_norvège:',
        'ja': u':旗_ノルウェー:',
        'ko': u':깃발_노르웨이:',
        'pt': ':bandeira_noruega:',
        'it': ':bandiera_norvegia:',
        'fa': u':پرچم_نروژ:',
        'id': ':bendera_norwegia:',
        'zh': u':挪威:'
    },
    u'\U0001F197': { # 🆗
        'en' : ':OK_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ok:'],
        'de': u':großbuchstaben_ok_in_blauem_quadrat:',
        'es': u':botón_ok:',
        'fr': ':bouton_ok:',
        'ja': u':okマーク:',
        'ko': u':오케이:',
        'pt': u':botão_ok:',
        'it': ':pulsante_ok:',
        'fa': u':دکمهٔ_ok:',
        'id': ':tombol_ok:',
        'zh': u':OK按钮:'
    },
    u'\U0001F44C': { # 👌
        'en' : ':OK_hand:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ok_hand:'],
        'de': ':ok-zeichen:',
        'es': u':señal_de_aprobación_con_la_mano:',
        'fr': ':ok:',
        'ja': u':okの手:',
        'ko': u':오케이를_표시한_손:',
        'pt': ':sinal_de_ok:',
        'it': ':mano_che_fa_ok:',
        'fa': u':علامت_اوکی:',
        'id': ':oke:',
        'zh': ':OK:'
    },
    u'\U0001F44C\U0001F3FF': { # 👌🏿
        'en' : ':OK_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ok-zeichen_dunkle_hautfarbe:',
        'es': u':señal_de_aprobación_con_la_mano_tono_de_piel_oscuro:',
        'fr': u':ok_peau_foncée:',
        'ja': u':okの手_濃い肌色:',
        'ko': u':오케이를_표시한_손_검은색_피부:',
        'pt': ':sinal_de_ok_pele_escura:',
        'it': ':mano_che_fa_ok_carnagione_scura:',
        'fa': u':علامت_اوکی_پوست_آبنوسی:',
        'id': ':oke_warna_kulit_gelap:',
        'zh': u':OK_较深肤色:'
    },
    u'\U0001F44C\U0001F3FB': { # 👌🏻
        'en' : ':OK_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ok-zeichen_helle_hautfarbe:',
        'es': u':señal_de_aprobación_con_la_mano_tono_de_piel_claro:',
        'fr': ':ok_peau_claire:',
        'ja': u':okの手_薄い肌色:',
        'ko': u':오케이를_표시한_손_하얀_피부:',
        'pt': ':sinal_de_ok_pele_clara:',
        'it': ':mano_che_fa_ok_carnagione_chiara:',
        'fa': u':علامت_اوکی_پوست_سفید:',
        'id': ':oke_warna_kulit_cerah:',
        'zh': u':OK_较浅肤色:'
    },
    u'\U0001F44C\U0001F3FE': { # 👌🏾
        'en' : ':OK_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ok-zeichen_mitteldunkle_hautfarbe:',
        'es': u':señal_de_aprobación_con_la_mano_tono_de_piel_oscuro_medio:',
        'fr': ':ok_peau_mate:',
        'ja': u':okの手_やや濃い肌色:',
        'ko': u':오케이를_표시한_손_진한_갈색_피부:',
        'pt': ':sinal_de_ok_pele_morena_escura:',
        'it': ':mano_che_fa_ok_carnagione_abbastanza_scura:',
        'fa': u':علامت_اوکی_پوست_گندمی:',
        'id': ':oke_warna_kulit_gelap-sedang:',
        'zh': u':OK_中等深肤色:'
    },
    u'\U0001F44C\U0001F3FC': { # 👌🏼
        'en' : ':OK_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ok-zeichen_mittelhelle_hautfarbe:',
        'es': u':señal_de_aprobación_con_la_mano_tono_de_piel_claro_medio:',
        'fr': ':ok_peau_moyennement_claire:',
        'ja': u':okの手_やや薄い肌色:',
        'ko': u':오케이를_표시한_손_연한_갈색_피부:',
        'pt': ':sinal_de_ok_pele_morena_clara:',
        'it': ':mano_che_fa_ok_carnagione_abbastanza_chiara:',
        'fa': u':علامت_اوکی_پوست_روشن:',
        'id': ':oke_warna_kulit_cerah-sedang:',
        'zh': u':OK_中等浅肤色:'
    },
    u'\U0001F44C\U0001F3FD': { # 👌🏽
        'en' : ':OK_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ok-zeichen_mittlere_hautfarbe:',
        'es': u':señal_de_aprobación_con_la_mano_tono_de_piel_medio:',
        'fr': u':ok_peau_légèrement_mate:',
        'ja': u':okの手_中間の肌色:',
        'ko': u':오케이를_표시한_손_갈색_피부:',
        'pt': ':sinal_de_ok_pele_morena:',
        'it': ':mano_che_fa_ok_carnagione_olivastra:',
        'fa': u':علامت_اوکی_پوست_طلایی:',
        'id': ':oke_warna_kulit_sedang:',
        'zh': u':OK_中等肤色:'
    },
    u'\U0001F51B': { # 🔛
        'en' : ':ON!_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':on:'],
        'de': ':on!-pfeil:',
        'es': ':flecha_on!:',
        'fr': u':flèche_activé:',
        'ja': u':on矢印:',
        'ko': u':켜짐:',
        'pt': ':seta_on!:',
        'it': ':freccia_on:',
        'fa': u':پیکان_روشن:',
        'id': ':tanda_panah_on!:',
        'zh': u':ON箭头:'
    },
    u'\U0001F17E\U0000FE0F': { # 🅾️
        'en' : ':O_button_(blood_type):',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':o2:'],
        'variant': True,
        'de': u':großbuchstabe_o_in_rotem_quadrat:',
        'es': u':grupo_sanguíneo_tipo_o:',
        'fr': ':groupe_sanguin_o:',
        'ja': u':血液型o型:',
        'ko': u':오형:',
        'pt': u':botão_o_(tipo_sanguíneo):',
        'it': ':gruppo_sanguigno_0:',
        'fa': u':دکمه_ا_(گروه_خونی):',
        'id': ':tombol_o_(golongan_darah):',
        'zh': u':O型血:'
    },
    u'\U0001F17E': { # 🅾
        'en' : ':O_button_(blood_type):',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':o2:'],
        'variant': True,
        'de': u':großbuchstabe_o_in_rotem_quadrat:',
        'es': u':grupo_sanguíneo_tipo_o:',
        'fr': ':groupe_sanguin_o:',
        'ja': u':血液型o型:',
        'ko': u':오형:',
        'pt': u':botão_o_(tipo_sanguíneo):',
        'it': ':gruppo_sanguigno_0:',
        'fa': u':دکمه_اُ_(گروه_خونی):',
        'id': ':tombol_o_(golongan_darah):',
        'zh': u':O型血:'
    },
    u'\U0001F1F4\U0001F1F2': { # 🇴🇲
        'en' : ':Oman:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Oman:', ':oman:'],
        'de': ':flagge_oman:',
        'es': u':bandera_omán:',
        'fr': ':drapeau_oman:',
        'ja': u':旗_オマーン:',
        'ko': u':깃발_오만:',
        'pt': u':bandeira_omã:',
        'it': ':bandiera_oman:',
        'fa': u':پرچم_عمان:',
        'id': ':bendera_oman:',
        'zh': u':阿曼:'
    },
    u'\U000026CE': { # ⛎
        'en' : ':Ophiuchus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ophiuchus:'],
        'de': u':schlangenträger:',
        'es': ':ofiuco:',
        'fr': ':serpentaire:',
        'ja': u':へびつかい座:',
        'ko': u':뱀주인자리:',
        'pt': u':signo_de_ofiúco:',
        'it': u':segno_zodiacale_dell’ofiuco:',
        'fa': u':برج_حوا:',
        'id': ':ophiuchus:',
        'zh': u':蛇夫座:'
    },
    u'\U0001F17F\U0000FE0F': { # 🅿️
        'en' : ':P_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':parking:'],
        'variant': True,
        'de': u':großbuchstabe_p_in_blauem_quadrat:',
        'es': ':aparcamiento:',
        'fr': ':bouton_p:',
        'ja': u':pマーク:',
        'ko': u':주차_표시:',
        'pt': u':botão_p:',
        'it': ':pulsante_p:',
        'fa': u':دکمه_پی:',
        'id': ':tombol_p:',
        'zh': u':停车按钮:'
    },
    u'\U0001F17F': { # 🅿
        'en' : ':P_button:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':parking:'],
        'variant': True,
        'de': u':großbuchstabe_p_in_blauem_quadrat:',
        'es': ':aparcamiento:',
        'fr': ':bouton_p:',
        'ja': u':pマーク:',
        'ko': u':주차_표시:',
        'pt': u':botão_p:',
        'it': ':pulsante_p:',
        'fa': u':دکمه_پی:',
        'id': ':tombol_p:',
        'zh': u':停车按钮:'
    },
    u'\U0001F1F5\U0001F1F0': { # 🇵🇰
        'en' : ':Pakistan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Pakistan:', ':pakistan:'],
        'de': ':flagge_pakistan:',
        'es': u':bandera_pakistán:',
        'fr': ':drapeau_pakistan:',
        'ja': u':旗_パキスタン:',
        'ko': u':깃발_파키스탄:',
        'pt': u':bandeira_paquistão:',
        'it': ':bandiera_pakistan:',
        'fa': u':پرچم_پاکستان:',
        'id': ':bendera_pakistan:',
        'zh': u':巴基斯坦:'
    },
    u'\U0001F1F5\U0001F1FC': { # 🇵🇼
        'en' : ':Palau:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Palau:', ':palau:'],
        'de': ':flagge_palau:',
        'es': ':bandera_palaos:',
        'fr': ':drapeau_palaos:',
        'ja': u':旗_パラオ:',
        'ko': u':깃발_팔라우:',
        'pt': ':bandeira_palau:',
        'it': ':bandiera_palau:',
        'fa': u':پرچم_پالائو:',
        'id': ':bendera_palau:',
        'zh': u':帕劳:'
    },
    u'\U0001F1F5\U0001F1F8': { # 🇵🇸
        'en' : ':Palestinian_Territories:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Palestinian_Territories:', ':palestinian_territories:'],
        'de': u':flagge_palästinensische_autonomiegebiete:',
        'es': ':bandera_territorios_palestinos:',
        'fr': ':drapeau_territoires_palestiniens:',
        'ja': u':旗_パレスチナ自治区:',
        'ko': u':깃발_팔레스타인_지구:',
        'pt': u':bandeira_territórios_palestinos:',
        'it': ':bandiera_territori_palestinesi:',
        'fa': u':پرچم_سرزمین_های_فلسطینی:',
        'id': ':bendera_wilayah_palestina:',
        'zh': u':巴勒斯坦领土:'
    },
    u'\U0001F1F5\U0001F1E6': { # 🇵🇦
        'en' : ':Panama:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Panama:', ':panama:'],
        'de': ':flagge_panama:',
        'es': u':bandera_panamá:',
        'fr': ':drapeau_panama:',
        'ja': u':旗_パナマ:',
        'ko': u':깃발_파나마:',
        'pt': u':bandeira_panamá:',
        'it': u':bandiera_panamá:',
        'fa': u':پرچم_پاناما:',
        'id': ':bendera_panama:',
        'zh': u':巴拿马:'
    },
    u'\U0001F1F5\U0001F1EC': { # 🇵🇬
        'en' : ':Papua_New_Guinea:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Papua_New_Guinea:', ':papua_new_guinea:'],
        'de': ':flagge_papua-neuguinea:',
        'es': u':bandera_papúa_nueva_guinea:',
        'fr': u':drapeau_papouasie-nouvelle-guinée:',
        'ja': u':旗_パプアニューギニア:',
        'ko': u':깃발_파푸아뉴기니:',
        'pt': u':bandeira_papua-nova_guiné:',
        'it': ':bandiera_papua_nuova_guinea:',
        'fa': u':پرچم_پاپوا_گینهٔ_نو:',
        'id': ':bendera_papua_nugini:',
        'zh': u':巴布亚新几内亚:'
    },
    u'\U0001F1F5\U0001F1FE': { # 🇵🇾
        'en' : ':Paraguay:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Paraguay:', ':paraguay:'],
        'de': ':flagge_paraguay:',
        'es': ':bandera_paraguay:',
        'fr': ':drapeau_paraguay:',
        'ja': u':旗_パラグアイ:',
        'ko': u':깃발_파라과이:',
        'pt': ':bandeira_paraguai:',
        'it': ':bandiera_paraguay:',
        'fa': u':پرچم_پاراگوئه:',
        'id': ':bendera_paraguay:',
        'zh': u':巴拉圭:'
    },
    u'\U0001F1F5\U0001F1EA': { # 🇵🇪
        'en' : ':Peru:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Peru:', ':peru:'],
        'de': ':flagge_peru:',
        'es': u':bandera_perú:',
        'fr': u':drapeau_pérou:',
        'ja': u':旗_ペルー:',
        'ko': u':깃발_페루:',
        'pt': ':bandeira_peru:',
        'it': u':bandiera_perù:',
        'fa': u':پرچم_پرو:',
        'id': ':bendera_peru:',
        'zh': u':秘鲁:'
    },
    u'\U0001F1F5\U0001F1ED': { # 🇵🇭
        'en' : ':Philippines:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Philippines:', ':philippines:'],
        'de': ':flagge_philippinen:',
        'es': ':bandera_filipinas:',
        'fr': ':drapeau_philippines:',
        'ja': u':旗_フィリピン:',
        'ko': u':깃발_필리핀:',
        'pt': ':bandeira_filipinas:',
        'it': ':bandiera_filippine:',
        'fa': u':پرچم_فیلیپین:',
        'id': ':bendera_filipina:',
        'zh': u':菲律宾:'
    },
    u'\U00002653': { # ♓
        'en' : ':Pisces:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pisces:'],
        'variant': True,
        'de': ':fische_(sternzeichen):',
        'es': ':piscis:',
        'fr': ':poissons:',
        'ja': u':うお座:',
        'ko': u':물고기자리:',
        'pt': ':signo_de_peixes:',
        'it': ':segno_zodiacale_dei_pesci:',
        'fa': u':برج_حوت:',
        'id': ':pisces:',
        'zh': u':双鱼座:'
    },
    u'\U0001F1F5\U0001F1F3': { # 🇵🇳
        'en' : ':Pitcairn_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Pitcairn_Islands:', ':pitcairn_islands:'],
        'de': ':flagge_pitcairninseln:',
        'es': ':bandera_islas_pitcairn:',
        'fr': u':drapeau_îles_pitcairn:',
        'ja': u':旗_ピトケアン諸島:',
        'ko': u':깃발_핏케언_제도:',
        'pt': ':bandeira_ilhas_pitcairn:',
        'it': ':bandiera_isole_pitcairn:',
        'fa': u':پرچم_جزایر_پیت_کرن:',
        'id': ':bendera_kepulauan_pitcairn:',
        'zh': u':皮特凯恩群岛:'
    },
    u'\U0001F1F5\U0001F1F1': { # 🇵🇱
        'en' : ':Poland:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Poland:', ':poland:'],
        'de': ':flagge_polen:',
        'es': ':bandera_polonia:',
        'fr': ':drapeau_pologne:',
        'ja': u':旗_ポーランド:',
        'ko': u':깃발_폴란드:',
        'pt': u':bandeira_polônia:',
        'it': ':bandiera_polonia:',
        'fa': u':پرچم_لهستان:',
        'id': ':bendera_polandia:',
        'zh': u':波兰:'
    },
    u'\U0001F1F5\U0001F1F9': { # 🇵🇹
        'en' : ':Portugal:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Portugal:', ':portugal:'],
        'de': ':flagge_portugal:',
        'es': ':bandera_portugal:',
        'fr': ':drapeau_portugal:',
        'ja': u':旗_ポルトガル:',
        'ko': u':깃발_포르투갈:',
        'pt': ':bandeira_portugal:',
        'it': ':bandiera_portogallo:',
        'fa': u':پرچم_پرتغال:',
        'id': ':bendera_portugal:',
        'zh': u':葡萄牙:'
    },
    u'\U0001F1F5\U0001F1F7': { # 🇵🇷
        'en' : ':Puerto_Rico:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Puerto_Rico:', ':puerto_rico:'],
        'de': ':flagge_puerto_rico:',
        'es': ':bandera_puerto_rico:',
        'fr': ':drapeau_porto_rico:',
        'ja': u':旗_プエルトリコ:',
        'ko': u':깃발_푸에르토리코:',
        'pt': ':bandeira_porto_rico:',
        'it': ':bandiera_portorico:',
        'fa': u':پرچم_پورتوریکو:',
        'id': ':bendera_puerto_riko:',
        'zh': u':波多黎各:'
    },
    u'\U0001F1F6\U0001F1E6': { # 🇶🇦
        'en' : ':Qatar:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Qatar:', ':qatar:'],
        'de': ':flagge_katar:',
        'es': ':bandera_catar:',
        'fr': ':drapeau_qatar:',
        'ja': u':旗_カタール:',
        'ko': u':깃발_카타르:',
        'pt': ':bandeira_catar:',
        'it': ':bandiera_qatar:',
        'fa': u':پرچم_قطر:',
        'id': ':bendera_qatar:',
        'zh': u':卡塔尔:'
    },
    u'\U0001F1F7\U0001F1F4': { # 🇷🇴
        'en' : ':Romania:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Romania:', ':romania:'],
        'de': u':flagge_rumänien:',
        'es': u':bandera_rumanía:',
        'fr': ':drapeau_roumanie:',
        'ja': u':旗_ルーマニア:',
        'ko': u':깃발_루마니아:',
        'pt': u':bandeira_romênia:',
        'it': ':bandiera_romania:',
        'fa': u':پرچم_رومانی:',
        'id': ':bendera_rumania:',
        'zh': u':罗马尼亚:'
    },
    u'\U0001F1F7\U0001F1FA': { # 🇷🇺
        'en' : ':Russia:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_Russia:', ':ru:'],
        'de': ':flagge_russland:',
        'es': ':bandera_rusia:',
        'fr': ':drapeau_russie:',
        'ja': u':旗_ロシア:',
        'ko': u':깃발_러시아:',
        'pt': u':bandeira_rússia:',
        'it': ':bandiera_russia:',
        'fa': u':پرچم_روسیه:',
        'id': ':bendera_rusia:',
        'zh': u':俄罗斯:'
    },
    u'\U0001F1F7\U0001F1FC': { # 🇷🇼
        'en' : ':Rwanda:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Rwanda:', ':rwanda:'],
        'de': ':flagge_ruanda:',
        'es': ':bandera_ruanda:',
        'fr': ':drapeau_rwanda:',
        'ja': u':旗_ルワンダ:',
        'ko': u':깃발_르완다:',
        'pt': ':bandeira_ruanda:',
        'it': ':bandiera_ruanda:',
        'fa': u':پرچم_رواندا:',
        'id': ':bendera_rwanda:',
        'zh': u':卢旺达:'
    },
    u'\U0001F1F7\U0001F1EA': { # 🇷🇪
        'en' : u':Réunion:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [u':flag_for_Réunion:', ':reunion:'],
        'de': u':flagge_réunion:',
        'es': u':bandera_reunión:',
        'fr': u':drapeau_la_réunion:',
        'ja': u':旗_レユニオン:',
        'ko': u':깃발_레위니옹:',
        'pt': u':bandeira_reunião:',
        'it': ':bandiera_riunione:',
        'fa': u':پرچم_رئونیون:',
        'id': u':bendera_réunion:',
        'zh': u':留尼汪:'
    },
    u'\U0001F51C': { # 🔜
        'en' : ':SOON_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':soon:'],
        'de': ':soon-pfeil:',
        'es': ':flecha_soon:',
        'fr': u':flèche_bientôt:',
        'ja': u':soon矢印:',
        'ko': u':곧:',
        'pt': ':seta_soon:',
        'it': ':freccia_soon:',
        'fa': u':پیکان_به_زودی:',
        'id': ':tanda_panah_soon:',
        'zh': u':SOON箭头:'
    },
    u'\U0001F198': { # 🆘
        'en' : ':SOS_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sos:'],
        'de': ':sos-zeichen:',
        'es': u':símbolo_de_socorro:',
        'fr': ':bouton_sos:',
        'ja': u':sosマーク:',
        'ko': u':에스오에스:',
        'pt': u':botão_sos:',
        'it': ':pulsante_sos:',
        'fa': u':دکمه_اس_او_اس:',
        'id': ':tombol_sos:',
        'zh': u':SOS按钮:'
    },
    u'\U00002650': { # ♐
        'en' : ':Sagittarius:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sagittarius:'],
        'variant': True,
        'de': u':schütze_(sternzeichen):',
        'es': ':sagitario:',
        'fr': ':sagittaire:',
        'ja': u':いて座:',
        'ko': u':사수자리:',
        'pt': u':signo_de_sagitário:',
        'it': ':segno_zodiacale_del_saggitario:',
        'fa': u':برج_قوس:',
        'id': ':sagitarius:',
        'zh': u':射手座:'
    },
    u'\U0001F1FC\U0001F1F8': { # 🇼🇸
        'en' : ':Samoa:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Samoa:', ':samoa:'],
        'de': ':flagge_samoa:',
        'es': ':bandera_samoa:',
        'fr': ':drapeau_samoa:',
        'ja': u':旗_サモア:',
        'ko': u':깃발_사모아:',
        'pt': ':bandeira_samoa:',
        'it': ':bandiera_samoa:',
        'fa': u':پرچم_ساموآ:',
        'id': ':bendera_samoa:',
        'zh': u':萨摩亚:'
    },
    u'\U0001F1F8\U0001F1F2': { # 🇸🇲
        'en' : ':San_Marino:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_San_Marino:', ':san_marino:'],
        'de': ':flagge_san_marino:',
        'es': ':bandera_san_marino:',
        'fr': ':drapeau_saint-marin:',
        'ja': u':旗_サンマリノ:',
        'ko': u':깃발_산마리노:',
        'pt': ':bandeira_san_marino:',
        'it': ':bandiera_san_marino:',
        'fa': u':پرچم_سان_مارینو:',
        'id': ':bendera_san_marino:',
        'zh': u':圣马力诺:'
    },
    u'\U0001F385': { # 🎅
        'en' : ':Santa_Claus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':santa:'],
        'de': ':weihnachtsmann:',
        'es': u':papá_noel:',
        'fr': u':père_noël:',
        'ja': u':サンタ:',
        'ko': u':산타클로스:',
        'pt': ':papai_noel:',
        'it': ':babbo_natale:',
        'fa': u':بابا_نوئل:',
        'id': ':sinterklas:',
        'zh': u':圣诞老人:'
    },
    u'\U0001F385\U0001F3FF': { # 🎅🏿
        'en' : ':Santa_Claus_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':weihnachtsmann_dunkle_hautfarbe:',
        'es': u':papá_noel_tono_de_piel_oscuro:',
        'fr': u':père_noël_peau_foncée:',
        'ja': u':サンタ_濃い肌色:',
        'ko': u':산타클로스_검은색_피부:',
        'pt': ':papai_noel_pele_escura:',
        'it': ':babbo_natale_carnagione_scura:',
        'fa': u':بابا_نوئل_پوست_آبنوسی:',
        'id': ':sinterklas_warna_kulit_gelap:',
        'zh': u':圣诞老人_较深肤色:'
    },
    u'\U0001F385\U0001F3FB': { # 🎅🏻
        'en' : ':Santa_Claus_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':weihnachtsmann_helle_hautfarbe:',
        'es': u':papá_noel_tono_de_piel_claro:',
        'fr': u':père_noël_peau_claire:',
        'ja': u':サンタ_薄い肌色:',
        'ko': u':산타클로스_하얀_피부:',
        'pt': ':papai_noel_pele_clara:',
        'it': ':babbo_natale_carnagione_chiara:',
        'fa': u':بابا_نوئل_پوست_سفید:',
        'id': ':sinterklas_warna_kulit_cerah:',
        'zh': u':圣诞老人_较浅肤色:'
    },
    u'\U0001F385\U0001F3FE': { # 🎅🏾
        'en' : ':Santa_Claus_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':weihnachtsmann_mitteldunkle_hautfarbe:',
        'es': u':papá_noel_tono_de_piel_oscuro_medio:',
        'fr': u':père_noël_peau_mate:',
        'ja': u':サンタ_やや濃い肌色:',
        'ko': u':산타클로스_진한_갈색_피부:',
        'pt': ':papai_noel_pele_morena_escura:',
        'it': ':babbo_natale_carnagione_abbastanza_scura:',
        'fa': u':بابا_نوئل_پوست_گندمی:',
        'id': ':sinterklas_warna_kulit_gelap-sedang:',
        'zh': u':圣诞老人_中等深肤色:'
    },
    u'\U0001F385\U0001F3FC': { # 🎅🏼
        'en' : ':Santa_Claus_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':weihnachtsmann_mittelhelle_hautfarbe:',
        'es': u':papá_noel_tono_de_piel_claro_medio:',
        'fr': u':père_noël_peau_moyennement_claire:',
        'ja': u':サンタ_やや薄い肌色:',
        'ko': u':산타클로스_연한_갈색_피부:',
        'pt': ':papai_noel_pele_morena_clara:',
        'it': ':babbo_natale_carnagione_abbastanza_chiara:',
        'fa': u':بابا_نوئل_پوست_روشن:',
        'id': ':sinterklas_warna_kulit_cerah-sedang:',
        'zh': u':圣诞老人_中等浅肤色:'
    },
    u'\U0001F385\U0001F3FD': { # 🎅🏽
        'en' : ':Santa_Claus_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':weihnachtsmann_mittlere_hautfarbe:',
        'es': u':papá_noel_tono_de_piel_medio:',
        'fr': u':père_noël_peau_légèrement_mate:',
        'ja': u':サンタ_中間の肌色:',
        'ko': u':산타클로스_갈색_피부:',
        'pt': ':papai_noel_pele_morena:',
        'it': ':babbo_natale_carnagione_olivastra:',
        'fa': u':بابا_نوئل_پوست_طلایی:',
        'id': ':sinterklas_warna_kulit_sedang:',
        'zh': u':圣诞老人_中等肤色:'
    },
    u'\U0001F1F8\U0001F1E6': { # 🇸🇦
        'en' : ':Saudi_Arabia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Saudi_Arabia:', ':saudi_arabia:'],
        'de': ':flagge_saudi-arabien:',
        'es': u':bandera_arabia_saudí:',
        'fr': ':drapeau_arabie_saoudite:',
        'ja': u':旗_サウジアラビア:',
        'ko': u':깃발_사우디아라비아:',
        'pt': u':bandeira_arábia_saudita:',
        'it': ':bandiera_arabia_saudita:',
        'fa': u':پرچم_عربستان_سعودی:',
        'id': ':bendera_arab_saudi:',
        'zh': u':沙特阿拉伯:'
    },
    u'\U0000264F': { # ♏
        'en' : ':Scorpio:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':scorpius:'],
        'variant': True,
        'de': ':skorpion_(sternzeichen):',
        'es': ':escorpio:',
        'fr': ':scorpion_zodiaque:',
        'ja': u':さそり座:',
        'ko': u':전갈자리:',
        'pt': u':signo_de_escorpião:',
        'it': ':segno_zodiacale_dello_scorpione:',
        'fa': u':برج_عقرب:',
        'id': ':scorpio:',
        'zh': u':天蝎座:'
    },
    u'\U0001F3F4\U000E0067\U000E0062\U000E0073\U000E0063\U000E0074\U000E007F': { # 🏴󠁧󠁢󠁳󠁣󠁴󠁿
        'en' : ':Scotland:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':scotland:'],
        'de': ':flagge_schottland:',
        'es': ':bandera_escocia:',
        'fr': u':drapeau_écosse:',
        'ja': u':旗_スコットランド:',
        'ko': u':깃발_스코틀랜드:',
        'pt': u':bandeira_escócia:',
        'it': ':bandiera_scozia:',
        'fa': u':پرچم_اسکاتلند:',
        'id': ':bendera_skotlandia:',
        'zh': u':苏格兰:'
    },
    u'\U0001F1F8\U0001F1F3': { # 🇸🇳
        'en' : ':Senegal:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Senegal:', ':senegal:'],
        'de': ':flagge_senegal:',
        'es': ':bandera_senegal:',
        'fr': u':drapeau_sénégal:',
        'ja': u':旗_セネガル:',
        'ko': u':깃발_세네갈:',
        'pt': ':bandeira_senegal:',
        'it': ':bandiera_senegal:',
        'fa': u':پرچم_سنگال:',
        'id': ':bendera_senegal:',
        'zh': u':塞内加尔:'
    },
    u'\U0001F1F7\U0001F1F8': { # 🇷🇸
        'en' : ':Serbia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Serbia:', ':serbia:'],
        'de': ':flagge_serbien:',
        'es': ':bandera_serbia:',
        'fr': ':drapeau_serbie:',
        'ja': u':旗_セルビア:',
        'ko': u':깃발_세르비아:',
        'pt': u':bandeira_sérvia:',
        'it': ':bandiera_serbia:',
        'fa': u':پرچم_صربستان:',
        'id': ':bendera_serbia:',
        'zh': u':塞尔维亚:'
    },
    u'\U0001F1F8\U0001F1E8': { # 🇸🇨
        'en' : ':Seychelles:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Seychelles:', ':seychelles:'],
        'de': ':flagge_seychellen:',
        'es': ':bandera_seychelles:',
        'fr': ':drapeau_seychelles:',
        'ja': u':旗_セーシェル:',
        'ko': u':깃발_세이셸:',
        'pt': ':bandeira_seicheles:',
        'it': ':bandiera_seychelles:',
        'fa': u':پرچم_سیشل:',
        'id': ':bendera_seychelles:',
        'zh': u':塞舌尔:'
    },
    u'\U0001F1F8\U0001F1F1': { # 🇸🇱
        'en' : ':Sierra_Leone:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Sierra_Leone:', ':sierra_leone:'],
        'de': ':flagge_sierra_leone:',
        'es': ':bandera_sierra_leona:',
        'fr': ':drapeau_sierra_leone:',
        'ja': u':旗_シエラレオネ:',
        'ko': u':깃발_시에라리온:',
        'pt': ':bandeira_serra_leoa:',
        'it': ':bandiera_sierra_leone:',
        'fa': u':پرچم_سیرالئون:',
        'id': ':bendera_sierra_leone:',
        'zh': u':塞拉利昂:'
    },
    u'\U0001F1F8\U0001F1EC': { # 🇸🇬
        'en' : ':Singapore:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Singapore:', ':singapore:'],
        'de': ':flagge_singapur:',
        'es': ':bandera_singapur:',
        'fr': ':drapeau_singapour:',
        'ja': u':旗_シンガポール:',
        'ko': u':깃발_싱가포르:',
        'pt': ':bandeira_singapura:',
        'it': ':bandiera_singapore:',
        'fa': u':پرچم_سنگاپور:',
        'id': ':bendera_singapura:',
        'zh': u':新加坡:'
    },
    u'\U0001F1F8\U0001F1FD': { # 🇸🇽
        'en' : ':Sint_Maarten:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Sint_Maarten:', ':sint_maarten:'],
        'de': ':flagge_sint_maarten:',
        'es': ':bandera_sint_maarten:',
        'fr': u':drapeau_saint-martin_(partie_néerlandaise):',
        'ja': u':旗_シント・マールテン:',
        'ko': u':깃발_신트마르턴:',
        'pt': ':bandeira_sint_maarten:',
        'it': ':bandiera_sint_maarten:',
        'fa': u':پرچم_سنت_مارتن:',
        'id': ':bendera_sint_maarten:',
        'zh': u':荷属圣马丁:'
    },
    u'\U0001F1F8\U0001F1F0': { # 🇸🇰
        'en' : ':Slovakia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Slovakia:', ':slovakia:'],
        'de': ':flagge_slowakei:',
        'es': ':bandera_eslovaquia:',
        'fr': ':drapeau_slovaquie:',
        'ja': u':旗_スロバキア:',
        'ko': u':깃발_슬로바키아:',
        'pt': u':bandeira_eslováquia:',
        'it': ':bandiera_slovacchia:',
        'fa': u':پرچم_اسلواکی:',
        'id': ':bendera_slovakia:',
        'zh': u':斯洛伐克:'
    },
    u'\U0001F1F8\U0001F1EE': { # 🇸🇮
        'en' : ':Slovenia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Slovenia:', ':slovenia:'],
        'de': ':flagge_slowenien:',
        'es': ':bandera_eslovenia:',
        'fr': u':drapeau_slovénie:',
        'ja': u':旗_スロベニア:',
        'ko': u':깃발_슬로베니아:',
        'pt': u':bandeira_eslovênia:',
        'it': ':bandiera_slovenia:',
        'fa': u':پرچم_اسلوونی:',
        'id': ':bendera_slovenia:',
        'zh': u':斯洛文尼亚:'
    },
    u'\U0001F1F8\U0001F1E7': { # 🇸🇧
        'en' : ':Solomon_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Solomon_Islands:', ':solomon_islands:'],
        'de': ':flagge_salomonen:',
        'es': u':bandera_islas_salomón:',
        'fr': u':drapeau_îles_salomon:',
        'ja': u':旗_ソロモン諸島:',
        'ko': u':깃발_솔로몬_제도:',
        'pt': u':bandeira_ilhas_salomão:',
        'it': ':bandiera_isole_salomone:',
        'fa': u':پرچم_جزایر_سلیمان:',
        'id': ':bendera_kepulauan_solomon:',
        'zh': u':所罗门群岛:'
    },
    u'\U0001F1F8\U0001F1F4': { # 🇸🇴
        'en' : ':Somalia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Somalia:', ':somalia:'],
        'de': ':flagge_somalia:',
        'es': ':bandera_somalia:',
        'fr': ':drapeau_somalie:',
        'ja': u':旗_ソマリア:',
        'ko': u':깃발_소말리아:',
        'pt': u':bandeira_somália:',
        'it': ':bandiera_somalia:',
        'fa': u':پرچم_سومالی:',
        'id': ':bendera_somalia:',
        'zh': u':索马里:'
    },
    u'\U0001F1FF\U0001F1E6': { # 🇿🇦
        'en' : ':South_Africa:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_South_Africa:', ':south_africa:'],
        'de': u':flagge_südafrika:',
        'es': u':bandera_sudáfrica:',
        'fr': ':drapeau_afrique_du_sud:',
        'ja': u':旗_南アフリカ:',
        'ko': u':깃발_남아프리카:',
        'pt': u':bandeira_áfrica_do_sul:',
        'it': ':bandiera_sudafrica:',
        'fa': u':پرچم_افریقای_جنوبی:',
        'id': ':bendera_afrika_selatan:',
        'zh': u':南非:'
    },
    u'\U0001F1EC\U0001F1F8': { # 🇬🇸
        'en' : ':South_Georgia_&_South_Sandwich_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_South_Georgia_&_South_Sandwich_Islands:', ':south_georgia_south_sandwich_islands:'],
        'de': u':flagge_südgeorgien_und_die_südlichen_sandwichinseln:',
        'es': ':bandera_islas_georgia_del_sur_y_sandwich_del_sur:',
        'fr': u':drapeau_géorgie_du_sud_et_îles_sandwich_du_sud:',
        'ja': u':旗_サウスジョージア・サウスサンドウィッチ諸島:',
        'ko': u':깃발_사우스조지아_사우스샌드위치_제도:',
        'pt': u':bandeira_ilhas_geórgia_do_sul_e_sandwich_do_sul:',
        'it': ':bandiera_georgia_del_sud_e_sandwich_australi:',
        'fa': u':پرچم_جورجیای_جنوبی_و_جزایر_ساندویچ_جنوبی:',
        'id': ':bendera_georgia_selatan_&_kep._sandwich_selatan:',
        'zh': u':南乔治亚和南桑威奇群岛:'
    },
    u'\U0001F1F0\U0001F1F7': { # 🇰🇷
        'en' : ':South_Korea:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_South_Korea:', ':kr:'],
        'de': u':flagge_südkorea:',
        'es': ':bandera_corea_del_sur:',
        'fr': u':drapeau_corée_du_sud:',
        'ja': u':旗_韓国:',
        'ko': u':깃발_대한민국:',
        'pt': ':bandeira_coreia_do_sul:',
        'it': ':bandiera_corea_del_sud:',
        'fa': u':پرچم_کرهٔ_جنوبی:',
        'id': ':bendera_korea_selatan:',
        'zh': u':韩国:'
    },
    u'\U0001F1F8\U0001F1F8': { # 🇸🇸
        'en' : ':South_Sudan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_South_Sudan:', ':south_sudan:'],
        'de': u':flagge_südsudan:',
        'es': u':bandera_sudán_del_sur:',
        'fr': ':drapeau_soudan_du_sud:',
        'ja': u':旗_南スーダン:',
        'ko': u':깃발_남수단:',
        'pt': u':bandeira_sudão_do_sul:',
        'it': ':bandiera_sud_sudan:',
        'fa': u':پرچم_سودان_جنوبی:',
        'id': ':bendera_sudan_selatan:',
        'zh': u':南苏丹:'
    },
    u'\U0001F1EA\U0001F1F8': { # 🇪🇸
        'en' : ':Spain:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_Spain:', ':es:'],
        'de': ':flagge_spanien:',
        'es': u':bandera_españa:',
        'fr': ':drapeau_espagne:',
        'ja': u':旗_スペイン:',
        'ko': u':깃발_스페인:',
        'pt': ':bandeira_espanha:',
        'it': ':bandiera_spagna:',
        'fa': u':پرچم_اسپانیا:',
        'id': ':bendera_spanyol:',
        'zh': u':西班牙:'
    },
    u'\U0001F1F1\U0001F1F0': { # 🇱🇰
        'en' : ':Sri_Lanka:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Sri_Lanka:', ':sri_lanka:'],
        'de': ':flagge_sri_lanka:',
        'es': ':bandera_sri_lanka:',
        'fr': ':drapeau_sri_lanka:',
        'ja': u':旗_スリランカ:',
        'ko': u':깃발_스리랑카:',
        'pt': ':bandeira_sri_lanka:',
        'it': ':bandiera_sri_lanka:',
        'fa': u':پرچم_سری_لانکا:',
        'id': ':bendera_sri_lanka:',
        'zh': u':斯里兰卡:'
    },
    u'\U0001F1E7\U0001F1F1': { # 🇧🇱
        'en' : u':St._Barthélemy:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [u':flag_for_St._Barthélemy:', ':st_barthelemy:'],
        'de': u':flagge_st._barthélemy:',
        'es': u':bandera_san_bartolomé:',
        'fr': u':drapeau_saint-barthélemy:',
        'ja': u':旗_サン・バルテルミー:',
        'ko': u':깃발_생바르텔레미:',
        'pt': u':bandeira_são_bartolomeu:',
        'it': u':bandiera_saint-barthélemy:',
        'fa': u':پرچم_سن_بارتلمی:',
        'id': u':bendera_saint_barthélemy:',
        'zh': u':圣巴泰勒米:'
    },
    u'\U0001F1F8\U0001F1ED': { # 🇸🇭
        'en' : ':St._Helena:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_St._Helena:', ':st_helena:'],
        'de': ':flagge_st._helena:',
        'es': ':bandera_santa_elena:',
        'fr': u':drapeau_sainte-hélène:',
        'ja': u':旗_セントヘレナ:',
        'ko': u':깃발_세인트헬레나:',
        'pt': ':bandeira_santa_helena:',
        'it': u':bandiera_sant’elena:',
        'fa': u':پرچم_سنت_هلن:',
        'id': ':bendera_saint_helena:',
        'zh': u':圣赫勒拿:'
    },
    u'\U0001F1F0\U0001F1F3': { # 🇰🇳
        'en' : ':St._Kitts_&_Nevis:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_St._Kitts_&_Nevis:', ':st_kitts_nevis:'],
        'de': ':flagge_st._kitts_und_nevis:',
        'es': u':bandera_san_cristóbal_y_nieves:',
        'fr': u':drapeau_saint-christophe-et-niévès:',
        'ja': u':旗_セントクリストファー・ネーヴィス:',
        'ko': u':깃발_세인트키츠_네비스:',
        'pt': u':bandeira_são_cristóvão_e_névis:',
        'it': ':bandiera_saint_kitts_e_nevis:',
        'fa': u':پرچم_سنت_کیتس_و_نویس:',
        'id': ':bendera_saint_kitts_dan_nevis:',
        'zh': u':圣基茨和尼维斯:'
    },
    u'\U0001F1F1\U0001F1E8': { # 🇱🇨
        'en' : ':St._Lucia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_St._Lucia:', ':st_lucia:'],
        'de': ':flagge_st._lucia:',
        'es': u':bandera_santa_lucía:',
        'fr': ':drapeau_sainte-lucie:',
        'ja': u':旗_セントルシア:',
        'ko': u':깃발_세인트루시아:',
        'pt': u':bandeira_santa_lúcia:',
        'it': ':bandiera_saint_lucia:',
        'fa': u':پرچم_سنت_لوسیا:',
        'id': ':bendera_saint_lucia:',
        'zh': u':圣卢西亚:'
    },
    u'\U0001F1F2\U0001F1EB': { # 🇲🇫
        'en' : ':St._Martin:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_St._Martin:', ':st_martin:'],
        'de': ':flagge_st._martin:',
        'es': u':bandera_san_martín:',
        'fr': ':drapeau_saint-martin:',
        'ja': u':旗_サン・マルタン:',
        'ko': u':깃발_생마르탱:',
        'pt': u':bandeira_são_martinho:',
        'it': ':bandiera_saint_martin:',
        'fa': u':پرچم_سنت_مارتین:',
        'id': ':bendera_saint_martin:',
        'zh': u':法属圣马丁:'
    },
    u'\U0001F1F5\U0001F1F2': { # 🇵🇲
        'en' : ':St._Pierre_&_Miquelon:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_St._Pierre_&_Miquelon:', ':st_pierre_miquelon:'],
        'de': ':flagge_st._pierre_und_miquelon:',
        'es': u':bandera_san_pedro_y_miquelón:',
        'fr': ':drapeau_saint-pierre-et-miquelon:',
        'ja': u':旗_サンピエール島・ミクロン島:',
        'ko': u':깃발_생피에르_미클롱:',
        'pt': u':bandeira_são_pedro_e_miquelão:',
        'it': ':bandiera_saint-pierre_e_miquelon:',
        'fa': u':پرچم_سن_پیر_و_میکلن:',
        'id': ':bendera_saint_pierre_dan_miquelon:',
        'zh': u':圣皮埃尔和密克隆群岛:'
    },
    u'\U0001F1FB\U0001F1E8': { # 🇻🇨
        'en' : ':St._Vincent_&_Grenadines:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_St._Vincent_&_Grenadines:', ':st_vincent_grenadines:'],
        'de': ':flagge_st._vincent_und_die_grenadinen:',
        'es': ':bandera_san_vicente_y_las_granadinas:',
        'fr': ':drapeau_saint-vincent-et-les-grenadines:',
        'ja': u':旗_セントビンセント及びグレナディーン諸島:',
        'ko': u':깃발_세인트빈센트그레나딘:',
        'pt': u':bandeira_são_vicente_e_granadinas:',
        'it': ':bandiera_saint_vincent_e_grenadine:',
        'fa': u':پرچم_سنت_وینسنت_و_گرنادین:',
        'id': ':bendera_saint_vincent_dan_grenadine:',
        'zh': u':圣文森特和格林纳丁斯:'
    },
    u'\U0001F5FD': { # 🗽
        'en' : ':Statue_of_Liberty:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':statue_of_liberty:'],
        'de': ':freiheitsstatue:',
        'es': ':estatua_de_la_libertad:',
        'fr': u':statue_de_la_liberté:',
        'ja': u':自由の女神:',
        'ko': u':자유의_여신상:',
        'pt': u':estátua_da_liberdade:',
        'it': u':statua_della_libertà:',
        'fa': u':مجسمهٔ_آزادی:',
        'id': ':patung_liberty:',
        'zh': u':自由女神像:'
    },
    u'\U0001F1F8\U0001F1E9': { # 🇸🇩
        'en' : ':Sudan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Sudan:', ':sudan:'],
        'de': ':flagge_sudan:',
        'es': u':bandera_sudán:',
        'fr': ':drapeau_soudan:',
        'ja': u':旗_スーダン:',
        'ko': u':깃발_수단:',
        'pt': u':bandeira_sudão:',
        'it': ':bandiera_sudan:',
        'fa': u':پرچم_سودان:',
        'id': ':bendera_sudan:',
        'zh': u':苏丹:'
    },
    u'\U0001F1F8\U0001F1F7': { # 🇸🇷
        'en' : ':Suriname:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Suriname:', ':suriname:'],
        'de': ':flagge_suriname:',
        'es': ':bandera_surinam:',
        'fr': ':drapeau_suriname:',
        'ja': u':旗_スリナム:',
        'ko': u':깃발_수리남:',
        'pt': ':bandeira_suriname:',
        'it': ':bandiera_suriname:',
        'fa': u':پرچم_سورینام:',
        'id': ':bendera_suriname:',
        'zh': u':苏里南:'
    },
    u'\U0001F1F8\U0001F1EF': { # 🇸🇯
        'en' : ':Svalbard_&_Jan_Mayen:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Svalbard_&_Jan_Mayen:', ':svalbard_jan_mayen:'],
        'de': ':flagge_spitzbergen_und_jan_mayen:',
        'es': ':bandera_svalbard_y_jan_mayen:',
        'fr': ':drapeau_svalbard_et_jan_mayen:',
        'ja': u':旗_スバールバル諸島・ヤンマイエン島:',
        'ko': u':깃발_스발바르제도-얀마웬섬:',
        'pt': ':bandeira_svalbard_e_jan_mayen:',
        'it': ':bandiera_svalbard_e_jan_mayen:',
        'fa': u':پرچم_سوالبارد_و_یان_ماین:',
        'id': ':bendera_kepulauan_svalbard_dan_jan_mayen:',
        'zh': u':斯瓦尔巴和扬马延:'
    },
    u'\U0001F1F8\U0001F1EA': { # 🇸🇪
        'en' : ':Sweden:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Sweden:', ':sweden:'],
        'de': ':flagge_schweden:',
        'es': ':bandera_suecia:',
        'fr': u':drapeau_suède:',
        'ja': u':旗_スウェーデン:',
        'ko': u':깃발_스웨덴:',
        'pt': u':bandeira_suécia:',
        'it': ':bandiera_svezia:',
        'fa': u':پرچم_سوئد:',
        'id': ':bendera_swedia:',
        'zh': u':瑞典:'
    },
    u'\U0001F1E8\U0001F1ED': { # 🇨🇭
        'en' : ':Switzerland:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Switzerland:', ':switzerland:'],
        'de': ':flagge_schweiz:',
        'es': ':bandera_suiza:',
        'fr': ':drapeau_suisse:',
        'ja': u':旗_スイス:',
        'ko': u':깃발_스위스:',
        'pt': u':bandeira_suíça:',
        'it': ':bandiera_svizzera:',
        'fa': u':پرچم_سوئیس:',
        'id': ':bendera_swiss:',
        'zh': u':瑞士:'
    },
    u'\U0001F1F8\U0001F1FE': { # 🇸🇾
        'en' : ':Syria:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Syria:', ':syria:'],
        'de': ':flagge_syrien:',
        'es': ':bandera_siria:',
        'fr': ':drapeau_syrie:',
        'ja': u':旗_シリア:',
        'ko': u':깃발_시리아:',
        'pt': u':bandeira_síria:',
        'it': ':bandiera_siria:',
        'fa': u':پرچم_سوریه:',
        'id': ':bendera_suriah:',
        'zh': u':叙利亚:'
    },
    u'\U0001F1F8\U0001F1F9': { # 🇸🇹
        'en' : u':São_Tomé_&_Príncipe:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [u':flag_for_São_Tomé_&_Príncipe:', ':sao_tome_principe:'],
        'de': u':flagge_são_tomé_und_príncipe:',
        'es': u':bandera_santo_tomé_y_príncipe:',
        'fr': u':drapeau_sao_tomé-et-principe:',
        'ja': u':旗_サントメ・プリンシペ:',
        'ko': u':깃발_상투메_프린시페:',
        'pt': u':bandeira_são_tomé_e_príncipe:',
        'it': u':bandiera_são_tomé_e_príncipe:',
        'fa': u':پرچم_سائوتومه_و_پرینسیپ:',
        'id': ':bendera_sao_tome_dan_principe:',
        'zh': u':圣多美和普林西比:'
    },
    u'\U0001F996': { # 🦖
        'en' : ':T-Rex:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':t-rex:'],
        'de': ':t-rex:',
        'es': ':t-rex:',
        'fr': ':t-rex:',
        'ja': u':ティラノサウルス:',
        'ko': u':티라노사우루스:',
        'pt': ':tiranossauro_rex:',
        'it': ':t-rex:',
        'fa': u':تی_رکس:',
        'id': ':t-rex:',
        'zh': u':霸王龙:'
    },
    u'\U0001F51D': { # 🔝
        'en' : ':TOP_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':top:'],
        'de': ':top-pfeil:',
        'es': ':flecha_top:',
        'fr': u':flèche_en_haut:',
        'ja': u':top矢印:',
        'ko': u':위로_화살표:',
        'pt': ':seta_top:',
        'it': ':freccia_top:',
        'fa': u':پیکان_رو:',
        'id': ':tanda_panah_top:',
        'zh': u':置顶:'
    },
    u'\U0001F1F9\U0001F1FC': { # 🇹🇼
        'en' : ':Taiwan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Taiwan:', ':taiwan:'],
        'de': ':flagge_taiwan:',
        'es': u':bandera_taiwán:',
        'fr': u':drapeau_taïwan:',
        'ja': u':旗_台湾:',
        'ko': u':깃발_대만:',
        'pt': ':bandeira_taiwan:',
        'it': ':bandiera_taiwan:',
        'fa': u':پرچم_تایوان:',
        'id': ':bendera_taiwan:',
        'zh': u':台湾:'
    },
    u'\U0001F1F9\U0001F1EF': { # 🇹🇯
        'en' : ':Tajikistan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Tajikistan:', ':tajikistan:'],
        'de': ':flagge_tadschikistan:',
        'es': u':bandera_tayikistán:',
        'fr': ':drapeau_tadjikistan:',
        'ja': u':旗_タジキスタン:',
        'ko': u':깃발_타지키스탄:',
        'pt': u':bandeira_tadjiquistão:',
        'it': ':bandiera_tagikistan:',
        'fa': u':پرچم_تاجیکستان:',
        'id': ':bendera_tajikistan:',
        'zh': u':塔吉克斯坦:'
    },
    u'\U0001F1F9\U0001F1FF': { # 🇹🇿
        'en' : ':Tanzania:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Tanzania:', ':tanzania:'],
        'de': ':flagge_tansania:',
        'es': ':bandera_tanzania:',
        'fr': ':drapeau_tanzanie:',
        'ja': u':旗_タンザニア:',
        'ko': u':깃발_탄자니아:',
        'pt': u':bandeira_tanzânia:',
        'it': ':bandiera_tanzania:',
        'fa': u':پرچم_تانزانیا:',
        'id': ':bendera_tanzania:',
        'zh': u':坦桑尼亚:'
    },
    u'\U00002649': { # ♉
        'en' : ':Taurus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':taurus:'],
        'variant': True,
        'de': ':stier_(sternzeichen):',
        'es': ':tauro:',
        'fr': ':taureau:',
        'ja': u':おうし座:',
        'ko': u':황소자리:',
        'pt': ':signo_de_touro:',
        'it': ':segno_zodiacale_del_toro:',
        'fa': u':برج_ثور:',
        'id': ':taurus:',
        'zh': u':金牛座:'
    },
    u'\U0001F1F9\U0001F1ED': { # 🇹🇭
        'en' : ':Thailand:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Thailand:', ':thailand:'],
        'de': ':flagge_thailand:',
        'es': ':bandera_tailandia:',
        'fr': u':drapeau_thaïlande:',
        'ja': u':旗_タイ:',
        'ko': u':깃발_태국:',
        'pt': u':bandeira_tailândia:',
        'it': ':bandiera_thailandia:',
        'fa': u':پرچم_تایلند:',
        'id': ':bendera_thailand:',
        'zh': u':泰国:'
    },
    u'\U0001F1F9\U0001F1F1': { # 🇹🇱
        'en' : ':Timor-Leste:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Timor__Leste:', ':timor_leste:'],
        'de': ':flagge_timor-leste:',
        'es': ':bandera_timor-leste:',
        'fr': ':drapeau_timor_oriental:',
        'ja': u':旗_東ティモール:',
        'ko': u':깃발_동티모르:',
        'pt': ':bandeira_timor-leste:',
        'it': ':bandiera_timor_est:',
        'fa': u':پرچم_تیمور-لسته:',
        'id': ':bendera_timor_leste:',
        'zh': u':东帝汶:'
    },
    u'\U0001F1F9\U0001F1EC': { # 🇹🇬
        'en' : ':Togo:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Togo:', ':togo:'],
        'de': ':flagge_togo:',
        'es': ':bandera_togo:',
        'fr': ':drapeau_togo:',
        'ja': u':旗_トーゴ:',
        'ko': u':깃발_토고:',
        'pt': ':bandeira_togo:',
        'it': ':bandiera_togo:',
        'fa': u':پرچم_توگو:',
        'id': ':bendera_togo:',
        'zh': u':多哥:'
    },
    u'\U0001F1F9\U0001F1F0': { # 🇹🇰
        'en' : ':Tokelau:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Tokelau:', ':tokelau:'],
        'de': ':flagge_tokelau:',
        'es': ':bandera_tokelau:',
        'fr': ':drapeau_tokelau:',
        'ja': u':旗_トケラウ:',
        'ko': u':깃발_토켈라우:',
        'pt': ':bandeira_tokelau:',
        'it': ':bandiera_tokelau:',
        'fa': u':پرچم_توکلائو:',
        'id': ':bendera_tokelau:',
        'zh': u':托克劳:'
    },
    u'\U0001F5FC': { # 🗼
        'en' : ':Tokyo_tower:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tokyo_tower:'],
        'de': ':tokyo_tower:',
        'es': ':torre_de_tokio:',
        'fr': ':tour_de_tokyo:',
        'ja': u':東京タワー:',
        'ko': u':도쿄_타워:',
        'pt': u':torre_de_tóquio:',
        'it': ':torre_di_tokyo:',
        'fa': u':برج_توکیو:',
        'id': ':menara_tokyo:',
        'zh': u':东京塔:'
    },
    u'\U0001F1F9\U0001F1F4': { # 🇹🇴
        'en' : ':Tonga:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Tonga:', ':tonga:'],
        'de': ':flagge_tonga:',
        'es': ':bandera_tonga:',
        'fr': ':drapeau_tonga:',
        'ja': u':旗_トンガ:',
        'ko': u':깃발_통가:',
        'pt': ':bandeira_tonga:',
        'it': ':bandiera_tonga:',
        'fa': u':پرچم_تونگا:',
        'id': ':bendera_tonga:',
        'zh': u':汤加:'
    },
    u'\U0001F1F9\U0001F1F9': { # 🇹🇹
        'en' : ':Trinidad_&_Tobago:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Trinidad_&_Tobago:', ':trinidad_tobago:'],
        'de': ':flagge_trinidad_und_tobago:',
        'es': ':bandera_trinidad_y_tobago:',
        'fr': u':drapeau_trinité-et-tobago:',
        'ja': u':旗_トリニダード・トバゴ:',
        'ko': u':깃발_트리니다드_토바고:',
        'pt': ':bandeira_trinidad_e_tobago:',
        'it': ':bandiera_trinidad_e_tobago:',
        'fa': u':پرچم_ترینیداد_و_توباگو:',
        'id': ':bendera_trinidad_dan_tobago:',
        'zh': u':特立尼达和多巴哥:'
    },
    u'\U0001F1F9\U0001F1E6': { # 🇹🇦
        'en' : ':Tristan_da_Cunha:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Tristan_da_Cunha:', ':tristan_da_cunha:'],
        'de': ':flagge_tristan_da_cunha:',
        'es': u':bandera_tristán_de_acuña:',
        'fr': ':drapeau_tristan_da_cunha:',
        'ja': u':旗_トリスタン・ダ・クーニャ:',
        'ko': u':깃발_트리스탄다쿠나:',
        'pt': u':bandeira_tristão_da_cunha:',
        'it': ':bandiera_tristan_da_cunha:',
        'fa': u':پرچم_تریستان_دا_کونا:',
        'id': ':bendera_tristan_da_cunha:',
        'zh': u':特里斯坦达库尼亚群岛:'
    },
    u'\U0001F1F9\U0001F1F3': { # 🇹🇳
        'en' : ':Tunisia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Tunisia:', ':tunisia:'],
        'de': ':flagge_tunesien:',
        'es': u':bandera_túnez:',
        'fr': ':drapeau_tunisie:',
        'ja': u':旗_チュニジア:',
        'ko': u':깃발_튀니지:',
        'pt': u':bandeira_tunísia:',
        'it': ':bandiera_tunisia:',
        'fa': u':پرچم_تونس:',
        'id': ':bendera_tunisia:',
        'zh': u':突尼斯:'
    },
    u'\U0001F1F9\U0001F1F7': { # 🇹🇷
        'en' : ':Turkey:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Turkey:', ':tr:'],
        'de': u':flagge_türkei:',
        'es': u':bandera_turquía:',
        'fr': ':drapeau_turquie:',
        'ja': u':旗_トルコ:',
        'ko': u':깃발_터키:',
        'pt': ':bandeira_turquia:',
        'it': ':bandiera_turchia:',
        'fa': u':پرچم_ترکیه:',
        'id': ':bendera_turki:',
        'zh': u':土耳其:'
    },
    u'\U0001F1F9\U0001F1F2': { # 🇹🇲
        'en' : ':Turkmenistan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Turkmenistan:', ':turkmenistan:'],
        'de': ':flagge_turkmenistan:',
        'es': u':bandera_turkmenistán:',
        'fr': u':drapeau_turkménistan:',
        'ja': u':旗_トルクメニスタン:',
        'ko': u':깃발_투르크메니스탄:',
        'pt': u':bandeira_turcomenistão:',
        'it': ':bandiera_turkmenistan:',
        'fa': u':پرچم_ترکمنستان:',
        'id': ':bendera_turkmenistan:',
        'zh': u':土库曼斯坦:'
    },
    u'\U0001F1F9\U0001F1E8': { # 🇹🇨
        'en' : ':Turks_&_Caicos_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Turks_&_Caicos_Islands:', ':turks_caicos_islands:'],
        'de': ':flagge_turks-_und_caicosinseln:',
        'es': ':bandera_islas_turcas_y_caicos:',
        'fr': u':drapeau_îles_turques-et-caïques:',
        'ja': u':旗_タークス・カイコス諸島:',
        'ko': u':깃발_터크스_케이커스_제도:',
        'pt': ':bandeira_ilhas_turcas_e_caicos:',
        'it': ':bandiera_isole_turks_e_caicos:',
        'fa': u':پرچم_جزایر_تورکس_و_کایکوس:',
        'id': ':bendera_kepulauan_turks_dan_caicos:',
        'zh': u':特克斯和凯科斯群岛:'
    },
    u'\U0001F1F9\U0001F1FB': { # 🇹🇻
        'en' : ':Tuvalu:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Tuvalu:', ':tuvalu:'],
        'de': ':flagge_tuvalu:',
        'es': ':bandera_tuvalu:',
        'fr': ':drapeau_tuvalu:',
        'ja': u':旗_ツバル:',
        'ko': u':깃발_투발루:',
        'pt': ':bandeira_tuvalu:',
        'it': ':bandiera_tuvalu:',
        'fa': u':پرچم_تووالو:',
        'id': ':bendera_tuvalu:',
        'zh': u':图瓦卢:'
    },
    u'\U0001F1FA\U0001F1F2': { # 🇺🇲
        'en' : ':U.S._Outlying_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_U.S._Outlying_Islands:', ':us_outlying_islands:'],
        'de': u':flagge_amerikanische_überseeinseln:',
        'es': ':bandera_islas_menores_alejadas_de_ee._uu.:',
        'fr': u':drapeau_îles_mineures_éloignées_des_états-unis:',
        'ja': u':旗_合衆国領有小離島:',
        'ko': u':깃발_미국령_해외_제도:',
        'pt': ':bandeira_ilhas_menores_distantes_dos_eua:',
        'it': ':bandiera_altre_isole_americane_del_pacifico:',
        'fa': u':پرچم_جزایر_دورافتادهٔ_ایالات_متحده:',
        'id': ':bendera_kepulauan_terluar_as:',
        'zh': u':美国本土外小岛屿:'
    },
    u'\U0001F1FB\U0001F1EE': { # 🇻🇮
        'en' : ':U.S._Virgin_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_U.S._Virgin_Islands:', ':us_virgin_islands:'],
        'de': ':flagge_amerikanische_jungferninseln:',
        'es': u':bandera_islas_vírgenes_de_ee._uu.:',
        'fr': u':drapeau_îles_vierges_des_états-unis:',
        'ja': u':旗_米領ヴァージン諸島:',
        'ko': u':깃발_미국령_버진아일랜드:',
        'pt': ':bandeira_ilhas_virgens_americanas:',
        'it': ':bandiera_isole_vergini_americane:',
        'fa': u':پرچم_جزایر_ویرجین_ایالات_متحده:',
        'id': ':bendera_kepulauan_virgin_amerika_serikat:',
        'zh': u':美属维尔京群岛:'
    },
    u'\U0001F199': { # 🆙
        'en' : ':UP!_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':up:'],
        'de': ':schriftzug_up!_im_blauen_quadrat:',
        'es': u':botón_up!:',
        'fr': ':bouton_vers_le_haut:',
        'ja': u':upマーク:',
        'ko': u':위로_버튼:',
        'pt': u':botão_up!:',
        'it': ':pulsante_up!:',
        'fa': u':دکمهٔ_!up:',
        'id': ':tombol_up!:',
        'zh': u':up按钮:'
    },
    u'\U0001F1FA\U0001F1EC': { # 🇺🇬
        'en' : ':Uganda:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Uganda:', ':uganda:'],
        'de': ':flagge_uganda:',
        'es': ':bandera_uganda:',
        'fr': ':drapeau_ouganda:',
        'ja': u':旗_ウガンダ:',
        'ko': u':깃발_우간다:',
        'pt': ':bandeira_uganda:',
        'it': ':bandiera_uganda:',
        'fa': u':پرچم_اوگاندا:',
        'id': ':bendera_uganda:',
        'zh': u':乌干达:'
    },
    u'\U0001F1FA\U0001F1E6': { # 🇺🇦
        'en' : ':Ukraine:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Ukraine:', ':ukraine:'],
        'de': ':flagge_ukraine:',
        'es': ':bandera_ucrania:',
        'fr': ':drapeau_ukraine:',
        'ja': u':旗_ウクライナ:',
        'ko': u':깃발_우크라이나:',
        'pt': u':bandeira_ucrânia:',
        'it': ':bandiera_ucraina:',
        'fa': u':پرچم_اوکراین:',
        'id': ':bendera_ukraina:',
        'zh': u':乌克兰:'
    },
    u'\U0001F1E6\U0001F1EA': { # 🇦🇪
        'en' : ':United_Arab_Emirates:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_United_Arab_Emirates:', ':united_arab_emirates:'],
        'de': ':flagge_vereinigte_arabische_emirate:',
        'es': u':bandera_emiratos_árabes_unidos:',
        'fr': u':drapeau_émirats_arabes_unis:',
        'ja': u':旗_アラブ首長国連邦:',
        'ko': u':깃발_아랍에미리트:',
        'pt': u':bandeira_emirados_árabes_unidos:',
        'it': ':bandiera_emirati_arabi_uniti:',
        'fa': u':پرچم_امارات_متحدهٔ_عربی:',
        'id': ':bendera_uni_emirat_arab:',
        'zh': u':阿拉伯联合酋长国:'
    },
    u'\U0001F1EC\U0001F1E7': { # 🇬🇧
        'en' : ':United_Kingdom:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_United_Kingdom:', ':gb:', ':uk:'],
        'de': u':flagge_vereinigtes_königreich:',
        'es': ':bandera_reino_unido:',
        'fr': ':drapeau_royaume-uni:',
        'ja': u':旗_イギリス:',
        'ko': u':깃발_영국:',
        'pt': ':bandeira_reino_unido:',
        'it': ':bandiera_regno_unito:',
        'fa': u':پرچم_بریتانیا:',
        'id': ':bendera_inggris_raya:',
        'zh': u':英国:'
    },
    u'\U0001F1FA\U0001F1F3': { # 🇺🇳
        'en' : ':United_Nations:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':united_nations:'],
        'de': ':flagge_vereinte_nationen:',
        'es': ':bandera_naciones_unidas:',
        'fr': ':drapeau_nations_unies:',
        'ja': u':旗_国際連合:',
        'ko': u':깃발_국제연합:',
        'pt': u':bandeira_nações_unidas:',
        'it': ':bandiera_nazioni_unite:',
        'fa': u':پرچم_سازمان_ملل_متحد:',
        'id': ':bendera_perserikatan_bangsa-bangsa:',
        'zh': u':联合国:'
    },
    u'\U0001F1FA\U0001F1F8': { # 🇺🇸
        'en' : ':United_States:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flag_for_United_States:', ':us:'],
        'de': ':flagge_vereinigte_staaten:',
        'es': ':bandera_estados_unidos:',
        'fr': u':drapeau_états-unis:',
        'ja': u':旗_アメリカ合衆国:',
        'ko': u':깃발_미국:',
        'pt': ':bandeira_estados_unidos:',
        'it': ':bandiera_stati_uniti:',
        'fa': u':پرچم_ایالات_متحده:',
        'id': ':bendera_amerika_serikat:',
        'zh': u':美国:'
    },
    u'\U0001F1FA\U0001F1FE': { # 🇺🇾
        'en' : ':Uruguay:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Uruguay:', ':uruguay:'],
        'de': ':flagge_uruguay:',
        'es': ':bandera_uruguay:',
        'fr': ':drapeau_uruguay:',
        'ja': u':旗_ウルグアイ:',
        'ko': u':깃발_우루과이:',
        'pt': ':bandeira_uruguai:',
        'it': ':bandiera_uruguay:',
        'fa': u':پرچم_اروگوئه:',
        'id': ':bendera_uruguay:',
        'zh': u':乌拉圭:'
    },
    u'\U0001F1FA\U0001F1FF': { # 🇺🇿
        'en' : ':Uzbekistan:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Uzbekistan:', ':uzbekistan:'],
        'de': ':flagge_usbekistan:',
        'es': u':bandera_uzbekistán:',
        'fr': u':drapeau_ouzbékistan:',
        'ja': u':旗_ウズベキスタン:',
        'ko': u':깃발_우즈베키스탄:',
        'pt': u':bandeira_uzbequistão:',
        'it': ':bandiera_uzbekistan:',
        'fa': u':پرچم_ازبکستان:',
        'id': ':bendera_uzbekistan:',
        'zh': u':乌兹别克斯坦:'
    },
    u'\U0001F19A': { # 🆚
        'en' : ':VS_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':vs:'],
        'de': ':schriftzug_vs_in_orangem_quadrat:',
        'es': u':botón_vs:',
        'fr': ':bouton_vs:',
        'ja': u':vsマーク:',
        'ko': u':대:',
        'pt': u':botão_vs:',
        'it': ':pulsante_vs:',
        'fa': u':دکمهٔ_vs:',
        'id': ':tombol_vs:',
        'zh': u':VS按钮:'
    },
    u'\U0001F1FB\U0001F1FA': { # 🇻🇺
        'en' : ':Vanuatu:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Vanuatu:', ':vanuatu:'],
        'de': ':flagge_vanuatu:',
        'es': ':bandera_vanuatu:',
        'fr': ':drapeau_vanuatu:',
        'ja': u':旗_バヌアツ:',
        'ko': u':깃발_바누아투:',
        'pt': ':bandeira_vanuatu:',
        'it': ':bandiera_vanuatu:',
        'fa': u':پرچم_وانواتو:',
        'id': ':bendera_vanuatu:',
        'zh': u':瓦努阿图:'
    },
    u'\U0001F1FB\U0001F1E6': { # 🇻🇦
        'en' : ':Vatican_City:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Vatican_City:', ':vatican_city:'],
        'de': ':flagge_vatikanstadt:',
        'es': ':bandera_ciudad_del_vaticano:',
        'fr': u':drapeau_état_de_la_cité_du_vatican:',
        'ja': u':旗_バチカン市国:',
        'ko': u':깃발_바티칸_시국:',
        'pt': ':bandeira_cidade_do_vaticano:',
        'it': u':bandiera_città_del_vaticano:',
        'fa': u':پرچم_واتیکان:',
        'id': ':bendera_vatikan:',
        'zh': u':梵蒂冈:'
    },
    u'\U0001F1FB\U0001F1EA': { # 🇻🇪
        'en' : ':Venezuela:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Venezuela:', ':venezuela:'],
        'de': ':flagge_venezuela:',
        'es': ':bandera_venezuela:',
        'fr': ':drapeau_venezuela:',
        'ja': u':旗_ベネズエラ:',
        'ko': u':깃발_베네수엘라:',
        'pt': ':bandeira_venezuela:',
        'it': ':bandiera_venezuela:',
        'fa': u':پرچم_ونزوئلا:',
        'id': ':bendera_venezuela:',
        'zh': u':委内瑞拉:'
    },
    u'\U0001F1FB\U0001F1F3': { # 🇻🇳
        'en' : ':Vietnam:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Vietnam:', ':vietnam:'],
        'de': ':flagge_vietnam:',
        'es': ':bandera_vietnam:',
        'fr': ':drapeau_vietnam:',
        'ja': u':旗_ベトナム:',
        'ko': u':깃발_베트남:',
        'pt': u':bandeira_vietnã:',
        'it': ':bandiera_vietnam:',
        'fa': u':پرچم_ویتنام:',
        'id': ':bendera_vietnam:',
        'zh': u':越南:'
    },
    u'\U0000264D': { # ♍
        'en' : ':Virgo:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':virgo:'],
        'variant': True,
        'de': ':jungfrau_(sternzeichen):',
        'es': ':virgo:',
        'fr': ':vierge:',
        'ja': u':おとめ座:',
        'ko': u':처녀자리:',
        'pt': ':signo_de_virgem:',
        'it': ':segno_zodiacale_della_vergine:',
        'fa': u':برج_سنبله:',
        'id': ':virgo:',
        'zh': u':处女座:'
    },
    u'\U0001F3F4\U000E0067\U000E0062\U000E0077\U000E006C\U000E0073\U000E007F': { # 🏴󠁧󠁢󠁷󠁬󠁳󠁿
        'en' : ':Wales:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':wales:'],
        'de': ':flagge_wales:',
        'es': ':bandera_gales:',
        'fr': ':drapeau_pays_de_galles:',
        'ja': u':旗_ウェールズ:',
        'ko': u':깃발_웨일즈:',
        'pt': u':bandeira_país_de_gales:',
        'it': ':bandiera_galles:',
        'fa': u':پرچم_ویلز:',
        'id': ':bendera_wales:',
        'zh': u':威尔士:'
    },
    u'\U0001F1FC\U0001F1EB': { # 🇼🇫
        'en' : ':Wallis_&_Futuna:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Wallis_&_Futuna:', ':wallis_futuna:'],
        'de': ':flagge_wallis_und_futuna:',
        'es': ':bandera_wallis_y_futuna:',
        'fr': ':drapeau_wallis-et-futuna:',
        'ja': u':旗_ウォリス・フツナ:',
        'ko': u':깃발_왈리스-푸투나_제도:',
        'pt': ':bandeira_wallis_e_futuna:',
        'it': ':bandiera_wallis_e_futuna:',
        'fa': u':پرچم_والیس_و_فوتونا:',
        'id': ':bendera_kepulauan_wallis_dan_futuna:',
        'zh': u':瓦利斯和富图纳:'
    },
    u'\U0001F1EA\U0001F1ED': { # 🇪🇭
        'en' : ':Western_Sahara:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Western_Sahara:', ':western_sahara:'],
        'de': ':flagge_westsahara:',
        'es': u':bandera_sáhara_occidental:',
        'fr': ':drapeau_sahara_occidental:',
        'ja': u':旗_西サハラ:',
        'ko': u':깃발_서사하라:',
        'pt': ':bandeira_saara_ocidental:',
        'it': ':bandiera_sahara_occidentale:',
        'fa': u':پرچم_صحرای_غربی:',
        'id': ':bendera_sahara_barat:',
        'zh': u':西撒哈拉:'
    },
    u'\U0001F1FE\U0001F1EA': { # 🇾🇪
        'en' : ':Yemen:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Yemen:', ':yemen:'],
        'de': ':flagge_jemen:',
        'es': ':bandera_yemen:',
        'fr': u':drapeau_yémen:',
        'ja': u':旗_イエメン:',
        'ko': u':깃발_예멘:',
        'pt': u':bandeira_iêmen:',
        'it': ':bandiera_yemen:',
        'fa': u':پرچم_یمن:',
        'id': ':bendera_yaman:',
        'zh': u':也门:'
    },
    u'\U0001F4A4': { # 💤
        'en' : ':ZZZ:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':zzz:'],
        'de': ':schlafen:',
        'es': u':símbolo_de_sueño:',
        'fr': ':endormi:',
        'ja': u':グーグー:',
        'ko': u':졸림:',
        'pt': ':zzz:',
        'it': ':sonno:',
        'fa': u':خروپف:',
        'id': ':zzz:',
        'zh': u':睡着:'
    },
    u'\U0001F1FF\U0001F1F2': { # 🇿🇲
        'en' : ':Zambia:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Zambia:', ':zambia:'],
        'de': ':flagge_sambia:',
        'es': ':bandera_zambia:',
        'fr': ':drapeau_zambie:',
        'ja': u':旗_ザンビア:',
        'ko': u':깃발_잠비아:',
        'pt': u':bandeira_zâmbia:',
        'it': ':bandiera_zambia:',
        'fa': u':پرچم_زامبیا:',
        'id': ':bendera_zambia:',
        'zh': u':赞比亚:'
    },
    u'\U0001F1FF\U0001F1FC': { # 🇿🇼
        'en' : ':Zimbabwe:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':flag_for_Zimbabwe:', ':zimbabwe:'],
        'de': ':flagge_simbabwe:',
        'es': ':bandera_zimbabue:',
        'fr': ':drapeau_zimbabwe:',
        'ja': u':旗_ジンバブエ:',
        'ko': u':깃발_짐바브웨:',
        'pt': u':bandeira_zimbábue:',
        'it': ':bandiera_zimbabwe:',
        'fa': u':پرچم_زیمبابوه:',
        'id': ':bendera_zimbabwe:',
        'zh': u':津巴布韦:'
    },
    u'\U0001F9EE': { # 🧮
        'en' : ':abacus:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':abakus:',
        'es': u':ábaco:',
        'fr': ':abaque:',
        'ja': u':そろばん:',
        'ko': u':주판:',
        'pt': u':ábaco:',
        'it': ':abaco:',
        'fa': u':چرتکه:',
        'id': ':sempoa:',
        'zh': u':算盘:'
    },
    u'\U0001FA97': { # 🪗
        'en' : ':accordion:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':akkordeon:',
        'es': u':acordeón:',
        'fr': u':accordéon:',
        'ja': u':アコーディオン:',
        'ko': u':아코디언:',
        'pt': u':acordeão:',
        'it': ':fisarmonica:',
        'fa': u':آکوردئون:',
        'id': ':akordeon:',
        'zh': u':手风琴:'
    },
    u'\U0001FA79': { # 🩹
        'en' : ':adhesive_bandage:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':heftpflaster:',
        'es': ':tirita:',
        'fr': ':sparadrap:',
        'ja': u':絆創膏:',
        'ko': u':반창고:',
        'pt': ':atadura_adesiva:',
        'it': ':cerotto:',
        'fa': u':چسب_زخم:',
        'id': ':plester_luka:',
        'zh': u':创可贴:'
    },
    u'\U0001F39F\U0000FE0F': { # 🎟️
        'en' : ':admission_tickets:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':tickets:'],
        'variant': True,
        'de': ':eintrittskarten:',
        'es': ':entradas:',
        'fr': u':billet_d’entrée:',
        'ja': u':入場券:',
        'ko': u':입장_티켓:',
        'pt': ':ingresso_de_cinema:',
        'it': u':biglietto_d’ingresso:',
        'fa': u':بلیت_ورود:',
        'id': ':tiket_masuk:',
        'zh': u':入场券:'
    },
    u'\U0001F39F': { # 🎟
        'en' : ':admission_tickets:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':tickets:'],
        'variant': True,
        'de': ':eintrittskarten:',
        'es': ':entradas:',
        'fr': u':billet_d’entrée:',
        'ja': u':入場券:',
        'ko': u':입장_티켓:',
        'pt': ':ingresso_de_cinema:',
        'it': u':biglietto_d’ingresso:',
        'fa': u':بلیت_ورود:',
        'id': ':tiket_masuk:',
        'zh': u':入场券:'
    },
    u'\U0001F6A1': { # 🚡
        'en' : ':aerial_tramway:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bergseilbahn:',
        'es': u':teleférico:',
        'fr': u':tramway_aérien:',
        'ja': u':ロープウェイ:',
        'ko': u':케이블카:',
        'pt': u':teleférico:',
        'it': ':funivia_aerea:',
        'fa': u':تراموای_هوایی:',
        'id': ':trem_gantung:',
        'zh': u':索道:'
    },
    u'\U00002708\U0000FE0F': { # ✈️
        'en' : ':airplane:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':flugzeug:',
        'es': u':avión:',
        'fr': ':avion:',
        'ja': u':飛行機:',
        'ko': u':비행기:',
        'pt': u':avião:',
        'it': ':aeroplano:',
        'fa': u':هواپیما:',
        'id': ':pesawat:',
        'zh': u':飞机:'
    },
    u'\U00002708': { # ✈
        'en' : ':airplane:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':flugzeug:',
        'es': u':avión:',
        'fr': ':avion:',
        'ja': u':飛行機:',
        'ko': u':비행기:',
        'pt': u':avião:',
        'it': ':aeroplano:',
        'fa': u':هواپیما:',
        'id': ':pesawat:',
        'zh': u':飞机:'
    },
    u'\U0001F6EC': { # 🛬
        'en' : ':airplane_arrival:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':airplane_arriving:', ':flight_arrival:'],
        'de': ':landung_eines_flugzeugs:',
        'es': u':avión_aterrizando:',
        'fr': u':avion_à_l’atterrissage:',
        'ja': u':飛行機着陸:',
        'ko': u':비행기_착륙:',
        'pt': u':avião_aterrissando:',
        'it': ':atterraggio:',
        'fa': u':زمان_ورود_هواپیما:',
        'id': ':pesawat_mendarat:',
        'zh': u':航班降落:'
    },
    u'\U0001F6EB': { # 🛫
        'en' : ':airplane_departure:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':flight_departure:'],
        'de': ':abflug:',
        'es': u':avión_despegando:',
        'fr': u':avion_au_décollage:',
        'ja': u':飛行機離陸:',
        'ko': u':비행기_이륙:',
        'pt': u':avião_decolando:',
        'it': ':decollo:',
        'fa': u':زمان_حرکت_هواپیما:',
        'id': ':pesawat_lepas_landas:',
        'zh': u':航班起飞:'
    },
    u'\U000023F0': { # ⏰
        'en' : ':alarm_clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wecker:',
        'es': ':reloj_despertador:',
        'fr': u':réveil:',
        'ja': u':目覚まし時計:',
        'ko': u':알람_시계:',
        'pt': ':despertador:',
        'it': ':sveglia:',
        'fa': u':ساعت_رومیزی:',
        'id': ':jam_weker:',
        'zh': u':闹钟:'
    },
    u'\U00002697\U0000FE0F': { # ⚗️
        'en' : ':alembic:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':destillierapparat:',
        'es': ':alambique:',
        'fr': ':alambic:',
        'ja': u':蒸留器:',
        'ko': u':증류기:',
        'pt': ':alambique:',
        'it': ':alambicco:',
        'fa': u':انبیق:',
        'id': ':alembic:',
        'zh': u':蒸馏器:'
    },
    u'\U00002697': { # ⚗
        'en' : ':alembic:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':destillierapparat:',
        'es': ':alambique:',
        'fr': ':alambic:',
        'ja': u':蒸留器:',
        'ko': u':증류기:',
        'pt': ':alambique:',
        'it': ':alambicco:',
        'fa': u':انبیق:',
        'id': ':alembic:',
        'zh': u':蒸馏器:'
    },
    u'\U0001F47D': { # 👽
        'en' : ':alien:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':außerirdischer:',
        'es': u':alienígena:',
        'fr': ':alien:',
        'ja': u':エイリアン:',
        'ko': u':외계인:',
        'pt': u':alienígena:',
        'it': ':alieno:',
        'fa': u':موجود_فضایی:',
        'id': ':alien:',
        'zh': u':外星人:'
    },
    u'\U0001F47E': { # 👾
        'en' : ':alien_monster:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':space_invader:'],
        'de': ':computerspiel-monster:',
        'es': u':monstruo_alienígena:',
        'fr': u':monstre_de_l’espace:',
        'ja': u':インベーダー:',
        'ko': u':에일리언:',
        'pt': u':monstro_alienígena:',
        'it': ':mostro_alieno:',
        'fa': u':هیولای_فضایی:',
        'id': ':monster_alien:',
        'zh': u':外星怪物:'
    },
    u'\U0001F691': { # 🚑
        'en' : ':ambulance:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':krankenwagen:',
        'es': ':ambulancia:',
        'fr': ':ambulance:',
        'ja': u':救急車:',
        'ko': u':구급차:',
        'pt': u':ambulância:',
        'it': ':ambulanza:',
        'fa': u':آمبولانس:',
        'id': ':ambulans:',
        'zh': u':救护车:'
    },
    u'\U0001F3C8': { # 🏈
        'en' : ':american_football:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':football:'],
        'de': ':football:',
        'es': u':balón_de_fútbol_americano:',
        'fr': u':football_américain:',
        'ja': u':アメフト:',
        'ko': u':미식축구공:',
        'pt': ':bola_de_futebol_americano:',
        'it': ':football_americano:',
        'fa': u':فوتبال_امریکایی:',
        'id': ':american_football:',
        'zh': u':美式橄榄球:'
    },
    u'\U0001F3FA': { # 🏺
        'en' : ':amphora:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':amphore:',
        'es': u':ánfora:',
        'fr': ':amphore:',
        'ja': u':壺:',
        'ko': u':암포라:',
        'pt': u':ânfora:',
        'it': ':anfora:',
        'fa': u':سبو:',
        'id': ':amphora:',
        'zh': u':双耳瓶:'
    },
    u'\U0001FAC0': { # 🫀
        'en' : ':anatomical_heart:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':herz_(organ):',
        'es': u':corazón_humano:',
        'fr': u':cœur:',
        'ja': u':心臓:',
        'ko': u':심장:',
        'pt': u':coração_humano:',
        'it': ':organo_del_cuore:',
        'fa': u':قلب:',
        'id': ':organ_jantung:',
        'zh': u':心脏器官:'
    },
    u'\U00002693': { # ⚓
        'en' : ':anchor:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':anker:',
        'es': ':ancla:',
        'fr': ':ancre:',
        'ja': u':錨:',
        'ko': u':닻:',
        'pt': u':âncora:',
        'it': ':ancora:',
        'fa': u':لنگر:',
        'id': ':jangkar:',
        'zh': u':锚:'
    },
    u'\U0001F4A2': { # 💢
        'en' : ':anger_symbol:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':anger:'],
        'de': u':ärger:',
        'es': u':símbolo_de_enfado:',
        'fr': u':symbole_de_colère:',
        'ja': u':むかっ:',
        'ko': u':화남:',
        'pt': u':símbolo_de_raiva:',
        'it': ':rabbia:',
        'fa': u':نماد_عصبانیت:',
        'id': ':marah:',
        'zh': u':怒:'
    },
    u'\U0001F620': { # 😠
        'en' : ':angry_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':angry:'],
        'de': u':verärgertes_gesicht:',
        'es': ':cara_enfadada:',
        'fr': u':visage_en_colère:',
        'ja': u':ぷんぷん:',
        'ko': u':화난_얼굴:',
        'pt': ':rosto_zangado:',
        'it': ':faccina_arrabbiata:',
        'fa': u':عصبانی:',
        'id': ':wajah_marah:',
        'zh': u':生气:'
    },
    u'\U0001F47F': { # 👿
        'en' : ':angry_face_with_horns:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':imp:'],
        'de': u':wütendes_gesicht_mit_hörnern:',
        'es': ':cara_enfadada_con_cuernos:',
        'fr': u':visage_en_colère_avec_des_cornes:',
        'ja': u':怒った悪魔:',
        'ko': u':머리에_뿔이_달린_화난_얼굴:',
        'pt': ':rosto_zangado_com_chifres:',
        'it': ':faccina_arrabbiata_con_corna:',
        'fa': u':چهره_عصبانی_با_دو_شاخ:',
        'id': ':wajah_marah_dengan_tanduk:',
        'zh': u':生气的恶魔:'
    },
    u'\U0001F627': { # 😧
        'en' : ':anguished_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':anguished:'],
        'de': ':qualvolles_gesicht:',
        'es': ':cara_angustiada:',
        'fr': u':visage_angoissé:',
        'ja': u':苦悩:',
        'ko': u':괴로워하는_얼굴:',
        'pt': ':rosto_angustiado:',
        'it': ':faccina_angosciata:',
        'fa': u':دردمند:',
        'id': ':wajah_menderita:',
        'zh': u':极度痛苦:'
    },
    u'\U0001F41C': { # 🐜
        'en' : ':ant:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':ameise:',
        'es': ':hormiga:',
        'fr': ':fourmi:',
        'ja': u':アリ:',
        'ko': u':개미:',
        'pt': ':formiga:',
        'it': ':formica:',
        'fa': u':مورچه:',
        'id': ':semut:',
        'zh': u':蚂蚁:'
    },
    u'\U0001F4F6': { # 📶
        'en' : ':antenna_bars:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':signal_strength:'],
        'de': u':balkenförmige_signalstärkenanzeige:',
        'es': ':barras_de_cobertura:',
        'fr': u':barres_de_réseau:',
        'ja': u':アンテナマーク:',
        'ko': u':안테나_신호:',
        'pt': ':barras_de_sinal:',
        'it': ':segnale_cellulare:',
        'fa': u':نوار_سیگنال:',
        'id': ':batang_antena:',
        'zh': u':信号强度条:'
    },
    u'\U0001F630': { # 😰
        'en' : ':anxious_face_with_sweat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cold_sweat:'],
        'de': u':besorgtes_gesicht_mit_schweißtropfen:',
        'es': ':cara_con_ansiedad_y_sudor:',
        'fr': ':visage_anxieux_avec_goutte_de_sueur:',
        'ja': u':冷や汗青ざめ:',
        'ko': u':땀_흘리며_불안해하는_얼굴:',
        'pt': ':rosto_ansioso_com_gota_de_suor:',
        'it': ':faccina_sudata_in_ansia:',
        'fa': u':عرق_ترس:',
        'id': ':wajah_ketakutan_berkeringat:',
        'zh': u':冷汗:'
    },
    u'\U0001F69B': { # 🚛
        'en' : ':articulated_lorry:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':sattelzug:',
        'es': u':camión_articulado:',
        'fr': ':semi-remorque:',
        'ja': u':トレーラー:',
        'ko': u':트레일러_트럭:',
        'pt': u':caminhão:',
        'it': ':autoarticolato:',
        'fa': u':کامیون_مفصلی:',
        'id': ':lori_gandeng:',
        'zh': u':铰接式货车:'
    },
    u'\U0001F9D1\U0000200D\U0001F3A8': { # 🧑‍🎨
        'en' : ':artist:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':künstler(in):',
        'es': ':artista:',
        'fr': ':artiste:',
        'ja': u':芸術家:',
        'ko': u':화가:',
        'pt': ':artista:',
        'it': ':artista:',
        'fa': u':هنرمند:',
        'id': ':seniman:',
        'zh': u':艺术家:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F3A8': { # 🧑🏿‍🎨
        'en' : ':artist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':künstler(in)_dunkle_hautfarbe:',
        'es': ':artista_tono_de_piel_oscuro:',
        'fr': u':artiste_peau_foncée:',
        'ja': u':芸術家_濃い肌色:',
        'ko': u':화가_검은색_피부:',
        'pt': ':artista_pele_escura:',
        'it': ':artista_carnagione_scura:',
        'fa': u':هنرمند_پوست_آبنوسی:',
        'id': ':seniman_warna_kulit_gelap:',
        'zh': u':艺术家_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F3A8': { # 🧑🏻‍🎨
        'en' : ':artist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':künstler(in)_helle_hautfarbe:',
        'es': ':artista_tono_de_piel_claro:',
        'fr': ':artiste_peau_claire:',
        'ja': u':芸術家_薄い肌色:',
        'ko': u':화가_하얀_피부:',
        'pt': ':artista_pele_clara:',
        'it': ':artista_carnagione_chiara:',
        'fa': u':هنرمند_پوست_سفید:',
        'id': ':seniman_warna_kulit_cerah:',
        'zh': u':艺术家_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F3A8': { # 🧑🏾‍🎨
        'en' : ':artist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':künstler(in)_mitteldunkle_hautfarbe:',
        'es': ':artista_tono_de_piel_oscuro_medio:',
        'fr': ':artiste_peau_mate:',
        'ja': u':芸術家_やや濃い肌色:',
        'ko': u':화가_진한_갈색_피부:',
        'pt': ':artista_pele_morena_escura:',
        'it': ':artista_carnagione_abbastanza_scura:',
        'fa': u':هنرمند_پوست_گندمی:',
        'id': ':seniman_warna_kulit_gelap-sedang:',
        'zh': u':艺术家_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F3A8': { # 🧑🏼‍🎨
        'en' : ':artist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':künstler(in)_mittelhelle_hautfarbe:',
        'es': ':artista_tono_de_piel_claro_medio:',
        'fr': ':artiste_peau_moyennement_claire:',
        'ja': u':芸術家_やや薄い肌色:',
        'ko': u':화가_연한_갈색_피부:',
        'pt': ':artista_pele_morena_clara:',
        'it': ':artista_carnagione_abbastanza_chiara:',
        'fa': u':هنرمند_پوست_روشن:',
        'id': ':seniman_warna_kulit_cerah-sedang:',
        'zh': u':艺术家_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F3A8': { # 🧑🏽‍🎨
        'en' : ':artist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':künstler(in)_mittlere_hautfarbe:',
        'es': ':artista_tono_de_piel_medio:',
        'fr': u':artiste_peau_légèrement_mate:',
        'ja': u':芸術家_中間の肌色:',
        'ko': u':화가_갈색_피부:',
        'pt': ':artista_pele_morena:',
        'it': ':artista_carnagione_olivastra:',
        'fa': u':هنرمند_پوست_طلایی:',
        'id': ':seniman_warna_kulit_sedang:',
        'zh': u':艺术家_中等肤色:'
    },
    u'\U0001F3A8': { # 🎨
        'en' : ':artist_palette:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':art:'],
        'de': ':mischpalette:',
        'es': ':paleta_de_pintor:',
        'fr': ':palette_de_peinture:',
        'ja': u':絵の具パレット:',
        'ko': u':팔레트:',
        'pt': ':paleta_de_tintas:',
        'it': ':tavolozza:',
        'fa': u':پالت_نقاشی:',
        'id': ':palet_pelukis:',
        'zh': u':调色盘:'
    },
    u'\U0001F632': { # 😲
        'en' : ':astonished_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':astonished:'],
        'de': ':erstauntes_gesicht:',
        'es': ':cara_asombrada:',
        'fr': u':visage_stupéfait:',
        'ja': u':びっくり:',
        'ko': u':깜짝_놀란_얼굴:',
        'pt': ':rosto_espantado:',
        'it': ':faccina_stupita:',
        'fa': u':بهت_زده:',
        'id': ':wajah_terpukau:',
        'zh': u':震惊:'
    },
    u'\U0001F9D1\U0000200D\U0001F680': { # 🧑‍🚀
        'en' : ':astronaut:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':astronaut(in):',
        'es': ':astronauta:',
        'fr': ':astronaute:',
        'ja': u':宇宙飛行士:',
        'ko': u':우주비행사:',
        'pt': ':astronauta:',
        'it': ':astronauta:',
        'fa': u':فضانورد:',
        'id': ':astronaut:',
        'zh': u':宇航员:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F680': { # 🧑🏿‍🚀
        'en' : ':astronaut_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':astronaut(in)_dunkle_hautfarbe:',
        'es': ':astronauta_tono_de_piel_oscuro:',
        'fr': u':astronaute_peau_foncée:',
        'ja': u':宇宙飛行士_濃い肌色:',
        'ko': u':우주비행사_검은색_피부:',
        'pt': ':astronauta_pele_escura:',
        'it': ':astronauta_carnagione_scura:',
        'fa': u':فضانورد_پوست_آبنوسی:',
        'id': ':astronaut_warna_kulit_gelap:',
        'zh': u':宇航员_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F680': { # 🧑🏻‍🚀
        'en' : ':astronaut_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':astronaut(in)_helle_hautfarbe:',
        'es': ':astronauta_tono_de_piel_claro:',
        'fr': ':astronaute_peau_claire:',
        'ja': u':宇宙飛行士_薄い肌色:',
        'ko': u':우주비행사_하얀_피부:',
        'pt': ':astronauta_pele_clara:',
        'it': ':astronauta_carnagione_chiara:',
        'fa': u':فضانورد_پوست_سفید:',
        'id': ':astronaut_warna_kulit_cerah:',
        'zh': u':宇航员_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F680': { # 🧑🏾‍🚀
        'en' : ':astronaut_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':astronaut(in)_mitteldunkle_hautfarbe:',
        'es': ':astronauta_tono_de_piel_oscuro_medio:',
        'fr': ':astronaute_peau_mate:',
        'ja': u':宇宙飛行士_やや濃い肌色:',
        'ko': u':우주비행사_진한_갈색_피부:',
        'pt': ':astronauta_pele_morena_escura:',
        'it': ':astronauta_carnagione_abbastanza_scura:',
        'fa': u':فضانورد_پوست_گندمی:',
        'id': ':astronaut_warna_kulit_gelap-sedang:',
        'zh': u':宇航员_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F680': { # 🧑🏼‍🚀
        'en' : ':astronaut_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':astronaut(in)_mittelhelle_hautfarbe:',
        'es': ':astronauta_tono_de_piel_claro_medio:',
        'fr': ':astronaute_peau_moyennement_claire:',
        'ja': u':宇宙飛行士_やや薄い肌色:',
        'ko': u':우주비행사_연한_갈색_피부:',
        'pt': ':astronauta_pele_morena_clara:',
        'it': ':astronauta_carnagione_abbastanza_chiara:',
        'fa': u':فضانورد_پوست_روشن:',
        'id': ':astronaut_warna_kulit_cerah-sedang:',
        'zh': u':宇航员_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F680': { # 🧑🏽‍🚀
        'en' : ':astronaut_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':astronaut(in)_mittlere_hautfarbe:',
        'es': ':astronauta_tono_de_piel_medio:',
        'fr': u':astronaute_peau_légèrement_mate:',
        'ja': u':宇宙飛行士_中間の肌色:',
        'ko': u':우주비행사_갈색_피부:',
        'pt': ':astronauta_pele_morena:',
        'it': ':astronauta_carnagione_olivastra:',
        'fa': u':فضانورد_پوست_طلایی:',
        'id': ':astronaut_warna_kulit_sedang:',
        'zh': u':宇航员_中等肤色:'
    },
    u'\U0000269B\U0000FE0F': { # ⚛️
        'en' : ':atom_symbol:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':atomzeichen:',
        'es': u':símbolo_de_átomo:',
        'fr': u':symbole_de_l’atome:',
        'ja': u':原子のシンボル:',
        'ko': u':원자_기호:',
        'pt': u':símbolo_de_átomo:',
        'it': u':simbolo_dell’atomo:',
        'fa': u':نماد_اتم:',
        'id': ':simbol_atom:',
        'zh': u':原子符号:'
    },
    u'\U0000269B': { # ⚛
        'en' : ':atom_symbol:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':atomzeichen:',
        'es': u':símbolo_de_átomo:',
        'fr': u':symbole_de_l’atome:',
        'ja': u':原子のシンボル:',
        'ko': u':원자_기호:',
        'pt': u':símbolo_de_átomo:',
        'it': u':simbolo_dell’atomo:',
        'fa': u':نماد_اتم:',
        'id': ':simbol_atom:',
        'zh': u':原子符号:'
    },
    u'\U0001F6FA': { # 🛺
        'en' : ':auto_rickshaw:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':autorikscha:',
        'es': ':mototaxi:',
        'fr': ':tuk_tuk:',
        'ja': u':三輪タクシー:',
        'ko': u':경삼륜차:',
        'pt': u':automóvel_riquixá:',
        'it': u':risciò_a_motore:',
        'fa': u':اتوریکشا:',
        'id': ':bajaj:',
        'zh': u':三轮摩托车:'
    },
    u'\U0001F697': { # 🚗
        'en' : ':automobile:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':car:', ':red_car:'],
        'de': ':auto:',
        'es': ':coche:',
        'fr': ':voiture:',
        'ja': u':自動車:',
        'ko': u':자동차:',
        'pt': ':carro:',
        'it': ':auto:',
        'fa': u':خودرو:',
        'id': ':mobil:',
        'zh': u':汽车:'
    },
    u'\U0001F951': { # 🥑
        'en' : ':avocado:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':avocado:',
        'es': ':aguacate:',
        'fr': ':avocat:',
        'ja': u':アボカド:',
        'ko': u':아보카도:',
        'pt': ':abacate:',
        'it': ':avocado:',
        'fa': u':آووکادو:',
        'id': ':alpukat:',
        'zh': u':鳄梨:'
    },
    u'\U0001FA93': { # 🪓
        'en' : ':axe:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':axt:',
        'es': ':hacha:',
        'fr': ':hache:',
        'ja': u':斧:',
        'ko': u':도끼:',
        'pt': ':machado:',
        'it': ':ascia:',
        'fa': u':تبر:',
        'id': ':kapak:',
        'zh': u':斧头:'
    },
    u'\U0001F476': { # 👶
        'en' : ':baby:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':baby:',
        'es': u':bebé:',
        'fr': u':bébé:',
        'ja': u':赤ん坊:',
        'ko': u':아기:',
        'pt': u':bebê:',
        'it': ':neonato:',
        'fa': u':نوزاد:',
        'id': ':bayi:',
        'zh': u':小宝贝:'
    },
    u'\U0001F47C': { # 👼
        'en' : ':baby_angel:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':angel:'],
        'de': ':putte:',
        'es': u':bebé_ángel:',
        'fr': u':bébé_ange:',
        'ja': u':天使:',
        'ko': u':아기_천사:',
        'pt': u':bebê_anjo:',
        'it': ':angioletto:',
        'fa': u':فرشته_کوچولو:',
        'id': ':malaikat_bayi:',
        'zh': u':小天使:'
    },
    u'\U0001F47C\U0001F3FF': { # 👼🏿
        'en' : ':baby_angel_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':putte_dunkle_hautfarbe:',
        'es': u':bebé_ángel_tono_de_piel_oscuro:',
        'fr': u':bébé_ange_peau_foncée:',
        'ja': u':天使_濃い肌色:',
        'ko': u':아기_천사_검은색_피부:',
        'pt': u':bebê_anjo_pele_escura:',
        'it': ':angioletto_carnagione_scura:',
        'fa': u':فرشته_کوچولو_پوست_آبنوسی:',
        'id': ':malaikat_bayi_warna_kulit_gelap:',
        'zh': u':小天使_较深肤色:'
    },
    u'\U0001F47C\U0001F3FB': { # 👼🏻
        'en' : ':baby_angel_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':putte_helle_hautfarbe:',
        'es': u':bebé_ángel_tono_de_piel_claro:',
        'fr': u':bébé_ange_peau_claire:',
        'ja': u':天使_薄い肌色:',
        'ko': u':아기_천사_하얀_피부:',
        'pt': u':bebê_anjo_pele_clara:',
        'it': ':angioletto_carnagione_chiara:',
        'fa': u':فرشته_کوچولو_پوست_سفید:',
        'id': ':malaikat_bayi_warna_kulit_cerah:',
        'zh': u':小天使_较浅肤色:'
    },
    u'\U0001F47C\U0001F3FE': { # 👼🏾
        'en' : ':baby_angel_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':putte_mitteldunkle_hautfarbe:',
        'es': u':bebé_ángel_tono_de_piel_oscuro_medio:',
        'fr': u':bébé_ange_peau_mate:',
        'ja': u':天使_やや濃い肌色:',
        'ko': u':아기_천사_진한_갈색_피부:',
        'pt': u':bebê_anjo_pele_morena_escura:',
        'it': ':angioletto_carnagione_abbastanza_scura:',
        'fa': u':فرشته_کوچولو_پوست_گندمی:',
        'id': ':malaikat_bayi_warna_kulit_gelap-sedang:',
        'zh': u':小天使_中等深肤色:'
    },
    u'\U0001F47C\U0001F3FC': { # 👼🏼
        'en' : ':baby_angel_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':putte_mittelhelle_hautfarbe:',
        'es': u':bebé_ángel_tono_de_piel_claro_medio:',
        'fr': u':bébé_ange_peau_moyennement_claire:',
        'ja': u':天使_やや薄い肌色:',
        'ko': u':아기_천사_연한_갈색_피부:',
        'pt': u':bebê_anjo_pele_morena_clara:',
        'it': ':angioletto_carnagione_abbastanza_chiara:',
        'fa': u':فرشته_کوچولو_پوست_روشن:',
        'id': ':malaikat_bayi_warna_kulit_cerah-sedang:',
        'zh': u':小天使_中等浅肤色:'
    },
    u'\U0001F47C\U0001F3FD': { # 👼🏽
        'en' : ':baby_angel_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':putte_mittlere_hautfarbe:',
        'es': u':bebé_ángel_tono_de_piel_medio:',
        'fr': u':bébé_ange_peau_légèrement_mate:',
        'ja': u':天使_中間の肌色:',
        'ko': u':아기_천사_갈색_피부:',
        'pt': u':bebê_anjo_pele_morena:',
        'it': ':angioletto_carnagione_olivastra:',
        'fa': u':فرشته_کوچولو_پوست_طلایی:',
        'id': ':malaikat_bayi_warna_kulit_sedang:',
        'zh': u':小天使_中等肤色:'
    },
    u'\U0001F37C': { # 🍼
        'en' : ':baby_bottle:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':babyflasche:',
        'es': u':biberón:',
        'fr': ':biberon:',
        'ja': u':ほにゅう瓶:',
        'ko': u':젖병:',
        'pt': ':mamadeira:',
        'it': ':biberon:',
        'fa': u':شیشه_شیر:',
        'id': ':botol_bayi:',
        'zh': u':奶瓶:'
    },
    u'\U0001F424': { # 🐤
        'en' : ':baby_chick:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':küken:',
        'es': ':pollito:',
        'fr': ':poussin:',
        'ja': u':ひよこ:',
        'ko': u':병아리:',
        'pt': ':pintinho_de_perfil:',
        'it': ':pulcino:',
        'fa': u':جوجه:',
        'id': ':itik_bayi:',
        'zh': u':小鸡:'
    },
    u'\U0001F476\U0001F3FF': { # 👶🏿
        'en' : ':baby_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':baby_dunkle_hautfarbe:',
        'es': u':bebé_tono_de_piel_oscuro:',
        'fr': u':bébé_peau_foncée:',
        'ja': u':赤ん坊_濃い肌色:',
        'ko': u':아기_검은색_피부:',
        'pt': u':bebê_pele_escura:',
        'it': ':neonato_carnagione_scura:',
        'fa': u':نوزاد_پوست_آبنوسی:',
        'id': ':bayi_warna_kulit_gelap:',
        'zh': u':小宝贝_较深肤色:'
    },
    u'\U0001F476\U0001F3FB': { # 👶🏻
        'en' : ':baby_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':baby_helle_hautfarbe:',
        'es': u':bebé_tono_de_piel_claro:',
        'fr': u':bébé_peau_claire:',
        'ja': u':赤ん坊_薄い肌色:',
        'ko': u':아기_하얀_피부:',
        'pt': u':bebê_pele_clara:',
        'it': ':neonato_carnagione_chiara:',
        'fa': u':نوزاد_پوست_سفید:',
        'id': ':bayi_warna_kulit_cerah:',
        'zh': u':小宝贝_较浅肤色:'
    },
    u'\U0001F476\U0001F3FE': { # 👶🏾
        'en' : ':baby_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':baby_mitteldunkle_hautfarbe:',
        'es': u':bebé_tono_de_piel_oscuro_medio:',
        'fr': u':bébé_peau_mate:',
        'ja': u':赤ん坊_やや濃い肌色:',
        'ko': u':아기_진한_갈색_피부:',
        'pt': u':bebê_pele_morena_escura:',
        'it': ':neonato_carnagione_abbastanza_scura:',
        'fa': u':نوزاد_پوست_گندمی:',
        'id': ':bayi_warna_kulit_gelap-sedang:',
        'zh': u':小宝贝_中等深肤色:'
    },
    u'\U0001F476\U0001F3FC': { # 👶🏼
        'en' : ':baby_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':baby_mittelhelle_hautfarbe:',
        'es': u':bebé_tono_de_piel_claro_medio:',
        'fr': u':bébé_peau_moyennement_claire:',
        'ja': u':赤ん坊_やや薄い肌色:',
        'ko': u':아기_연한_갈색_피부:',
        'pt': u':bebê_pele_morena_clara:',
        'it': ':neonato_carnagione_abbastanza_chiara:',
        'fa': u':نوزاد_پوست_روشن:',
        'id': ':bayi_warna_kulit_cerah-sedang:',
        'zh': u':小宝贝_中等浅肤色:'
    },
    u'\U0001F476\U0001F3FD': { # 👶🏽
        'en' : ':baby_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':baby_mittlere_hautfarbe:',
        'es': u':bebé_tono_de_piel_medio:',
        'fr': u':bébé_peau_légèrement_mate:',
        'ja': u':赤ん坊_中間の肌色:',
        'ko': u':아기_갈색_피부:',
        'pt': u':bebê_pele_morena:',
        'it': ':neonato_carnagione_olivastra:',
        'fa': u':نوزاد_پوست_طلایی:',
        'id': ':bayi_warna_kulit_sedang:',
        'zh': u':小宝贝_中等肤色:'
    },
    u'\U0001F6BC': { # 🚼
        'en' : ':baby_symbol:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':symbol_baby:',
        'es': u':señal_de_bebé:',
        'fr': u':symbole_bébé:',
        'ja': u':ベビーシート:',
        'ko': u':수유실:',
        'pt': u':símbolo_de_bebê:',
        'it': ':simbolo_con_immagine_di_bambino:',
        'fa': u':نماد_نوزاد:',
        'id': ':simbol_bayi:',
        'zh': u':宝宝:'
    },
    u'\U0001F447': { # 👇
        'en' : ':backhand_index_pointing_down:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':point_down:'],
        'variant': True,
        'de': ':nach_unten_weisender_zeigefinger:',
        'es': u':dorso_de_mano_con_índice_hacia_abajo:',
        'fr': ':main_avec_index_pointant_vers_le_bas:',
        'ja': u':下指差し:',
        'ko': u':아래쪽을_가리키는_손등:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_baixo:',
        'it': ':indice_abbassato:',
        'fa': u':اشاره_به_پایین:',
        'id': ':menunjuk_ke_bawah:',
        'zh': u':反手食指向下指:'
    },
    u'\U0001F447\U0001F3FF': { # 👇🏿
        'en' : ':backhand_index_pointing_down_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_unten_weisender_zeigefinger_dunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_abajo_tono_de_piel_oscuro:',
        'fr': u':main_avec_index_pointant_vers_le_bas_peau_foncée:',
        'ja': u':下指差し_濃い肌色:',
        'ko': u':아래쪽을_가리키는_손등_검은색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_baixo_pele_escura:',
        'it': ':indice_abbassato_carnagione_scura:',
        'fa': u':اشاره_به_پایین_پوست_آبنوسی:',
        'id': ':menunjuk_ke_bawah_warna_kulit_gelap:',
        'zh': u':反手食指向下指_较深肤色:'
    },
    u'\U0001F447\U0001F3FB': { # 👇🏻
        'en' : ':backhand_index_pointing_down_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_unten_weisender_zeigefinger_helle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_abajo_tono_de_piel_claro:',
        'fr': ':main_avec_index_pointant_vers_le_bas_peau_claire:',
        'ja': u':下指差し_薄い肌色:',
        'ko': u':아래쪽을_가리키는_손등_하얀_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_baixo_pele_clara:',
        'it': ':indice_abbassato_carnagione_chiara:',
        'fa': u':اشاره_به_پایین_پوست_سفید:',
        'id': ':menunjuk_ke_bawah_warna_kulit_cerah:',
        'zh': u':反手食指向下指_较浅肤色:'
    },
    u'\U0001F447\U0001F3FE': { # 👇🏾
        'en' : ':backhand_index_pointing_down_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_unten_weisender_zeigefinger_mitteldunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_abajo_tono_de_piel_oscuro_medio:',
        'fr': ':main_avec_index_pointant_vers_le_bas_peau_mate:',
        'ja': u':下指差し_やや濃い肌色:',
        'ko': u':아래쪽을_가리키는_손등_진한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_baixo_pele_morena_escura:',
        'it': ':indice_abbassato_carnagione_abbastanza_scura:',
        'fa': u':اشاره_به_پایین_پوست_گندمی:',
        'id': ':menunjuk_ke_bawah_warna_kulit_gelap-sedang:',
        'zh': u':反手食指向下指_中等深肤色:'
    },
    u'\U0001F447\U0001F3FC': { # 👇🏼
        'en' : ':backhand_index_pointing_down_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_unten_weisender_zeigefinger_mittelhelle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_abajo_tono_de_piel_claro_medio:',
        'fr': ':main_avec_index_pointant_vers_le_bas_peau_moyennement_claire:',
        'ja': u':下指差し_やや薄い肌色:',
        'ko': u':아래쪽을_가리키는_손등_연한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_baixo_pele_morena_clara:',
        'it': ':indice_abbassato_carnagione_abbastanza_chiara:',
        'fa': u':اشاره_به_پایین_پوست_روشن:',
        'id': ':menunjuk_ke_bawah_warna_kulit_cerah-sedang:',
        'zh': u':反手食指向下指_中等浅肤色:'
    },
    u'\U0001F447\U0001F3FD': { # 👇🏽
        'en' : ':backhand_index_pointing_down_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_unten_weisender_zeigefinger_mittlere_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_abajo_tono_de_piel_medio:',
        'fr': u':main_avec_index_pointant_vers_le_bas_peau_légèrement_mate:',
        'ja': u':下指差し_中間の肌色:',
        'ko': u':아래쪽을_가리키는_손등_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_baixo_pele_morena:',
        'it': ':indice_abbassato_carnagione_olivastra:',
        'fa': u':اشاره_به_پایین_پوست_طلایی:',
        'id': ':menunjuk_ke_bawah_warna_kulit_sedang:',
        'zh': u':反手食指向下指_中等肤色:'
    },
    u'\U0001F448': { # 👈
        'en' : ':backhand_index_pointing_left:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':point_left:'],
        'variant': True,
        'de': ':nach_links_weisender_zeigefinger:',
        'es': u':dorso_de_mano_con_índice_a_la_izquierda:',
        'fr': u':main_avec_index_pointant_à_gauche:',
        'ja': u':左指差し:',
        'ko': u':왼쪽을_가리키는_손등:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_esquerda:',
        'it': ':indice_verso_sinistra:',
        'fa': u':اشاره_به_چپ:',
        'id': ':menunjuk_ke_arah_kiri:',
        'zh': u':反手食指向左指:'
    },
    u'\U0001F448\U0001F3FF': { # 👈🏿
        'en' : ':backhand_index_pointing_left_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_links_weisender_zeigefinger_dunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_izquierda_tono_de_piel_oscuro:',
        'fr': u':main_avec_index_pointant_à_gauche_peau_foncée:',
        'ja': u':左指差し_濃い肌色:',
        'ko': u':왼쪽을_가리키는_손등_검은색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_esquerda_pele_escura:',
        'it': ':indice_verso_sinistra_carnagione_scura:',
        'fa': u':اشاره_به_چپ_پوست_آبنوسی:',
        'id': ':menunjuk_ke_arah_kiri_warna_kulit_gelap:',
        'zh': u':反手食指向左指_较深肤色:'
    },
    u'\U0001F448\U0001F3FB': { # 👈🏻
        'en' : ':backhand_index_pointing_left_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_links_weisender_zeigefinger_helle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_izquierda_tono_de_piel_claro:',
        'fr': u':main_avec_index_pointant_à_gauche_peau_claire:',
        'ja': u':左指差し_薄い肌色:',
        'ko': u':왼쪽을_가리키는_손등_하얀_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_esquerda_pele_clara:',
        'it': ':indice_verso_sinistra_carnagione_chiara:',
        'fa': u':اشاره_به_چپ_پوست_سفید:',
        'id': ':menunjuk_ke_arah_kiri_warna_kulit_cerah:',
        'zh': u':反手食指向左指_较浅肤色:'
    },
    u'\U0001F448\U0001F3FE': { # 👈🏾
        'en' : ':backhand_index_pointing_left_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_links_weisender_zeigefinger_mitteldunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_izquierda_tono_de_piel_oscuro_medio:',
        'fr': u':main_avec_index_pointant_à_gauche_peau_mate:',
        'ja': u':左指差し_やや濃い肌色:',
        'ko': u':왼쪽을_가리키는_손등_진한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_esquerda_pele_morena_escura:',
        'it': ':indice_verso_sinistra_carnagione_abbastanza_scura:',
        'fa': u':اشاره_به_چپ_پوست_گندمی:',
        'id': ':menunjuk_ke_arah_kiri_warna_kulit_gelap-sedang:',
        'zh': u':反手食指向左指_中等深肤色:'
    },
    u'\U0001F448\U0001F3FC': { # 👈🏼
        'en' : ':backhand_index_pointing_left_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_links_weisender_zeigefinger_mittelhelle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_izquierda_tono_de_piel_claro_medio:',
        'fr': u':main_avec_index_pointant_à_gauche_peau_moyennement_claire:',
        'ja': u':左指差し_やや薄い肌色:',
        'ko': u':왼쪽을_가리키는_손등_연한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_esquerda_pele_morena_clara:',
        'it': ':indice_verso_sinistra_carnagione_abbastanza_chiara:',
        'fa': u':اشاره_به_چپ_پوست_روشن:',
        'id': ':menunjuk_ke_arah_kiri_warna_kulit_cerah-sedang:',
        'zh': u':反手食指向左指_中等浅肤色:'
    },
    u'\U0001F448\U0001F3FD': { # 👈🏽
        'en' : ':backhand_index_pointing_left_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_links_weisender_zeigefinger_mittlere_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_izquierda_tono_de_piel_medio:',
        'fr': u':main_avec_index_pointant_à_gauche_peau_légèrement_mate:',
        'ja': u':左指差し_中間の肌色:',
        'ko': u':왼쪽을_가리키는_손등_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_esquerda_pele_morena:',
        'it': ':indice_verso_sinistra_carnagione_olivastra:',
        'fa': u':اشاره_به_چپ_پوست_طلایی:',
        'id': ':menunjuk_ke_arah_kiri_warna_kulit_sedang:',
        'zh': u':反手食指向左指_中等肤色:'
    },
    u'\U0001F449': { # 👉
        'en' : ':backhand_index_pointing_right:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':point_right:'],
        'variant': True,
        'de': ':nach_rechts_weisender_zeigefinger:',
        'es': u':dorso_de_mano_con_índice_a_la_derecha:',
        'fr': u':main_avec_index_pointant_à_droite:',
        'ja': u':右指差し:',
        'ko': u':오른쪽을_가리키는_손등:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_direita:',
        'it': ':indice_verso_destra:',
        'fa': u':اشاره_به_راست:',
        'id': ':menunjuk_ke_arah_kanan:',
        'zh': u':反手食指向右指:'
    },
    u'\U0001F449\U0001F3FF': { # 👉🏿
        'en' : ':backhand_index_pointing_right_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_rechts_weisender_zeigefinger_dunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_derecha_tono_de_piel_oscuro:',
        'fr': u':main_avec_index_pointant_à_droite_peau_foncée:',
        'ja': u':右指差し_濃い肌色:',
        'ko': u':오른쪽을_가리키는_손등_검은색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_direita_pele_escura:',
        'it': ':indice_verso_destra_carnagione_scura:',
        'fa': u':اشاره_به_راست_پوست_آبنوسی:',
        'id': ':menunjuk_ke_arah_kanan_warna_kulit_gelap:',
        'zh': u':反手食指向右指_较深肤色:'
    },
    u'\U0001F449\U0001F3FB': { # 👉🏻
        'en' : ':backhand_index_pointing_right_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_rechts_weisender_zeigefinger_helle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_derecha_tono_de_piel_claro:',
        'fr': u':main_avec_index_pointant_à_droite_peau_claire:',
        'ja': u':右指差し_薄い肌色:',
        'ko': u':오른쪽을_가리키는_손등_하얀_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_direita_pele_clara:',
        'it': ':indice_verso_destra_carnagione_chiara:',
        'fa': u':اشاره_به_راست_پوست_سفید:',
        'id': ':menunjuk_ke_arah_kanan_warna_kulit_cerah:',
        'zh': u':反手食指向右指_较浅肤色:'
    },
    u'\U0001F449\U0001F3FE': { # 👉🏾
        'en' : ':backhand_index_pointing_right_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_rechts_weisender_zeigefinger_mitteldunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_derecha_tono_de_piel_oscuro_medio:',
        'fr': u':main_avec_index_pointant_à_droite_peau_mate:',
        'ja': u':右指差し_やや濃い肌色:',
        'ko': u':오른쪽을_가리키는_손등_진한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_direita_pele_morena_escura:',
        'it': ':indice_verso_destra_carnagione_abbastanza_scura:',
        'fa': u':اشاره_به_راست_پوست_گندمی:',
        'id': ':menunjuk_ke_arah_kanan_warna_kulit_gelap-sedang:',
        'zh': u':反手食指向右指_中等深肤色:'
    },
    u'\U0001F449\U0001F3FC': { # 👉🏼
        'en' : ':backhand_index_pointing_right_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_rechts_weisender_zeigefinger_mittelhelle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_derecha_tono_de_piel_claro_medio:',
        'fr': u':main_avec_index_pointant_à_droite_peau_moyennement_claire:',
        'ja': u':右指差し_やや薄い肌色:',
        'ko': u':오른쪽을_가리키는_손등_연한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_direita_pele_morena_clara:',
        'it': ':indice_verso_destra_carnagione_abbastanza_chiara:',
        'fa': u':اشاره_به_راست_پوست_روشن:',
        'id': ':menunjuk_ke_arah_kanan_warna_kulit_cerah-sedang:',
        'zh': u':反手食指向右指_中等浅肤色:'
    },
    u'\U0001F449\U0001F3FD': { # 👉🏽
        'en' : ':backhand_index_pointing_right_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_rechts_weisender_zeigefinger_mittlere_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_a_la_derecha_tono_de_piel_medio:',
        'fr': u':main_avec_index_pointant_à_droite_peau_légèrement_mate:',
        'ja': u':右指差し_中間の肌色:',
        'ko': u':오른쪽을_가리키는_손등_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_a_direita_pele_morena:',
        'it': ':indice_verso_destra_carnagione_olivastra:',
        'fa': u':اشاره_به_راست_پوست_طلایی:',
        'id': ':menunjuk_ke_arah_kanan_warna_kulit_sedang:',
        'zh': u':反手食指向右指_中等肤色:'
    },
    u'\U0001F446': { # 👆
        'en' : ':backhand_index_pointing_up:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':point_up_2:'],
        'variant': True,
        'de': ':nach_oben_weisender_zeigefinger_von_hinten:',
        'es': u':dorso_de_mano_con_índice_hacia_arriba:',
        'fr': ':main_avec_index_pointant_vers_le_haut:',
        'ja': u':手の甲上指差し:',
        'ko': u':위쪽을_가리키는_손등:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_cima:',
        'it': ':indice_alzato:',
        'fa': u':اشاره_به_بالا_با_پشت_دست:',
        'id': ':menunjuk_ke_atas_(dibalik):',
        'zh': u':反手食指向上指:'
    },
    u'\U0001F446\U0001F3FF': { # 👆🏿
        'en' : ':backhand_index_pointing_up_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_hinten_dunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_arriba_tono_de_piel_oscuro:',
        'fr': u':main_avec_index_pointant_vers_le_haut_peau_foncée:',
        'ja': u':手の甲上指差し_濃い肌色:',
        'ko': u':위쪽을_가리키는_손등_검은색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_cima_pele_escura:',
        'it': ':indice_alzato_carnagione_scura:',
        'fa': u':اشاره_به_بالا_با_پشت_دست_پوست_آبنوسی:',
        'id': ':menunjuk_ke_atas_(dibalik)_warna_kulit_gelap:',
        'zh': u':反手食指向上指_较深肤色:'
    },
    u'\U0001F446\U0001F3FB': { # 👆🏻
        'en' : ':backhand_index_pointing_up_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_hinten_helle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_arriba_tono_de_piel_claro:',
        'fr': ':main_avec_index_pointant_vers_le_haut_peau_claire:',
        'ja': u':手の甲上指差し_薄い肌色:',
        'ko': u':위쪽을_가리키는_손등_하얀_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_cima_pele_clara:',
        'it': ':indice_alzato_carnagione_chiara:',
        'fa': u':اشاره_به_بالا_با_پشت_دست_پوست_سفید:',
        'id': ':menunjuk_ke_atas_(dibalik)_warna_kulit_cerah:',
        'zh': u':反手食指向上指_较浅肤色:'
    },
    u'\U0001F446\U0001F3FE': { # 👆🏾
        'en' : ':backhand_index_pointing_up_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_hinten_mitteldunkle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_arriba_tono_de_piel_oscuro_medio:',
        'fr': ':main_avec_index_pointant_vers_le_haut_peau_mate:',
        'ja': u':手の甲上指差し_やや濃い肌色:',
        'ko': u':위쪽을_가리키는_손등_진한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_cima_pele_morena_escura:',
        'it': ':indice_alzato_carnagione_abbastanza_scura:',
        'fa': u':اشاره_به_بالا_با_پشت_دست_پوست_گندمی:',
        'id': ':menunjuk_ke_atas_(dibalik)_warna_kulit_gelap-sedang:',
        'zh': u':反手食指向上指_中等深肤色:'
    },
    u'\U0001F446\U0001F3FC': { # 👆🏼
        'en' : ':backhand_index_pointing_up_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_hinten_mittelhelle_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_arriba_tono_de_piel_claro_medio:',
        'fr': ':main_avec_index_pointant_vers_le_haut_peau_moyennement_claire:',
        'ja': u':手の甲上指差し_やや薄い肌色:',
        'ko': u':위쪽을_가리키는_손등_연한_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_cima_pele_morena_clara:',
        'it': ':indice_alzato_carnagione_abbastanza_chiara:',
        'fa': u':اشاره_به_بالا_با_پشت_دست_پوست_روشن:',
        'id': ':menunjuk_ke_atas_(dibalik)_warna_kulit_cerah-sedang:',
        'zh': u':反手食指向上指_中等浅肤色:'
    },
    u'\U0001F446\U0001F3FD': { # 👆🏽
        'en' : ':backhand_index_pointing_up_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_hinten_mittlere_hautfarbe:',
        'es': u':dorso_de_mano_con_índice_hacia_arriba_tono_de_piel_medio:',
        'fr': u':main_avec_index_pointant_vers_le_haut_peau_légèrement_mate:',
        'ja': u':手の甲上指差し_中間の肌色:',
        'ko': u':위쪽을_가리키는_손등_갈색_피부:',
        'pt': u':dorso_da_mão_com_dedo_indicador_apontando_para_cima_pele_morena:',
        'it': ':indice_alzato_carnagione_olivastra:',
        'fa': u':اشاره_به_بالا_با_پشت_دست_پوست_طلایی:',
        'id': ':menunjuk_ke_atas_(dibalik)_warna_kulit_sedang:',
        'zh': u':反手食指向上指_中等肤色:'
    },
    u'\U0001F392': { # 🎒
        'en' : ':backpack:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':school_satchel:'],
        'de': ':schulranzen:',
        'es': ':mochila_escolar:',
        'fr': ':cartable:',
        'ja': u':バックパック:',
        'ko': u':학교_가방:',
        'pt': ':mochila:',
        'it': ':zaino:',
        'fa': u':کوله_پشتی:',
        'id': ':tas_sekolah:',
        'zh': u':书包:'
    },
    u'\U0001F953': { # 🥓
        'en' : ':bacon:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':bacon:',
        'es': ':beicon:',
        'fr': ':lard:',
        'ja': u':ベーコン:',
        'ko': u':베이컨:',
        'pt': ':bacon:',
        'it': ':pancetta:',
        'fa': u':بیکن:',
        'id': ':babi_asap:',
        'zh': u':培根:'
    },
    u'\U0001F9A1': { # 🦡
        'en' : ':badger:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':dachs:',
        'es': u':tejón:',
        'fr': ':blaireau:',
        'ja': u':アナグマ:',
        'ko': u':오소리:',
        'pt': ':texugo:',
        'it': ':tasso:',
        'fa': u':گورکن:',
        'id': ':musang:',
        'zh': u':獾:'
    },
    u'\U0001F3F8': { # 🏸
        'en' : ':badminton:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':badminton_racquet_and_shuttlecock:'],
        'de': ':badminton:',
        'es': u':bádminton:',
        'fr': ':badminton:',
        'ja': u':バドミントン:',
        'ko': u':배드민턴:',
        'pt': ':badminton:',
        'it': ':badminton:',
        'fa': u':بدمینتون:',
        'id': ':bulu_tangkis:',
        'zh': u':羽毛球:'
    },
    u'\U0001F96F': { # 🥯
        'en' : ':bagel:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bagel:',
        'es': ':bagel:',
        'fr': ':bagel:',
        'ja': u':ベーグル:',
        'ko': u':베이글:',
        'pt': ':rosca:',
        'it': ':bagel:',
        'fa': u':نان_بیگل:',
        'id': ':bagel:',
        'zh': u':面包圈:'
    },
    u'\U0001F6C4': { # 🛄
        'en' : ':baggage_claim:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':gepäckausgabe:',
        'es': ':recogida_de_equipajes:',
        'fr': ':retrait_des_bagages:',
        'ja': u':手荷物受取:',
        'ko': u':짐_찾는_곳:',
        'pt': u':restituição_de_bagagem:',
        'it': ':simbolo_del_ritiro_bagagli:',
        'fa': u':دریافت_بار:',
        'id': ':pengambilan_bagasi:',
        'zh': u':提取行李:'
    },
    u'\U0001F956': { # 🥖
        'en' : ':baguette_bread:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':baguette:',
        'es': ':baguete:',
        'fr': ':baguette:',
        'ja': u':バゲット:',
        'ko': u':바게트:',
        'pt': ':baguete:',
        'it': ':baguette:',
        'fa': u':نان_باگت:',
        'id': ':roti_baguette:',
        'zh': u':法式长棍面包:'
    },
    u'\U00002696\U0000FE0F': { # ⚖️
        'en' : ':balance_scale:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':scales:'],
        'variant': True,
        'de': ':waage:',
        'es': ':balanza:',
        'fr': u':balance_à_poids:',
        'ja': u':天秤:',
        'ko': u':접시저울:',
        'pt': u':balança:',
        'it': ':bilancia_a_doppio_piatto:',
        'fa': u':ترازو:',
        'id': ':timbangan_gantung:',
        'zh': u':天平:'
    },
    u'\U00002696': { # ⚖
        'en' : ':balance_scale:',
        'status' : unqualified,
        'E' : 1,
        'alias' : [':scales:'],
        'variant': True,
        'de': ':waage:',
        'es': ':balanza:',
        'fr': u':balance_à_poids:',
        'ja': u':天秤:',
        'ko': u':접시저울:',
        'pt': u':balança:',
        'it': ':bilancia_a_doppio_piatto:',
        'fa': u':ترازو:',
        'id': ':timbangan_gantung:',
        'zh': u':天平:'
    },
    u'\U0001F9B2': { # 🦲
        'en' : ':bald:',
        'status' : component,
        'E' : 11,
        'de': ':glatze:',
        'es': ':sin_pelo:',
        'fr': ':chauve:',
        'ja': u':はげ頭:',
        'ko': u':대머리:',
        'pt': ':careca:',
        'it': ':calvo:',
        'fa': u':تاس:',
        'id': ':gundul:',
        'zh': u':秃顶:'
    },
    u'\U0001FA70': { # 🩰
        'en' : ':ballet_shoes:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':ballettschuhe:',
        'es': ':zapatillas_de_ballet:',
        'fr': ':chaussons_de_danse:',
        'ja': u':トウシューズ:',
        'ko': u':발레_슈즈:',
        'pt': u':sapatilha_de_balé:',
        'it': ':scarpette_da_ballerina:',
        'fa': u':کفش_باله:',
        'id': ':sepatu_balet:',
        'zh': u':芭蕾舞鞋:'
    },
    u'\U0001F388': { # 🎈
        'en' : ':balloon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':luftballon:',
        'es': ':globo:',
        'fr': ':ballon_gonflable:',
        'ja': u':風船:',
        'ko': u':풍선:',
        'pt': u':balão:',
        'it': ':palloncino:',
        'fa': u':بادکنک:',
        'id': ':balon:',
        'zh': u':气球:'
    },
    u'\U0001F5F3\U0000FE0F': { # 🗳️
        'en' : ':ballot_box_with_ballot:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':ballot_box:'],
        'variant': True,
        'de': ':urne_mit_wahlzettel:',
        'es': ':urna_con_papeleta:',
        'fr': u':urne_électorale:',
        'ja': u':投票箱:',
        'ko': u':투표_용지가_있는_투표_상자:',
        'pt': u':urna_eleitoral_com_cédula:',
        'it': ':urna_elettorale_con_scheda:',
        'fa': u':صندوق_رأی:',
        'id': ':kotak_dengan_surat_suara:',
        'zh': u':投票箱:'
    },
    u'\U0001F5F3': { # 🗳
        'en' : ':ballot_box_with_ballot:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':ballot_box:'],
        'variant': True,
        'de': ':urne_mit_wahlzettel:',
        'es': ':urna_con_papeleta:',
        'fr': u':urne_électorale:',
        'ja': u':投票箱:',
        'ko': u':투표_용지가_있는_투표_상자:',
        'pt': u':urna_eleitoral_com_cédula:',
        'it': ':urna_elettorale_con_scheda:',
        'fa': u':صندوق_رأی:',
        'id': ':kotak_dengan_surat_suara:',
        'zh': u':投票箱:'
    },
    u'\U0001F34C': { # 🍌
        'en' : ':banana:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':banane:',
        'es': u':plátano:',
        'fr': ':banane:',
        'ja': u':バナナ:',
        'ko': u':바나나:',
        'pt': ':banana:',
        'it': ':banana:',
        'fa': u':موز:',
        'id': ':pisang:',
        'zh': u':香蕉:'
    },
    u'\U0001FA95': { # 🪕
        'en' : ':banjo:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':banjo:',
        'es': ':banjo:',
        'fr': ':banjo:',
        'ja': u':バンジョー:',
        'ko': u':밴조:',
        'pt': ':banjo:',
        'it': ':banjo:',
        'fa': u':بانجو:',
        'id': ':banjo:',
        'zh': u':班卓琴:'
    },
    u'\U0001F3E6': { # 🏦
        'en' : ':bank:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':bank:',
        'es': ':banco:',
        'fr': ':banque:',
        'ja': u':銀行:',
        'ko': u':은행:',
        'pt': ':banco:',
        'it': ':banca:',
        'fa': u':بانک:',
        'id': ':bank:',
        'zh': u':银行:'
    },
    u'\U0001F4CA': { # 📊
        'en' : ':bar_chart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':balkendiagramm:',
        'es': u':gráfico_de_barras:',
        'fr': u':graphiques_à_barres:',
        'ja': u':棒グラフ:',
        'ko': u':막대_그래프:',
        'pt': u':gráfico_de_barras:',
        'it': ':grafico_a_barre:',
        'fa': u':نمودار_ستونی:',
        'id': ':diagram_batang:',
        'zh': u':条形图:'
    },
    u'\U0001F488': { # 💈
        'en' : ':barber_pole:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':barber:'],
        'de': u':barbershop-säule:',
        'es': ':poste_de_barbero:',
        'fr': ':enseigne_de_barbier:',
        'ja': u':床屋:',
        'ko': u':이발소:',
        'pt': ':barbearia:',
        'it': ':barbiere:',
        'fa': u':چراغ_سلمانی:',
        'id': ':tanda_salon:',
        'zh': u':理发店:'
    },
    u'\U000026BE': { # ⚾
        'en' : ':baseball:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':baseball:',
        'es': u':béisbol:',
        'fr': ':baseball:',
        'ja': u':野球:',
        'ko': u':야구공:',
        'pt': ':bola_de_beisebol:',
        'it': ':palla_da_baseball:',
        'fa': u':بیسبال:',
        'id': ':bisbol:',
        'zh': u':棒球:'
    },
    u'\U0001F9FA': { # 🧺
        'en' : ':basket:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':korb:',
        'es': ':cesta:',
        'fr': ':panier:',
        'ja': u':かご:',
        'ko': u':바구니:',
        'pt': ':cesta:',
        'it': ':cesto:',
        'fa': u':سبد:',
        'id': ':keranjang:',
        'zh': u':筐:'
    },
    u'\U0001F3C0': { # 🏀
        'en' : ':basketball:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':basketball:',
        'es': u':balón_de_baloncesto:',
        'fr': ':basket:',
        'ja': u':バスケットボール:',
        'ko': u':농구:',
        'pt': ':bola_de_basquete:',
        'it': ':palla_da_pallacanestro:',
        'fa': u':بسکتبال:',
        'id': ':bola_basket:',
        'zh': u':篮球:'
    },
    u'\U0001F987': { # 🦇
        'en' : ':bat:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':fledermaus:',
        'es': u':murciélago:',
        'fr': ':chauve-souris:',
        'ja': u':コウモリ:',
        'ko': u':박쥐:',
        'pt': ':morcego:',
        'it': ':pipistrello:',
        'fa': u':خفاش:',
        'id': ':kelelawar:',
        'zh': u':蝙蝠:'
    },
    u'\U0001F6C1': { # 🛁
        'en' : ':bathtub:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':badewanne:',
        'es': u':bañera:',
        'fr': ':baignoire:',
        'ja': u':バスタブ:',
        'ko': u':욕조:',
        'pt': ':banheira:',
        'it': ':vasca:',
        'fa': u':وان_حمام:',
        'id': ':bathtub:',
        'zh': u':浴缸:'
    },
    u'\U0001F50B': { # 🔋
        'en' : ':battery:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':batterie:',
        'es': ':pila:',
        'fr': ':pile:',
        'ja': u':電池:',
        'ko': u':배터리:',
        'pt': ':pilha:',
        'it': ':batteria:',
        'fa': u':باتری:',
        'id': ':baterai:',
        'zh': u':电池:'
    },
    u'\U0001F3D6\U0000FE0F': { # 🏖️
        'en' : ':beach_with_umbrella:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':beach_umbrella:'],
        'variant': True,
        'de': ':strand_mit_sonnenschirm:',
        'es': ':playa_y_sombrilla:',
        'fr': ':plage_avec_parasol:',
        'ja': u':ビーチパラソル:',
        'ko': u':파라솔이_있는_해변:',
        'pt': ':praia_e_guarda-sol:',
        'it': ':spiaggia_con_ombrellone:',
        'fa': u':ساحل_و_سایبان:',
        'id': ':pantai_dan_payung:',
        'zh': u':沙滩伞:'
    },
    u'\U0001F3D6': { # 🏖
        'en' : ':beach_with_umbrella:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':beach_umbrella:'],
        'variant': True,
        'de': ':strand_mit_sonnenschirm:',
        'es': ':playa_y_sombrilla:',
        'fr': ':plage_avec_parasol:',
        'ja': u':ビーチパラソル:',
        'ko': u':파라솔이_있는_해변:',
        'pt': ':praia_e_guarda-sol:',
        'it': ':spiaggia_con_ombrellone:',
        'fa': u':ساحل_و_سایبان:',
        'id': ':pantai_dan_payung:',
        'zh': u':沙滩伞:'
    },
    u'\U0001F601': { # 😁
        'en' : ':beaming_face_with_smiling_eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':grin:'],
        'de': ':strahlendes_gesicht_mit_lachenden_augen:',
        'es': ':cara_radiante_con_ojos_sonrientes:',
        'fr': ':visage_souriant_aux_yeux_rieurs:',
        'ja': u':にやっと笑う:',
        'ko': u':미소_짓는_눈으로_웃는_얼굴:',
        'pt': ':rosto_contente_com_olhos_sorridentes:',
        'it': ':faccina_raggiante_con_occhi_felici:',
        'fa': u':خندهٔ_دندانی:',
        'id': ':wajah_gembira_dengan_mata_bahagia:',
        'zh': u':嘻嘻:'
    },
    u'\U0001FAD8': { # 🫘
        'en' : ':beans:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':bohnen:',
        'es': ':alubias:',
        'fr': ':haricots:',
        'ja': u':豆:',
        'ko': u':콩:',
        'pt': u':feijões:',
        'it': ':fagioli:',
        'fa': u':لوبیا:',
        'id': ':kacang_merah:',
        'zh': u':豆:'
    },
    u'\U0001F43B': { # 🐻
        'en' : ':bear:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':bär:',
        'es': ':oso:',
        'fr': ':ours:',
        'ja': u':クマの顔:',
        'ko': u':곰_얼굴:',
        'pt': ':rosto_de_urso:',
        'it': ':orso:',
        'fa': u':خرس:',
        'id': ':beruang:',
        'zh': u':熊:'
    },
    u'\U0001F493': { # 💓
        'en' : ':beating_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heartbeat:'],
        'de': ':schlagendes_herz:',
        'es': u':corazón_latiendo:',
        'fr': u':cœur_battant:',
        'ja': u':ドキドキするハート:',
        'ko': u':두근거리는_하트:',
        'pt': u':coração_pulsante:',
        'it': ':cuore_che_batte:',
        'fa': u':قلب_تپنده:',
        'id': ':hati_berdetak:',
        'zh': u':心跳:'
    },
    u'\U0001F9AB': { # 🦫
        'en' : ':beaver:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':biber:',
        'es': ':castor:',
        'fr': ':castor:',
        'ja': u':ビーバー:',
        'ko': u':비버:',
        'pt': ':castor:',
        'it': ':castoro:',
        'fa': u':بیدستر:',
        'id': ':biwara:',
        'zh': u':海狸:'
    },
    u'\U0001F6CF\U0000FE0F': { # 🛏️
        'en' : ':bed:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':bett:',
        'es': ':cama:',
        'fr': ':lit:',
        'ja': u':ベッド:',
        'ko': u':침대:',
        'pt': ':cama:',
        'it': ':letto:',
        'fa': u':تختخواب:',
        'id': ':tempat_tidur:',
        'zh': u':床:'
    },
    u'\U0001F6CF': { # 🛏
        'en' : ':bed:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':bett:',
        'es': ':cama:',
        'fr': ':lit:',
        'ja': u':ベッド:',
        'ko': u':침대:',
        'pt': ':cama:',
        'it': ':letto:',
        'fa': u':تختخواب:',
        'id': ':tempat_tidur:',
        'zh': u':床:'
    },
    u'\U0001F37A': { # 🍺
        'en' : ':beer_mug:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':beer:'],
        'de': ':bierkrug:',
        'es': ':jarra_de_cerveza:',
        'fr': ':chope:',
        'ja': u':ビールジョッキ:',
        'ko': u':맥주잔:',
        'pt': ':cerveja:',
        'it': ':boccale_di_birra:',
        'fa': u':لیوان_آب_جو:',
        'id': ':mug_bir:',
        'zh': u':啤酒:'
    },
    u'\U0001FAB2': { # 🪲
        'en' : ':beetle:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':käfer:',
        'es': ':escarabajo:',
        'fr': u':scarabée:',
        'ja': u':カブトムシ:',
        'ko': u':딱정벌레:',
        'pt': ':besouro:',
        'it': ':coleottero:',
        'fa': u':سوسک:',
        'id': ':kumbang:',
        'zh': u':甲虫:'
    },
    u'\U0001F514': { # 🔔
        'en' : ':bell:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':glocke:',
        'es': ':campana:',
        'fr': ':cloche:',
        'ja': u':ベル:',
        'ko': u':종:',
        'pt': ':sino:',
        'it': ':campana:',
        'fa': u':زنگ:',
        'id': ':lonceng:',
        'zh': u':铃铛:'
    },
    u'\U0001FAD1': { # 🫑
        'en' : ':bell_pepper:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':paprika:',
        'es': ':pimiento:',
        'fr': ':poivron:',
        'ja': u':赤ピーマン:',
        'ko': u':피망:',
        'pt': u':pimentão:',
        'it': ':peperone:',
        'fa': u':فلفل_دلمه_ای:',
        'id': ':paprika:',
        'zh': u':灯笼椒:'
    },
    u'\U0001F515': { # 🔕
        'en' : ':bell_with_slash:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':no_bell:'],
        'de': ':durchgestrichene_glocke:',
        'es': u':campana_con_signo_de_cancelación:',
        'fr': u':alarme_désactivée:',
        'ja': u':ベル消音:',
        'ko': u':음소거:',
        'pt': ':sino_silenciado:',
        'it': ':campana_sbarrata:',
        'fa': u':خط_قرمز_روی_زنگوله:',
        'id': ':lonceng_dicoret:',
        'zh': u':禁止响铃:'
    },
    u'\U0001F6CE\U0000FE0F': { # 🛎️
        'en' : ':bellhop_bell:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':rezeptionsklingel:',
        'es': ':timbre_de_hotel:',
        'fr': ':cloche_de_comptoir:',
        'ja': u':ベルボーイベル:',
        'ko': u':호출_벨:',
        'pt': ':sineta:',
        'it': ':campanello_da_hotel:',
        'fa': u':زنگ_میز_پذیرش:',
        'id': ':bel_meja:',
        'zh': u':服务铃:'
    },
    u'\U0001F6CE': { # 🛎
        'en' : ':bellhop_bell:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':rezeptionsklingel:',
        'es': ':timbre_de_hotel:',
        'fr': ':cloche_de_comptoir:',
        'ja': u':ベルボーイベル:',
        'ko': u':호출_벨:',
        'pt': ':sineta:',
        'it': ':campanello_da_hotel:',
        'fa': u':زنگ_میز_پذیرش:',
        'id': ':bel_meja:',
        'zh': u':服务铃:'
    },
    u'\U0001F371': { # 🍱
        'en' : ':bento_box:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bento:'],
        'de': ':bento-box:',
        'es': ':caja_de_bento:',
        'fr': u':boîte_déjeuner:',
        'ja': u':弁当:',
        'ko': u':도시락:',
        'pt': u':bentô:',
        'it': ':bento_box:',
        'fa': u':جعبه_بنتو:',
        'id': ':kotak_bento:',
        'zh': u':盒饭:'
    },
    u'\U0001F9C3': { # 🧃
        'en' : ':beverage_box:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':trinkpäckchen:',
        'es': ':tetrabrik:',
        'fr': ':briquette_de_jus:',
        'ja': u':紙パック飲料:',
        'ko': u':음료_팩:',
        'pt': ':suco_de_caixa:',
        'it': ':bevanda_monodose:',
        'fa': u':پاکت_نوشیدنی:',
        'id': ':kotak_minuman:',
        'zh': u':饮料盒:'
    },
    u'\U0001F6B2': { # 🚲
        'en' : ':bicycle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bike:'],
        'variant': True,
        'de': ':fahrrad:',
        'es': ':bicicleta:',
        'fr': u':vélo:',
        'ja': u':自転車:',
        'ko': u':자전거:',
        'pt': ':bicicleta:',
        'it': ':bicicletta:',
        'fa': u':دوچرخه:',
        'id': ':sepeda:',
        'zh': u':自行车:'
    },
    u'\U0001F459': { # 👙
        'en' : ':bikini:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':bikini:',
        'es': ':bikini:',
        'fr': ':bikini:',
        'ja': u':ビキニ:',
        'ko': u':비키니:',
        'pt': u':biquíni:',
        'it': ':bikini:',
        'fa': u':بیکینی:',
        'id': ':bikini:',
        'zh': u':比基尼:'
    },
    u'\U0001F9E2': { # 🧢
        'en' : ':billed_cap:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':baseballmütze:',
        'es': ':gorra_con_visera:',
        'fr': u':casquette_américaine:',
        'ja': u':キャップ:',
        'ko': u':야구모자:',
        'pt': u':boné:',
        'it': ':cappello_con_visiera:',
        'fa': u':کلاه_لبه_دار:',
        'id': ':topi_berlidah:',
        'zh': u':鸭舌帽:'
    },
    u'\U00002623\U0000FE0F': { # ☣️
        'en' : ':biohazard:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':biohazard_sign:'],
        'variant': True,
        'de': u':biogefährdung:',
        'es': u':riesgo_biológico:',
        'fr': ':danger_biologique:',
        'ja': u':バイオハザード:',
        'ko': u':생물학적_위험:',
        'pt': u':risco_biológico:',
        'it': ':simbolo_del_rischio_biologico:',
        'fa': u':خطر_زیستی:',
        'id': ':biohazard:',
        'zh': u':生物危害:'
    },
    u'\U00002623': { # ☣
        'en' : ':biohazard:',
        'status' : unqualified,
        'E' : 1,
        'alias' : [':biohazard_sign:'],
        'variant': True,
        'de': u':biogefährdung:',
        'es': u':riesgo_biológico:',
        'fr': ':danger_biologique:',
        'ja': u':バイオハザード:',
        'ko': u':생물학적_위험:',
        'pt': u':risco_biológico:',
        'it': ':simbolo_del_rischio_biologico:',
        'fa': u':خطر_زیستی:',
        'id': ':biohazard:',
        'zh': u':生物危害:'
    },
    u'\U0001F426': { # 🐦
        'en' : ':bird:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':vogel:',
        'es': u':pájaro:',
        'fr': ':oiseau:',
        'ja': u':鳥:',
        'ko': u':새:',
        'pt': u':pássaro:',
        'it': ':uccello:',
        'fa': u':پرنده:',
        'id': ':burung:',
        'zh': u':鸟:'
    },
    u'\U0001F382': { # 🎂
        'en' : ':birthday_cake:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':birthday:'],
        'de': ':geburtstagskuchen:',
        'es': u':tarta_de_cumpleaños:',
        'fr': u':gâteau_d’anniversaire:',
        'ja': u':バースデーケーキ:',
        'ko': u':생일_케이크:',
        'pt': u':bolo_de_aniversário:',
        'it': ':torta_di_compleanno:',
        'fa': u':کیک_تولد:',
        'id': ':kue_ulang_tahun:',
        'zh': u':生日蛋糕:'
    },
    u'\U0001F9AC': { # 🦬
        'en' : ':bison:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':bison:',
        'es': ':bisonte:',
        'fr': ':bison:',
        'ja': u':バイソン:',
        'ko': u':들소:',
        'pt': u':bisão:',
        'it': ':bisonte:',
        'fa': u':گاومیش:',
        'id': ':bison:',
        'zh': u':大野牛:'
    },
    u'\U0001FAE6': { # 🫦
        'en' : ':biting_lip:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':auf_lippe_beißen:',
        'es': ':labio_mordido:',
        'fr': u':lèvres_qui_se_mordent:',
        'ja': u':唇を咬んでいる口:',
        'ko': u':입술을_깨물고_있는_입:',
        'pt': u':mordendo_o_lábio:',
        'it': ':bocca_che_morde_il_labbro:',
        'fa': u':گازگرفتن_لب:',
        'id': ':menggigit_bibir:',
        'zh': u':咬住嘴唇:'
    },
    u'\U0001F426\U0000200D\U00002B1B': { # 🐦‍⬛
        'en' : ':black_bird:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001F408\U0000200D\U00002B1B': { # 🐈‍⬛
        'en' : ':black_cat:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':schwarze_katze:',
        'es': ':gato_negro:',
        'fr': ':chat_noir:',
        'ja': u':黒猫:',
        'ko': u':검은_고양이:',
        'pt': ':gato_preto:',
        'it': ':gatto_nero:',
        'fa': u':گربه_سیاه:',
        'id': ':kucing_hitam:',
        'zh': u':黑猫:'
    },
    u'\U000026AB': { # ⚫
        'en' : ':black_circle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':schwarzer_punkt:',
        'es': u':círculo_negro:',
        'fr': ':disque_noir:',
        'ja': u':黒い丸:',
        'ko': u':검은색_원:',
        'pt': u':círculo_preto:',
        'it': ':cerchio_nero:',
        'fa': u':دایره_مشکی:',
        'id': ':lingkaran_hitam:',
        'zh': u':黑色圆:'
    },
    u'\U0001F3F4': { # 🏴
        'en' : ':black_flag:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':waving_black_flag:'],
        'de': ':schwarze_flagge:',
        'es': ':bandera_negra:',
        'fr': ':drapeau_noir:',
        'ja': u':黒旗:',
        'ko': u':펄럭이는_검은색_깃발:',
        'pt': ':bandeira_preta:',
        'it': ':bandiera_nera:',
        'fa': u':پرچم_سیاه:',
        'id': ':bendera_hitam:',
        'zh': u':举黑旗:'
    },
    u'\U0001F5A4': { # 🖤
        'en' : ':black_heart:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schwarzes_herz:',
        'es': u':corazón_negro:',
        'fr': u':cœur_noir:',
        'ja': u':黒いハート:',
        'ko': u':검은색_하트:',
        'pt': u':coração_preto:',
        'it': ':cuore_nero:',
        'fa': u':قلب_سیاه:',
        'id': ':hati_hitam:',
        'zh': u':黑心:'
    },
    u'\U00002B1B': { # ⬛
        'en' : ':black_large_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':großes_schwarzes_quadrat:',
        'es': ':cuadrado_negro_grande:',
        'fr': u':grand_carré_noir:',
        'ja': u':黒四角特大:',
        'ko': u':큰_검은색_사각형:',
        'pt': ':quadrado_preto_grande:',
        'it': ':quadrato_nero_grande:',
        'fa': u':مربع_مشکی_بزرگ:',
        'id': ':persegi_besar_hitam:',
        'zh': u':黑线大方框:'
    },
    u'\U000025FE': { # ◾
        'en' : ':black_medium-small_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':black_medium_small_square:'],
        'variant': True,
        'de': ':mittelkleines_schwarzes_quadrat:',
        'es': u':cuadrado_negro_mediano-pequeño:',
        'fr': u':carré_petit_moyen_noir:',
        'ja': u':黒四角中:',
        'ko': u':중각_작은_검은색_사각형:',
        'pt': u':quadrado_preto_médio_menor:',
        'it': ':quadrato_nero_medio-piccolo:',
        'fa': u':مربع_مشکی_نسبتاً_کوچک:',
        'id': ':persegi_kecil_medium_hitam:',
        'zh': u':黑色中小方块:'
    },
    u'\U000025FC\U0000FE0F': { # ◼️
        'en' : ':black_medium_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':mittelgroßes_schwarzes_quadrat:',
        'es': ':cuadrado_negro_mediano:',
        'fr': u':carré_moyen_noir:',
        'ja': u':黒四角大:',
        'ko': u':중간_검은색_사각형:',
        'pt': u':quadrado_preto_médio:',
        'it': ':quadrato_nero_medio:',
        'fa': u':مربع_مشکی_متوسط:',
        'id': ':persegi_medium_hitam:',
        'zh': u':黑色中方块:'
    },
    u'\U000025FC': { # ◼
        'en' : ':black_medium_square:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': u':mittelgroßes_schwarzes_quadrat:',
        'es': ':cuadrado_negro_mediano:',
        'fr': u':carré_moyen_noir:',
        'ja': u':黒四角大:',
        'ko': u':중간_검은색_사각형:',
        'pt': u':quadrado_preto_médio:',
        'it': ':quadrato_nero_medio:',
        'fa': u':مربع_مشکی_متوسط:',
        'id': ':persegi_medium_hitam:',
        'zh': u':黑色中方块:'
    },
    u'\U00002712\U0000FE0F': { # ✒️
        'en' : ':black_nib:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':schwarzer_federhalter:',
        'es': ':pluma_negra:',
        'fr': ':stylo_plume_noir:',
        'ja': u':ペン先:',
        'ko': u':검은색_펜촉:',
        'pt': ':ponta_de_caneta_tinteiro:',
        'it': ':pennino:',
        'fa': u':قلم_مشکی:',
        'id': ':ujung_pena:',
        'zh': u':钢笔尖:'
    },
    u'\U00002712': { # ✒
        'en' : ':black_nib:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':schwarzer_federhalter:',
        'es': ':pluma_negra:',
        'fr': ':stylo_plume_noir:',
        'ja': u':ペン先:',
        'ko': u':검은색_펜촉:',
        'pt': ':ponta_de_caneta_tinteiro:',
        'it': ':pennino:',
        'fa': u':قلم_مشکی:',
        'id': ':ujung_pena:',
        'zh': u':钢笔尖:'
    },
    u'\U000025AA\U0000FE0F': { # ▪️
        'en' : ':black_small_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':kleines_schwarzes_quadrat:',
        'es': u':cuadrado_negro_pequeño:',
        'fr': u':petit_carré_noir:',
        'ja': u':黒四角小:',
        'ko': u':작은_검은색_사각형:',
        'pt': ':quadrado_preto_pequeno:',
        'it': ':quadrato_nero_piccolo:',
        'fa': u':مربع_مشکی_کوچک:',
        'id': ':persegi_kecil_hitam:',
        'zh': u':黑色小方块:'
    },
    u'\U000025AA': { # ▪
        'en' : ':black_small_square:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':kleines_schwarzes_quadrat:',
        'es': u':cuadrado_negro_pequeño:',
        'fr': u':petit_carré_noir:',
        'ja': u':黒四角小:',
        'ko': u':작은_검은색_사각형:',
        'pt': ':quadrado_preto_pequeno:',
        'it': ':quadrato_nero_piccolo:',
        'fa': u':مربع_مشکی_کوچک:',
        'id': ':persegi_kecil_hitam:',
        'zh': u':黑色小方块:'
    },
    u'\U0001F532': { # 🔲
        'en' : ':black_square_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':schwarze_quadratische_schaltfläche:',
        'es': u':botón_cuadrado_con_borde_negro:',
        'fr': u':carré_noir:',
        'ja': u':黒枠四角:',
        'ko': u':테두리가_검은_사각_버튼:',
        'pt': u':botão_quadrado_preto:',
        'it': ':tasto_quadrato_bianco_con_bordo_nero:',
        'fa': u':دکمۀ_مربع_مشکی:',
        'id': ':tombol_persegi_hitam:',
        'zh': u':黑色方形按钮:'
    },
    u'\U0001F33C': { # 🌼
        'en' : ':blossom:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':gelbe_blüte:',
        'es': ':flor:',
        'fr': ':bourgeon:',
        'ja': u':開花:',
        'ko': u':꽃송이:',
        'pt': ':flor:',
        'it': ':fiore:',
        'fa': u':شکوفه:',
        'id': ':mekar:',
        'zh': u':开花:'
    },
    u'\U0001F421': { # 🐡
        'en' : ':blowfish:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kugelfisch:',
        'es': ':pez_globo:',
        'fr': ':poisson-lune:',
        'ja': u':フグ:',
        'ko': u':복어:',
        'pt': ':baiacu:',
        'it': ':pesce_palla:',
        'fa': u':ماهی_بادکنکی:',
        'id': ':ikan_gembung:',
        'zh': u':河豚:'
    },
    u'\U0001F4D8': { # 📘
        'en' : ':blue_book:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':blaues_buch:',
        'es': ':libro_azul:',
        'fr': ':livre_bleu:',
        'ja': u':青の本:',
        'ko': u':파란색_책:',
        'pt': ':livro_azul:',
        'it': ':libro_blu:',
        'fa': u':کتاب_آبی:',
        'id': ':buku_biru:',
        'zh': u':蓝色书本:'
    },
    u'\U0001F535': { # 🔵
        'en' : ':blue_circle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':large_blue_circle:'],
        'de': ':blauer_punkt:',
        'es': u':círculo_azul:',
        'fr': ':disque_bleu:',
        'ja': u':青い丸:',
        'ko': u':파란_원:',
        'pt': u':círculo_azul:',
        'it': ':cerchio_blu:',
        'fa': u':دایره_آبی:',
        'id': ':lingkaran_biru:',
        'zh': u':蓝色圆:'
    },
    u'\U0001F499': { # 💙
        'en' : ':blue_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':blaues_herz:',
        'es': u':corazón_azul:',
        'fr': u':cœur_bleu:',
        'ja': u':青いハート:',
        'ko': u':파란색_하트:',
        'pt': u':coração_azul:',
        'it': ':cuore_blu:',
        'fa': u':قلب_آبی:',
        'id': ':hati_biru:',
        'zh': u':蓝心:'
    },
    u'\U0001F7E6': { # 🟦
        'en' : ':blue_square:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':blaues_quadrat:',
        'es': ':cuadrado_azul:',
        'fr': u':carré_bleu:',
        'ja': u':青い四角:',
        'ko': u':파란색_사각형:',
        'pt': ':quadrado_azul:',
        'it': ':quadrato_blu:',
        'fa': u':مربع_آبی:',
        'id': ':persegi_biru:',
        'zh': u':蓝色方块:'
    },
    u'\U0001FAD0': { # 🫐
        'en' : ':blueberries:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':blaubeeren:',
        'es': u':arándanos:',
        'fr': ':myrtilles:',
        'ja': u':ブルーベリー:',
        'ko': u':블루베리:',
        'pt': ':mirtilos:',
        'it': ':mirtilli:',
        'fa': u':توت_آبی:',
        'id': ':blueberry:',
        'zh': u':蓝莓:'
    },
    u'\U0001F417': { # 🐗
        'en' : ':boar:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wildschwein:',
        'es': u':jabalí:',
        'fr': ':sanglier:',
        'ja': u':イノシシ:',
        'ko': u':멧돼지:',
        'pt': ':javali:',
        'it': ':cinghiale:',
        'fa': u':گراز_نر:',
        'id': ':babi_hutan:',
        'zh': u':野猪:'
    },
    u'\U0001F4A3': { # 💣
        'en' : ':bomb:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':bombe:',
        'es': ':bomba:',
        'fr': ':bombe:',
        'ja': u':爆弾:',
        'ko': u':폭탄:',
        'pt': ':bomba:',
        'it': ':bomba:',
        'fa': u':بمب:',
        'id': ':bom:',
        'zh': u':炸弹:'
    },
    u'\U0001F9B4': { # 🦴
        'en' : ':bone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':knochen:',
        'es': ':hueso:',
        'fr': ':os:',
        'ja': u':骨:',
        'ko': u':뼈다귀:',
        'pt': ':osso:',
        'it': ':osso:',
        'fa': u':استخوان:',
        'id': ':tulang:',
        'zh': u':骨头:'
    },
    u'\U0001F516': { # 🔖
        'en' : ':bookmark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':lesezeichen:',
        'es': u':marcapáginas:',
        'fr': ':marque-page:',
        'ja': u':しおり:',
        'ko': u':북마크:',
        'pt': u':marcador_de_página:',
        'it': ':segnalibro:',
        'fa': u':نشان_گذار_کتاب:',
        'id': ':pembatas_buku:',
        'zh': u':书签:'
    },
    u'\U0001F4D1': { # 📑
        'en' : ':bookmark_tabs:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':pagemarker:',
        'es': ':marcadores:',
        'fr': ':signets:',
        'ja': u':ページに付箋:',
        'ko': u':북마크_탭:',
        'pt': u':marcadores_de_página:',
        'it': ':etichette_segnalibro:',
        'fa': u':برچسب_های_نشانه_گذاری:',
        'id': ':penanda_halaman_buku:',
        'zh': u':标签页:'
    },
    u'\U0001F4DA': { # 📚
        'en' : ':books:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':bücherstapel:',
        'es': ':libros:',
        'fr': ':livres:',
        'ja': u':本の山:',
        'ko': u':책_여러_권:',
        'pt': ':livros:',
        'it': ':libri:',
        'fa': u':چند_کتاب:',
        'id': ':buku:',
        'zh': u':书:'
    },
    u'\U0001FA83': { # 🪃
        'en' : ':boomerang:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':bumerang:',
        'es': u':bumerán:',
        'fr': ':boomerang:',
        'ja': u':ブーメラン:',
        'ko': u':부메랑:',
        'pt': ':bumerangue:',
        'it': ':boomerang:',
        'fa': u':بومرنگ:',
        'id': ':bumerang:',
        'zh': u':回旋镖:'
    },
    u'\U0001F37E': { # 🍾
        'en' : ':bottle_with_popping_cork:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':champagne:'],
        'de': ':flasche_mit_knallendem_korken:',
        'es': ':botella_descorchada:',
        'fr': ':bouteille_de_champagne:',
        'ja': u':シャンパン:',
        'ko': u':코르크가_튀어나오고_있는_병:',
        'pt': ':garrafa_de_champanhe:',
        'it': ':bottiglia_stappata:',
        'fa': u':شامپاین_جوشان:',
        'id': ':botol_dengan_penyumbat_terlepas:',
        'zh': u':开香槟:'
    },
    u'\U0001F490': { # 💐
        'en' : ':bouquet:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':blumenstrauß:',
        'es': ':ramo_de_flores:',
        'fr': ':bouquet:',
        'ja': u':花束:',
        'ko': u':꽃다발:',
        'pt': u':buquê:',
        'it': ':mazzo_di_fiori:',
        'fa': u':دسته_گل:',
        'id': ':karangan_bunga:',
        'zh': u':花束:'
    },
    u'\U0001F3F9': { # 🏹
        'en' : ':bow_and_arrow:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':pfeil_und_bogen:',
        'es': ':arco_y_flecha:',
        'fr': u':arc_et_flèche:',
        'ja': u':弓矢:',
        'ko': u':활과_화살:',
        'pt': ':arco_e_flecha:',
        'it': ':arco_e_freccia:',
        'fa': u':تیر_و_کمان:',
        'id': ':busur_dan_panah:',
        'zh': u':弓和箭:'
    },
    u'\U0001F963': { # 🥣
        'en' : ':bowl_with_spoon:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':schüssel_mit_löffel:',
        'es': ':cuenco_con_cuchara:',
        'fr': u':bol_avec_cuillère:',
        'ja': u':ボウルとスプーン:',
        'ko': u':스푼과_사발:',
        'pt': ':tigela_com_colher:',
        'it': ':ciotola_con_cucchiaio:',
        'fa': u':کاسه_و_قاشق:',
        'id': ':mangkuk_dengan_sendok:',
        'zh': u':碗勺:'
    },
    u'\U0001F3B3': { # 🎳
        'en' : ':bowling:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':bowling:',
        'es': ':bolos:',
        'fr': ':bowling:',
        'ja': u':ボウリング:',
        'ko': u':볼링:',
        'pt': ':boliche:',
        'it': ':bowling:',
        'fa': u':بولینگ:',
        'id': ':bowling:',
        'zh': u':保龄球:'
    },
    u'\U0001F94A': { # 🥊
        'en' : ':boxing_glove:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':boxhandschuh:',
        'es': ':guante_de_boxeo:',
        'fr': ':gant_de_boxe:',
        'ja': u':ボクシング:',
        'ko': u':권투_글러브:',
        'pt': ':luva_de_boxe:',
        'it': ':guantone_da_pugilato:',
        'fa': u':دست_کش_بوکس:',
        'id': ':sarung_tinju:',
        'zh': u':拳击手套:'
    },
    u'\U0001F466': { # 👦
        'en' : ':boy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':junge:',
        'es': u':niño:',
        'fr': u':garçon:',
        'ja': u':男の子:',
        'ko': u':남자_아이:',
        'pt': ':menino:',
        'it': ':bambino:',
        'fa': u':پسر:',
        'id': ':anak_laki-laki:',
        'zh': u':男孩:'
    },
    u'\U0001F466\U0001F3FF': { # 👦🏿
        'en' : ':boy_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':junge_dunkle_hautfarbe:',
        'es': u':niño_tono_de_piel_oscuro:',
        'fr': u':garçon_peau_foncée:',
        'ja': u':男の子_濃い肌色:',
        'ko': u':남자_아이_검은색_피부:',
        'pt': ':menino_pele_escura:',
        'it': ':bambino_carnagione_scura:',
        'fa': u':پسر_پوست_آبنوسی:',
        'id': ':anak_laki-laki_warna_kulit_gelap:',
        'zh': u':男孩_较深肤色:'
    },
    u'\U0001F466\U0001F3FB': { # 👦🏻
        'en' : ':boy_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':junge_helle_hautfarbe:',
        'es': u':niño_tono_de_piel_claro:',
        'fr': u':garçon_peau_claire:',
        'ja': u':男の子_薄い肌色:',
        'ko': u':남자_아이_하얀_피부:',
        'pt': ':menino_pele_clara:',
        'it': ':bambino_carnagione_chiara:',
        'fa': u':پسر_پوست_سفید:',
        'id': ':anak_laki-laki_warna_kulit_cerah:',
        'zh': u':男孩_较浅肤色:'
    },
    u'\U0001F466\U0001F3FE': { # 👦🏾
        'en' : ':boy_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':junge_mitteldunkle_hautfarbe:',
        'es': u':niño_tono_de_piel_oscuro_medio:',
        'fr': u':garçon_peau_mate:',
        'ja': u':男の子_やや濃い肌色:',
        'ko': u':남자_아이_진한_갈색_피부:',
        'pt': ':menino_pele_morena_escura:',
        'it': ':bambino_carnagione_abbastanza_scura:',
        'fa': u':پسر_پوست_گندمی:',
        'id': ':anak_laki-laki_warna_kulit_gelap-sedang:',
        'zh': u':男孩_中等深肤色:'
    },
    u'\U0001F466\U0001F3FC': { # 👦🏼
        'en' : ':boy_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':junge_mittelhelle_hautfarbe:',
        'es': u':niño_tono_de_piel_claro_medio:',
        'fr': u':garçon_peau_moyennement_claire:',
        'ja': u':男の子_やや薄い肌色:',
        'ko': u':남자_아이_연한_갈색_피부:',
        'pt': ':menino_pele_morena_clara:',
        'it': ':bambino_carnagione_abbastanza_chiara:',
        'fa': u':پسر_پوست_روشن:',
        'id': ':anak_laki-laki_warna_kulit_cerah-sedang:',
        'zh': u':男孩_中等浅肤色:'
    },
    u'\U0001F466\U0001F3FD': { # 👦🏽
        'en' : ':boy_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':junge_mittlere_hautfarbe:',
        'es': u':niño_tono_de_piel_medio:',
        'fr': u':garçon_peau_légèrement_mate:',
        'ja': u':男の子_中間の肌色:',
        'ko': u':남자_아이_갈색_피부:',
        'pt': ':menino_pele_morena:',
        'it': ':bambino_carnagione_olivastra:',
        'fa': u':پسر_پوست_طلایی:',
        'id': ':anak_laki-laki_warna_kulit_sedang:',
        'zh': u':男孩_中等肤色:'
    },
    u'\U0001F9E0': { # 🧠
        'en' : ':brain:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':gehirn:',
        'es': ':cerebro:',
        'fr': ':cerveau:',
        'ja': u':脳:',
        'ko': u':뇌:',
        'pt': u':cérebro:',
        'it': ':cervello:',
        'fa': u':مغز:',
        'id': ':otak:',
        'zh': u':脑:'
    },
    u'\U0001F35E': { # 🍞
        'en' : ':bread:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':brot:',
        'es': ':pan_de_molde:',
        'fr': ':pain:',
        'ja': u':食パン:',
        'ko': u':빵:',
        'pt': u':pão:',
        'it': ':pane_in_cassetta:',
        'fa': u':نان:',
        'id': ':roti:',
        'zh': u':面包:'
    },
    u'\U0001F931': { # 🤱
        'en' : ':breast-feeding:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':breast_feeding:'],
        'de': ':stillen:',
        'es': ':lactancia_materna:',
        'fr': ':allaitement:',
        'ja': u':授乳:',
        'ko': u':모유_수유:',
        'pt': ':amamentando:',
        'it': ':allattare:',
        'fa': u':تغذیه_با_شیر_مادر:',
        'id': ':menyusui:',
        'zh': u':母乳喂养:'
    },
    u'\U0001F931\U0001F3FF': { # 🤱🏿
        'en' : ':breast-feeding_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':stillen_dunkle_hautfarbe:',
        'es': ':lactancia_materna_tono_de_piel_oscuro:',
        'fr': u':allaitement_peau_foncée:',
        'ja': u':授乳_濃い肌色:',
        'ko': u':모유_수유_검은색_피부:',
        'pt': ':amamentando_pele_escura:',
        'it': ':allattare_carnagione_scura:',
        'fa': u':تغذیه_با_شیر_مادر_پوست_آبنوسی:',
        'id': ':menyusui_warna_kulit_gelap:',
        'zh': u':母乳喂养_较深肤色:'
    },
    u'\U0001F931\U0001F3FB': { # 🤱🏻
        'en' : ':breast-feeding_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':stillen_helle_hautfarbe:',
        'es': ':lactancia_materna_tono_de_piel_claro:',
        'fr': ':allaitement_peau_claire:',
        'ja': u':授乳_薄い肌色:',
        'ko': u':모유_수유_하얀_피부:',
        'pt': ':amamentando_pele_clara:',
        'it': ':allattare_carnagione_chiara:',
        'fa': u':تغذیه_با_شیر_مادر_پوست_سفید:',
        'id': ':menyusui_warna_kulit_cerah:',
        'zh': u':母乳喂养_较浅肤色:'
    },
    u'\U0001F931\U0001F3FE': { # 🤱🏾
        'en' : ':breast-feeding_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':stillen_mitteldunkle_hautfarbe:',
        'es': ':lactancia_materna_tono_de_piel_oscuro_medio:',
        'fr': ':allaitement_peau_mate:',
        'ja': u':授乳_やや濃い肌色:',
        'ko': u':모유_수유_진한_갈색_피부:',
        'pt': ':amamentando_pele_morena_escura:',
        'it': ':allattare_carnagione_abbastanza_scura:',
        'fa': u':تغذیه_با_شیر_مادر_پوست_گندمی:',
        'id': ':menyusui_warna_kulit_gelap-sedang:',
        'zh': u':母乳喂养_中等深肤色:'
    },
    u'\U0001F931\U0001F3FC': { # 🤱🏼
        'en' : ':breast-feeding_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':stillen_mittelhelle_hautfarbe:',
        'es': ':lactancia_materna_tono_de_piel_claro_medio:',
        'fr': ':allaitement_peau_moyennement_claire:',
        'ja': u':授乳_やや薄い肌色:',
        'ko': u':모유_수유_연한_갈색_피부:',
        'pt': ':amamentando_pele_morena_clara:',
        'it': ':allattare_carnagione_abbastanza_chiara:',
        'fa': u':تغذیه_با_شیر_مادر_پوست_روشن:',
        'id': ':menyusui_warna_kulit_cerah-sedang:',
        'zh': u':母乳喂养_中等浅肤色:'
    },
    u'\U0001F931\U0001F3FD': { # 🤱🏽
        'en' : ':breast-feeding_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':stillen_mittlere_hautfarbe:',
        'es': ':lactancia_materna_tono_de_piel_medio:',
        'fr': u':allaitement_peau_légèrement_mate:',
        'ja': u':授乳_中間の肌色:',
        'ko': u':모유_수유_갈색_피부:',
        'pt': ':amamentando_pele_morena:',
        'it': ':allattare_carnagione_olivastra:',
        'fa': u':تغذیه_با_شیر_مادر_پوست_طلایی:',
        'id': ':menyusui_warna_kulit_sedang:',
        'zh': u':母乳喂养_中等肤色:'
    },
    u'\U0001F9F1': { # 🧱
        'en' : ':brick:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':bricks:'],
        'de': ':ziegelstein:',
        'es': ':ladrillo:',
        'fr': ':brique:',
        'ja': u':れんが:',
        'ko': u':벽돌:',
        'pt': ':tijolo:',
        'it': ':mattoni:',
        'fa': u':دیوار_آجری:',
        'id': ':batu_bata:',
        'zh': u':砖:'
    },
    u'\U0001F309': { # 🌉
        'en' : ':bridge_at_night:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':brücke_vor_nachthimmel:',
        'es': ':puente_de_noche:',
        'fr': ':pont_de_nuit:',
        'ja': u':夜の橋:',
        'ko': u':밤하늘을_배경으로_하는_다리:',
        'pt': u':ponte_à_noite:',
        'it': ':ponte_di_notte:',
        'fa': u':پل_در_شب:',
        'id': ':jembatan_di_malam_hari:',
        'zh': u':夜幕下的桥:'
    },
    u'\U0001F4BC': { # 💼
        'en' : ':briefcase:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':aktentasche:',
        'es': u':maletín:',
        'fr': ':porte-documents:',
        'ja': u':ブリーフケース:',
        'ko': u':서류_가방:',
        'pt': ':maleta:',
        'it': ':valigetta_24_ore:',
        'fa': u':کیف_اسناد:',
        'id': ':tas_kantor:',
        'zh': u':公文包:'
    },
    u'\U0001FA72': { # 🩲
        'en' : ':briefs:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':swim_brief:'],
        'de': ':slip:',
        'es': ':ropa_interior:',
        'fr': ':slip:',
        'ja': u':ブリーフ:',
        'ko': u':삼각_수영복:',
        'pt': ':cueca:',
        'it': ':slip:',
        'fa': u':شورت_اسلیپ:',
        'id': ':celana_renang:',
        'zh': u':三角裤:'
    },
    u'\U0001F506': { # 🔆
        'en' : ':bright_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':high_brightness:'],
        'de': ':heller-taste:',
        'es': ':brillo_alto:',
        'fr': u':luminosité_élevée:',
        'ja': u':高輝度:',
        'ko': u':밝기_높음:',
        'pt': u':botão_de_aumentar_brilho:',
        'it': u':luminosità_elevata:',
        'fa': u':دکمهٔ_روشن_کردن_صفحه:',
        'id': ':tombol_cerahkan:',
        'zh': u':高亮度按钮:'
    },
    u'\U0001F966': { # 🥦
        'en' : ':broccoli:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':brokkoli:',
        'es': u':brócoli:',
        'fr': ':brocoli:',
        'ja': u':ブロッコリー:',
        'ko': u':브로콜리:',
        'pt': u':brócolis:',
        'it': ':broccoli:',
        'fa': u':بروکلی:',
        'id': ':brokoli:',
        'zh': u':西兰花:'
    },
    u'\U0001F494': { # 💔
        'en' : ':broken_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':gebrochenes_herz:',
        'es': u':corazón_roto:',
        'fr': u':cœur_brisé:',
        'ja': u':割れたハート:',
        'ko': u':깨진_하트:',
        'pt': u':coração_partido:',
        'it': ':cuore_infranto:',
        'fa': u':قلب_شکسته:',
        'id': ':patah_hati:',
        'zh': u':心碎:'
    },
    u'\U0001F9F9': { # 🧹
        'en' : ':broom:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':besen:',
        'es': ':escoba:',
        'fr': ':balai:',
        'ja': u':ほうき:',
        'ko': u':빗자루:',
        'pt': ':vassoura:',
        'it': ':scopa:',
        'fa': u':جارو:',
        'id': ':sapu:',
        'zh': u':扫帚:'
    },
    u'\U0001F7E4': { # 🟤
        'en' : ':brown_circle:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':brauner_punkt:',
        'es': u':círculo_marrón:',
        'fr': ':disque_marron:',
        'ja': u':茶色の丸:',
        'ko': u':갈색_원:',
        'pt': u':círculo_marrom:',
        'it': ':cerchio_marrone:',
        'fa': u':دایره_قهوه_ای:',
        'id': ':lingkaran_cokelat:',
        'zh': u':棕色圆:'
    },
    u'\U0001F90E': { # 🤎
        'en' : ':brown_heart:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':braunes_herz:',
        'es': u':corazón_marrón:',
        'fr': u':cœur_marron:',
        'ja': u':茶色いハート:',
        'ko': u':갈색_하트:',
        'pt': u':coração_marrom:',
        'it': ':cuore_marrone:',
        'fa': u':قلب_قهوه_ای:',
        'id': ':hati_cokelat:',
        'zh': u':棕心:'
    },
    u'\U0001F7EB': { # 🟫
        'en' : ':brown_square:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':braunes_quadrat:',
        'es': u':cuadrado_marrón:',
        'fr': u':carré_marron:',
        'ja': u':茶色い四角:',
        'ko': u':갈색_사각형:',
        'pt': ':quadrado_marrom:',
        'it': ':quadrato_marrone:',
        'fa': u':مربع_قهوه_ای:',
        'id': ':persegi_cokelat:',
        'zh': u':棕色方块:'
    },
    u'\U0001F9CB': { # 🧋
        'en' : ':bubble_tea:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':bubble_tea:',
        'es': u':té_de_burbujas:',
        'fr': u':thé_aux_perles:',
        'ja': u':タピオカドリンク:',
        'ko': u':버블티:',
        'pt': u':chá_perolado:',
        'it': ':bubble_tea:',
        'fa': u':چای_حُبابی:',
        'id': ':teh_bubble:',
        'zh': u':珍珠奶茶:'
    },
    u'\U0001FAE7': { # 🫧
        'en' : ':bubbles:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':blasen:',
        'es': ':burbujas:',
        'fr': ':bulles:',
        'ja': u':泡:',
        'ko': u':거품:',
        'pt': ':bolhas:',
        'it': ':bolle:',
        'fa': u':حباب:',
        'id': ':gelembung:',
        'zh': u':气泡:'
    },
    u'\U0001FAA3': { # 🪣
        'en' : ':bucket:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':eimer:',
        'es': ':cubo:',
        'fr': ':seau:',
        'ja': u':バケツ:',
        'ko': u':양동이:',
        'pt': ':balde:',
        'it': ':secchio:',
        'fa': u':سطل:',
        'id': ':ember:',
        'zh': u':桶:'
    },
    u'\U0001F41B': { # 🐛
        'en' : ':bug:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':raupe:',
        'es': ':bicho:',
        'fr': ':chenille:',
        'ja': u':毛虫:',
        'ko': u':송충이:',
        'pt': ':inseto:',
        'it': ':insetto:',
        'fa': u':حشره:',
        'id': ':serangga_kecil:',
        'zh': u':毛毛虫:'
    },
    u'\U0001F3D7\U0000FE0F': { # 🏗️
        'en' : ':building_construction:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kran:',
        'es': u':construcción:',
        'fr': u':construction_d’un_bâtiment:',
        'ja': u':建設中:',
        'ko': u':건물_공사:',
        'pt': u':construção:',
        'it': ':edificio_in_costruzione:',
        'fa': u':ساخت_وساز_ساختمانی:',
        'id': ':konstruksi_bangunan:',
        'zh': u':施工:'
    },
    u'\U0001F3D7': { # 🏗
        'en' : ':building_construction:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kran:',
        'es': u':construcción:',
        'fr': u':construction_d’un_bâtiment:',
        'ja': u':建設中:',
        'ko': u':건물_공사:',
        'pt': u':construção:',
        'it': ':edificio_in_costruzione:',
        'fa': u':ساخت_وساز_ساختمانی:',
        'id': ':konstruksi_bangunan:',
        'zh': u':施工:'
    },
    u'\U0001F685': { # 🚅
        'en' : ':bullet_train:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bullettrain_front:'],
        'de': ':hochgeschwindigkeitszug:',
        'es': ':tren_bala:',
        'fr': u':train_à_grande_vitesse:',
        'ja': u':0系新幹線:',
        'ko': u':고속철:',
        'pt': u':trem_de_alta_velocidade_japonês:',
        'it': u':treno_alta_velocità_punta_arrotondata:',
        'fa': u':قطار_تندرو:',
        'id': ':kereta_ekspres_peluru:',
        'zh': u':子弹头高速列车:'
    },
    u'\U0001F3AF': { # 🎯
        'en' : ':bullseye:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dart:'],
        'de': ':darts:',
        'es': ':diana:',
        'fr': ':dans_le_mille:',
        'ja': u':的:',
        'ko': u':과녁_명중:',
        'pt': ':no_alvo:',
        'it': ':bersaglio:',
        'fa': u':پیکان_در_قلب_هدف:',
        'id': ':dart:',
        'zh': u':正中靶心的飞镖:'
    },
    u'\U0001F32F': { # 🌯
        'en' : ':burrito:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':burrito:',
        'es': ':burrito:',
        'fr': ':burrito:',
        'ja': u':ブリトー:',
        'ko': u':부리또:',
        'pt': ':burrito:',
        'it': ':burrito:',
        'fa': u':بوریتو:',
        'id': ':burrito:',
        'zh': u':墨西哥玉米煎饼:'
    },
    u'\U0001F68C': { # 🚌
        'en' : ':bus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':bus:',
        'es': u':autobús:',
        'fr': ':bus:',
        'ja': u':バス:',
        'ko': u':버스:',
        'pt': u':ônibus:',
        'it': ':bus:',
        'fa': u':اتوبوس:',
        'id': ':bus:',
        'zh': u':公交车:'
    },
    u'\U0001F68F': { # 🚏
        'en' : ':bus_stop:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':busstop:'],
        'de': ':bushaltestelle:',
        'es': u':parada_de_autobús:',
        'fr': u':arrêt_de_bus:',
        'ja': u':バス停:',
        'ko': u':버스_정류장:',
        'pt': u':ponto_de_ônibus:',
        'it': u':fermata_dell’autobus:',
        'fa': u':ایستگاه_اتوبوس:',
        'id': ':halte_bus:',
        'zh': u':公交车站:'
    },
    u'\U0001F464': { # 👤
        'en' : ':bust_in_silhouette:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':silhouette_einer_büste:',
        'es': ':silueta_de_busto:',
        'fr': ':silhouette_de_buste:',
        'ja': u':人のシルエット:',
        'ko': u':사람_그림자:',
        'pt': ':silhueta_de_busto:',
        'it': ':profilo_di_persona:',
        'fa': u':تندیس_سایه_نما:',
        'id': ':siluet_foto_setengah_badan:',
        'zh': u':人像:'
    },
    u'\U0001F465': { # 👥
        'en' : ':busts_in_silhouette:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':silhouette_mehrerer_büsten:',
        'es': ':dos_siluetas_de_bustos:',
        'fr': ':silhouettes_de_bustes:',
        'ja': u':2人のシルエット:',
        'ko': u':사람들_그림자:',
        'pt': ':silhueta_de_bustos:',
        'it': ':profilo_di_due_persone:',
        'fa': u':تندیس_های_سایه_نما:',
        'id': ':beberapa_siluet_foto_setengah_badan:',
        'zh': u':双人像:'
    },
    u'\U0001F9C8': { # 🧈
        'en' : ':butter:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':butter:',
        'es': ':mantequilla:',
        'fr': ':beurre:',
        'ja': u':バター:',
        'ko': u':버터:',
        'pt': ':manteiga:',
        'it': ':burro:',
        'fa': u':کره:',
        'id': ':mentega:',
        'zh': u':黄油:'
    },
    u'\U0001F98B': { # 🦋
        'en' : ':butterfly:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schmetterling:',
        'es': ':mariposa:',
        'fr': ':papillon:',
        'ja': u':チョウ:',
        'ko': u':나비:',
        'pt': ':borboleta:',
        'it': ':farfalla:',
        'fa': u':پروانه:',
        'id': ':kupu-kupu:',
        'zh': u':蝴蝶:'
    },
    u'\U0001F335': { # 🌵
        'en' : ':cactus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kaktus:',
        'es': ':cactus:',
        'fr': ':cactus:',
        'ja': u':サボテン:',
        'ko': u':선인장:',
        'pt': ':cacto:',
        'it': ':cactus:',
        'fa': u':کاکتوس:',
        'id': ':kaktus:',
        'zh': u':仙人掌:'
    },
    u'\U0001F4C5': { # 📅
        'en' : ':calendar:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':date:'],
        'de': ':kalender:',
        'es': ':calendario:',
        'fr': ':calendrier:',
        'ja': u':カレンダー:',
        'ko': u':달력:',
        'pt': u':calendário:',
        'it': ':calendario:',
        'fa': u':تقویم:',
        'id': ':kalender:',
        'zh': u':日历:'
    },
    u'\U0001F919': { # 🤙
        'en' : ':call_me_hand:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':ruf-mich-an-handzeichen:',
        'es': ':mano_haciendo_el_gesto_de_llamar:',
        'fr': u':signe_appel_téléphonique_avec_les_doigts:',
        'ja': u':電話の合図:',
        'ko': u':전화를_걸라는_손_모양:',
        'pt': ':sinal_me_liga:',
        'it': ':mano_con_gesto_di_chiamata:',
        'fa': u':دست_به_شکل_تلفن:',
        'id': ':panggil_saya:',
        'zh': u':给我打电话:'
    },
    u'\U0001F919\U0001F3FF': { # 🤙🏿
        'en' : ':call_me_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':ruf-mich-an-handzeichen_dunkle_hautfarbe:',
        'es': ':mano_haciendo_el_gesto_de_llamar_tono_de_piel_oscuro:',
        'fr': u':signe_appel_téléphonique_avec_les_doigts_peau_foncée:',
        'ja': u':電話の合図_濃い肌色:',
        'ko': u':전화를_걸라는_손_모양_검은색_피부:',
        'pt': ':sinal_me_liga_pele_escura:',
        'it': ':mano_con_gesto_di_chiamata_carnagione_scura:',
        'fa': u':دست_به_شکل_تلفن_پوست_آبنوسی:',
        'id': ':panggil_saya_warna_kulit_gelap:',
        'zh': u':给我打电话_较深肤色:'
    },
    u'\U0001F919\U0001F3FB': { # 🤙🏻
        'en' : ':call_me_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':ruf-mich-an-handzeichen_helle_hautfarbe:',
        'es': ':mano_haciendo_el_gesto_de_llamar_tono_de_piel_claro:',
        'fr': u':signe_appel_téléphonique_avec_les_doigts_peau_claire:',
        'ja': u':電話の合図_薄い肌色:',
        'ko': u':전화를_걸라는_손_모양_하얀_피부:',
        'pt': ':sinal_me_liga_pele_clara:',
        'it': ':mano_con_gesto_di_chiamata_carnagione_chiara:',
        'fa': u':دست_به_شکل_تلفن_پوست_سفید:',
        'id': ':panggil_saya_warna_kulit_cerah:',
        'zh': u':给我打电话_较浅肤色:'
    },
    u'\U0001F919\U0001F3FE': { # 🤙🏾
        'en' : ':call_me_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':ruf-mich-an-handzeichen_mitteldunkle_hautfarbe:',
        'es': ':mano_haciendo_el_gesto_de_llamar_tono_de_piel_oscuro_medio:',
        'fr': u':signe_appel_téléphonique_avec_les_doigts_peau_mate:',
        'ja': u':電話の合図_やや濃い肌色:',
        'ko': u':전화를_걸라는_손_모양_진한_갈색_피부:',
        'pt': ':sinal_me_liga_pele_morena_escura:',
        'it': ':mano_con_gesto_di_chiamata_carnagione_abbastanza_scura:',
        'fa': u':دست_به_شکل_تلفن_پوست_گندمی:',
        'id': ':panggil_saya_warna_kulit_gelap-sedang:',
        'zh': u':给我打电话_中等深肤色:'
    },
    u'\U0001F919\U0001F3FC': { # 🤙🏼
        'en' : ':call_me_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':ruf-mich-an-handzeichen_mittelhelle_hautfarbe:',
        'es': ':mano_haciendo_el_gesto_de_llamar_tono_de_piel_claro_medio:',
        'fr': u':signe_appel_téléphonique_avec_les_doigts_peau_moyennement_claire:',
        'ja': u':電話の合図_やや薄い肌色:',
        'ko': u':전화를_걸라는_손_모양_연한_갈색_피부:',
        'pt': ':sinal_me_liga_pele_morena_clara:',
        'it': ':mano_con_gesto_di_chiamata_carnagione_abbastanza_chiara:',
        'fa': u':دست_به_شکل_تلفن_پوست_روشن:',
        'id': ':panggil_saya_warna_kulit_cerah-sedang:',
        'zh': u':给我打电话_中等浅肤色:'
    },
    u'\U0001F919\U0001F3FD': { # 🤙🏽
        'en' : ':call_me_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':ruf-mich-an-handzeichen_mittlere_hautfarbe:',
        'es': ':mano_haciendo_el_gesto_de_llamar_tono_de_piel_medio:',
        'fr': u':signe_appel_téléphonique_avec_les_doigts_peau_légèrement_mate:',
        'ja': u':電話の合図_中間の肌色:',
        'ko': u':전화를_걸라는_손_모양_갈색_피부:',
        'pt': ':sinal_me_liga_pele_morena:',
        'it': ':mano_con_gesto_di_chiamata_carnagione_olivastra:',
        'fa': u':دست_به_شکل_تلفن_پوست_طلایی:',
        'id': ':panggil_saya_warna_kulit_sedang:',
        'zh': u':给我打电话_中等肤色:'
    },
    u'\U0001F42A': { # 🐪
        'en' : ':camel:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':dromedary_camel:'],
        'de': ':dromedar:',
        'es': ':dromedario:',
        'fr': ':dromadaire:',
        'ja': u':ラクダ:',
        'ko': u':낙타:',
        'pt': ':camelo:',
        'it': ':dromedario:',
        'fa': u':شتر:',
        'id': ':unta:',
        'zh': u':骆驼:'
    },
    u'\U0001F4F7': { # 📷
        'en' : ':camera:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':fotoapparat:',
        'es': u':cámara_de_fotos:',
        'fr': ':appareil_photo:',
        'ja': u':カメラ:',
        'ko': u':카메라:',
        'pt': u':câmera:',
        'it': ':fotocamera:',
        'fa': u':دوربین:',
        'id': ':kamera:',
        'zh': u':相机:'
    },
    u'\U0001F4F8': { # 📸
        'en' : ':camera_with_flash:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':camera_flash:'],
        'de': ':fotoapparat_mit_blitz:',
        'es': u':cámara_con_flash:',
        'fr': ':appareil_photo_avec_flash:',
        'ja': u':フラッシュを焚いているカメラ:',
        'ko': u':플래시를_터트리고_있는_카메라:',
        'pt': u':câmera_com_flash:',
        'it': ':fotocamera_con_flash:',
        'fa': u':دوربین_با_فلاش:',
        'id': ':kamera_dengan_flash:',
        'zh': u':开闪光灯的相机:'
    },
    u'\U0001F3D5\U0000FE0F': { # 🏕️
        'en' : ':camping:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':camping:',
        'es': ':camping:',
        'fr': ':camping:',
        'ja': u':キャンプ:',
        'ko': u':캠핑:',
        'pt': ':acampamento:',
        'it': ':campeggio:',
        'fa': u':چادرزنی:',
        'id': ':berkemah:',
        'zh': u':露营:'
    },
    u'\U0001F3D5': { # 🏕
        'en' : ':camping:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':camping:',
        'es': ':camping:',
        'fr': ':camping:',
        'ja': u':キャンプ:',
        'ko': u':캠핑:',
        'pt': ':acampamento:',
        'it': ':campeggio:',
        'fa': u':چادرزنی:',
        'id': ':berkemah:',
        'zh': u':露营:'
    },
    u'\U0001F56F\U0000FE0F': { # 🕯️
        'en' : ':candle:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kerze:',
        'es': ':vela:',
        'fr': ':bougie:',
        'ja': u':ろうそく:',
        'ko': u':양초:',
        'pt': ':vela:',
        'it': ':candela:',
        'fa': u':شمع:',
        'id': ':lilin:',
        'zh': u':蜡烛:'
    },
    u'\U0001F56F': { # 🕯
        'en' : ':candle:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kerze:',
        'es': ':vela:',
        'fr': ':bougie:',
        'ja': u':ろうそく:',
        'ko': u':양초:',
        'pt': ':vela:',
        'it': ':candela:',
        'fa': u':شمع:',
        'id': ':lilin:',
        'zh': u':蜡烛:'
    },
    u'\U0001F36C': { # 🍬
        'en' : ':candy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':bonbon:',
        'es': ':caramelo:',
        'fr': ':bonbon:',
        'ja': u':キャンディ:',
        'ko': u':사탕:',
        'pt': ':bala:',
        'it': ':caramella:',
        'fa': u':آب_نبات_:',
        'id': ':permen:',
        'zh': u':糖:'
    },
    u'\U0001F96B': { # 🥫
        'en' : ':canned_food:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':konserve:',
        'es': ':comida_enlatada:',
        'fr': ':aliments_en_conserve:',
        'ja': u':缶詰:',
        'ko': u':통조림:',
        'pt': ':comida_enlatada:',
        'it': ':cibo_in_scatola:',
        'fa': u':غذای_کنسروشده:',
        'id': ':makanan_kaleng:',
        'zh': u':罐头食品:'
    },
    u'\U0001F6F6': { # 🛶
        'en' : ':canoe:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':kanu:',
        'es': ':canoa:',
        'fr': u':canoë:',
        'ja': u':カヌー:',
        'ko': u':카누:',
        'pt': ':canoa:',
        'it': ':canoa:',
        'fa': u':بلم:',
        'id': ':kano:',
        'zh': u':独木舟:'
    },
    u'\U0001F5C3\U0000FE0F': { # 🗃️
        'en' : ':card_file_box:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':karteikasten:',
        'es': ':archivador_de_tarjetas:',
        'fr': u':boîte_à_dossiers:',
        'ja': u':カードファイルボックス:',
        'ko': u':카드_파일_상자:',
        'pt': ':caixa_de_arquivos:',
        'it': ':schedario_da_tavolo:',
        'fa': u':جعبه_نگه_داری_کارت:',
        'id': ':kotak_file_kartu:',
        'zh': u':卡片盒:'
    },
    u'\U0001F5C3': { # 🗃
        'en' : ':card_file_box:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':karteikasten:',
        'es': ':archivador_de_tarjetas:',
        'fr': u':boîte_à_dossiers:',
        'ja': u':カードファイルボックス:',
        'ko': u':카드_파일_상자:',
        'pt': ':caixa_de_arquivos:',
        'it': ':schedario_da_tavolo:',
        'fa': u':جعبه_نگه_داری_کارت:',
        'id': ':kotak_file_kartu:',
        'zh': u':卡片盒:'
    },
    u'\U0001F4C7': { # 📇
        'en' : ':card_index:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':rotationskartei:',
        'es': ':organizador_de_fichas:',
        'fr': u':carnet_d’adresses:',
        'ja': u':カードインデックス:',
        'ko': u':카드_인덱스:',
        'pt': u':índice_de_cartões:',
        'it': ':schedario:',
        'fa': u':کارت_های_راهنما:',
        'id': ':indeks_kartu:',
        'zh': u':卡片索引:'
    },
    u'\U0001F5C2\U0000FE0F': { # 🗂️
        'en' : ':card_index_dividers:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':karteibahnen:',
        'es': ':separador_de_fichas:',
        'fr': ':intercalaires:',
        'ja': u':カードフォルダー:',
        'ko': u':카드_색인_파일:',
        'pt': ':divisores_de_pastas:',
        'it': ':divisori_per_schedario:',
        'fa': u':جداکننده:',
        'id': ':pembagi_indeks_kartu:',
        'zh': u':索引分隔文件夹:'
    },
    u'\U0001F5C2': { # 🗂
        'en' : ':card_index_dividers:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':karteireiter:',
        'es': ':separador_de_fichas:',
        'fr': ':intercalaires:',
        'ja': u':カードフォルダー:',
        'ko': u':카드_색인_파일:',
        'pt': ':divisores_de_pastas:',
        'it': ':divisori_per_schedario:',
        'fa': u':جداکننده:',
        'id': ':pembagi_indeks_kartu:',
        'zh': u':索引分隔文件夹:'
    },
    u'\U0001F3A0': { # 🎠
        'en' : ':carousel_horse:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':karussellpferd:',
        'es': ':caballo_de_tiovivo:',
        'fr': u':cheval_de_manège:',
        'ja': u':メリーゴーランド:',
        'ko': u':회전_목마:',
        'pt': ':carrossel:',
        'it': ':cavallo_da_giostra:',
        'fa': u':چرخ_وفلک_اسبی:',
        'id': ':komidi_putar:',
        'zh': u':旋转木马:'
    },
    u'\U0001F38F': { # 🎏
        'en' : ':carp_streamer:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flags:'],
        'de': u':traditionelle_japanische_windsäcke:',
        'es': u':banderín_de_carpas:',
        'fr': ':koinobori:',
        'ja': u':こいのぼり:',
        'ko': u':물고기_깃발:',
        'pt': ':bandeira_de_carpas:',
        'it': ':aquilone_a_forma_di_carpa:',
        'fa': u':پرچم_های_ماهی_در_باد:',
        'id': ':bendera_ikan_koi:',
        'zh': u':鲤鱼旗:'
    },
    u'\U0001FA9A': { # 🪚
        'en' : ':carpentry_saw:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':handsäge:',
        'es': u':sierra_de_carpintería:',
        'fr': ':scie:',
        'ja': u':のこぎり:',
        'ko': u':목공_톱:',
        'pt': ':serrote:',
        'it': ':sega_da_falegname:',
        'fa': u':اره_نجاری:',
        'id': ':gergaji_kayu:',
        'zh': u':木工锯:'
    },
    u'\U0001F955': { # 🥕
        'en' : ':carrot:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':karotte:',
        'es': ':zanahoria:',
        'fr': ':carotte:',
        'ja': u':人参:',
        'ko': u':당근:',
        'pt': ':cenoura:',
        'it': ':carota:',
        'fa': u':هویج:',
        'id': ':wortel:',
        'zh': u':胡萝卜:'
    },
    u'\U0001F3F0': { # 🏰
        'en' : ':castle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':european_castle:'],
        'de': ':schloss:',
        'es': ':castillo_europeo:',
        'fr': u':château:',
        'ja': u':西洋の城:',
        'ko': u':유럽_성:',
        'pt': ':castelo:',
        'it': ':castello:',
        'fa': u':قلعه:',
        'id': ':kastel:',
        'zh': u':欧洲城堡:'
    },
    u'\U0001F408': { # 🐈
        'en' : ':cat:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':cat2:'],
        'variant': True,
        'de': ':katze:',
        'es': ':gato:',
        'fr': ':chat:',
        'ja': u':ネコ:',
        'ko': u':고양이:',
        'pt': ':gato:',
        'it': ':gatto:',
        'fa': u':گربه:',
        'id': ':kucing:',
        'zh': u':猫:'
    },
    u'\U0001F431': { # 🐱
        'en' : ':cat_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cat:'],
        'de': ':katzengesicht:',
        'es': ':cara_de_gato:',
        'fr': u':tête_de_chat:',
        'ja': u':ネコの顔:',
        'ko': u':고양이_얼굴:',
        'pt': ':rosto_de_gato:',
        'it': ':muso_di_gatto:',
        'fa': u':صورت_گربه:',
        'id': ':wajah_kucing:',
        'zh': u':猫脸:'
    },
    u'\U0001F639': { # 😹
        'en' : ':cat_with_tears_of_joy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':joy_cat:'],
        'de': u':katze_mit_freudentränen:',
        'es': ':gato_llorando_de_risa:',
        'fr': ':chat_qui_pleure_de_joie:',
        'ja': u':嬉し泣きする猫:',
        'ko': u':기쁨의_눈물을_흘리는_고양이_얼굴:',
        'pt': u':rosto_de_gato_com_lágrimas_de_alegria:',
        'it': ':gatto_con_lacrime_di_gioia:',
        'fa': u':گربهٔ_خندان_با_اشک_شوق:',
        'id': ':wajah_kucing_gembira_berurai_air_mata:',
        'zh': u':笑出眼泪的猫:'
    },
    u'\U0001F63C': { # 😼
        'en' : ':cat_with_wry_smile:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':smirk_cat:'],
        'de': u':verwegen_lächelnde_katze:',
        'es': ':gato_haciendo_una_mueca:',
        'fr': ':chat_avec_sourire_en_coin:',
        'ja': u':にやりとする猫:',
        'ko': u':썩소_짓는_고양이:',
        'pt': u':rosto_de_gato_com_sorriso_irônico:',
        'it': ':gatto_con_sorriso_sarcastico:',
        'fa': u':گربه_با_پوزخند:',
        'id': ':wajah_kucing_tersenyum_sombong:',
        'zh': u':奸笑的猫:'
    },
    u'\U000026D3\U0000FE0F': { # ⛓️
        'en' : ':chains:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':ketten:',
        'es': ':cadenas:',
        'fr': u':chaînes:',
        'ja': u':鎖:',
        'ko': u':쇠사슬:',
        'pt': ':correntes:',
        'it': ':catene:',
        'fa': u':غل_و_زنجیر:',
        'id': ':rantai:',
        'zh': u':链条:'
    },
    u'\U000026D3': { # ⛓
        'en' : ':chains:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':ketten:',
        'es': ':cadenas:',
        'fr': u':chaînes:',
        'ja': u':鎖:',
        'ko': u':쇠사슬:',
        'pt': ':correntes:',
        'it': ':catene:',
        'fa': u':غل_و_زنجیر:',
        'id': ':rantai:',
        'zh': u':链条:'
    },
    u'\U0001FA91': { # 🪑
        'en' : ':chair:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stuhl:',
        'es': ':silla:',
        'fr': ':chaise:',
        'ja': u':椅子:',
        'ko': u':의자:',
        'pt': ':cadeira:',
        'it': ':sedia:',
        'fa': u':صندلی:',
        'id': ':bangku:',
        'zh': u':椅子:'
    },
    u'\U0001F4C9': { # 📉
        'en' : ':chart_decreasing:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':chart_with_downwards_trend:'],
        'de': u':abwärtstrend:',
        'es': u':gráfica_de_evolución_descendente:',
        'fr': ':graphique_en_baisse:',
        'ja': u':グラフ下向き:',
        'ko': u':내려가는_그래프:',
        'pt': u':gráfico_caindo:',
        'it': ':grafico_con_andamento_negativo:',
        'fa': u':نمودار_نزولی:',
        'id': ':bagan_menurun:',
        'zh': u':趋势向下的图表:'
    },
    u'\U0001F4C8': { # 📈
        'en' : ':chart_increasing:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':chart_with_upwards_trend:'],
        'de': u':aufwärtstrend:',
        'es': u':gráfica_de_evolución_ascendente:',
        'fr': ':graphique_en_hausse:',
        'ja': u':グラフ上向き:',
        'ko': u':상승하는_그래프:',
        'pt': u':gráfico_subindo:',
        'it': ':grafico_con_andamento_positivo:',
        'fa': u':نمودار_صعودی:',
        'id': ':bagan_meningkat:',
        'zh': u':趋势向上的图表:'
    },
    u'\U0001F4B9': { # 💹
        'en' : ':chart_increasing_with_yen:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':chart:'],
        'de': ':steigende_kurve_mit_yen-zeichen:',
        'es': ':mercado_al_alza:',
        'fr': ':courbe_avec_yen_en_hausse:',
        'ja': u':為替:',
        'ko': u':엔화_관련_상승하는_그래프:',
        'pt': u':gráfico_subindo_com_iene:',
        'it': ':grafico_ascendente:',
        'fa': u':نمودار_صعودی_با_ین:',
        'id': ':bagan_meningkat_dengan_yen:',
        'zh': u':趋势向上且带有日元符号的图表:'
    },
    u'\U00002611\U0000FE0F': { # ☑️
        'en' : ':check_box_with_check:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ballot_box_with_check:'],
        'variant': True,
        'de': u':abstimmungsfeld_mit_häkchen:',
        'es': u':casilla_con_marca_de_verificación:',
        'fr': u':case_cochée:',
        'ja': u':チェックボックス:',
        'ko': u':체크박스:',
        'pt': u':caixa_de_seleção_marcada_com_tique:',
        'it': ':riquadro_con_spunta:',
        'fa': u':مربع_با_علامت_تیک:',
        'id': ':kotak_bercentang:',
        'zh': u':勾选框:'
    },
    u'\U00002611': { # ☑
        'en' : ':check_box_with_check:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':ballot_box_with_check:'],
        'variant': True,
        'de': u':abgehaktes_kästchen:',
        'es': u':casilla_con_marca_de_verificación:',
        'fr': u':case_cochée:',
        'ja': u':チェックボックス:',
        'ko': u':체크박스:',
        'pt': u':caixa_de_seleção_marcada_com_tique:',
        'it': ':riquadro_con_spunta:',
        'fa': u':مربع_با_علامت_تیک:',
        'id': ':kotak_bercentang:',
        'zh': u':勾选框:'
    },
    u'\U00002714\U0000FE0F': { # ✔️
        'en' : ':check_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heavy_check_mark:'],
        'variant': True,
        'de': u':kräftiges_häkchen:',
        'es': u':marca_de_verificación:',
        'fr': ':coche:',
        'ja': u':太字のチェック:',
        'ko': u':진한_체크_표시:',
        'pt': u':marca_de_seleção:',
        'it': ':segno_di_spunta_nero:',
        'fa': u':علامت_تیک:',
        'id': ':tanda_centang_tebal:',
        'zh': u':勾号:'
    },
    u'\U00002714': { # ✔
        'en' : ':check_mark:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':heavy_check_mark:'],
        'variant': True,
        'de': u':kräftiges_häkchen:',
        'es': u':marca_de_verificación:',
        'fr': ':coche:',
        'ja': u':太字のチェック:',
        'ko': u':진한_체크_표시:',
        'pt': u':marca_de_seleção:',
        'it': ':segno_di_spunta:',
        'fa': u':علامت_تیک:',
        'id': ':tanda_centang_tebal:',
        'zh': u':勾号:'
    },
    u'\U00002705': { # ✅
        'en' : ':check_mark_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':white_check_mark:'],
        'de': u':weißes_häkchen:',
        'es': u':botón_de_marca_de_verificación:',
        'fr': u':bouton_coché:',
        'ja': u':白抜きのチェック:',
        'ko': u':체크_표시:',
        'pt': u':marca_de_seleção_branca:',
        'it': ':pulsante_segno_di_spunta:',
        'fa': u':علامت_تأیید:',
        'id': ':tanda_centang_putih_tebal:',
        'zh': u':勾号按钮:'
    },
    u'\U0001F9C0': { # 🧀
        'en' : ':cheese_wedge:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':cheese:'],
        'de': u':käsestück:',
        'es': u':cuña_de_queso:',
        'fr': ':part_de_fromage:',
        'ja': u':チーズ:',
        'ko': u':치즈_조각:',
        'pt': ':queijo:',
        'it': ':fetta_di_formaggio:',
        'fa': u':قاچ_پنیر:',
        'id': ':irisan_keju:',
        'zh': u':芝士:'
    },
    u'\U0001F3C1': { # 🏁
        'en' : ':chequered_flag:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':checkered_flag:'],
        'de': ':zielflagge:',
        'es': ':bandera_de_cuadros:',
        'fr': u':drapeau_à_damier:',
        'ja': u':チェッカーフラッグ:',
        'ko': u':격자_무늬_깃발:',
        'pt': ':bandeira_quadriculada:',
        'it': ':bandiera_a_scacchi:',
        'fa': u':پرچم_شطرنجی:',
        'id': ':bendera_kotak-kotak:',
        'zh': u':终点旗:'
    },
    u'\U0001F352': { # 🍒
        'en' : ':cherries:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kirschen:',
        'es': ':cerezas:',
        'fr': ':cerises:',
        'ja': u':さくらんぼ:',
        'ko': u':체리:',
        'pt': ':cereja:',
        'it': ':ciliegie:',
        'fa': u':گیلاس:',
        'id': ':ceri:',
        'zh': u':樱桃:'
    },
    u'\U0001F338': { # 🌸
        'en' : ':cherry_blossom:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':kirschblüte:',
        'es': ':flor_de_cerezo:',
        'fr': ':fleur_de_cerisier:',
        'ja': u':桜:',
        'ko': u':벚꽃:',
        'pt': ':flor_de_cerejeira:',
        'it': ':fiore_di_ciliegio:',
        'fa': u':شکوفه_گیلاس:',
        'id': ':sakura:',
        'zh': u':樱花:'
    },
    u'\U0000265F\U0000FE0F': { # ♟️
        'en' : ':chess_pawn:',
        'status' : fully_qualified,
        'E' : 11,
        'variant': True,
        'de': ':bauer_schach:',
        'es': u':peón_de_ajedrez:',
        'fr': u':pion_d’échec:',
        'ja': u':チェスの駒:',
        'ko': u':체스_폰:',
        'pt': u':peão_de_xadrez:',
        'it': ':pedina_degli_scacchi:',
        'fa': u':پیاده_شطرنج:',
        'id': ':pion_catur:',
        'zh': u':兵:'
    },
    u'\U0000265F': { # ♟
        'en' : ':chess_pawn:',
        'status' : unqualified,
        'E' : 11,
        'variant': True,
        'de': ':bauer_schach:',
        'es': u':peón_de_ajedrez:',
        'fr': u':pion_d’échec:',
        'ja': u':チェスの駒:',
        'ko': u':체스_폰:',
        'pt': u':peão_de_xadrez:',
        'it': ':pedina_degli_scacchi:',
        'fa': u':پیاده_شطرنج:',
        'id': ':pion_catur:',
        'zh': u':兵:'
    },
    u'\U0001F330': { # 🌰
        'en' : ':chestnut:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kastanie:',
        'es': u':castaña:',
        'fr': u':châtaigne:',
        'ja': u':くり:',
        'ko': u':밤:',
        'pt': ':castanha:',
        'it': ':castagna:',
        'fa': u':فندق:',
        'id': ':kastanye:',
        'zh': u':栗子:'
    },
    u'\U0001F414': { # 🐔
        'en' : ':chicken:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':huhn:',
        'es': ':gallina:',
        'fr': ':poule:',
        'ja': u':にわとり:',
        'ko': u':닭:',
        'pt': ':galinha:',
        'it': ':gallina:',
        'fa': u':مرغ:',
        'id': ':ayam:',
        'zh': u':鸡:'
    },
    u'\U0001F9D2': { # 🧒
        'en' : ':child:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kind:',
        'es': ':infante:',
        'fr': ':enfant:',
        'ja': u':子供:',
        'ko': u':어린이:',
        'pt': u':criança:',
        'it': ':bimbo:',
        'fa': u':بچه:',
        'id': ':anak:',
        'zh': u':儿童:'
    },
    u'\U0001F9D2\U0001F3FF': { # 🧒🏿
        'en' : ':child_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kind_dunkle_hautfarbe:',
        'es': ':infante_tono_de_piel_oscuro:',
        'fr': u':enfant_peau_foncée:',
        'ja': u':子供_濃い肌色:',
        'ko': u':어린이_검은색_피부:',
        'pt': u':criança_pele_escura:',
        'it': ':bimbo_carnagione_scura:',
        'fa': u':بچه_پوست_آبنوسی:',
        'id': ':anak_warna_kulit_gelap:',
        'zh': u':儿童_较深肤色:'
    },
    u'\U0001F9D2\U0001F3FB': { # 🧒🏻
        'en' : ':child_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kind_helle_hautfarbe:',
        'es': ':infante_tono_de_piel_claro:',
        'fr': ':enfant_peau_claire:',
        'ja': u':子供_薄い肌色:',
        'ko': u':어린이_하얀_피부:',
        'pt': u':criança_pele_clara:',
        'it': ':bimbo_carnagione_chiara:',
        'fa': u':بچه_پوست_سفید:',
        'id': ':anak_warna_kulit_cerah:',
        'zh': u':儿童_较浅肤色:'
    },
    u'\U0001F9D2\U0001F3FE': { # 🧒🏾
        'en' : ':child_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kind_mitteldunkle_hautfarbe:',
        'es': ':infante_tono_de_piel_oscuro_medio:',
        'fr': ':enfant_peau_mate:',
        'ja': u':子供_やや濃い肌色:',
        'ko': u':어린이_진한_갈색_피부:',
        'pt': u':criança_pele_morena_escura:',
        'it': ':bimbo_carnagione_abbastanza_scura:',
        'fa': u':بچه_پوست_گندمی:',
        'id': ':anak_warna_kulit_gelap-sedang:',
        'zh': u':儿童_中等深肤色:'
    },
    u'\U0001F9D2\U0001F3FC': { # 🧒🏼
        'en' : ':child_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kind_mittelhelle_hautfarbe:',
        'es': ':infante_tono_de_piel_claro_medio:',
        'fr': ':enfant_peau_moyennement_claire:',
        'ja': u':子供_やや薄い肌色:',
        'ko': u':어린이_연한_갈색_피부:',
        'pt': u':criança_pele_morena_clara:',
        'it': ':bimbo_carnagione_abbastanza_chiara:',
        'fa': u':بچه_پوست_روشن:',
        'id': ':anak_warna_kulit_cerah-sedang:',
        'zh': u':儿童_中等浅肤色:'
    },
    u'\U0001F9D2\U0001F3FD': { # 🧒🏽
        'en' : ':child_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kind_mittlere_hautfarbe:',
        'es': ':infante_tono_de_piel_medio:',
        'fr': u':enfant_peau_légèrement_mate:',
        'ja': u':子供_中間の肌色:',
        'ko': u':어린이_갈색_피부:',
        'pt': u':criança_pele_morena:',
        'it': ':bimbo_carnagione_olivastra:',
        'fa': u':بچه_پوست_طلایی:',
        'id': ':anak_warna_kulit_sedang:',
        'zh': u':儿童_中等肤色:'
    },
    u'\U0001F6B8': { # 🚸
        'en' : ':children_crossing:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':kinder_überqueren_die_straße:',
        'es': u':niños_cruzando:',
        'fr': u':traversée_d’enfants:',
        'ja': u':児童横断:',
        'ko': u':어린이_보호_구역:',
        'pt': u':crianças_atravessando:',
        'it': ':attraversamento_bambini:',
        'fa': u':عبور_کودکان:',
        'id': ':anak-anak_menyeberang:',
        'zh': u':儿童过街:'
    },
    u'\U0001F43F\U0000FE0F': { # 🐿️
        'en' : ':chipmunk:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':streifenhörnchen:',
        'es': ':ardilla:',
        'fr': u':écureuil:',
        'ja': u':リス:',
        'ko': u':얼룩다람쥐:',
        'pt': ':esquilo:',
        'it': ':scoiattolo:',
        'fa': u':سنجاب_راه_راه:',
        'id': ':tupai:',
        'zh': u':松鼠:'
    },
    u'\U0001F43F': { # 🐿
        'en' : ':chipmunk:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':streifenhörnchen:',
        'es': ':ardilla:',
        'fr': u':écureuil:',
        'ja': u':リス:',
        'ko': u':얼룩다람쥐:',
        'pt': ':esquilo:',
        'it': ':scoiattolo:',
        'fa': u':سنجاب_راه_راه:',
        'id': ':tupai:',
        'zh': u':松鼠:'
    },
    u'\U0001F36B': { # 🍫
        'en' : ':chocolate_bar:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schokoladentafel:',
        'es': ':tableta_de_chocolate:',
        'fr': u':barre_chocolatée:',
        'ja': u':チョコレート:',
        'ko': u':초콜렛:',
        'pt': ':chocolate:',
        'it': ':cioccolato:',
        'fa': u':تخته_شکلات:',
        'id': ':sebatang_cokelat:',
        'zh': u':巧克力:'
    },
    u'\U0001F962': { # 🥢
        'en' : ':chopsticks:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':essstäbchen:',
        'es': ':palillos:',
        'fr': ':baguettes:',
        'ja': u':はし:',
        'ko': u':젓가락:',
        'pt': ':hashi:',
        'it': ':bacchette:',
        'fa': u':چاپ_استیک:',
        'id': ':sumpit:',
        'zh': u':筷子:'
    },
    u'\U000026EA': { # ⛪
        'en' : ':church:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':kirche:',
        'es': ':iglesia:',
        'fr': u':église:',
        'ja': u':教会:',
        'ko': u':교회:',
        'pt': ':igreja:',
        'it': ':chiesa:',
        'fa': u':کلیسا:',
        'id': ':gereja:',
        'zh': u':教堂:'
    },
    u'\U0001F6AC': { # 🚬
        'en' : ':cigarette:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':smoking:'],
        'de': ':zigarette:',
        'es': ':cigarrillo:',
        'fr': ':cigarette:',
        'ja': u':煙草:',
        'ko': u':흡연_구역_신호:',
        'pt': ':cigarro:',
        'it': ':sigaretta:',
        'fa': u':سیگار:',
        'id': ':rokok:',
        'zh': u':香烟:'
    },
    u'\U0001F3A6': { # 🎦
        'en' : ':cinema:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kinosymbol:',
        'es': ':cine:',
        'fr': u':cinéma:',
        'ja': u':映画:',
        'ko': u':영화:',
        'pt': ':cinema:',
        'it': ':simbolo_del_cinema:',
        'fa': u':سینما:',
        'id': ':film:',
        'zh': u':电影院:'
    },
    u'\U000024C2\U0000FE0F': { # Ⓜ️
        'en' : ':circled_M:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':m:'],
        'variant': True,
        'de': ':buchstabe_m_in_kreis:',
        'es': u':m_en_círculo:',
        'fr': u':m_encerclé:',
        'ja': u':丸いmマーク:',
        'ko': u':원글자_엠:',
        'pt': u':círculo_com_a_letra_m:',
        'it': ':pulsante_m_cerchiata:',
        'fa': u':حرف_ام_در_دایره:',
        'id': ':huruf_m_dalam_lingkaran:',
        'zh': u':圆圈包围的M:'
    },
    u'\U000024C2': { # Ⓜ
        'en' : ':circled_M:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':m:'],
        'variant': True,
        'de': ':buchstabe_m_in_kreis:',
        'es': u':m_en_círculo:',
        'fr': u':m_encerclé:',
        'ja': u':丸いmマーク:',
        'ko': u':원글자_엠:',
        'pt': u':círculo_com_a_letra_m:',
        'it': ':pulsante_m_cerchiata:',
        'fa': u':حرف_ام_در_دایره:',
        'id': ':huruf_m_dalam_lingkaran:',
        'zh': u':圆圈包围的M:'
    },
    u'\U0001F3AA': { # 🎪
        'en' : ':circus_tent:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':zirkuszelt:',
        'es': ':carpa_de_circo:',
        'fr': ':chapiteau:',
        'ja': u':サーカス:',
        'ko': u':서커스:',
        'pt': ':circo:',
        'it': ':circo:',
        'fa': u':چادر_سیرک:',
        'id': ':tenda_sirkus:',
        'zh': u':马戏团帐篷:'
    },
    u'\U0001F3D9\U0000FE0F': { # 🏙️
        'en' : ':cityscape:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':skyline:',
        'es': ':paisaje_urbano:',
        'fr': ':ville:',
        'ja': u':高層ビル:',
        'ko': u':도시_전경:',
        'pt': ':cidade:',
        'it': ':paesaggio_urbano:',
        'fa': u':نمای_شهر:',
        'id': ':panorama_kota:',
        'zh': u':城市风光:'
    },
    u'\U0001F3D9': { # 🏙
        'en' : ':cityscape:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':skyline:',
        'es': ':paisaje_urbano:',
        'fr': ':ville:',
        'ja': u':高層ビル:',
        'ko': u':도시_전경:',
        'pt': ':cidade:',
        'it': ':paesaggio_urbano:',
        'fa': u':نمای_شهر:',
        'id': ':panorama_kota:',
        'zh': u':城市风光:'
    },
    u'\U0001F306': { # 🌆
        'en' : ':cityscape_at_dusk:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':city_sunset:'],
        'de': ':abendstimmung_in_der_stadt:',
        'es': ':ciudad_al_atardecer:',
        'fr': u':ville_au_crépuscule:',
        'ja': u':夕暮れの都会:',
        'ko': u':도시_야경:',
        'pt': ':cidade_ao_anoitecer:',
        'it': u':città_al_tramonto:',
        'fa': u':نمای_شهر_هنگام_غروب:',
        'id': ':panorama_kota_di_sore_hari:',
        'zh': u':城市黄昏:'
    },
    u'\U0001F5DC\U0000FE0F': { # 🗜️
        'en' : ':clamp:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':compression:'],
        'variant': True,
        'de': ':schraubzwinge:',
        'es': ':tornillo_de_banco:',
        'fr': ':serre-joint:',
        'ja': u':万力:',
        'ko': u':압축기:',
        'pt': u':braçadeira:',
        'it': ':morsetto:',
        'fa': u':پرس:',
        'id': ':klem:',
        'zh': u':夹钳:'
    },
    u'\U0001F5DC': { # 🗜
        'en' : ':clamp:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':compression:'],
        'variant': True,
        'de': ':schraubzwinge:',
        'es': ':tornillo_de_banco:',
        'fr': ':serre-joint:',
        'ja': u':万力:',
        'ko': u':압축기:',
        'pt': u':braçadeira:',
        'it': ':morsetto:',
        'fa': u':پرس:',
        'id': ':klem:',
        'zh': u':夹钳:'
    },
    u'\U0001F3AC': { # 🎬
        'en' : ':clapper_board:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clapper:'],
        'variant': True,
        'de': ':filmklappe:',
        'es': ':claqueta:',
        'fr': ':clap:',
        'ja': u':カチンコ:',
        'ko': u':슬레이트:',
        'pt': ':claquete:',
        'it': ':ciak:',
        'fa': u':کلاکت:',
        'id': ':papan_sutradara:',
        'zh': u':场记板:'
    },
    u'\U0001F44F': { # 👏
        'en' : ':clapping_hands:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clap:'],
        'de': u':klatschende_hände:',
        'es': ':manos_aplaudiendo:',
        'fr': ':applaudissements:',
        'ja': u':拍手:',
        'ko': u':손뼉:',
        'pt': u':mãos_aplaudindo:',
        'it': ':mani_che_applaudono:',
        'fa': u':دست_زدن:',
        'id': ':tepuk_tangan:',
        'zh': u':鼓掌:'
    },
    u'\U0001F44F\U0001F3FF': { # 👏🏿
        'en' : ':clapping_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':klatschende_hände_dunkle_hautfarbe:',
        'es': ':manos_aplaudiendo_tono_de_piel_oscuro:',
        'fr': u':applaudissements_peau_foncée:',
        'ja': u':拍手_濃い肌色:',
        'ko': u':손뼉_검은색_피부:',
        'pt': u':mãos_aplaudindo_pele_escura:',
        'it': ':mani_che_applaudono_carnagione_scura:',
        'fa': u':دست_زدن_پوست_آبنوسی:',
        'id': ':tepuk_tangan_warna_kulit_gelap:',
        'zh': u':鼓掌_较深肤色:'
    },
    u'\U0001F44F\U0001F3FB': { # 👏🏻
        'en' : ':clapping_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':klatschende_hände_helle_hautfarbe:',
        'es': ':manos_aplaudiendo_tono_de_piel_claro:',
        'fr': ':applaudissements_peau_claire:',
        'ja': u':拍手_薄い肌色:',
        'ko': u':손뼉_하얀_피부:',
        'pt': u':mãos_aplaudindo_pele_clara:',
        'it': ':mani_che_applaudono_carnagione_chiara:',
        'fa': u':دست_زدن_پوست_سفید:',
        'id': ':tepuk_tangan_warna_kulit_cerah:',
        'zh': u':鼓掌_较浅肤色:'
    },
    u'\U0001F44F\U0001F3FE': { # 👏🏾
        'en' : ':clapping_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':klatschende_hände_mitteldunkle_hautfarbe:',
        'es': ':manos_aplaudiendo_tono_de_piel_oscuro_medio:',
        'fr': ':applaudissements_peau_mate:',
        'ja': u':拍手_やや濃い肌色:',
        'ko': u':손뼉_진한_갈색_피부:',
        'pt': u':mãos_aplaudindo_pele_morena_escura:',
        'it': ':mani_che_applaudono_carnagione_abbastanza_scura:',
        'fa': u':دست_زدن_پوست_گندمی:',
        'id': ':tepuk_tangan_warna_kulit_gelap-sedang:',
        'zh': u':鼓掌_中等深肤色:'
    },
    u'\U0001F44F\U0001F3FC': { # 👏🏼
        'en' : ':clapping_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':klatschende_hände_mittelhelle_hautfarbe:',
        'es': ':manos_aplaudiendo_tono_de_piel_claro_medio:',
        'fr': ':applaudissements_peau_moyennement_claire:',
        'ja': u':拍手_やや薄い肌色:',
        'ko': u':손뼉_연한_갈색_피부:',
        'pt': u':mãos_aplaudindo_pele_morena_clara:',
        'it': ':mani_che_applaudono_carnagione_abbastanza_chiara:',
        'fa': u':دست_زدن_پوست_روشن:',
        'id': ':tepuk_tangan_warna_kulit_cerah-sedang:',
        'zh': u':鼓掌_中等浅肤色:'
    },
    u'\U0001F44F\U0001F3FD': { # 👏🏽
        'en' : ':clapping_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':klatschende_hände_mittlere_hautfarbe:',
        'es': ':manos_aplaudiendo_tono_de_piel_medio:',
        'fr': u':applaudissements_peau_légèrement_mate:',
        'ja': u':拍手_中間の肌色:',
        'ko': u':손뼉_갈색_피부:',
        'pt': u':mãos_aplaudindo_pele_morena:',
        'it': ':mani_che_applaudono_carnagione_olivastra:',
        'fa': u':دست_زدن_پوست_طلایی:',
        'id': ':tepuk_tangan_warna_kulit_sedang:',
        'zh': u':鼓掌_中等肤色:'
    },
    u'\U0001F3DB\U0000FE0F': { # 🏛️
        'en' : ':classical_building:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':antikes_gebäude:',
        'es': u':edificio_clásico:',
        'fr': ':monument_classique:',
        'ja': u':歴史的な建物:',
        'ko': u':고전_양식의_건축물:',
        'pt': u':prédio_grego:',
        'it': ':edificio_classico:',
        'fa': u':ساختمان_باستانی:',
        'id': ':bangunan_klasik:',
        'zh': u':古典建筑:'
    },
    u'\U0001F3DB': { # 🏛
        'en' : ':classical_building:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':antikes_gebäude:',
        'es': u':edificio_clásico:',
        'fr': ':monument_classique:',
        'ja': u':歴史的な建物:',
        'ko': u':고전_양식의_건축물:',
        'pt': u':prédio_grego:',
        'it': ':edificio_classico:',
        'fa': u':ساختمان_باستانی:',
        'id': ':bangunan_klasik:',
        'zh': u':古典建筑:'
    },
    u'\U0001F37B': { # 🍻
        'en' : ':clinking_beer_mugs:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':beers:'],
        'de': u':bierkrüge:',
        'es': ':jarras_de_cerveza_brindando:',
        'fr': u':chopes_de_bière:',
        'ja': u':ビールで乾杯:',
        'ko': u':맥주:',
        'pt': ':canecas_de_cerveja:',
        'it': ':boccali_di_birra:',
        'fa': u':لیوان_های_آبجو_را_به_هم_زدن:',
        'id': ':mug_bir_berdenting:',
        'zh': u':干杯:'
    },
    u'\U0001F942': { # 🥂
        'en' : ':clinking_glasses:',
        'status' : fully_qualified,
        'E' : 3,
        'de': u':sektgläser:',
        'es': ':copas_brindando:',
        'fr': ':trinquer:',
        'ja': u':グラスで乾杯:',
        'ko': u':건배하는_샴페인_잔:',
        'pt': u':taças_brindando:',
        'it': ':brindisi:',
        'fa': u':صدای_به_هم_خوردن_پیاله_ها:',
        'id': ':mendentingkan_gelas:',
        'zh': u':碰杯:'
    },
    u'\U0001F4CB': { # 📋
        'en' : ':clipboard:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':klemmbrett:',
        'es': ':portapapeles:',
        'fr': ':porte-bloc:',
        'ja': u':クリップボード:',
        'ko': u':클립보드:',
        'pt': ':prancheta:',
        'it': ':portablocco:',
        'fa': u':تختهٔ_گیره_دار:',
        'id': ':papan_klip:',
        'zh': u':剪贴板:'
    },
    u'\U0001F503': { # 🔃
        'en' : ':clockwise_vertical_arrows:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrows_clockwise:'],
        'de': u':kreisförmige_pfeile_im_uhrzeigersinn:',
        'es': ':flechas_verticales_en_sentido_horario:',
        'fr': u':flèches_dans_le_sens_horaire:',
        'ja': u':右回り縦矢印:',
        'ko': u':시계_방향_화살표:',
        'pt': u':setas_verticais_no_sentido_horário:',
        'it': ':frecce_verticali_che_ruotano_in_senso_orario:',
        'fa': u':جهت_عقربه_های_ساعت:',
        'id': ':tanda_panah_searah_jarum_jam:',
        'zh': u':顺时针垂直箭头:'
    },
    u'\U0001F4D5': { # 📕
        'en' : ':closed_book:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':geschlossenes_buch:',
        'es': ':libro_cerrado:',
        'fr': u':livre_fermé:',
        'ja': u':閉じた本:',
        'ko': u':펼치지_않은_책:',
        'pt': ':livro_fechado:',
        'it': ':libro_chiuso:',
        'fa': u':کتاب_بسته:',
        'id': ':buku_tertutup:',
        'zh': u':合上的书本:'
    },
    u'\U0001F4EA': { # 📪
        'en' : ':closed_mailbox_with_lowered_flag:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mailbox_closed:'],
        'variant': True,
        'de': ':geschlossener_briefkasten_ohne_post:',
        'es': u':buzón_cerrado_con_la_bandera_bajada:',
        'fr': u':boîte_aux_lettres_fermée_drapeau_baissé:',
        'ja': u':閉じた郵便受け(手紙なし):',
        'ko': u':표지가_내려간_닫힌_우편함:',
        'pt': ':caixa_de_correio_fechada_com_bandeira_abaixada:',
        'it': ':cassetta_postale_chiusa_bandierina_abbassata:',
        'fa': u':صندوق_پستی_بسته_با_پرچم_پایین:',
        'id': ':kotak_surat_tertutup_dengan_bendera_turun:',
        'zh': u':无待收信件:'
    },
    u'\U0001F4EB': { # 📫
        'en' : ':closed_mailbox_with_raised_flag:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mailbox:'],
        'variant': True,
        'de': ':geschlossener_briefkasten_mit_post:',
        'es': u':buzón_cerrado_con_la_bandera_levantada:',
        'fr': u':boîte_aux_lettres_fermée_drapeau_levé:',
        'ja': u':閉じた郵便受け(手紙あり):',
        'ko': u':표지가_올라간_닫힌_우편함:',
        'pt': ':caixa_de_correio_fechada_com_bandeira_levantada:',
        'it': ':cassetta_postale_chiusa_bandierina_alzata:',
        'fa': u':صندوق_پستی_بسته_با_پرچم_بالا:',
        'id': ':kotak_surat_tertutup_dengan_bendera_terangkat:',
        'zh': u':有待收信件:'
    },
    u'\U0001F302': { # 🌂
        'en' : ':closed_umbrella:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':geschlossener_regenschirm:',
        'es': ':paraguas_cerrado:',
        'fr': u':parapluie_fermé:',
        'ja': u':閉じた傘:',
        'ko': u':접힌_우산:',
        'pt': ':guarda-chuva_fechado:',
        'it': ':ombrello_chiuso:',
        'fa': u':چتر_بسته:',
        'id': ':payung_tertutup:',
        'zh': u':收起的伞:'
    },
    u'\U00002601\U0000FE0F': { # ☁️
        'en' : ':cloud:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':wolke:',
        'es': ':nube:',
        'fr': ':nuage:',
        'ja': u':雲:',
        'ko': u':구름:',
        'pt': ':nuvem:',
        'it': ':nuvola:',
        'fa': u':ابر:',
        'id': ':awan:',
        'zh': u':云:'
    },
    u'\U00002601': { # ☁
        'en' : ':cloud:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':wolke:',
        'es': ':nube:',
        'fr': ':nuage:',
        'ja': u':雲:',
        'ko': u':구름:',
        'pt': ':nuvem:',
        'it': ':nuvola:',
        'fa': u':ابر:',
        'id': ':awan:',
        'zh': u':云:'
    },
    u'\U0001F329\U0000FE0F': { # 🌩️
        'en' : ':cloud_with_lightning:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':wolke_mit_blitz:',
        'es': ':nube_con_rayo:',
        'fr': u':nuage_avec_éclair:',
        'ja': u':雷雲:',
        'ko': u':번개구름:',
        'pt': u':nuvem_com_trovão:',
        'it': ':fulmini:',
        'fa': u':ابر_با_برق:',
        'id': ':awan_petir:',
        'zh': u':打雷:'
    },
    u'\U0001F329': { # 🌩
        'en' : ':cloud_with_lightning:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':wolke_mit_blitz:',
        'es': ':nube_con_rayo:',
        'fr': u':nuage_avec_éclair:',
        'ja': u':雷雲:',
        'ko': u':번개구름:',
        'pt': u':nuvem_com_trovão:',
        'it': ':fulmini:',
        'fa': u':ابر_با_برق:',
        'id': ':awan_petir:',
        'zh': u':打雷:'
    },
    u'\U000026C8\U0000FE0F': { # ⛈️
        'en' : ':cloud_with_lightning_and_rain:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':thunder_cloud_and_rain:'],
        'variant': True,
        'de': ':wolke_mit_blitz_und_regen:',
        'es': ':nube_con_rayo_y_lluvia:',
        'fr': u':nuage_avec_éclair_et_pluie:',
        'ja': u':雷雨:',
        'ko': u':번개가_치는_비구름:',
        'pt': u':chuva_com_trovão:',
        'it': ':temporale:',
        'fa': u':ابر_با_رعدوبرق_و_باران:',
        'id': ':awan_dengan_petir_dan_hujan:',
        'zh': u':雷阵雨:'
    },
    u'\U000026C8': { # ⛈
        'en' : ':cloud_with_lightning_and_rain:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':thunder_cloud_and_rain:'],
        'variant': True,
        'de': ':wolke_mit_blitz_und_regen:',
        'es': ':nube_con_rayo_y_lluvia:',
        'fr': u':nuage_avec_éclair_et_pluie:',
        'ja': u':雷雨:',
        'ko': u':번개가_치는_비구름:',
        'pt': u':chuva_com_trovão:',
        'it': ':temporale:',
        'fa': u':ابر_با_رعدوبرق_و_باران:',
        'id': ':awan_dengan_petir_dan_hujan:',
        'zh': u':雷阵雨:'
    },
    u'\U0001F327\U0000FE0F': { # 🌧️
        'en' : ':cloud_with_rain:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':wolke_mit_regen:',
        'es': ':nube_con_lluvia:',
        'fr': ':nuage_avec_pluie:',
        'ja': u':雨雲:',
        'ko': u':비구름:',
        'pt': ':nuvem_com_chuva:',
        'it': ':pioggia:',
        'fa': u':ابر_بارانی:',
        'id': ':awan_hujan:',
        'zh': u':下雨:'
    },
    u'\U0001F327': { # 🌧
        'en' : ':cloud_with_rain:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':wolke_mit_regen:',
        'es': ':nube_con_lluvia:',
        'fr': ':nuage_avec_pluie:',
        'ja': u':雨雲:',
        'ko': u':비구름:',
        'pt': ':nuvem_com_chuva:',
        'it': ':pioggia:',
        'fa': u':ابر_بارانی:',
        'id': ':awan_hujan:',
        'zh': u':下雨:'
    },
    u'\U0001F328\U0000FE0F': { # 🌨️
        'en' : ':cloud_with_snow:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':wolke_mit_schnee:',
        'es': ':nube_con_nieve:',
        'fr': ':nuage_avec_neige:',
        'ja': u':雪雲:',
        'ko': u':눈구름:',
        'pt': ':nuvem_com_neve:',
        'it': ':neve:',
        'fa': u':ابر_برفی:',
        'id': ':awan_salju:',
        'zh': u':下雪:'
    },
    u'\U0001F328': { # 🌨
        'en' : ':cloud_with_snow:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':wolke_mit_schnee:',
        'es': ':nube_con_nieve:',
        'fr': ':nuage_avec_neige:',
        'ja': u':雪雲:',
        'ko': u':눈구름:',
        'pt': ':nuvem_com_neve:',
        'it': ':neve:',
        'fa': u':ابر_برفی:',
        'id': ':awan_salju:',
        'zh': u':下雪:'
    },
    u'\U0001F921': { # 🤡
        'en' : ':clown_face:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':clown-gesicht:',
        'es': ':cara_de_payaso:',
        'fr': ':visage_de_clown:',
        'ja': u':ピエロの顔:',
        'ko': u':어릿광대_얼굴:',
        'pt': u':rosto_de_palhaço:',
        'it': ':faccina_pagliaccio:',
        'fa': u':دلقک:',
        'id': ':badut:',
        'zh': u':小丑脸:'
    },
    u'\U00002663\U0000FE0F': { # ♣️
        'en' : ':club_suit:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clubs:'],
        'variant': True,
        'de': ':kreuz:',
        'es': u':palo_de_tréboles:',
        'fr': u':trèfle_cartes:',
        'ja': u':クラブ:',
        'ko': u':클럽:',
        'pt': ':naipe_de_paus:',
        'it': ':fiori:',
        'fa': u':خال_گشنیز:',
        'id': ':keriting:',
        'zh': u':梅花:'
    },
    u'\U00002663': { # ♣
        'en' : ':club_suit:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':clubs:'],
        'variant': True,
        'de': ':kreuz:',
        'es': u':palo_de_tréboles:',
        'fr': u':trèfle_cartes:',
        'ja': u':クラブ:',
        'ko': u':클럽:',
        'pt': ':naipe_de_paus:',
        'it': ':fiori:',
        'fa': u':خال_گشنیز:',
        'id': ':keriting:',
        'zh': u':梅花:'
    },
    u'\U0001F45D': { # 👝
        'en' : ':clutch_bag:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pouch:'],
        'de': ':clutch:',
        'es': ':bolso_de_mano:',
        'fr': ':pochette:',
        'ja': u':ポーチ:',
        'ko': u':파우치:',
        'pt': ':bolsa_pequena:',
        'it': ':pochette:',
        'fa': u':کیف_بدون_تسمه_زنانه:',
        'id': ':kantung:',
        'zh': u':手袋:'
    },
    u'\U0001F9E5': { # 🧥
        'en' : ':coat:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mantel:',
        'es': ':abrigo:',
        'fr': ':manteau:',
        'ja': u':コート:',
        'ko': u':코트:',
        'pt': ':casaco:',
        'it': ':cappotto:',
        'fa': u':پالتو:',
        'id': ':mantel:',
        'zh': u':外套:'
    },
    u'\U0001FAB3': { # 🪳
        'en' : ':cockroach:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':kakerlake:',
        'es': ':cucaracha:',
        'fr': ':cafard:',
        'ja': u':ゴキブリ:',
        'ko': u':바퀴벌레:',
        'pt': ':barata:',
        'it': ':scarafaggio:',
        'fa': u':سوسک_حمام:',
        'id': ':kecoak:',
        'zh': u':蟑螂:'
    },
    u'\U0001F378': { # 🍸
        'en' : ':cocktail_glass:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cocktail:'],
        'variant': True,
        'de': ':cocktailglas:',
        'es': u':copa_de_cóctel:',
        'fr': ':cocktail:',
        'ja': u':カクテルグラス:',
        'ko': u':칵테일:',
        'pt': ':coquetel:',
        'it': ':cocktail:',
        'fa': u':جام_کوکتل:',
        'id': ':gelas_cocktail:',
        'zh': u':鸡尾酒:'
    },
    u'\U0001F965': { # 🥥
        'en' : ':coconut:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kokosnuss:',
        'es': ':coco:',
        'fr': ':noix_de_coco:',
        'ja': u':ココナツ:',
        'ko': u':코코넛:',
        'pt': ':coco:',
        'it': ':cocco:',
        'fa': u':نارگیل:',
        'id': ':kelapa:',
        'zh': u':椰子:'
    },
    u'\U000026B0\U0000FE0F': { # ⚰️
        'en' : ':coffin:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':sarg:',
        'es': u':ataúd:',
        'fr': ':cercueil:',
        'ja': u':棺桶:',
        'ko': u':관:',
        'pt': u':caixão:',
        'it': ':bara:',
        'fa': u':تابوت:',
        'id': ':peti_mati:',
        'zh': u':棺材:'
    },
    u'\U000026B0': { # ⚰
        'en' : ':coffin:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':sarg:',
        'es': u':ataúd:',
        'fr': ':cercueil:',
        'ja': u':棺桶:',
        'ko': u':관:',
        'pt': u':caixão:',
        'it': ':bara:',
        'fa': u':تابوت:',
        'id': ':peti_mati:',
        'zh': u':棺材:'
    },
    u'\U0001FA99': { # 🪙
        'en' : ':coin:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':münze:',
        'es': ':moneda:',
        'fr': u':pièce:',
        'ja': u':コイン:',
        'ko': u':동전:',
        'pt': ':moeda:',
        'it': ':moneta:',
        'fa': u':سکه:',
        'id': ':koin:',
        'zh': u':硬币:'
    },
    u'\U0001F976': { # 🥶
        'en' : ':cold_face:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frierendes_gesicht:',
        'es': u':cara_con_frío:',
        'fr': ':visage_bleu_et_froid:',
        'ja': u':寒い顔:',
        'ko': u':추워하는_얼굴:',
        'pt': ':rosto_gelado:',
        'it': ':faccina_congelata:',
        'fa': u':خیلی_سرد:',
        'id': ':wajah_kedinginan:',
        'zh': u':冷脸:'
    },
    u'\U0001F4A5': { # 💥
        'en' : ':collision:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':boom:'],
        'de': u':zusammenstoß:',
        'es': u':colisión:',
        'fr': ':explosion:',
        'ja': u':衝突:',
        'ko': u':충돌:',
        'pt': u':colisão:',
        'it': ':collisione:',
        'fa': u':برخورد:',
        'id': ':tabrakan:',
        'zh': u':爆炸:'
    },
    u'\U00002604\U0000FE0F': { # ☄️
        'en' : ':comet:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':komet:',
        'es': ':meteorito:',
        'fr': u':comète:',
        'ja': u':彗星:',
        'ko': u':혜성:',
        'pt': ':cometa:',
        'it': ':cometa:',
        'fa': u':ستاره_دنباله_دار:',
        'id': ':komet:',
        'zh': u':彗星:'
    },
    u'\U00002604': { # ☄
        'en' : ':comet:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':komet:',
        'es': ':meteorito:',
        'fr': u':comète:',
        'ja': u':彗星:',
        'ko': u':혜성:',
        'pt': ':cometa:',
        'it': ':cometa:',
        'fa': u':ستاره_دنباله_دار:',
        'id': ':komet:',
        'zh': u':彗星:'
    },
    u'\U0001F9ED': { # 🧭
        'en' : ':compass:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':kompass:',
        'es': u':brújula:',
        'fr': ':boussole:',
        'ja': u':コンパス:',
        'ko': u':나침반:',
        'pt': u':bússola:',
        'it': ':bussola:',
        'fa': u':قطب_نما:',
        'id': ':kompas:',
        'zh': u':指南针:'
    },
    u'\U0001F4BD': { # 💽
        'en' : ':computer_disk:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':minidisc:'],
        'de': ':minidisc:',
        'es': ':minidisc:',
        'fr': u':disque_d’ordinateur:',
        'ja': ':md:',
        'ko': u':엠디:',
        'pt': ':minidisc:',
        'it': ':minidisc:',
        'fa': u':مینی_دیسک:',
        'id': ':disk_komputer:',
        'zh': u':电脑光盘:'
    },
    u'\U0001F5B1\U0000FE0F': { # 🖱️
        'en' : ':computer_mouse:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':three_button_mouse:'],
        'variant': True,
        'de': ':computermaus:',
        'es': u':ratón_de_ordenador:',
        'fr': u':souris_d’ordinateur:',
        'ja': u':マウス:',
        'ko': u':컴퓨터_마우스:',
        'pt': ':mouse:',
        'it': ':mouse:',
        'fa': u':موشواره:',
        'id': ':mouse_komputer:',
        'zh': u':电脑鼠标:'
    },
    u'\U0001F5B1': { # 🖱
        'en' : ':computer_mouse:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':three_button_mouse:'],
        'variant': True,
        'de': ':computermaus:',
        'es': u':ratón_de_ordenador:',
        'fr': u':souris_d’ordinateur:',
        'ja': u':マウス:',
        'ko': u':컴퓨터_마우스:',
        'pt': ':mouse:',
        'it': ':mouse:',
        'fa': u':موشواره:',
        'id': ':mouse_komputer:',
        'zh': u':电脑鼠标:'
    },
    u'\U0001F38A': { # 🎊
        'en' : ':confetti_ball:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':konfettiball:',
        'es': ':bola_de_confeti:',
        'fr': ':confettis:',
        'ja': u':くす玉:',
        'ko': u':박_터트리기:',
        'pt': ':confete:',
        'it': ':coriandoli:',
        'fa': u':توپ_پولکی:',
        'id': ':bola_konfeti:',
        'zh': u':五彩纸屑球:'
    },
    u'\U0001F616': { # 😖
        'en' : ':confounded_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':confounded:'],
        'de': ':verwirrtes_gesicht:',
        'es': u':cara_de_frustración:',
        'fr': u':visage_déconcerté:',
        'ja': u':困惑した顔:',
        'ko': u':당혹한_얼굴:',
        'pt': ':rosto_perplexo:',
        'it': ':faccina_frustrata:',
        'fa': u':سردرگم:',
        'id': ':wajah_stres:',
        'zh': u':困惑:'
    },
    u'\U0001F615': { # 😕
        'en' : ':confused_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':confused:'],
        'de': ':verwundertes_gesicht:',
        'es': u':cara_de_confusión:',
        'fr': ':visage_confus:',
        'ja': u':混乱:',
        'ko': u':혼란스러워하는_얼굴:',
        'pt': ':rosto_confuso:',
        'it': ':faccina_confusa:',
        'fa': u':گیج_شده:',
        'id': ':wajah_bingung:',
        'zh': u':困扰:'
    },
    u'\U0001F6A7': { # 🚧
        'en' : ':construction:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':baustellenabsperrung:',
        'es': ':obras:',
        'fr': ':travaux:',
        'ja': u':工事中:',
        'ko': u':공사_중:',
        'pt': u':em_construção:',
        'it': ':area_cantiere:',
        'fa': u':ساخت_وساز:',
        'id': ':konstruksi:',
        'zh': u':路障:'
    },
    u'\U0001F477': { # 👷
        'en' : ':construction_worker:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':bauarbeiter(in):',
        'es': u':profesional_de_la_construcción:',
        'fr': u':personnel_du_bâtiment:',
        'ja': u':建設作業員:',
        'ko': u':건설_노동자:',
        'pt': u':trabalhador_de_construção_civil:',
        'it': ':operaio_edile:',
        'fa': u':کارگر:',
        'id': ':pekerja_konstruksi:',
        'zh': u':建筑工人:'
    },
    u'\U0001F477\U0001F3FF': { # 👷🏿
        'en' : ':construction_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bauarbeiter(in)_dunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_tono_de_piel_oscuro:',
        'fr': u':personnel_du_bâtiment_peau_foncée:',
        'ja': u':建設作業員_濃い肌色:',
        'ko': u':건설_노동자_검은색_피부:',
        'pt': u':trabalhador_de_construção_civil_pele_escura:',
        'it': ':operaio_edile_carnagione_scura:',
        'fa': u':کارگر_پوست_آبنوسی:',
        'id': ':pekerja_konstruksi_warna_kulit_gelap:',
        'zh': u':建筑工人_较深肤色:'
    },
    u'\U0001F477\U0001F3FB': { # 👷🏻
        'en' : ':construction_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bauarbeiter(in)_helle_hautfarbe:',
        'es': u':profesional_de_la_construcción_tono_de_piel_claro:',
        'fr': u':personnel_du_bâtiment_peau_claire:',
        'ja': u':建設作業員_薄い肌色:',
        'ko': u':건설_노동자_하얀_피부:',
        'pt': u':trabalhador_de_construção_civil_pele_clara:',
        'it': ':operaio_edile_carnagione_chiara:',
        'fa': u':کارگر_پوست_سفید:',
        'id': ':pekerja_konstruksi_warna_kulit_cerah:',
        'zh': u':建筑工人_较浅肤色:'
    },
    u'\U0001F477\U0001F3FE': { # 👷🏾
        'en' : ':construction_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bauarbeiter(in)_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_tono_de_piel_oscuro_medio:',
        'fr': u':personnel_du_bâtiment_peau_mate:',
        'ja': u':建設作業員_やや濃い肌色:',
        'ko': u':건설_노동자_진한_갈색_피부:',
        'pt': u':trabalhador_de_construção_civil_pele_morena_escura:',
        'it': ':operaio_edile_carnagione_abbastanza_scura:',
        'fa': u':کارگر_پوست_گندمی:',
        'id': ':pekerja_konstruksi_warna_kulit_gelap-sedang:',
        'zh': u':建筑工人_中等深肤色:'
    },
    u'\U0001F477\U0001F3FC': { # 👷🏼
        'en' : ':construction_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bauarbeiter(in)_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_construcción_tono_de_piel_claro_medio:',
        'fr': u':personnel_du_bâtiment_peau_moyennement_claire:',
        'ja': u':建設作業員_やや薄い肌色:',
        'ko': u':건설_노동자_연한_갈색_피부:',
        'pt': u':trabalhador_de_construção_civil_pele_morena_clara:',
        'it': ':operaio_edile_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_پوست_روشن:',
        'id': ':pekerja_konstruksi_warna_kulit_cerah-sedang:',
        'zh': u':建筑工人_中等浅肤色:'
    },
    u'\U0001F477\U0001F3FD': { # 👷🏽
        'en' : ':construction_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bauarbeiter(in)_mittlere_hautfarbe:',
        'es': u':profesional_de_la_construcción_tono_de_piel_medio:',
        'fr': u':personnel_du_bâtiment_peau_légèrement_mate:',
        'ja': u':建設作業員_中間の肌色:',
        'ko': u':건설_노동자_갈색_피부:',
        'pt': u':trabalhador_de_construção_civil_pele_morena:',
        'it': ':operaio_edile_carnagione_olivastra:',
        'fa': u':کارگر_پوست_طلایی:',
        'id': ':pekerja_konstruksi_warna_kulit_sedang:',
        'zh': u':建筑工人_中等肤色:'
    },
    u'\U0001F39B\U0000FE0F': { # 🎛️
        'en' : ':control_knobs:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':drehregler:',
        'es': ':ruedas_de_control:',
        'fr': u':boutons_de_réglage:',
        'ja': u':コントロールつまみ:',
        'ko': u':컨트롤_레버:',
        'pt': u':botões_giratórios:',
        'it': ':manopole_di_controllo:',
        'fa': u':دسته_های_کنترل:',
        'id': ':kenop_kontrol:',
        'zh': u':控制旋钮:'
    },
    u'\U0001F39B': { # 🎛
        'en' : ':control_knobs:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':drehregler:',
        'es': ':ruedas_de_control:',
        'fr': u':boutons_de_réglage:',
        'ja': u':コントロールつまみ:',
        'ko': u':컨트롤_레버:',
        'pt': u':botões_giratórios:',
        'it': ':manopole_di_controllo:',
        'fa': u':دسته_های_کنترل:',
        'id': ':kenop_kontrol:',
        'zh': u':控制旋钮:'
    },
    u'\U0001F3EA': { # 🏪
        'en' : ':convenience_store:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':minimarkt:',
        'es': ':tienda_24_horas:',
        'fr': u':supérette:',
        'ja': u':コンビニ:',
        'ko': u':편의점:',
        'pt': u':loja_de_conveniência:',
        'it': ':minimarket:',
        'fa': u':بقالی:',
        'id': ':minimarket:',
        'zh': u':便利店:'
    },
    u'\U0001F9D1\U0000200D\U0001F373': { # 🧑‍🍳
        'en' : ':cook:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':koch/köchin:',
        'es': ':chef:',
        'fr': ':cuisinier_(tous_genres):',
        'ja': u':コック:',
        'ko': u':요리사:',
        'pt': ':chef_de_cozinha:',
        'it': ':persona_che_cucina:',
        'fa': u':آشپز:',
        'id': ':koki:',
        'zh': u':厨师:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F373': { # 🧑🏿‍🍳
        'en' : ':cook_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':koch/köchin_dunkle_hautfarbe:',
        'es': ':chef_tono_de_piel_oscuro:',
        'fr': u':cuisinier_(tous_genres)_peau_foncée:',
        'ja': u':コック_濃い肌色:',
        'ko': u':요리사_검은색_피부:',
        'pt': ':chef_de_cozinha_pele_escura:',
        'it': ':persona_che_cucina_carnagione_scura:',
        'fa': u':آشپز_پوست_آبنوسی:',
        'id': ':koki_warna_kulit_gelap:',
        'zh': u':厨师_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F373': { # 🧑🏻‍🍳
        'en' : ':cook_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':koch/köchin_helle_hautfarbe:',
        'es': ':chef_tono_de_piel_claro:',
        'fr': ':cuisinier_(tous_genres)_peau_claire:',
        'ja': u':コック_薄い肌色:',
        'ko': u':요리사_하얀_피부:',
        'pt': ':chef_de_cozinha_pele_clara:',
        'it': ':persona_che_cucina_carnagione_chiara:',
        'fa': u':آشپز_پوست_سفید:',
        'id': ':koki_warna_kulit_cerah:',
        'zh': u':厨师_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F373': { # 🧑🏾‍🍳
        'en' : ':cook_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':koch/köchin_mitteldunkle_hautfarbe:',
        'es': ':chef_tono_de_piel_oscuro_medio:',
        'fr': ':cuisinier_(tous_genres)_peau_mate:',
        'ja': u':コック_やや濃い肌色:',
        'ko': u':요리사_진한_갈색_피부:',
        'pt': ':chef_de_cozinha_pele_morena_escura:',
        'it': ':persona_che_cucina_carnagione_abbastanza_scura:',
        'fa': u':آشپز_پوست_گندمی:',
        'id': ':koki_warna_kulit_gelap-sedang:',
        'zh': u':厨师_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F373': { # 🧑🏼‍🍳
        'en' : ':cook_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':koch/köchin_mittelhelle_hautfarbe:',
        'es': ':chef_tono_de_piel_claro_medio:',
        'fr': ':cuisinier_(tous_genres)_peau_moyennement_claire:',
        'ja': u':コック_やや薄い肌色:',
        'ko': u':요리사_연한_갈색_피부:',
        'pt': ':chef_de_cozinha_pele_morena_clara:',
        'it': ':persona_che_cucina_carnagione_abbastanza_chiara:',
        'fa': u':آشپز_پوست_روشن:',
        'id': ':koki_warna_kulit_cerah-sedang:',
        'zh': u':厨师_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F373': { # 🧑🏽‍🍳
        'en' : ':cook_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':koch/köchin_mittlere_hautfarbe:',
        'es': ':chef_tono_de_piel_medio:',
        'fr': u':cuisinier_(tous_genres)_peau_légèrement_mate:',
        'ja': u':コック_中間の肌色:',
        'ko': u':요리사_갈색_피부:',
        'pt': ':chef_de_cozinha_pele_morena:',
        'it': ':persona_che_cucina_carnagione_olivastra:',
        'fa': u':آشپز_پوست_طلایی:',
        'id': ':koki_warna_kulit_sedang:',
        'zh': u':厨师_中等肤色:'
    },
    u'\U0001F35A': { # 🍚
        'en' : ':cooked_rice:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':rice:'],
        'de': u':reis_in_schüssel:',
        'es': ':arroz_cocido:',
        'fr': ':bol_de_riz:',
        'ja': u':ごはん:',
        'ko': u':밥:',
        'pt': ':arroz_cozido:',
        'it': ':riso_bollito:',
        'fa': u':برنج_پخته:',
        'id': ':nasi_matang:',
        'zh': u':米饭:'
    },
    u'\U0001F36A': { # 🍪
        'en' : ':cookie:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':keks:',
        'es': ':galleta:',
        'fr': ':cookie:',
        'ja': u':クッキー:',
        'ko': u':쿠키:',
        'pt': ':biscoito:',
        'it': ':biscotto:',
        'fa': u':کلوچه:',
        'id': ':biskuit:',
        'zh': u':饼干:'
    },
    u'\U0001F373': { # 🍳
        'en' : ':cooking:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':egg:', ':fried_egg:'],
        'de': ':spiegelei_in_bratpfanne:',
        'es': ':cocinar:',
        'fr': u':œuf_au_plat:',
        'ja': u':料理:',
        'ko': u':프라이팬:',
        'pt': ':ovo_frito:',
        'it': ':cucinare:',
        'fa': u':آشپزی:',
        'id': ':memasak:',
        'zh': u':煎蛋:'
    },
    u'\U000000A9\U0000FE0F': { # ©️
        'en' : ':copyright:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':copyright:',
        'es': ':copyright:',
        'fr': ':symbole_copyright:',
        'ja': u':著作権マーク:',
        'ko': u':저작권:',
        'pt': u':símbolo_de_copyright:',
        'it': ':copyright:',
        'fa': u':حق_نسخه_برداری:',
        'id': ':hak_cipta:',
        'zh': u':版权:'
    },
    u'\U000000A9': { # ©
        'en' : ':copyright:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':copyright:',
        'es': ':copyright:',
        'fr': ':symbole_copyright:',
        'ja': u':著作権マーク:',
        'ko': u':저작권:',
        'pt': u':símbolo_de_copyright:',
        'it': ':copyright:',
        'fa': u':حق_نسخه_برداری:',
        'id': ':hak_cipta:',
        'zh': u':版权:'
    },
    u'\U0001FAB8': { # 🪸
        'en' : ':coral:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':koralle:',
        'es': ':coral:',
        'fr': ':corail:',
        'ja': u':サンゴ:',
        'ko': u':산호초:',
        'pt': ':coral:',
        'it': ':corallo:',
        'fa': u':مرجان:',
        'id': ':terumbu_karang:',
        'zh': u':珊瑚:'
    },
    u'\U0001F6CB\U0000FE0F': { # 🛋️
        'en' : ':couch_and_lamp:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':sofa_und_lampe:',
        'es': u':sofá_y_lámpara:',
        'fr': u':canapé_et_lampe:',
        'ja': u':ソファとランプ:',
        'ko': u':소파와_전등:',
        'pt': u':sofá_e_luminária:',
        'it': ':divano_e_lampada:',
        'fa': u':مبل_راحتی_و_چراغ:',
        'id': ':sofa_dan_lampu:',
        'zh': u':沙发和灯:'
    },
    u'\U0001F6CB': { # 🛋
        'en' : ':couch_and_lamp:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':sofa_und_lampe:',
        'es': u':sofá_y_lámpara:',
        'fr': u':canapé_et_lampe:',
        'ja': u':ソファとランプ:',
        'ko': u':소파와_전등:',
        'pt': u':sofá_e_luminária:',
        'it': ':divano_e_lampada:',
        'fa': u':مبل_راحتی_و_چراغ:',
        'id': ':sofa_dan_lampu:',
        'zh': u':沙发和灯:'
    },
    u'\U0001F504': { # 🔄
        'en' : ':counterclockwise_arrows_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':arrows_counterclockwise:'],
        'de': ':pfeile_gegen_den_uhrzeigersinn:',
        'es': ':flechas_en_sentido_antihorario:',
        'fr': u':flèches_dans_le_sens_antihoraire:',
        'ja': u':左回り矢印:',
        'ko': u':반시계_방향_화살표:',
        'pt': u':botão_de_setas_em_sentido_anti-horário:',
        'it': ':frecce_che_ruotano_in_senso_antiorario:',
        'fa': u':خلاف_جهت_عقربه_های_ساعت:',
        'id': ':tanda_panah_berlawanan_arah_jarum_jam:',
        'zh': u':逆时针箭头按钮:'
    },
    u'\U0001F491': { # 💑
        'en' : ':couple_with_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':liebespaar:',
        'es': ':pareja_enamorada:',
        'fr': u':couple_avec_cœur:',
        'ja': u':カップルとハート:',
        'ko': u':연인:',
        'pt': ':casal_apaixonado:',
        'it': ':coppia_con_cuore:',
        'fa': u':زوج_عاشق:',
        'id': ':pasangan_dengan_hati:',
        'zh': u':情侣:'
    },
    u'\U0001F491\U0001F3FF': { # 💑🏿
        'en' : ':couple_with_heart_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_dunkle_hautfarbe:',
        'es': ':pareja_enamorada_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__peau_foncée:',
        'pt': ':casal_apaixonado_pele_escura:',
        'it': ':coppia_con_cuore_carnagione_scura:'
    },
    u'\U0001F491\U0001F3FB': { # 💑🏻
        'en' : ':couple_with_heart_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_helle_hautfarbe:',
        'es': ':pareja_enamorada_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__peau_claire:',
        'pt': ':casal_apaixonado_pele_clara:',
        'it': ':coppia_con_cuore_carnagione_chiara:'
    },
    u'\U0001F468\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468': { # 👨‍❤️‍👨
        'en' : ':couple_with_heart_man_man:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':liebespaar_mann,_mann:',
        'es': ':pareja_enamorada_hombre_y_hombre:',
        'fr': u':couple_avec_cœur_homme_et_homme:',
        'ja': u':カップルとハート_男性_男性:',
        'ko': u':연인_남자_남자:',
        'pt': ':casal_apaixonado_homem_e_homem:',
        'it': ':coppia_con_cuore_uomo_e_uomo:',
        'fa': u':زوج_عاشق_مرد_مرد:',
        'id': ':pasangan_dengan_hati_pria_pria:',
        'zh': u':情侣_男人男人:'
    },
    u'\U0001F468\U0000200D\U00002764\U0000200D\U0001F468': { # 👨‍❤‍👨
        'en' : ':couple_with_heart_man_man:',
        'status' : minimally_qualified,
        'E' : 2
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👨🏿‍❤️‍👨🏿
        'en' : ':couple_with_heart_man_man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_und_dunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__homme_homme_et_peau_foncée:',
        'ja': u':カップルとハート_男性_男性_濃い肌色:',
        'ko': u':연인_남자_남자_검은색_피부:',
        'pt': ':casal_apaixonado_homem_homem_e_pele_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_e_carnagione_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap:',
        'zh': u':情侣_男人男人较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👨🏿‍❤‍👨🏿
        'en' : ':couple_with_heart_man_man_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👨🏿‍❤️‍👨🏻
        'en' : ':couple_with_heart_man_man_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_foncée_et_peau_claire:',
        'ja': u':カップルとハート_男性_男性_濃い肌色_薄い肌色:',
        'ko': u':연인_남자_남자_검은색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':情侣_男人男人较深肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👨🏿‍❤‍👨🏻
        'en' : ':couple_with_heart_man_man_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👨🏿‍❤️‍👨🏾
        'en' : ':couple_with_heart_man_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_foncée_et_peau_mate:',
        'ja': u':カップルとハート_男性_男性_濃い肌色_やや濃い肌色:',
        'ko': u':연인_남자_남자_검은색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_escura_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':情侣_男人男人较深肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👨🏿‍❤‍👨🏾
        'en' : ':couple_with_heart_man_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👨🏿‍❤️‍👨🏼
        'en' : ':couple_with_heart_man_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_男性_男性_濃い肌色_やや薄い肌色:',
        'ko': u':연인_남자_남자_검은색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':情侣_男人男人较深肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👨🏿‍❤‍👨🏼
        'en' : ':couple_with_heart_man_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👨🏿‍❤️‍👨🏽
        'en' : ':couple_with_heart_man_man_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_男性_男性_濃い肌色_中間の肌色:',
        'ko': u':연인_남자_남자_검은색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':情侣_男人男人较深肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👨🏿‍❤‍👨🏽
        'en' : ':couple_with_heart_man_man_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👨🏻‍❤️‍👨🏻
        'en' : ':couple_with_heart_man_man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_und_helle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__homme_homme_et_peau_claire:',
        'ja': u':カップルとハート_男性_男性_薄い肌色:',
        'ko': u':연인_남자_남자_하얀_피부:',
        'pt': ':casal_apaixonado_homem_homem_e_pele_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah:',
        'zh': u':情侣_男人男人较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👨🏻‍❤‍👨🏻
        'en' : ':couple_with_heart_man_man_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👨🏻‍❤️‍👨🏿
        'en' : ':couple_with_heart_man_man_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_claire_et_peau_foncée:',
        'ja': u':カップルとハート_男性_男性_薄い肌色_濃い肌色:',
        'ko': u':연인_남자_남자_하얀_피부_검은색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':情侣_男人男人较浅肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👨🏻‍❤‍👨🏿
        'en' : ':couple_with_heart_man_man_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👨🏻‍❤️‍👨🏾
        'en' : ':couple_with_heart_man_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_claire_et_peau_mate:',
        'ja': u':カップルとハート_男性_男性_薄い肌色_やや濃い肌色:',
        'ko': u':연인_남자_남자_하얀_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_سفید_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':情侣_男人男人较浅肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👨🏻‍❤‍👨🏾
        'en' : ':couple_with_heart_man_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👨🏻‍❤️‍👨🏼
        'en' : ':couple_with_heart_man_man_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_claire_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_男性_男性_薄い肌色_やや薄い肌色:',
        'ko': u':연인_남자_남자_하얀_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_clara_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_سفید_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':情侣_男人男人较浅肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👨🏻‍❤‍👨🏼
        'en' : ':couple_with_heart_man_man_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👨🏻‍❤️‍👨🏽
        'en' : ':couple_with_heart_man_man_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_男性_男性_薄い肌色_中間の肌色:',
        'ko': u':연인_남자_남자_하얀_피부_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_سفید_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':情侣_男人男人较浅肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👨🏻‍❤‍👨🏽
        'en' : ':couple_with_heart_man_man_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👨🏾‍❤️‍👨🏾
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_und_mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_et_peau_mate:',
        'ja': u':カップルとハート_男性_男性_やや濃い肌色:',
        'ko': u':연인_남자_남자_진한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap-sedang:',
        'zh': u':情侣_男人男人中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👨🏾‍❤‍👨🏾
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👨🏾‍❤️‍👨🏿
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_mate_et_peau_foncée:',
        'ja': u':カップルとハート_男性_男性_やや濃い肌色_濃い肌色:',
        'ko': u':연인_남자_남자_진한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_escura_e_pele_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':情侣_男人男人中等深肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👨🏾‍❤‍👨🏿
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👨🏾‍❤️‍👨🏻
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_mate_et_peau_claire:',
        'ja': u':カップルとハート_男性_男性_やや濃い肌色_薄い肌色:',
        'ko': u':연인_남자_남자_진한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_گندمی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':情侣_男人男人中等深肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👨🏾‍❤‍👨🏻
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👨🏾‍❤️‍👨🏼
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_男性_男性_やや濃い肌色_やや薄い肌色:',
        'ko': u':연인_남자_남자_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_گندمی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_男人男人中等深肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👨🏾‍❤‍👨🏼
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👨🏾‍❤️‍👨🏽
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_mate_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_男性_男性_やや濃い肌色_中間の肌色:',
        'ko': u':연인_남자_남자_진한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_گندمی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':情侣_男人男人中等深肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👨🏾‍❤‍👨🏽
        'en' : ':couple_with_heart_man_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👨🏼‍❤️‍👨🏼
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_und_mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_男性_男性_やや薄い肌色:',
        'ko': u':연인_남자_남자_연한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah-sedang:',
        'zh': u':情侣_男人男人中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👨🏼‍❤‍👨🏼
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👨🏼‍❤️‍👨🏿
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':カップルとハート_男性_男性_やや薄い肌色_濃い肌色:',
        'ko': u':연인_남자_남자_연한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':情侣_男人男人中等浅肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👨🏼‍❤‍👨🏿
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👨🏼‍❤️‍👨🏻
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_moyennement_claire_et_peau_claire:',
        'ja': u':カップルとハート_男性_男性_やや薄い肌色_薄い肌色:',
        'ko': u':연인_남자_남자_연한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_clara_e_pele_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_روشن_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':情侣_男人男人中等浅肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👨🏼‍❤‍👨🏻
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👨🏼‍❤️‍👨🏾
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_moyennement_claire_et_peau_mate:',
        'ja': u':カップルとハート_男性_男性_やや薄い肌色_やや濃い肌色:',
        'ko': u':연인_남자_남자_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_روشن_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_男人男人中等浅肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👨🏼‍❤‍👨🏾
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👨🏼‍❤️‍👨🏽
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_男性_男性_やや薄い肌色_中間の肌色:',
        'ko': u':연인_남자_남자_연한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_روشن_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':情侣_男人男人中等浅肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👨🏼‍❤‍👨🏽
        'en' : ':couple_with_heart_man_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👨🏽‍❤️‍👨🏽
        'en' : ':couple_with_heart_man_man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_und_mittlere_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__homme_homme_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_男性_男性_中間の肌色:',
        'ko': u':연인_남자_남자_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_e_pele_morena:',
        'it': ':coppia_con_cuore_uomo_uomo_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_مرد_مرد_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_sedang:',
        'zh': u':情侣_男人男人中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👨🏽‍❤‍👨🏽
        'en' : ':couple_with_heart_man_man_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👨🏽‍❤️‍👨🏿
        'en' : ':couple_with_heart_man_man_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':カップルとハート_男性_男性_中間の肌色_濃い肌色:',
        'ko': u':연인_남자_남자_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_e_pele_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':情侣_男人男人中等肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👨🏽‍❤‍👨🏿
        'en' : ':couple_with_heart_man_man_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👨🏽‍❤️‍👨🏻
        'en' : ':couple_with_heart_man_man_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__homme_homme_peau_légèrement_mate_et_peau_claire:',
        'ja': u':カップルとハート_男性_男性_中間の肌色_薄い肌色:',
        'ko': u':연인_남자_남자_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_e_pele_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_طلایی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':情侣_男人男人中等肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👨🏽‍❤‍👨🏻
        'en' : ':couple_with_heart_man_man_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👨🏽‍❤️‍👨🏾
        'en' : ':couple_with_heart_man_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_légèrement_mate_et_peau_mate:',
        'ja': u':カップルとハート_男性_男性_中間の肌色_やや濃い肌色:',
        'ko': u':연인_남자_남자_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_طلایی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_男人男人中等肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👨🏽‍❤‍👨🏾
        'en' : ':couple_with_heart_man_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👨🏽‍❤️‍👨🏼
        'en' : ':couple_with_heart_man_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mann_mann_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_hombre_hombre_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__homme_homme_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_男性_男性_中間の肌色_やや薄い肌色:',
        'ko': u':연인_남자_남자_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_homem_homem_pele_morena_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_uomo_uomo_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_مرد_مرد_پوست_طلایی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_pria_pria_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_男人男人中等肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👨🏽‍❤‍👨🏼
        'en' : ':couple_with_heart_man_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F491\U0001F3FE': { # 💑🏾
        'en' : ':couple_with_heart_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__peau_mate:',
        'pt': ':casal_apaixonado_pele_morena_escura:',
        'it': ':coppia_con_cuore_carnagione_abbastanza_scura:'
    },
    u'\U0001F491\U0001F3FC': { # 💑🏼
        'en' : ':couple_with_heart_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__peau_moyennement_claire:',
        'pt': ':casal_apaixonado_pele_morena_clara:',
        'it': ':coppia_con_cuore_carnagione_abbastanza_chiara:'
    },
    u'\U0001F491\U0001F3FD': { # 💑🏽
        'en' : ':couple_with_heart_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_mittlere_hautfarbe:',
        'es': ':pareja_enamorada_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__peau_légèrement_mate:',
        'pt': ':casal_apaixonado_pele_morena:',
        'it': ':coppia_con_cuore_carnagione_olivastra:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏿‍❤️‍🧑🏻
        'en' : ':couple_with_heart_person_person_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_foncée_et_peau_claire:',
        'ja': u':カップルとハート_大人_大人_濃い肌色_薄い肌色:',
        'ko': u':연인_사람_사람_검은색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':情侣_成人成人较深肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏿‍❤‍🧑🏻
        'en' : ':couple_with_heart_person_person_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏿‍❤️‍🧑🏾
        'en' : ':couple_with_heart_person_person_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_foncée_et_peau_mate:',
        'ja': u':カップルとハート_大人_大人_濃い肌色_やや濃い肌色:',
        'ko': u':연인_사람_사람_검은색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_escura_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':情侣_成人成人较深肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏿‍❤‍🧑🏾
        'en' : ':couple_with_heart_person_person_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏿‍❤️‍🧑🏼
        'en' : ':couple_with_heart_person_person_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_大人_大人_濃い肌色_やや薄い肌色:',
        'ko': u':연인_사람_사람_검은색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':情侣_成人成人较深肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏿‍❤‍🧑🏼
        'en' : ':couple_with_heart_person_person_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏿‍❤️‍🧑🏽
        'en' : ':couple_with_heart_person_person_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_大人_大人_濃い肌色_中間の肌色:',
        'ko': u':연인_사람_사람_검은색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':情侣_成人成人较深肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏿‍❤‍🧑🏽
        'en' : ':couple_with_heart_person_person_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏻‍❤️‍🧑🏿
        'en' : ':couple_with_heart_person_person_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_claire_et_peau_foncée:',
        'ja': u':カップルとハート_大人_大人_薄い肌色_濃い肌色:',
        'ko': u':연인_사람_사람_하얀_피부_검은색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':情侣_成人成人较浅肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏻‍❤‍🧑🏿
        'en' : ':couple_with_heart_person_person_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏻‍❤️‍🧑🏾
        'en' : ':couple_with_heart_person_person_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_claire_et_peau_mate:',
        'ja': u':カップルとハート_大人_大人_薄い肌色_やや濃い肌色:',
        'ko': u':연인_사람_사람_하얀_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_سفید_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':情侣_成人成人较浅肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏻‍❤‍🧑🏾
        'en' : ':couple_with_heart_person_person_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏻‍❤️‍🧑🏼
        'en' : ':couple_with_heart_person_person_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_claire_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_大人_大人_薄い肌色_やや薄い肌色:',
        'ko': u':연인_사람_사람_하얀_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_clara_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_سفید_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':情侣_成人成人较浅肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏻‍❤‍🧑🏼
        'en' : ':couple_with_heart_person_person_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏻‍❤️‍🧑🏽
        'en' : ':couple_with_heart_person_person_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_大人_大人_薄い肌色_中間の肌色:',
        'ko': u':연인_사람_사람_하얀_피부_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_سفید_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':情侣_成人成人较浅肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏻‍❤‍🧑🏽
        'en' : ':couple_with_heart_person_person_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏾‍❤️‍🧑🏿
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_mate_et_peau_foncée:',
        'ja': u':カップルとハート_大人_大人_やや濃い肌色_濃い肌色:',
        'ko': u':연인_사람_사람_진한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_escura_e_pele_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':情侣_成人成人中等深肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏾‍❤‍🧑🏿
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏾‍❤️‍🧑🏻
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_mate_et_peau_claire:',
        'ja': u':カップルとハート_大人_大人_やや濃い肌色_薄い肌色:',
        'ko': u':연인_사람_사람_진한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':情侣_成人成人中等深肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏾‍❤‍🧑🏻
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏾‍❤️‍🧑🏼
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_大人_大人_やや濃い肌色_やや薄い肌色:',
        'ko': u':연인_사람_사람_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_成人成人中等深肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏾‍❤‍🧑🏼
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏾‍❤️‍🧑🏽
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_mate_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_大人_大人_やや濃い肌色_中間の肌色:',
        'ko': u':연인_사람_사람_진한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':情侣_成人成人中等深肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏾‍❤‍🧑🏽
        'en' : ':couple_with_heart_person_person_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏼‍❤️‍🧑🏿
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':カップルとハート_大人_大人_やや薄い肌色_濃い肌色:',
        'ko': u':연인_사람_사람_연한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':情侣_成人成人中等浅肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏼‍❤‍🧑🏿
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏼‍❤️‍🧑🏻
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_moyennement_claire_et_peau_claire:',
        'ja': u':カップルとハート_大人_大人_やや薄い肌色_薄い肌色:',
        'ko': u':연인_사람_사람_연한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_clara_e_pele_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_روشن_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':情侣_成人成人中等浅肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏼‍❤‍🧑🏻
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏼‍❤️‍🧑🏾
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_moyennement_claire_et_peau_mate:',
        'ja': u':カップルとハート_大人_大人_やや薄い肌色_やや濃い肌色:',
        'ko': u':연인_사람_사람_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_روشن_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_成人成人中等浅肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏼‍❤‍🧑🏾
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏼‍❤️‍🧑🏽
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_大人_大人_やや薄い肌色_中間の肌色:',
        'ko': u':연인_사람_사람_연한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_روشن_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':情侣_成人成人中等浅肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏼‍❤‍🧑🏽
        'en' : ':couple_with_heart_person_person_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏽‍❤️‍🧑🏿
        'en' : ':couple_with_heart_person_person_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':カップルとハート_大人_大人_中間の肌色_濃い肌色:',
        'ko': u':연인_사람_사람_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_e_pele_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':情侣_成人成人中等肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏽‍❤‍🧑🏿
        'en' : ':couple_with_heart_person_person_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏽‍❤️‍🧑🏻
        'en' : ':couple_with_heart_person_person_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_légèrement_mate_et_peau_claire:',
        'ja': u':カップルとハート_大人_大人_中間の肌色_薄い肌色:',
        'ko': u':연인_사람_사람_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_e_pele_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':情侣_成人成人中等肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏽‍❤‍🧑🏻
        'en' : ':couple_with_heart_person_person_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏽‍❤️‍🧑🏾
        'en' : ':couple_with_heart_person_person_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_légèrement_mate_et_peau_mate:',
        'ja': u':カップルとハート_大人_大人_中間の肌色_やや濃い肌色:',
        'ko': u':연인_사람_사람_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_成人成人中等肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏽‍❤‍🧑🏾
        'en' : ':couple_with_heart_person_person_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏽‍❤️‍🧑🏼
        'en' : ':couple_with_heart_person_person_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_erwachsener_erwachsener_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__adulte_adulte_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_大人_大人_中間の肌色_やや薄い肌色:',
        'ko': u':연인_사람_사람_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_pessoa_pessoa_pele_morena_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_persona_persona_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_dewasa_dewasa_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_成人成人中等肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏽‍❤‍🧑🏼
        'en' : ':couple_with_heart_person_person_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468': { # 👩‍❤️‍👨
        'en' : ':couple_with_heart_woman_man:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':liebespaar_frau,_mann:',
        'es': ':pareja_enamorada_mujer_y_hombre:',
        'fr': u':couple_avec_cœur_femme_et_homme:',
        'ja': u':カップルとハート_女性_男性:',
        'ko': u':연인_여자_남자:',
        'pt': ':casal_apaixonado_mulher_e_homem:',
        'it': ':coppia_con_cuore_donna_e_uomo:',
        'fa': u':زوج_عاشق_زن_مرد:',
        'id': ':pasangan_dengan_hati_wanita_pria:',
        'zh': u':情侣_女人男人:'
    },
    u'\U0001F469\U0000200D\U00002764\U0000200D\U0001F468': { # 👩‍❤‍👨
        'en' : ':couple_with_heart_woman_man:',
        'status' : minimally_qualified,
        'E' : 2
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👩🏿‍❤️‍👨🏿
        'en' : ':couple_with_heart_woman_man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_und_dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_homme_et_peau_foncée:',
        'ja': u':カップルとハート_女性_男性_濃い肌色:',
        'ko': u':연인_여자_남자_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_uomo_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_مرد_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap:',
        'zh': u':情侣_女人男人较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👩🏿‍❤‍👨🏿
        'en' : ':couple_with_heart_woman_man_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👩🏿‍❤️‍👨🏻
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_foncée_et_peau_claire:',
        'ja': u':カップルとハート_女性_男性_濃い肌色_薄い肌色:',
        'ko': u':연인_여자_남자_검은색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':情侣_女人男人较深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👩🏿‍❤‍👨🏻
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👩🏿‍❤️‍👨🏾
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_foncée_et_peau_mate:',
        'ja': u':カップルとハート_女性_男性_濃い肌色_やや濃い肌色:',
        'ko': u':연인_여자_남자_검은색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_escura_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人男人较深肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👩🏿‍❤‍👨🏾
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👩🏿‍❤️‍👨🏼
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_男性_濃い肌色_やや薄い肌色:',
        'ko': u':연인_여자_남자_검은색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人男人较深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👩🏿‍❤‍👨🏼
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👩🏿‍❤️‍👨🏽
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_男性_濃い肌色_中間の肌色:',
        'ko': u':연인_여자_남자_검은색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':情侣_女人男人较深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👩🏿‍❤‍👨🏽
        'en' : ':couple_with_heart_woman_man_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👩🏻‍❤️‍👨🏻
        'en' : ':couple_with_heart_woman_man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_und_helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_homme_et_peau_claire:',
        'ja': u':カップルとハート_女性_男性_薄い肌色:',
        'ko': u':연인_여자_남자_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_homem_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_uomo_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah:',
        'zh': u':情侣_女人男人较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👩🏻‍❤‍👨🏻
        'en' : ':couple_with_heart_woman_man_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👩🏻‍❤️‍👨🏿
        'en' : ':couple_with_heart_woman_man_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_claire_et_peau_foncée:',
        'ja': u':カップルとハート_女性_男性_薄い肌色_濃い肌色:',
        'ko': u':연인_여자_남자_하얀_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':情侣_女人男人较浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👩🏻‍❤‍👨🏿
        'en' : ':couple_with_heart_woman_man_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👩🏻‍❤️‍👨🏾
        'en' : ':couple_with_heart_woman_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_claire_et_peau_mate:',
        'ja': u':カップルとハート_女性_男性_薄い肌色_やや濃い肌色:',
        'ko': u':연인_여자_남자_하얀_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_سفید_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人男人较浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👩🏻‍❤‍👨🏾
        'en' : ':couple_with_heart_woman_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👩🏻‍❤️‍👨🏼
        'en' : ':couple_with_heart_woman_man_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_claire_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_男性_薄い肌色_やや薄い肌色:',
        'ko': u':연인_여자_남자_하얀_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_clara_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_سفید_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人男人较浅肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👩🏻‍❤‍👨🏼
        'en' : ':couple_with_heart_woman_man_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👩🏻‍❤️‍👨🏽
        'en' : ':couple_with_heart_woman_man_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_男性_薄い肌色_中間の肌色:',
        'ko': u':연인_여자_남자_하얀_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_سفید_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':情侣_女人男人较浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👩🏻‍❤‍👨🏽
        'en' : ':couple_with_heart_woman_man_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👩🏾‍❤️‍👨🏾
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_und_mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_et_peau_mate:',
        'ja': u':カップルとハート_女性_男性_やや濃い肌色:',
        'ko': u':연인_여자_남자_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_uomo_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_مرد_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人男人中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👩🏾‍❤‍👨🏾
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👩🏾‍❤️‍👨🏿
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_mate_et_peau_foncée:',
        'ja': u':カップルとハート_女性_男性_やや濃い肌色_濃い肌色:',
        'ko': u':연인_여자_남자_진한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_escura_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':情侣_女人男人中等深肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👩🏾‍❤‍👨🏿
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👩🏾‍❤️‍👨🏻
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_mate_et_peau_claire:',
        'ja': u':カップルとハート_女性_男性_やや濃い肌色_薄い肌色:',
        'ko': u':연인_여자_남자_진한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_گندمی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':情侣_女人男人中等深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👩🏾‍❤‍👨🏻
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👩🏾‍❤️‍👨🏼
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_男性_やや濃い肌色_やや薄い肌色:',
        'ko': u':연인_여자_남자_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_گندمی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人男人中等深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👩🏾‍❤‍👨🏼
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👩🏾‍❤️‍👨🏽
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_mate_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_男性_やや濃い肌色_中間の肌色:',
        'ko': u':연인_여자_남자_진한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_گندمی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':情侣_女人男人中等深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👩🏾‍❤‍👨🏽
        'en' : ':couple_with_heart_woman_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👩🏼‍❤️‍👨🏼
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_und_mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_男性_やや薄い肌色:',
        'ko': u':연인_여자_남자_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_uomo_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人男人中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👩🏼‍❤‍👨🏼
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👩🏼‍❤️‍👨🏿
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':カップルとハート_女性_男性_やや薄い肌色_濃い肌色:',
        'ko': u':연인_여자_남자_연한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':情侣_女人男人中等浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👩🏼‍❤‍👨🏿
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👩🏼‍❤️‍👨🏻
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_moyennement_claire_et_peau_claire:',
        'ja': u':カップルとハート_女性_男性_やや薄い肌色_薄い肌色:',
        'ko': u':연인_여자_남자_연한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_clara_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_روشن_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':情侣_女人男人中等浅肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👩🏼‍❤‍👨🏻
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👩🏼‍❤️‍👨🏾
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_moyennement_claire_et_peau_mate:',
        'ja': u':カップルとハート_女性_男性_やや薄い肌色_やや濃い肌色:',
        'ko': u':연인_여자_남자_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_روشن_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人男人中等浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👩🏼‍❤‍👨🏾
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👩🏼‍❤️‍👨🏽
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_男性_やや薄い肌色_中間の肌色:',
        'ko': u':연인_여자_남자_연한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_روشن_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':情侣_女人男人中等浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👩🏼‍❤‍👨🏽
        'en' : ':couple_with_heart_woman_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FD': { # 👩🏽‍❤️‍👨🏽
        'en' : ':couple_with_heart_woman_man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_und_mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_homme_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_男性_中間の肌色:',
        'ko': u':연인_여자_남자_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_uomo_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_مرد_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_sedang:',
        'zh': u':情侣_女人男人中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FD': { # 👩🏽‍❤‍👨🏽
        'en' : ':couple_with_heart_woman_man_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FF': { # 👩🏽‍❤️‍👨🏿
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':カップルとハート_女性_男性_中間の肌色_濃い肌色:',
        'ko': u':연인_여자_남자_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':情侣_女人男人中等肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FF': { # 👩🏽‍❤‍👨🏿
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FB': { # 👩🏽‍❤️‍👨🏻
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_homme_peau_légèrement_mate_et_peau_claire:',
        'ja': u':カップルとハート_女性_男性_中間の肌色_薄い肌色:',
        'ko': u':연인_여자_남자_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_طلایی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':情侣_女人男人中等肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FB': { # 👩🏽‍❤‍👨🏻
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FE': { # 👩🏽‍❤️‍👨🏾
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_légèrement_mate_et_peau_mate:',
        'ja': u':カップルとハート_女性_男性_中間の肌色_やや濃い肌色:',
        'ko': u':연인_여자_남자_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_طلایی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人男人中等肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FE': { # 👩🏽‍❤‍👨🏾
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F468\U0001F3FC': { # 👩🏽‍❤️‍👨🏼
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_mann_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_hombre_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_homme_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_男性_中間の肌色_やや薄い肌色:',
        'ko': u':연인_여자_남자_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_homem_pele_morena_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_uomo_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_مرد_پوست_طلایی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_pria_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人男人中等肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F468\U0001F3FC': { # 👩🏽‍❤‍👨🏼
        'en' : ':couple_with_heart_woman_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469': { # 👩‍❤️‍👩
        'en' : ':couple_with_heart_woman_woman:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':liebespaar_frau,_frau:',
        'es': ':pareja_enamorada_mujer_y_mujer:',
        'fr': u':couple_avec_cœur_femme_et_femme:',
        'ja': u':カップルとハート_女性_女性:',
        'ko': u':연인_여자_여자:',
        'pt': ':casal_apaixonado_mulher_e_mulher:',
        'it': ':coppia_con_cuore_donna_e_donna:',
        'fa': u':زوج_عاشق_زن_زن:',
        'id': ':pasangan_dengan_hati_wanita_wanita:',
        'zh': u':情侣_女人女人:'
    },
    u'\U0001F469\U0000200D\U00002764\U0000200D\U0001F469': { # 👩‍❤‍👩
        'en' : ':couple_with_heart_woman_woman:',
        'status' : minimally_qualified,
        'E' : 2
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FF': { # 👩🏿‍❤️‍👩🏿
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_und_dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_femme_et_peau_foncée:',
        'ja': u':カップルとハート_女性_女性_濃い肌色:',
        'ko': u':연인_여자_여자_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_donna_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_زن_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap:',
        'zh': u':情侣_女人女人较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FF': { # 👩🏿‍❤‍👩🏿
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FB': { # 👩🏿‍❤️‍👩🏻
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_foncée_et_peau_claire:',
        'ja': u':カップルとハート_女性_女性_濃い肌色_薄い肌色:',
        'ko': u':연인_여자_여자_검은색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':情侣_女人女人较深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FB': { # 👩🏿‍❤‍👩🏻
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FE': { # 👩🏿‍❤️‍👩🏾
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_foncée_et_peau_mate:',
        'ja': u':カップルとハート_女性_女性_濃い肌色_やや濃い肌色:',
        'ko': u':연인_여자_여자_검은색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_escura_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人女人较深肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FE': { # 👩🏿‍❤‍👩🏾
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FC': { # 👩🏿‍❤️‍👩🏼
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_女性_濃い肌色_やや薄い肌色:',
        'ko': u':연인_여자_여자_검은색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人女人较深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FC': { # 👩🏿‍❤‍👩🏼
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FD': { # 👩🏿‍❤️‍👩🏽
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_女性_濃い肌色_中間の肌色:',
        'ko': u':연인_여자_여자_검은색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_زن_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':情侣_女人女人较深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FD': { # 👩🏿‍❤‍👩🏽
        'en' : ':couple_with_heart_woman_woman_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FB': { # 👩🏻‍❤️‍👩🏻
        'en' : ':couple_with_heart_woman_woman_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_und_helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_femme_et_peau_claire:',
        'ja': u':カップルとハート_女性_女性_薄い肌色:',
        'ko': u':연인_여자_여자_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_donna_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_زن_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah:',
        'zh': u':情侣_女人女人较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FB': { # 👩🏻‍❤‍👩🏻
        'en' : ':couple_with_heart_woman_woman_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FF': { # 👩🏻‍❤️‍👩🏿
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_claire_et_peau_foncée:',
        'ja': u':カップルとハート_女性_女性_薄い肌色_濃い肌色:',
        'ko': u':연인_여자_여자_하얀_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':情侣_女人女人较浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FF': { # 👩🏻‍❤‍👩🏿
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FE': { # 👩🏻‍❤️‍👩🏾
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_claire_et_peau_mate:',
        'ja': u':カップルとハート_女性_女性_薄い肌色_やや濃い肌色:',
        'ko': u':연인_여자_여자_하얀_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_سفید_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人女人较浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FE': { # 👩🏻‍❤‍👩🏾
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FC': { # 👩🏻‍❤️‍👩🏼
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_claire_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_女性_薄い肌色_やや薄い肌色:',
        'ko': u':연인_여자_여자_하얀_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_clara_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_سفید_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人女人较浅肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FC': { # 👩🏻‍❤‍👩🏼
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FD': { # 👩🏻‍❤️‍👩🏽
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_女性_薄い肌色_中間の肌色:',
        'ko': u':연인_여자_여자_하얀_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_زن_پوست_سفید_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':情侣_女人女人较浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FD': { # 👩🏻‍❤‍👩🏽
        'en' : ':couple_with_heart_woman_woman_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FE': { # 👩🏾‍❤️‍👩🏾
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_und_mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_et_peau_mate:',
        'ja': u':カップルとハート_女性_女性_やや濃い肌色:',
        'ko': u':연인_여자_여자_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_donna_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_زن_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人女人中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FE': { # 👩🏾‍❤‍👩🏾
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FF': { # 👩🏾‍❤️‍👩🏿
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_mate_et_peau_foncée:',
        'ja': u':カップルとハート_女性_女性_やや濃い肌色_濃い肌色:',
        'ko': u':연인_여자_여자_진한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_escura_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':情侣_女人女人中等深肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FF': { # 👩🏾‍❤‍👩🏿
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FB': { # 👩🏾‍❤️‍👩🏻
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_mate_et_peau_claire:',
        'ja': u':カップルとハート_女性_女性_やや濃い肌色_薄い肌色:',
        'ko': u':연인_여자_여자_진한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_escura_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_گندمی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':情侣_女人女人中等深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FB': { # 👩🏾‍❤‍👩🏻
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FC': { # 👩🏾‍❤️‍👩🏼
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_女性_やや濃い肌色_やや薄い肌色:',
        'ko': u':연인_여자_여자_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_escura_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_گندمی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人女人中等深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FC': { # 👩🏾‍❤‍👩🏼
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FD': { # 👩🏾‍❤️‍👩🏽
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_mate_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_女性_やや濃い肌色_中間の肌色:',
        'ko': u':연인_여자_여자_진한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_escura_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_زن_پوست_گندمی_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':情侣_女人女人中等深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FD': { # 👩🏾‍❤‍👩🏽
        'en' : ':couple_with_heart_woman_woman_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FC': { # 👩🏼‍❤️‍👩🏼
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_und_mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_女性_やや薄い肌色:',
        'ko': u':연인_여자_여자_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_donna_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_زن_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人女人中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FC': { # 👩🏼‍❤‍👩🏼
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FF': { # 👩🏼‍❤️‍👩🏿
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':カップルとハート_女性_女性_やや薄い肌色_濃い肌色:',
        'ko': u':연인_여자_여자_연한_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_clara_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':情侣_女人女人中等浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FF': { # 👩🏼‍❤‍👩🏿
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FB': { # 👩🏼‍❤️‍👩🏻
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_moyennement_claire_et_peau_claire:',
        'ja': u':カップルとハート_女性_女性_やや薄い肌色_薄い肌色:',
        'ko': u':연인_여자_여자_연한_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_clara_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_روشن_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':情侣_女人女人中等浅肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FB': { # 👩🏼‍❤‍👩🏻
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FE': { # 👩🏼‍❤️‍👩🏾
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_moyennement_claire_et_peau_mate:',
        'ja': u':カップルとハート_女性_女性_やや薄い肌色_やや濃い肌色:',
        'ko': u':연인_여자_여자_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_clara_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_روشن_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人女人中等浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FE': { # 👩🏼‍❤‍👩🏾
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FD': { # 👩🏼‍❤️‍👩🏽
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_女性_やや薄い肌色_中間の肌色:',
        'ko': u':연인_여자_여자_연한_갈색_피부_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_clara_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_زن_پوست_روشن_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':情侣_女人女人中等浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FD': { # 👩🏼‍❤‍👩🏽
        'en' : ':couple_with_heart_woman_woman_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FD': { # 👩🏽‍❤️‍👩🏽
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_und_mittlere_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_medio:',
        'fr': u':couple_avec_cœur__femme_femme_et_peau_légèrement_mate:',
        'ja': u':カップルとハート_女性_女性_中間の肌色:',
        'ko': u':연인_여자_여자_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_e_pele_morena:',
        'it': ':coppia_con_cuore_donna_donna_e_carnagione_olivastra:',
        'fa': u':زوج_عاشق_زن_زن_و_پوست_طلایی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_sedang:',
        'zh': u':情侣_女人女人中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FD': { # 👩🏽‍❤‍👩🏽
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FF': { # 👩🏽‍❤️‍👩🏿
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':カップルとハート_女性_女性_中間の肌色_濃い肌色:',
        'ko': u':연인_여자_여자_갈색_피부_검은색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_e_pele_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':情侣_女人女人中等肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FF': { # 👩🏽‍❤‍👩🏿
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FB': { # 👩🏽‍❤️‍👩🏻
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':couple_avec_cœur__femme_femme_peau_légèrement_mate_et_peau_claire:',
        'ja': u':カップルとハート_女性_女性_中間の肌色_薄い肌色:',
        'ko': u':연인_여자_여자_갈색_피부_하얀_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_e_pele_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_طلایی_و_پوست_سفید:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':情侣_女人女人中等肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FB': { # 👩🏽‍❤‍👩🏻
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FE': { # 👩🏽‍❤️‍👩🏾
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_légèrement_mate_et_peau_mate:',
        'ja': u':カップルとハート_女性_女性_中間の肌色_やや濃い肌色:',
        'ko': u':연인_여자_여자_갈색_피부_진한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_e_pele_morena_escura:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':زوج_عاشق_زن_زن_پوست_طلایی_و_پوست_گندمی:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':情侣_女人女人中等肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FE': { # 👩🏽‍❤‍👩🏾
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F469\U0001F3FC': { # 👩🏽‍❤️‍👩🏼
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':liebespaar_frau_frau_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':pareja_enamorada_mujer_mujer_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':couple_avec_cœur__femme_femme_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':カップルとハート_女性_女性_中間の肌色_やや薄い肌色:',
        'ko': u':연인_여자_여자_갈색_피부_연한_갈색_피부:',
        'pt': ':casal_apaixonado_mulher_mulher_pele_morena_e_pele_morena_clara:',
        'it': ':coppia_con_cuore_donna_donna_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':زوج_عاشق_زن_زن_پوست_طلایی_و_پوست_روشن:',
        'id': ':pasangan_dengan_hati_wanita_wanita_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':情侣_女人女人中等肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F469\U0001F3FC': { # 👩🏽‍❤‍👩🏼
        'en' : ':couple_with_heart_woman_woman_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F404': { # 🐄
        'en' : ':cow:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':cow2:'],
        'de': ':kuh:',
        'es': ':vaca:',
        'fr': ':vache:',
        'ja': u':牝牛:',
        'ko': u':젖소:',
        'pt': ':vaca:',
        'it': ':mucca:',
        'fa': u':گاو_ماده:',
        'id': ':sapi:',
        'zh': u':奶牛:'
    },
    u'\U0001F42E': { # 🐮
        'en' : ':cow_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cow:'],
        'de': ':kuhgesicht:',
        'es': ':cara_de_vaca:',
        'fr': u':tête_de_vache:',
        'ja': u':牛の顔:',
        'ko': u':소_얼굴:',
        'pt': ':rosto_de_vaca:',
        'it': ':muso_di_mucca:',
        'fa': u':صورت_گاو:',
        'id': ':wajah_sapi:',
        'zh': u':奶牛头:'
    },
    u'\U0001F920': { # 🤠
        'en' : ':cowboy_hat_face:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':gesicht_mit_cowboyhut:',
        'es': ':cara_con_sombrero_de_vaquero:',
        'fr': ':visage_avec_chapeau_de_cowboy:',
        'ja': u':カウボーイの顔:',
        'ko': u':카우보이_모자_쓴_얼굴:',
        'pt': u':rosto_com_chapéu_de_caubói:',
        'it': ':faccina_con_cappello_da_cowboy:',
        'fa': u':کلاه_کابوی:',
        'id': ':wajah_koboi:',
        'zh': u':牛仔帽脸:'
    },
    u'\U0001F980': { # 🦀
        'en' : ':crab:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':krebs:',
        'es': ':cangrejo:',
        'fr': ':crabe:',
        'ja': u':カニ:',
        'ko': u':꽃게:',
        'pt': ':caranguejo:',
        'it': ':granchio:',
        'fa': u':خرچنگ:',
        'id': ':kepiting:',
        'zh': u':蟹:'
    },
    u'\U0001F58D\U0000FE0F': { # 🖍️
        'en' : ':crayon:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':lower_left_crayon:'],
        'variant': True,
        'de': ':wachsmalstift:',
        'es': u':lápiz_de_cera:',
        'fr': ':crayon_pastel:',
        'ja': u':クレヨン:',
        'ko': u':크레용:',
        'pt': ':giz_de_cera:',
        'it': ':pastello_a_cera:',
        'fa': u':مدادشمعی:',
        'id': ':krayon:',
        'zh': u':蜡笔:'
    },
    u'\U0001F58D': { # 🖍
        'en' : ':crayon:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':lower_left_crayon:'],
        'variant': True,
        'de': ':wachsmalstift:',
        'es': u':lápiz_de_cera:',
        'fr': ':crayon_pastel:',
        'ja': u':クレヨン:',
        'ko': u':크레용:',
        'pt': ':giz_de_cera:',
        'it': ':pastello_a_cera:',
        'fa': u':مدادشمعی:',
        'id': ':krayon:',
        'zh': u':蜡笔:'
    },
    u'\U0001F4B3': { # 💳
        'en' : ':credit_card:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':kreditkarte:',
        'es': u':tarjeta_de_crédito:',
        'fr': ':carte_bancaire:',
        'ja': u':クレジットカード:',
        'ko': u':신용카드:',
        'pt': u':cartão_de_crédito:',
        'it': ':carta_di_credito:',
        'fa': u':کارت_اعتباری:',
        'id': ':kartu_kredit:',
        'zh': u':信用卡:'
    },
    u'\U0001F319': { # 🌙
        'en' : ':crescent_moon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':mondsichel:',
        'es': ':luna:',
        'fr': ':croissant_de_lune:',
        'ja': u':三日月:',
        'ko': u':초승달:',
        'pt': ':lua_crescente:',
        'it': ':spicchio_di_luna:',
        'fa': u':هلال_ماه:',
        'id': ':bulan_sabit:',
        'zh': u':弯月:'
    },
    u'\U0001F997': { # 🦗
        'en' : ':cricket:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':grille:',
        'es': ':grillo:',
        'fr': ':criquet:',
        'ja': u':バッタ:',
        'ko': u':귀뚜라미:',
        'pt': ':grilo:',
        'it': ':grillo:',
        'fa': u':جیرجیرک:',
        'id': ':jangkrik:',
        'zh': u':蟋蟀:'
    },
    u'\U0001F3CF': { # 🏏
        'en' : ':cricket_game:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':cricket_bat_and_ball:'],
        'de': ':kricket:',
        'es': u':críquet:',
        'fr': ':cricket:',
        'ja': u':クリケット:',
        'ko': u':크리켓:',
        'pt': u':críquete:',
        'it': ':cricket:',
        'fa': u':کریکت:',
        'id': ':kriket:',
        'zh': u':板球:'
    },
    u'\U0001F40A': { # 🐊
        'en' : ':crocodile:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':krokodil:',
        'es': ':cocodrilo:',
        'fr': ':crocodile:',
        'ja': u':ワニ:',
        'ko': u':악어:',
        'pt': ':crocodilo:',
        'it': ':coccodrillo:',
        'fa': u':تمساح:',
        'id': ':buaya:',
        'zh': u':鳄鱼:'
    },
    u'\U0001F950': { # 🥐
        'en' : ':croissant:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':croissant:',
        'es': u':cruasán:',
        'fr': ':croissant:',
        'ja': u':クロワッサン:',
        'ko': u':크루아상:',
        'pt': ':croissant:',
        'it': ':croissant:',
        'fa': u':کرواسان:',
        'id': ':croissant:',
        'zh': u':羊角面包:'
    },
    u'\U0000274C': { # ❌
        'en' : ':cross_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':x:'],
        'de': ':kreuzzeichen:',
        'es': ':marca_de_cruz:',
        'fr': ':croix:',
        'ja': u':バツ:',
        'ko': u':엑스_표시:',
        'pt': ':xis:',
        'it': ':croce:',
        'fa': u':ضربدر:',
        'id': ':tanda_silang:',
        'zh': u':叉号:'
    },
    u'\U0000274E': { # ❎
        'en' : ':cross_mark_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':negative_squared_cross_mark:'],
        'de': u':angekreuztes_kästchen:',
        'es': u':botón_con_marca_de_cruz:',
        'fr': ':bouton_croix:',
        'ja': u':白抜きのバツ:',
        'ko': u':초록_상자_안_엑스표:',
        'pt': u':botão_de_xis:',
        'it': ':croce_con_quadrato:',
        'fa': u':دکمه_ایکس:',
        'id': ':tombol_tanda_silang:',
        'zh': u':叉号按钮:'
    },
    u'\U0001F91E': { # 🤞
        'en' : ':crossed_fingers:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hand_mit_gekreuzten_fingern:',
        'es': ':dedos_cruzados:',
        'fr': u':doigts_croisés:',
        'ja': u':指をクロス:',
        'ko': u':검지와_중지_크로스:',
        'pt': ':dedos_cruzados:',
        'it': ':dita_incrociate:',
        'fa': u':انگشتان_گره_خورده:',
        'id': ':jari_menyilang:',
        'zh': u':交叉的手指:'
    },
    u'\U0001F91E\U0001F3FF': { # 🤞🏿
        'en' : ':crossed_fingers_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hand_mit_gekreuzten_fingern_dunkle_hautfarbe:',
        'es': ':dedos_cruzados_tono_de_piel_oscuro:',
        'fr': u':doigts_croisés_peau_foncée:',
        'ja': u':指をクロス_濃い肌色:',
        'ko': u':검지와_중지_크로스_검은색_피부:',
        'pt': ':dedos_cruzados_pele_escura:',
        'it': ':dita_incrociate_carnagione_scura:',
        'fa': u':انگشتان_گره_خورده_پوست_آبنوسی:',
        'id': ':jari_menyilang_warna_kulit_gelap:',
        'zh': u':交叉的手指_较深肤色:'
    },
    u'\U0001F91E\U0001F3FB': { # 🤞🏻
        'en' : ':crossed_fingers_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hand_mit_gekreuzten_fingern_helle_hautfarbe:',
        'es': ':dedos_cruzados_tono_de_piel_claro:',
        'fr': u':doigts_croisés_peau_claire:',
        'ja': u':指をクロス_薄い肌色:',
        'ko': u':검지와_중지_크로스_하얀_피부:',
        'pt': ':dedos_cruzados_pele_clara:',
        'it': ':dita_incrociate_carnagione_chiara:',
        'fa': u':انگشتان_گره_خورده_پوست_سفید:',
        'id': ':jari_menyilang_warna_kulit_cerah:',
        'zh': u':交叉的手指_较浅肤色:'
    },
    u'\U0001F91E\U0001F3FE': { # 🤞🏾
        'en' : ':crossed_fingers_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hand_mit_gekreuzten_fingern_mitteldunkle_hautfarbe:',
        'es': ':dedos_cruzados_tono_de_piel_oscuro_medio:',
        'fr': u':doigts_croisés_peau_mate:',
        'ja': u':指をクロス_やや濃い肌色:',
        'ko': u':검지와_중지_크로스_진한_갈색_피부:',
        'pt': ':dedos_cruzados_pele_morena_escura:',
        'it': ':dita_incrociate_carnagione_abbastanza_scura:',
        'fa': u':انگشتان_گره_خورده_پوست_گندمی:',
        'id': ':jari_menyilang_warna_kulit_gelap-sedang:',
        'zh': u':交叉的手指_中等深肤色:'
    },
    u'\U0001F91E\U0001F3FC': { # 🤞🏼
        'en' : ':crossed_fingers_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hand_mit_gekreuzten_fingern_mittelhelle_hautfarbe:',
        'es': ':dedos_cruzados_tono_de_piel_claro_medio:',
        'fr': u':doigts_croisés_peau_moyennement_claire:',
        'ja': u':指をクロス_やや薄い肌色:',
        'ko': u':검지와_중지_크로스_연한_갈색_피부:',
        'pt': ':dedos_cruzados_pele_morena_clara:',
        'it': ':dita_incrociate_carnagione_abbastanza_chiara:',
        'fa': u':انگشتان_گره_خورده_پوست_روشن:',
        'id': ':jari_menyilang_warna_kulit_cerah-sedang:',
        'zh': u':交叉的手指_中等浅肤色:'
    },
    u'\U0001F91E\U0001F3FD': { # 🤞🏽
        'en' : ':crossed_fingers_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hand_mit_gekreuzten_fingern_mittlere_hautfarbe:',
        'es': ':dedos_cruzados_tono_de_piel_medio:',
        'fr': u':doigts_croisés_peau_légèrement_mate:',
        'ja': u':指をクロス_中間の肌色:',
        'ko': u':검지와_중지_크로스_갈색_피부:',
        'pt': ':dedos_cruzados_pele_morena:',
        'it': ':dita_incrociate_carnagione_olivastra:',
        'fa': u':انگشتان_گره_خورده_پوست_طلایی:',
        'id': ':jari_menyilang_warna_kulit_sedang:',
        'zh': u':交叉的手指_中等肤色:'
    },
    u'\U0001F38C': { # 🎌
        'en' : ':crossed_flags:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':überkreuzte_flaggen:',
        'es': ':banderas_cruzadas:',
        'fr': u':drapeaux_croisés:',
        'ja': u':祝日の旗:',
        'ko': u':엇갈린_일본_국기:',
        'pt': ':bandeiras_cruzadas:',
        'it': ':bandiere_del_giappone_incrociate:',
        'fa': u':پرچم_های_ضرب_دری:',
        'id': ':bendera_menyilang:',
        'zh': u':交叉旗:'
    },
    u'\U00002694\U0000FE0F': { # ⚔️
        'en' : ':crossed_swords:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':gekreuzte_schwerter:',
        'es': ':espadas_cruzadas:',
        'fr': u':épées_croisées:',
        'ja': u':クロスした剣:',
        'ko': u':쌍검:',
        'pt': ':espadas_cruzadas:',
        'it': ':spade_incrociate:',
        'fa': u':شمشیرهای_ضرب_دری:',
        'id': ':pedang_bersilang:',
        'zh': u':交叉放置的剑:'
    },
    u'\U00002694': { # ⚔
        'en' : ':crossed_swords:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':gekreuzte_schwerter:',
        'es': ':espadas_cruzadas:',
        'fr': u':épées_croisées:',
        'ja': u':クロスした剣:',
        'ko': u':쌍검:',
        'pt': ':espadas_cruzadas:',
        'it': ':spade_incrociate:',
        'fa': u':شمشیرهای_ضرب_دری:',
        'id': ':pedang_bersilang:',
        'zh': u':交叉放置的剑:'
    },
    u'\U0001F451': { # 👑
        'en' : ':crown:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':krone:',
        'es': ':corona:',
        'fr': ':couronne:',
        'ja': u':王冠:',
        'ko': u':왕관:',
        'pt': ':coroa:',
        'it': ':corona:',
        'fa': u':تاج:',
        'id': ':mahkota:',
        'zh': u':皇冠:'
    },
    u'\U0001FA7C': { # 🩼
        'en' : ':crutch:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':krücke:',
        'es': ':muleta:',
        'fr': u':béquille:',
        'ja': u':松葉杖:',
        'ko': u':목발:',
        'pt': ':muleta:',
        'it': ':stampella:',
        'fa': u':عصای_زیر_بغل:',
        'id': ':kruk:',
        'zh': u':拐杖:'
    },
    u'\U0001F63F': { # 😿
        'en' : ':crying_cat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':crying_cat_face:'],
        'de': ':weinende_katze:',
        'es': ':gato_llorando:',
        'fr': ':chat_qui_pleure:',
        'ja': u':泣いている猫:',
        'ko': u':울고_있는_고양이_얼굴:',
        'pt': ':rosto_de_gato_chorando:',
        'it': ':gatto_che_piange:',
        'fa': u':گربهٔ_گریان:',
        'id': ':wajah_kucing_menangis:',
        'zh': u':哭泣的猫:'
    },
    u'\U0001F622': { # 😢
        'en' : ':crying_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cry:'],
        'de': ':weinendes_gesicht:',
        'es': ':cara_llorando:',
        'fr': ':visage_qui_pleure:',
        'ja': u':泣き顔:',
        'ko': u':우는_얼굴:',
        'pt': ':rosto_chorando:',
        'it': ':faccina_che_piange:',
        'fa': u':گریان:',
        'id': ':wajah_menangis:',
        'zh': u':哭:'
    },
    u'\U0001F52E': { # 🔮
        'en' : ':crystal_ball:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kristallkugel:',
        'es': ':bola_de_cristal:',
        'fr': ':boule_de_cristal:',
        'ja': u':水晶玉:',
        'ko': u':수정_구슬:',
        'pt': ':bola_de_cristal:',
        'it': ':sfera_di_cristallo:',
        'fa': u':گوی:',
        'id': ':bola_kristal:',
        'zh': u':水晶球:'
    },
    u'\U0001F952': { # 🥒
        'en' : ':cucumber:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':gurke:',
        'es': ':pepino:',
        'fr': ':concombre:',
        'ja': u':キュウリ:',
        'ko': u':오이:',
        'pt': ':pepino:',
        'it': ':cetriolo:',
        'fa': u':خیار:',
        'id': ':ketimun:',
        'zh': u':黄瓜:'
    },
    u'\U0001F964': { # 🥤
        'en' : ':cup_with_straw:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':becher_mit_strohhalm:',
        'es': ':vaso_con_pajita:',
        'fr': ':gobelet_avec_paille:',
        'ja': u':ストローカップ:',
        'ko': u':빨대와_컵:',
        'pt': ':copo_com_canudo:',
        'it': ':bicchiere_con_cannuccia:',
        'fa': u':فنجان_با_نی:',
        'id': ':cangkir_dengan_sedotan:',
        'zh': u':带吸管杯:'
    },
    u'\U0001F9C1': { # 🧁
        'en' : ':cupcake:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':cupcake:',
        'es': ':magdalena:',
        'fr': ':cupcake:',
        'ja': u':カップケーキ:',
        'ko': u':컵케이크:',
        'pt': ':cupcake:',
        'it': ':cupcake:',
        'fa': u':کیک_فنجانی:',
        'id': ':kue_mangkuk:',
        'zh': u':纸杯蛋糕:'
    },
    u'\U0001F94C': { # 🥌
        'en' : ':curling_stone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':curlingstein:',
        'es': ':piedra_de_curling:',
        'fr': ':pierre_de_curling:',
        'ja': u':カーリング:',
        'ko': u':컬링_스톤:',
        'pt': ':pedra_de_curling:',
        'it': ':stone_da_curling:',
        'fa': u':سنگ_کرلینگ:',
        'id': ':batu_curling:',
        'zh': u':冰壶:'
    },
    u'\U0001F9B1': { # 🦱
        'en' : ':curly_hair:',
        'status' : component,
        'E' : 11,
        'de': ':lockiges_haar:',
        'es': ':pelo_rizado:',
        'fr': u':cheveux_bouclés:',
        'ja': u':巻き毛:',
        'ko': u':곱슬머리:',
        'pt': ':cabelo_cacheado:',
        'it': ':capelli_ricci:',
        'fa': u':موفرفری:',
        'id': ':rambut_keriting:',
        'zh': u':卷发:'
    },
    u'\U000027B0': { # ➰
        'en' : ':curly_loop:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schleife:',
        'es': ':bucle:',
        'fr': ':boucle:',
        'ja': u':ループ:',
        'ko': u':고리:',
        'pt': u':laço_encaracolado:',
        'it': ':occhiello:',
        'fa': u':حلقه_مجعد:',
        'id': ':untaian_bergelombang:',
        'zh': u':卷曲环:'
    },
    u'\U0001F4B1': { # 💱
        'en' : ':currency_exchange:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':geldwechsel:',
        'es': ':cambio_de_divisas:',
        'fr': ':conversion_de_devise:',
        'ja': u':外貨両替:',
        'ko': u':환전:',
        'pt': u':câmbio_de_moeda:',
        'it': ':cambio_valuta:',
        'fa': u':تبدیل_ارز:',
        'id': ':kurs:',
        'zh': u':货币兑换:'
    },
    u'\U0001F35B': { # 🍛
        'en' : ':curry_rice:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':curry:'],
        'de': ':reis_mit_curry:',
        'es': ':arroz_con_curry:',
        'fr': ':riz_au_curry:',
        'ja': u':カレーライス:',
        'ko': u':카레라이스:',
        'pt': ':arroz_com_curry:',
        'it': ':riso_al_curry:',
        'fa': u':برنج_با_کاری:',
        'id': ':nasi_kari:',
        'zh': u':咖喱饭:'
    },
    u'\U0001F36E': { # 🍮
        'en' : ':custard:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':pudding:',
        'es': ':flan:',
        'fr': u':crème_renversée:',
        'ja': u':プリン:',
        'ko': u':커스타드_푸딩:',
        'pt': ':pudim:',
        'it': ':budino:',
        'fa': u':کاستارد:',
        'id': ':puding_susu:',
        'zh': u':奶黄:'
    },
    u'\U0001F6C3': { # 🛃
        'en' : ':customs:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':zollkontrolle:',
        'es': ':aduana:',
        'fr': ':douane:',
        'ja': u':税関:',
        'ko': u':세관:',
        'pt': u':alfândega:',
        'it': ':simbolo_della_dogana:',
        'fa': u':گمرک:',
        'id': ':bea_cukai:',
        'zh': u':海关:'
    },
    u'\U0001F969': { # 🥩
        'en' : ':cut_of_meat:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':fleischstück:',
        'es': ':corte_de_carne:',
        'fr': ':morceau_de_viande:',
        'ja': u':ステーキ肉:',
        'ko': u':고깃덩이:',
        'pt': ':corte_de_carne:',
        'it': ':taglio_di_carne:',
        'fa': u':برش_گوشت:',
        'id': ':potongan_daging:',
        'zh': u':肉块:'
    },
    u'\U0001F300': { # 🌀
        'en' : ':cyclone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wirbel:',
        'es': u':ciclón:',
        'fr': ':cyclone:',
        'ja': u':渦巻き:',
        'ko': u':태풍:',
        'pt': ':ciclone:',
        'it': ':ciclone:',
        'fa': u':چرخند:',
        'id': ':topan:',
        'zh': u':台风:'
    },
    u'\U0001F5E1\U0000FE0F': { # 🗡️
        'en' : ':dagger:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':dagger_knife:'],
        'variant': True,
        'de': ':dolch:',
        'es': u':puñal:',
        'fr': ':dague:',
        'ja': u':短刀:',
        'ko': u':단검:',
        'pt': ':adaga:',
        'it': ':pugnale:',
        'fa': u':خنجر:',
        'id': ':belati:',
        'zh': u':匕首:'
    },
    u'\U0001F5E1': { # 🗡
        'en' : ':dagger:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':dagger_knife:'],
        'variant': True,
        'de': ':dolch:',
        'es': u':puñal:',
        'fr': ':dague:',
        'ja': u':短刀:',
        'ko': u':단검:',
        'pt': ':adaga:',
        'it': ':pugnale:',
        'fa': u':خنجر:',
        'id': ':belati:',
        'zh': u':匕首:'
    },
    u'\U0001F361': { # 🍡
        'en' : ':dango:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':dango:',
        'es': ':dango:',
        'fr': ':brochette_de_bonbons:',
        'ja': u':だんご:',
        'ko': u':떡꼬치:',
        'pt': ':dango:',
        'it': ':dango:',
        'fa': u':دانگو:',
        'id': ':dango:',
        'zh': u':团子:'
    },
    u'\U0001F3FF': { # 🏿
        'en' : ':dark_skin_tone:',
        'status' : component,
        'E' : 1,
        'alias' : [':emoji_modifier_fitzpatrick_type__6:'],
        'de': ':dunkle_hautfarbe:',
        'es': ':tono_de_piel_oscuro:',
        'fr': u':peau_foncée:',
        'ja': u':濃い肌色:',
        'ko': u':검은색_피부:',
        'pt': ':pele_escura:',
        'it': ':carnagione_scura:',
        'fa': u':پوست_آبنوسی:',
        'id': ':warna_kulit_gelap:',
        'zh': u':较深肤色:'
    },
    u'\U0001F4A8': { # 💨
        'en' : ':dashing_away:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dash:'],
        'de': ':staubwolke:',
        'es': ':salir_corriendo:',
        'fr': u':décamper:',
        'ja': u':ダッシュ:',
        'ko': u':달려나감:',
        'pt': ':rapidez:',
        'it': ':nuvola_di_polvere:',
        'fa': u':به_سرعت_باد:',
        'id': ':berlari:',
        'zh': u':尾气:'
    },
    u'\U0001F9CF\U0000200D\U00002642\U0000FE0F': { # 🧏‍♂️
        'en' : ':deaf_man:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörloser_mann:',
        'es': ':hombre_sordo:',
        'fr': ':homme_sourd:',
        'ja': u':耳の不自由な男性:',
        'ko': u':청각장애가_있는_남자:',
        'pt': ':homem_surdo:',
        'it': ':uomo_con_problemi_di_udito:',
        'fa': u':مرد_ناشنوا:',
        'id': ':pria_tuli:',
        'zh': u':失聪的男人:'
    },
    u'\U0001F9CF\U0000200D\U00002642': { # 🧏‍♂
        'en' : ':deaf_man:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörloser_mann:',
        'es': ':hombre_sordo:',
        'fr': ':homme_sourd:',
        'ja': u':耳の不自由な男性:',
        'ko': u':청각장애가_있는_남자:',
        'pt': ':homem_surdo:',
        'it': ':uomo_con_problemi_di_udito:',
        'fa': u':مرد_ناشنوا:',
        'id': ':pria_tuli:',
        'zh': u':失聪的男人:'
    },
    u'\U0001F9CF\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧏🏿‍♂️
        'en' : ':deaf_man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_dunkle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_oscuro:',
        'fr': u':homme_sourd_peau_foncée:',
        'ja': u':耳の不自由な男性_濃い肌色:',
        'ko': u':청각장애가_있는_남자_검은색_피부:',
        'pt': ':homem_surdo_pele_escura:',
        'it': ':uomo_con_problemi_di_udito_carnagione_scura:',
        'fa': u':مرد_ناشنوا_پوست_آبنوسی:',
        'id': ':pria_tuli_warna_kulit_gelap:',
        'zh': u':失聪的男人_较深肤色:'
    },
    u'\U0001F9CF\U0001F3FF\U0000200D\U00002642': { # 🧏🏿‍♂
        'en' : ':deaf_man_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_dunkle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_oscuro:',
        'fr': u':homme_sourd_peau_foncée:',
        'ja': u':耳の不自由な男性_濃い肌色:',
        'ko': u':청각장애가_있는_남자_검은색_피부:',
        'pt': ':homem_surdo_pele_escura:',
        'it': ':uomo_con_problemi_di_udito_carnagione_scura:',
        'fa': u':مرد_ناشنوا_پوست_آبنوسی:',
        'id': ':pria_tuli_warna_kulit_gelap:',
        'zh': u':失聪的男人_较深肤色:'
    },
    u'\U0001F9CF\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧏🏻‍♂️
        'en' : ':deaf_man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_helle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_claro:',
        'fr': ':homme_sourd_peau_claire:',
        'ja': u':耳の不自由な男性_薄い肌色:',
        'ko': u':청각장애가_있는_남자_하얀_피부:',
        'pt': ':homem_surdo_pele_clara:',
        'it': ':uomo_con_problemi_di_udito_carnagione_chiara:',
        'fa': u':مرد_ناشنوا_پوست_سفید:',
        'id': ':pria_tuli_warna_kulit_cerah:',
        'zh': u':失聪的男人_较浅肤色:'
    },
    u'\U0001F9CF\U0001F3FB\U0000200D\U00002642': { # 🧏🏻‍♂
        'en' : ':deaf_man_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_helle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_claro:',
        'fr': ':homme_sourd_peau_claire:',
        'ja': u':耳の不自由な男性_薄い肌色:',
        'ko': u':청각장애가_있는_남자_하얀_피부:',
        'pt': ':homem_surdo_pele_clara:',
        'it': ':uomo_con_problemi_di_udito_carnagione_chiara:',
        'fa': u':مرد_ناشنوا_پوست_سفید:',
        'id': ':pria_tuli_warna_kulit_cerah:',
        'zh': u':失聪的男人_较浅肤色:'
    },
    u'\U0001F9CF\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧏🏾‍♂️
        'en' : ':deaf_man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_sourd_peau_mate:',
        'ja': u':耳の不自由な男性_やや濃い肌色:',
        'ko': u':청각장애가_있는_남자_진한_갈색_피부:',
        'pt': ':homem_surdo_pele_morena_escura:',
        'it': ':uomo_con_problemi_di_udito_carnagione_abbastanza_scura:',
        'fa': u':مرد_ناشنوا_پوست_گندمی:',
        'id': ':pria_tuli_warna_kulit_gelap-sedang:',
        'zh': u':失聪的男人_中等深肤色:'
    },
    u'\U0001F9CF\U0001F3FE\U0000200D\U00002642': { # 🧏🏾‍♂
        'en' : ':deaf_man_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_sourd_peau_mate:',
        'ja': u':耳の不自由な男性_やや濃い肌色:',
        'ko': u':청각장애가_있는_남자_진한_갈색_피부:',
        'pt': ':homem_surdo_pele_morena_escura:',
        'it': ':uomo_con_problemi_di_udito_carnagione_abbastanza_scura:',
        'fa': u':مرد_ناشنوا_پوست_گندمی:',
        'id': ':pria_tuli_warna_kulit_gelap-sedang:',
        'zh': u':失聪的男人_中等深肤色:'
    },
    u'\U0001F9CF\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧏🏼‍♂️
        'en' : ':deaf_man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_claro_medio:',
        'fr': ':homme_sourd_peau_moyennement_claire:',
        'ja': u':耳の不自由な男性_やや薄い肌色:',
        'ko': u':청각장애가_있는_남자_연한_갈색_피부:',
        'pt': ':homem_surdo_pele_morena_clara:',
        'it': ':uomo_con_problemi_di_udito_carnagione_abbastanza_chiara:',
        'fa': u':مرد_ناشنوا_پوست_روشن:',
        'id': ':pria_tuli_warna_kulit_cerah-sedang:',
        'zh': u':失聪的男人_中等浅肤色:'
    },
    u'\U0001F9CF\U0001F3FC\U0000200D\U00002642': { # 🧏🏼‍♂
        'en' : ':deaf_man_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_claro_medio:',
        'fr': ':homme_sourd_peau_moyennement_claire:',
        'ja': u':耳の不自由な男性_やや薄い肌色:',
        'ko': u':청각장애가_있는_남자_연한_갈색_피부:',
        'pt': ':homem_surdo_pele_morena_clara:',
        'it': ':uomo_con_problemi_di_udito_carnagione_abbastanza_chiara:',
        'fa': u':مرد_ناشنوا_پوست_روشن:',
        'id': ':pria_tuli_warna_kulit_cerah-sedang:',
        'zh': u':失聪的男人_中等浅肤色:'
    },
    u'\U0001F9CF\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧏🏽‍♂️
        'en' : ':deaf_man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_mittlere_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_medio:',
        'fr': u':homme_sourd_peau_légèrement_mate:',
        'ja': u':耳の不自由な男性_中間の肌色:',
        'ko': u':청각장애가_있는_남자_갈색_피부:',
        'pt': ':homem_surdo_pele_morena:',
        'it': ':uomo_con_problemi_di_udito_carnagione_olivastra:',
        'fa': u':مرد_ناشنوا_پوست_طلایی:',
        'id': ':pria_tuli_warna_kulit_sedang:',
        'zh': u':失聪的男人_中等肤色:'
    },
    u'\U0001F9CF\U0001F3FD\U0000200D\U00002642': { # 🧏🏽‍♂
        'en' : ':deaf_man_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörloser_mann_mittlere_hautfarbe:',
        'es': ':hombre_sordo_tono_de_piel_medio:',
        'fr': u':homme_sourd_peau_légèrement_mate:',
        'ja': u':耳の不自由な男性_中間の肌色:',
        'ko': u':청각장애가_있는_남자_갈색_피부:',
        'pt': ':homem_surdo_pele_morena:',
        'it': ':uomo_con_problemi_di_udito_carnagione_olivastra:',
        'fa': u':مرد_ناشنوا_پوست_طلایی:',
        'id': ':pria_tuli_warna_kulit_sedang:',
        'zh': u':失聪的男人_中等肤色:'
    },
    u'\U0001F9CF': { # 🧏
        'en' : ':deaf_person:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_person:',
        'es': ':persona_sorda:',
        'fr': ':personne_sourde:',
        'ja': u':耳の不自由な人:',
        'ko': u':청각_장애가_있는_사람:',
        'pt': ':pessoa_surda:',
        'it': ':persona_con_problemi_di_udito:',
        'fa': u':آدم_ناشنوا:',
        'id': ':orang_tuli:',
        'zh': u':失聪者:'
    },
    u'\U0001F9CF\U0001F3FF': { # 🧏🏿
        'en' : ':deaf_person_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_person_dunkle_hautfarbe:',
        'es': ':persona_sorda_tono_de_piel_oscuro:',
        'fr': u':personne_sourde_peau_foncée:',
        'ja': u':耳の不自由な人_濃い肌色:',
        'ko': u':청각_장애가_있는_사람_검은색_피부:',
        'pt': ':pessoa_surda_pele_escura:',
        'it': ':persona_con_problemi_di_udito_carnagione_scura:',
        'fa': u':آدم_ناشنوا_پوست_آبنوسی:',
        'id': ':orang_tuli_warna_kulit_gelap:',
        'zh': u':失聪者_较深肤色:'
    },
    u'\U0001F9CF\U0001F3FB': { # 🧏🏻
        'en' : ':deaf_person_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_person_helle_hautfarbe:',
        'es': ':persona_sorda_tono_de_piel_claro:',
        'fr': ':personne_sourde_peau_claire:',
        'ja': u':耳の不自由な人_薄い肌色:',
        'ko': u':청각_장애가_있는_사람_하얀_피부:',
        'pt': ':pessoa_surda_pele_clara:',
        'it': ':persona_con_problemi_di_udito_carnagione_chiara:',
        'fa': u':آدم_ناشنوا_پوست_سفید:',
        'id': ':orang_tuli_warna_kulit_cerah:',
        'zh': u':失聪者_较浅肤色:'
    },
    u'\U0001F9CF\U0001F3FE': { # 🧏🏾
        'en' : ':deaf_person_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_person_mitteldunkle_hautfarbe:',
        'es': ':persona_sorda_tono_de_piel_oscuro_medio:',
        'fr': ':personne_sourde_peau_mate:',
        'ja': u':耳の不自由な人_やや濃い肌色:',
        'ko': u':청각_장애가_있는_사람_진한_갈색_피부:',
        'pt': ':pessoa_surda_pele_morena_escura:',
        'it': ':persona_con_problemi_di_udito_carnagione_abbastanza_scura:',
        'fa': u':آدم_ناشنوا_پوست_گندمی:',
        'id': ':orang_tuli_warna_kulit_gelap-sedang:',
        'zh': u':失聪者_中等深肤色:'
    },
    u'\U0001F9CF\U0001F3FC': { # 🧏🏼
        'en' : ':deaf_person_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_person_mittelhelle_hautfarbe:',
        'es': ':persona_sorda_tono_de_piel_claro_medio:',
        'fr': ':personne_sourde_peau_moyennement_claire:',
        'ja': u':耳の不自由な人_やや薄い肌色:',
        'ko': u':청각_장애가_있는_사람_연한_갈색_피부:',
        'pt': ':pessoa_surda_pele_morena_clara:',
        'it': ':persona_con_problemi_di_udito_carnagione_abbastanza_chiara:',
        'fa': u':آدم_ناشنوا_پوست_روشن:',
        'id': ':orang_tuli_warna_kulit_cerah-sedang:',
        'zh': u':失聪者_中等浅肤色:'
    },
    u'\U0001F9CF\U0001F3FD': { # 🧏🏽
        'en' : ':deaf_person_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_person_mittlere_hautfarbe:',
        'es': ':persona_sorda_tono_de_piel_medio:',
        'fr': u':personne_sourde_peau_légèrement_mate:',
        'ja': u':耳の不自由な人_中間の肌色:',
        'ko': u':청각_장애가_있는_사람_갈색_피부:',
        'pt': ':pessoa_surda_pele_morena:',
        'it': ':persona_con_problemi_di_udito_carnagione_olivastra:',
        'fa': u':آدم_ناشنوا_پوست_طلایی:',
        'id': ':orang_tuli_warna_kulit_sedang:',
        'zh': u':失聪者_中等肤色:'
    },
    u'\U0001F9CF\U0000200D\U00002640\U0000FE0F': { # 🧏‍♀️
        'en' : ':deaf_woman:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_frau:',
        'es': ':mujer_sorda:',
        'fr': ':femme_sourde:',
        'ja': u':耳の不自由な女性:',
        'ko': u':청각장애가_있는_여자:',
        'pt': ':mulher_surda:',
        'it': ':donna_con_problemi_di_udito:',
        'fa': u':زن_ناشنوا:',
        'id': ':wanita_tuli:',
        'zh': u':失聪的女人:'
    },
    u'\U0001F9CF\U0000200D\U00002640': { # 🧏‍♀
        'en' : ':deaf_woman:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörlose_frau:',
        'es': ':mujer_sorda:',
        'fr': ':femme_sourde:',
        'ja': u':耳の不自由な女性:',
        'ko': u':청각장애가_있는_여자:',
        'pt': ':mulher_surda:',
        'it': ':donna_con_problemi_di_udito:',
        'fa': u':زن_ناشنوا:',
        'id': ':wanita_tuli:',
        'zh': u':失聪的女人:'
    },
    u'\U0001F9CF\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧏🏿‍♀️
        'en' : ':deaf_woman_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_dunkle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_oscuro:',
        'fr': u':femme_sourde_peau_foncée:',
        'ja': u':耳の不自由な女性_濃い肌色:',
        'ko': u':청각장애가_있는_여자_검은색_피부:',
        'pt': ':mulher_surda_pele_escura:',
        'it': ':donna_con_problemi_di_udito_carnagione_scura:',
        'fa': u':زن_ناشنوا_پوست_آبنوسی:',
        'id': ':wanita_tuli_warna_kulit_gelap:',
        'zh': u':失聪的女人_较深肤色:'
    },
    u'\U0001F9CF\U0001F3FF\U0000200D\U00002640': { # 🧏🏿‍♀
        'en' : ':deaf_woman_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_dunkle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_oscuro:',
        'fr': u':femme_sourde_peau_foncée:',
        'ja': u':耳の不自由な女性_濃い肌色:',
        'ko': u':청각장애가_있는_여자_검은색_피부:',
        'pt': ':mulher_surda_pele_escura:',
        'it': ':donna_con_problemi_di_udito_carnagione_scura:',
        'fa': u':زن_ناشنوا_پوست_آبنوسی:',
        'id': ':wanita_tuli_warna_kulit_gelap:',
        'zh': u':失聪的女人_较深肤色:'
    },
    u'\U0001F9CF\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧏🏻‍♀️
        'en' : ':deaf_woman_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_helle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_claro:',
        'fr': ':femme_sourde_peau_claire:',
        'ja': u':耳の不自由な女性_薄い肌色:',
        'ko': u':청각장애가_있는_여자_하얀_피부:',
        'pt': ':mulher_surda_pele_clara:',
        'it': ':donna_con_problemi_di_udito_carnagione_chiara:',
        'fa': u':زن_ناشنوا_پوست_سفید:',
        'id': ':wanita_tuli_warna_kulit_cerah:',
        'zh': u':失聪的女人_较浅肤色:'
    },
    u'\U0001F9CF\U0001F3FB\U0000200D\U00002640': { # 🧏🏻‍♀
        'en' : ':deaf_woman_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_helle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_claro:',
        'fr': ':femme_sourde_peau_claire:',
        'ja': u':耳の不自由な女性_薄い肌色:',
        'ko': u':청각장애가_있는_여자_하얀_피부:',
        'pt': ':mulher_surda_pele_clara:',
        'it': ':donna_con_problemi_di_udito_carnagione_chiara:',
        'fa': u':زن_ناشنوا_پوست_سفید:',
        'id': ':wanita_tuli_warna_kulit_cerah:',
        'zh': u':失聪的女人_较浅肤色:'
    },
    u'\U0001F9CF\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧏🏾‍♀️
        'en' : ':deaf_woman_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_oscuro_medio:',
        'fr': ':femme_sourde_peau_mate:',
        'ja': u':耳の不自由な女性_やや濃い肌色:',
        'ko': u':청각장애가_있는_여자_진한_갈색_피부:',
        'pt': ':mulher_surda_pele_morena_escura:',
        'it': ':donna_con_problemi_di_udito_carnagione_abbastanza_scura:',
        'fa': u':زن_ناشنوا_پوست_گندمی:',
        'id': ':wanita_tuli_warna_kulit_gelap-sedang:',
        'zh': u':失聪的女人_中等深肤色:'
    },
    u'\U0001F9CF\U0001F3FE\U0000200D\U00002640': { # 🧏🏾‍♀
        'en' : ':deaf_woman_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_oscuro_medio:',
        'fr': ':femme_sourde_peau_mate:',
        'ja': u':耳の不自由な女性_やや濃い肌色:',
        'ko': u':청각장애가_있는_여자_진한_갈색_피부:',
        'pt': ':mulher_surda_pele_morena_escura:',
        'it': ':donna_con_problemi_di_udito_carnagione_abbastanza_scura:',
        'fa': u':زن_ناشنوا_پوست_گندمی:',
        'id': ':wanita_tuli_warna_kulit_gelap-sedang:',
        'zh': u':失聪的女人_中等深肤色:'
    },
    u'\U0001F9CF\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧏🏼‍♀️
        'en' : ':deaf_woman_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_claro_medio:',
        'fr': ':femme_sourde_peau_moyennement_claire:',
        'ja': u':耳の不自由な女性_やや薄い肌色:',
        'ko': u':청각장애가_있는_여자_연한_갈색_피부:',
        'pt': ':mulher_surda_pele_morena_clara:',
        'it': ':donna_con_problemi_di_udito_carnagione_abbastanza_chiara:',
        'fa': u':زن_ناشنوا_پوست_روشن:',
        'id': ':wanita_tuli_warna_kulit_cerah-sedang:',
        'zh': u':失聪的女人_中等浅肤色:'
    },
    u'\U0001F9CF\U0001F3FC\U0000200D\U00002640': { # 🧏🏼‍♀
        'en' : ':deaf_woman_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_claro_medio:',
        'fr': ':femme_sourde_peau_moyennement_claire:',
        'ja': u':耳の不自由な女性_やや薄い肌色:',
        'ko': u':청각장애가_있는_여자_연한_갈색_피부:',
        'pt': ':mulher_surda_pele_morena_clara:',
        'it': ':donna_con_problemi_di_udito_carnagione_abbastanza_chiara:',
        'fa': u':زن_ناشنوا_پوست_روشن:',
        'id': ':wanita_tuli_warna_kulit_cerah-sedang:',
        'zh': u':失聪的女人_中等浅肤色:'
    },
    u'\U0001F9CF\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧏🏽‍♀️
        'en' : ':deaf_woman_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_mittlere_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_medio:',
        'fr': u':femme_sourde_peau_légèrement_mate:',
        'ja': u':耳の不自由な女性_中間の肌色:',
        'ko': u':청각장애가_있는_여자_갈색_피부:',
        'pt': ':mulher_surda_pele_morena:',
        'it': ':donna_con_problemi_di_udito_carnagione_olivastra:',
        'fa': u':زن_ناشنوا_پوست_طلایی:',
        'id': ':wanita_tuli_warna_kulit_sedang:',
        'zh': u':失聪的女人_中等肤色:'
    },
    u'\U0001F9CF\U0001F3FD\U0000200D\U00002640': { # 🧏🏽‍♀
        'en' : ':deaf_woman_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': u':gehörlose_frau_mittlere_hautfarbe:',
        'es': ':mujer_sorda_tono_de_piel_medio:',
        'fr': u':femme_sourde_peau_légèrement_mate:',
        'ja': u':耳の不自由な女性_中間の肌色:',
        'ko': u':청각장애가_있는_여자_갈색_피부:',
        'pt': ':mulher_surda_pele_morena:',
        'it': ':donna_con_problemi_di_udito_carnagione_olivastra:',
        'fa': u':زن_ناشنوا_پوست_طلایی:',
        'id': ':wanita_tuli_warna_kulit_sedang:',
        'zh': u':失聪的女人_中等肤色:'
    },
    u'\U0001F333': { # 🌳
        'en' : ':deciduous_tree:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':laubbaum:',
        'es': u':árbol_de_hoja_caduca:',
        'fr': u':arbre_à_feuilles_caduques:',
        'ja': u':落葉樹:',
        'ko': u':나무:',
        'pt': u':árvore_caidiça:',
        'it': ':albero_deciduo:',
        'fa': u':درخت_سبز:',
        'id': ':pohon_meranggas:',
        'zh': u':落叶树:'
    },
    u'\U0001F98C': { # 🦌
        'en' : ':deer:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hirsch:',
        'es': ':ciervo:',
        'fr': ':cerf:',
        'ja': u':シカ:',
        'ko': u':사슴:',
        'pt': ':cervo:',
        'it': ':cervo:',
        'fa': u':گوزن:',
        'id': ':rusa:',
        'zh': u':鹿:'
    },
    u'\U0001F69A': { # 🚚
        'en' : ':delivery_truck:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':truck:'],
        'de': ':lieferwagen:',
        'es': u':camión_de_reparto:',
        'fr': ':camion_de_livraison:',
        'ja': u':トラック:',
        'ko': u':운송_트럭:',
        'pt': u':caminhão_de_entrega:',
        'it': ':camion:',
        'fa': u':کامیون_پخش:',
        'id': ':truk_pengiriman:',
        'zh': u':货车:'
    },
    u'\U0001F3EC': { # 🏬
        'en' : ':department_store:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kaufhaus:',
        'es': ':grandes_almacenes:',
        'fr': ':grand_magasin:',
        'ja': u':デパート:',
        'ko': u':백화점:',
        'pt': ':loja_de_departamentos:',
        'it': ':grande_magazzino:',
        'fa': u':فروشگاه_بزرگ:',
        'id': ':toserba:',
        'zh': u':商场:'
    },
    u'\U0001F3DA\U0000FE0F': { # 🏚️
        'en' : ':derelict_house:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':derelict_house_building:'],
        'variant': True,
        'de': ':verfallenes_haus:',
        'es': ':casa_abandonada:',
        'fr': u':maison_abandonnée:',
        'ja': u':廃屋:',
        'ko': u':낡은_주택_건물:',
        'pt': ':casa_abandonada:',
        'it': ':casa_in_rovina:',
        'fa': u':خانه_متروکه:',
        'id': ':rumah_terlantar:',
        'zh': u':废墟:'
    },
    u'\U0001F3DA': { # 🏚
        'en' : ':derelict_house:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':derelict_house_building:'],
        'variant': True,
        'de': ':verfallenes_haus:',
        'es': ':casa_abandonada:',
        'fr': u':maison_abandonnée:',
        'ja': u':廃屋:',
        'ko': u':낡은_주택_건물:',
        'pt': ':casa_abandonada:',
        'it': ':casa_in_rovina:',
        'fa': u':خانهٔ_متروکه:',
        'id': ':rumah_terlantar:',
        'zh': u':废墟:'
    },
    u'\U0001F3DC\U0000FE0F': { # 🏜️
        'en' : ':desert:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':wüste:',
        'es': ':desierto:',
        'fr': u':désert:',
        'ja': u':砂漠:',
        'ko': u':사막:',
        'pt': ':deserto:',
        'it': ':deserto:',
        'fa': u':بیابان:',
        'id': ':gurun:',
        'zh': u':沙漠:'
    },
    u'\U0001F3DC': { # 🏜
        'en' : ':desert:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':wüste:',
        'es': ':desierto:',
        'fr': u':désert:',
        'ja': u':砂漠:',
        'ko': u':사막:',
        'pt': ':deserto:',
        'it': ':deserto:',
        'fa': u':بیابان:',
        'id': ':gurun:',
        'zh': u':沙漠:'
    },
    u'\U0001F3DD\U0000FE0F': { # 🏝️
        'en' : ':desert_island:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':einsame_insel:',
        'es': ':isla_desierta:',
        'fr': u':île_déserte:',
        'ja': u':無人島:',
        'ko': u':사막_섬:',
        'pt': ':ilha_deserta:',
        'it': ':isola_deserta:',
        'fa': u':جزیره_خالی_از_سکنه:',
        'id': ':pulau_terpencil:',
        'zh': u':无人荒岛:'
    },
    u'\U0001F3DD': { # 🏝
        'en' : ':desert_island:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':einsame_insel:',
        'es': ':isla_desierta:',
        'fr': u':île_déserte:',
        'ja': u':無人島:',
        'ko': u':사막_섬:',
        'pt': ':ilha_deserta:',
        'it': ':isola_deserta:',
        'fa': u':جزیرهٔ_خالی_از_سکنه:',
        'id': ':pulau_terpencil:',
        'zh': u':无人荒岛:'
    },
    u'\U0001F5A5\U0000FE0F': { # 🖥️
        'en' : ':desktop_computer:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':desktopcomputer:',
        'es': ':ordenador_de_sobremesa:',
        'fr': ':ordinateur_de_bureau:',
        'ja': u':デスクトップパソコン:',
        'ko': u':데스크톱_컴퓨터:',
        'pt': ':computador_de_mesa:',
        'it': ':computer_fisso:',
        'fa': u':رایانه_میزی:',
        'id': ':komputer_desktop:',
        'zh': u':台式电脑:'
    },
    u'\U0001F5A5': { # 🖥
        'en' : ':desktop_computer:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':desktopcomputer:',
        'es': ':ordenador_de_sobremesa:',
        'fr': ':ordinateur_de_bureau:',
        'ja': u':デスクトップパソコン:',
        'ko': u':데스크톱_컴퓨터:',
        'pt': ':computador_de_mesa:',
        'it': ':computer_fisso:',
        'fa': u':رایانهٔ_میزی:',
        'id': ':komputer_desktop:',
        'zh': u':台式电脑:'
    },
    u'\U0001F575\U0000FE0F': { # 🕵️
        'en' : ':detective:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':sleuth_or_spy:'],
        'variant': True,
        'de': ':detektiv(in):',
        'es': ':detective:',
        'fr': u':détective:',
        'ja': u':探偵:',
        'ko': u':탐정:',
        'pt': ':detetive:',
        'it': ':detective:',
        'fa': u':کارآگاه:',
        'id': ':detektif:',
        'zh': u':侦探:'
    },
    u'\U0001F575': { # 🕵
        'en' : ':detective:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':sleuth_or_spy:'],
        'variant': True,
        'de': ':detektiv(in):',
        'es': ':detective:',
        'fr': u':détective:',
        'ja': u':探偵:',
        'ko': u':탐정:',
        'pt': ':detetive:',
        'it': ':detective:',
        'fa': u':کارآگاه:',
        'id': ':detektif:',
        'zh': u':侦探:'
    },
    u'\U0001F575\U0001F3FF': { # 🕵🏿
        'en' : ':detective_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':detektiv(in)_dunkle_hautfarbe:',
        'es': ':detective_tono_de_piel_oscuro:',
        'fr': u':détective_peau_foncée:',
        'ja': u':探偵_濃い肌色:',
        'ko': u':탐정_검은색_피부:',
        'pt': ':detetive_pele_escura:',
        'it': ':detective_carnagione_scura:',
        'fa': u':کارآگاه_پوست_آبنوسی:',
        'id': ':detektif_warna_kulit_gelap:',
        'zh': u':侦探_较深肤色:'
    },
    u'\U0001F575\U0001F3FB': { # 🕵🏻
        'en' : ':detective_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':detektiv(in)_helle_hautfarbe:',
        'es': ':detective_tono_de_piel_claro:',
        'fr': u':détective_peau_claire:',
        'ja': u':探偵_薄い肌色:',
        'ko': u':탐정_하얀_피부:',
        'pt': ':detetive_pele_clara:',
        'it': ':detective_carnagione_chiara:',
        'fa': u':کارآگاه_پوست_سفید:',
        'id': ':detektif_warna_kulit_cerah:',
        'zh': u':侦探_较浅肤色:'
    },
    u'\U0001F575\U0001F3FE': { # 🕵🏾
        'en' : ':detective_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':detektiv(in)_mitteldunkle_hautfarbe:',
        'es': ':detective_tono_de_piel_oscuro_medio:',
        'fr': u':détective_peau_mate:',
        'ja': u':探偵_やや濃い肌色:',
        'ko': u':탐정_진한_갈색_피부:',
        'pt': ':detetive_pele_morena_escura:',
        'it': ':detective_carnagione_abbastanza_scura:',
        'fa': u':کارآگاه_پوست_گندمی:',
        'id': ':detektif_warna_kulit_gelap-sedang:',
        'zh': u':侦探_中等深肤色:'
    },
    u'\U0001F575\U0001F3FC': { # 🕵🏼
        'en' : ':detective_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':detektiv(in)_mittelhelle_hautfarbe:',
        'es': ':detective_tono_de_piel_claro_medio:',
        'fr': u':détective_peau_moyennement_claire:',
        'ja': u':探偵_やや薄い肌色:',
        'ko': u':탐정_연한_갈색_피부:',
        'pt': ':detetive_pele_morena_clara:',
        'it': ':detective_carnagione_abbastanza_chiara:',
        'fa': u':کارآگاه_پوست_روشن:',
        'id': ':detektif_warna_kulit_cerah-sedang:',
        'zh': u':侦探_中等浅肤色:'
    },
    u'\U0001F575\U0001F3FD': { # 🕵🏽
        'en' : ':detective_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':detektiv(in)_mittlere_hautfarbe:',
        'es': ':detective_tono_de_piel_medio:',
        'fr': u':détective_peau_légèrement_mate:',
        'ja': u':探偵_中間の肌色:',
        'ko': u':탐정_갈색_피부:',
        'pt': ':detetive_pele_morena:',
        'it': ':detective_carnagione_olivastra:',
        'fa': u':کارآگاه_پوست_طلایی:',
        'id': ':detektif_warna_kulit_sedang:',
        'zh': u':侦探_中等肤色:'
    },
    u'\U00002666\U0000FE0F': { # ♦️
        'en' : ':diamond_suit:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':diamonds:'],
        'variant': True,
        'de': ':karo:',
        'es': ':palo_de_diamantes:',
        'fr': ':carreau:',
        'ja': u':ダイヤ:',
        'ko': u':다이아몬드:',
        'pt': ':naipe_de_ouros:',
        'it': ':quadri:',
        'fa': u':خال_خشت:',
        'id': ':wajik:',
        'zh': u':方片:'
    },
    u'\U00002666': { # ♦
        'en' : ':diamond_suit:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':diamonds:'],
        'variant': True,
        'de': ':karo:',
        'es': ':palo_de_diamantes:',
        'fr': ':carreau:',
        'ja': u':ダイヤ:',
        'ko': u':다이아몬드:',
        'pt': ':naipe_de_ouros:',
        'it': ':quadri:',
        'fa': u':خال_خشت:',
        'id': ':wajik:',
        'zh': u':方片:'
    },
    u'\U0001F4A0': { # 💠
        'en' : ':diamond_with_a_dot:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':diamond_shape_with_a_dot_inside:'],
        'de': ':rautenform_mit_punkt:',
        'es': u':rombo_con_pétalo:',
        'fr': ':diamant_avec_un_point:',
        'ja': u':ドット付きひし形:',
        'ko': u':점이_찍힌_다이아몬드_모양:',
        'pt': ':diamante_com_um_ponto:',
        'it': ':petalo_di_fiore:',
        'fa': u':لوزی_نقطه_دار:',
        'id': ':wajik_bertitik:',
        'zh': u':带圆点的菱形:'
    },
    u'\U0001F505': { # 🔅
        'en' : ':dim_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':low_brightness:'],
        'de': ':taste_dimmen:',
        'es': ':brillo_bajo:',
        'fr': u':luminosité_faible:',
        'ja': u':低輝度:',
        'ko': u':밝기_낮음:',
        'pt': u':botão_de_diminuir_brilho:',
        'it': u':luminosità_bassa:',
        'fa': u':دکمهٔ_تار_کردن_صفحه:',
        'id': ':tombol_redupkan:',
        'zh': u':低亮度按钮:'
    },
    u'\U0001F61E': { # 😞
        'en' : ':disappointed_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':disappointed:'],
        'de': u':enttäuschtes_gesicht:',
        'es': ':cara_decepcionada:',
        'fr': u':visage_déçu:',
        'ja': u':失望した顔:',
        'ko': u':실망한_얼굴:',
        'pt': ':rosto_desapontado:',
        'it': ':faccina_delusa:',
        'fa': u':ناامید:',
        'id': ':wajah_kecewa:',
        'zh': u':失望:'
    },
    u'\U0001F978': { # 🥸
        'en' : ':disguised_face:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':verkleidet:',
        'es': ':cara_disfrazada:',
        'fr': u':visage_déguisé:',
        'ja': u':変装した顔:',
        'ko': u':변장한_얼굴:',
        'pt': u':rosto_disfarçado:',
        'it': ':faccina_travestita:',
        'fa': u':تغییرقیافه_داده:',
        'id': ':wajah_menyamar:',
        'zh': u':伪装的脸:'
    },
    u'\U00002797': { # ➗
        'en' : ':divide:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heavy_division_sign:'],
        'de': ':geteilt_durch:',
        'es': u':división:',
        'fr': ':signe_diviser:',
        'ja': u':割り算:',
        'ko': u':나누기:',
        'pt': u':símbolo_de_divisão:',
        'it': ':divisione:',
        'fa': u':تقسیم_کردن:',
        'id': ':bagi:',
        'zh': u':除:'
    },
    u'\U0001F93F': { # 🤿
        'en' : ':diving_mask:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':tauchmaske:',
        'es': u':máscara_de_buceo:',
        'fr': u':masque_de_plongée:',
        'ja': u':ダイビング_マスク:',
        'ko': u':다이빙_마스크:',
        'pt': u':máscara_de_mergulho:',
        'it': ':maschera_da_sub:',
        'fa': u':ماسک_غواصی:',
        'id': ':kacamata_selam:',
        'zh': u':潜水面罩:'
    },
    u'\U0001FA94': { # 🪔
        'en' : ':diya_lamp:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':öllampe:',
        'es': u':lámpara_de_aceite:',
        'fr': ':diya:',
        'ja': u':ディヤランプ:',
        'ko': u':기름_램프:',
        'pt': u':lâmpada_de_óleo:',
        'it': ':diya:',
        'fa': u':چراغ_دایا:',
        'id': ':lampu_diya:',
        'zh': u':印度油灯:'
    },
    u'\U0001F4AB': { # 💫
        'en' : ':dizzy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schwindlig:',
        'es': u':símbolo_de_mareo:',
        'fr': u':étourdissement:',
        'ja': u':くらくら:',
        'ko': u':어지러움:',
        'pt': ':zonzo:',
        'it': ':stella_con_scia:',
        'fa': u':سرگیجه:',
        'id': ':pusing:',
        'zh': u':头晕:'
    },
    u'\U0001F9EC': { # 🧬
        'en' : ':dna:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':dna:',
        'es': ':adn:',
        'fr': ':adn:',
        'ja': ':dna:',
        'ko': ':dna:',
        'pt': ':dna:',
        'it': ':dna:',
        'fa': u':دی_ان_ای:',
        'id': ':dna:',
        'zh': ':DNA:'
    },
    u'\U0001F9A4': { # 🦤
        'en' : ':dodo:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':dodo:',
        'es': ':dodo:',
        'fr': ':dodo:',
        'ja': u':ドードー:',
        'ko': u':도도새:',
        'pt': u':dodô:',
        'it': ':dodo:',
        'fa': u':دودو:',
        'id': ':dodo:',
        'zh': u':渡渡鸟:'
    },
    u'\U0001F415': { # 🐕
        'en' : ':dog:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':dog2:'],
        'variant': True,
        'de': ':hund:',
        'es': ':perro:',
        'fr': ':chien:',
        'ja': u':イヌ:',
        'ko': u':개:',
        'pt': ':cachorro:',
        'it': ':cane:',
        'fa': u':سگ:',
        'id': ':anjing:',
        'zh': u':狗:'
    },
    u'\U0001F436': { # 🐶
        'en' : ':dog_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dog:'],
        'de': ':hundegesicht:',
        'es': ':cara_de_perro:',
        'fr': u':tête_de_chien:',
        'ja': u':イヌの顔:',
        'ko': u':강아지_얼굴:',
        'pt': ':rosto_de_cachorro:',
        'it': ':muso_di_cane:',
        'fa': u':صورت_سگ:',
        'id': ':wajah_anjing:',
        'zh': u':狗脸:'
    },
    u'\U0001F4B5': { # 💵
        'en' : ':dollar_banknote:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dollar:'],
        'de': ':dollar-banknote:',
        'es': u':billete_de_dólar:',
        'fr': ':billet_en_dollars:',
        'ja': u':ドル札:',
        'ko': u':달러:',
        'pt': u':nota_de_dólar:',
        'it': ':banconota_dollaro:',
        'fa': u':اسکناس_دلار:',
        'id': ':uang_kertas_dolar:',
        'zh': u':美元:'
    },
    u'\U0001F42C': { # 🐬
        'en' : ':dolphin:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flipper:'],
        'de': ':delfin:',
        'es': u':delfín:',
        'fr': ':dauphin:',
        'ja': u':イルカ:',
        'ko': u':돌고래:',
        'pt': ':golfinho:',
        'it': ':delfino:',
        'fa': u':دلفین:',
        'id': ':lumba-lumba:',
        'zh': u':海豚:'
    },
    u'\U0001FACF': { # 🫏
        'en' : ':donkey:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':esel:',
        'es': ':burro:',
        'fr': u':âne:',
        'ja': u':ロバ:',
        'ko': u':당나귀:',
        'pt': ':burro:',
        'it': ':asino:',
        'fa': u':الاغ:',
        'id': ':keledai:',
        'zh': u':驴:'
    },
    u'\U0001F6AA': { # 🚪
        'en' : ':door:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':tür:',
        'es': ':puerta:',
        'fr': ':porte:',
        'ja': u':ドア:',
        'ko': u':문:',
        'pt': ':porta:',
        'it': ':porta:',
        'fa': u':در:',
        'id': ':pintu:',
        'zh': u':门:'
    },
    u'\U0001FAE5': { # 🫥
        'en' : ':dotted_line_face:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':gestricheltes_gesicht:',
        'es': u':cara_con_línea_de_puntos:',
        'fr': u':visage_en_pointillés:',
        'ja': u':点線の顔:',
        'ko': u':테두리가_점선으로_된_얼굴:',
        'pt': ':rosto_com_linha_pontilhada:',
        'it': ':faccina_tratteggiata:',
        'fa': u':چهره_با_خط_چین:',
        'id': ':wajah_dengan_garis_titik-titik:',
        'zh': u':虚线脸:'
    },
    u'\U0001F52F': { # 🔯
        'en' : ':dotted_six-pointed_star:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':six_pointed_star:'],
        'de': ':hexagramm_mit_punkt:',
        'es': ':estrella_de_seis_puntas:',
        'fr': u':étoile_à_6_branches:',
        'ja': u':六芒星:',
        'ko': u':육각_별:',
        'pt': ':estrela_de_seis_pontas:',
        'it': ':stella_a_sei_punte:',
        'fa': u':ستارهٔ_شش_پر:',
        'id': ':bintang_sudut_enam_bertitik:',
        'zh': u':带中间点的六芒星:'
    },
    u'\U000027BF': { # ➿
        'en' : ':double_curly_loop:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':loop:'],
        'de': ':doppelschleife:',
        'es': ':bucle_doble:',
        'fr': ':double_boucle:',
        'ja': u':ダブルループ:',
        'ko': u':두_개의_고리:',
        'pt': ':loop_encaracolado_duas_vezes:',
        'it': ':doppio_occhiello:',
        'fa': u':حلقه_مجعد_دوتایی:',
        'id': ':untaian_bergelombang_ganda:',
        'zh': u':双卷曲环:'
    },
    u'\U0000203C\U0000FE0F': { # ‼️
        'en' : ':double_exclamation_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bangbang:'],
        'variant': True,
        'de': ':doppeltes_ausrufezeichen:',
        'es': u':exclamación_doble:',
        'fr': u':double_point_d’exclamation:',
        'ja': u':二重感嘆符:',
        'ko': u':두_개의_느낌표:',
        'pt': u':dupla_exclamação:',
        'it': ':doppio_punto_esclamativo:',
        'fa': u':علامت_تعجب_دوتایی:',
        'id': ':tanda_seru_ganda:',
        'zh': u':双感叹号:'
    },
    u'\U0000203C': { # ‼
        'en' : ':double_exclamation_mark:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':bangbang:'],
        'variant': True,
        'de': ':doppeltes_ausrufezeichen:',
        'es': u':exclamación_doble:',
        'fr': u':double_point_d’exclamation:',
        'ja': u':二重感嘆符:',
        'ko': u':두_개의_느낌표:',
        'pt': u':dupla_exclamação:',
        'it': ':doppio_punto_esclamativo:',
        'fa': u':علامت_تعجب_دوتایی:',
        'id': ':tanda_seru_ganda:',
        'zh': u':双感叹号:'
    },
    u'\U0001F369': { # 🍩
        'en' : ':doughnut:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':donut:',
        'es': u':dónut:',
        'fr': ':doughnut:',
        'ja': u':ドーナツ:',
        'ko': u':도넛:',
        'pt': ':donut:',
        'it': ':ciambella:',
        'fa': u':دونات:',
        'id': ':donat:',
        'zh': u':甜甜圈:'
    },
    u'\U0001F54A\U0000FE0F': { # 🕊️
        'en' : ':dove:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':dove_of_peace:'],
        'variant': True,
        'de': ':taube:',
        'es': ':paloma:',
        'fr': ':colombe:',
        'ja': u':ハト:',
        'ko': u':비둘기:',
        'pt': ':pomba_branca:',
        'it': ':colomba:',
        'fa': u':کبوتر:',
        'id': ':merpati:',
        'zh': u':鸽:'
    },
    u'\U0001F54A': { # 🕊
        'en' : ':dove:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':dove_of_peace:'],
        'variant': True,
        'de': ':taube:',
        'es': ':paloma:',
        'fr': ':colombe:',
        'ja': u':ハト:',
        'ko': u':비둘기:',
        'pt': ':pomba_branca:',
        'it': ':colomba:',
        'fa': u':کبوتر:',
        'id': ':merpati:',
        'zh': u':鸽:'
    },
    u'\U00002199\U0000FE0F': { # ↙️
        'en' : ':down-left_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_lower_left:'],
        'variant': True,
        'de': ':pfeil_nach_links_unten:',
        'es': ':flecha_hacia_la_esquina_inferior_izquierda:',
        'fr': u':flèche_bas_gauche:',
        'ja': u':左下矢印:',
        'ko': u':좌하향_화살표:',
        'pt': ':seta_para_baixo_e_para_a_esquerda:',
        'it': ':freccia_in_basso_a_sinistra:',
        'fa': u':پیکان_پایین_چپ:',
        'id': ':tanda_panah_kiri_bawah:',
        'zh': u':左下箭头:'
    },
    u'\U00002199': { # ↙
        'en' : ':down-left_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_lower_left:'],
        'variant': True,
        'de': ':pfeil_nach_links_unten:',
        'es': ':flecha_hacia_la_esquina_inferior_izquierda:',
        'fr': u':flèche_bas_gauche:',
        'ja': u':左下矢印:',
        'ko': u':좌하향_화살표:',
        'pt': ':seta_para_baixo_e_para_a_esquerda:',
        'it': ':freccia_in_basso_a_sinistra:',
        'fa': u':پیکان_پایین_چپ:',
        'id': ':tanda_panah_kiri_bawah:',
        'zh': u':左下箭头:'
    },
    u'\U00002198\U0000FE0F': { # ↘️
        'en' : ':down-right_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_lower_right:'],
        'variant': True,
        'de': ':pfeil_nach_rechts_unten:',
        'es': ':flecha_hacia_la_esquina_inferior_derecha:',
        'fr': u':flèche_bas_droite:',
        'ja': u':右下矢印:',
        'ko': u':우하향_화살표:',
        'pt': ':seta_para_baixo_e_para_a_direita:',
        'it': ':freccia_in_basso_a_destra:',
        'fa': u':پیکان_پایین_راست:',
        'id': ':tanda_panah_kanan_bawah:',
        'zh': u':右下箭头:'
    },
    u'\U00002198': { # ↘
        'en' : ':down-right_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_lower_right:'],
        'variant': True,
        'de': ':pfeil_nach_rechts_unten:',
        'es': ':flecha_hacia_la_esquina_inferior_derecha:',
        'fr': u':flèche_bas_droite:',
        'ja': u':右下矢印:',
        'ko': u':우하향_화살표:',
        'pt': ':seta_para_baixo_e_para_a_direita:',
        'it': ':freccia_in_basso_a_destra:',
        'fa': u':پیکان_پایین_راست:',
        'id': ':tanda_panah_kanan_bawah:',
        'zh': u':右下箭头:'
    },
    u'\U00002B07\U0000FE0F': { # ⬇️
        'en' : ':down_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_down:'],
        'variant': True,
        'de': ':pfeil_nach_unten:',
        'es': ':flecha_hacia_abajo:',
        'fr': u':flèche_bas:',
        'ja': u':下矢印:',
        'ko': u':하향_화살표:',
        'pt': ':seta_para_baixo:',
        'it': ':freccia_rivolta_verso_il_basso:',
        'fa': u':پیکان_پایین:',
        'id': ':tanda_panah_bawah:',
        'zh': u':向下箭头:'
    },
    u'\U00002B07': { # ⬇
        'en' : ':down_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_down:'],
        'variant': True,
        'de': ':pfeil_nach_unten:',
        'es': ':flecha_hacia_abajo:',
        'fr': u':flèche_bas:',
        'ja': u':下矢印:',
        'ko': u':하향_화살표:',
        'pt': ':seta_para_baixo:',
        'it': ':freccia_rivolta_verso_il_basso:',
        'fa': u':پیکان_پایین:',
        'id': ':tanda_panah_bawah:',
        'zh': u':向下箭头:'
    },
    u'\U0001F613': { # 😓
        'en' : ':downcast_face_with_sweat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sweat:'],
        'de': u':bedrücktes_gesicht_mit_schweiß:',
        'es': u':cara_con_sudor_frío:',
        'fr': u':visage_démoralisé_avec_goutte_de_sueur:',
        'ja': u':冷や汗:',
        'ko': u':식은땀_흘리는_얼굴:',
        'pt': ':rosto_cabisbaixo_com_gota_de_suor:',
        'it': ':faccina_abbattuta_sudata:',
        'fa': u':عرق_سرد:',
        'id': ':wajah_berkeringat:',
        'zh': u':汗:'
    },
    u'\U0001F53D': { # 🔽
        'en' : ':downwards_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_down_small:'],
        'de': u':abwärts-schaltfläche:',
        'es': u':triángulo_hacia_abajo:',
        'fr': ':petit_triangle_bas:',
        'ja': u':下ボタン:',
        'ko': u':아래쪽_삼각형:',
        'pt': u':botão_apontando_para_baixo:',
        'it': ':pulsante_a_triangolo_rivolto_verso_il_basso:',
        'fa': u':دکمهٔ_پایین:',
        'id': ':tombol_turun:',
        'zh': u':向下三角形按钮:'
    },
    u'\U0001F409': { # 🐉
        'en' : ':dragon:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':drache:',
        'es': u':dragón:',
        'fr': ':dragon:',
        'ja': u':ドラゴン:',
        'ko': u':용:',
        'pt': u':dragão:',
        'it': ':drago:',
        'fa': u':اژدها:',
        'id': ':naga:',
        'zh': u':龙:'
    },
    u'\U0001F432': { # 🐲
        'en' : ':dragon_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':drachengesicht:',
        'es': u':cara_de_dragón:',
        'fr': u':tête_de_dragon:',
        'ja': u':ドラゴンの顔:',
        'ko': u':용_얼굴:',
        'pt': u':rosto_de_dragão:',
        'it': ':testa_di_drago:',
        'fa': u':صورت_اژدها:',
        'id': ':wajah_naga:',
        'zh': u':龙头:'
    },
    u'\U0001F457': { # 👗
        'en' : ':dress:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kleid:',
        'es': ':vestido:',
        'fr': ':robe:',
        'ja': u':ワンピース:',
        'ko': u':원피스:',
        'pt': ':vestido:',
        'it': ':vestito:',
        'fa': u':پیراهن_زنانه:',
        'id': ':gaun:',
        'zh': u':连衣裙:'
    },
    u'\U0001F924': { # 🤤
        'en' : ':drooling_face:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':sabberndes_gesicht:',
        'es': ':cara_babeando:',
        'fr': ':visage_qui_bave:',
        'ja': u':よだれを垂らした顔:',
        'ko': u':침_흘리는_얼굴:',
        'pt': ':rosto_babando:',
        'it': ':faccina_che_sbava:',
        'fa': u':آب_افتادن_دهان:',
        'id': ':ngiler:',
        'zh': u':流口水:'
    },
    u'\U0001FA78': { # 🩸
        'en' : ':drop_of_blood:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':blutstropfen:',
        'es': ':gota_de_sangre:',
        'fr': ':goutte_de_sang:',
        'ja': u':血液:',
        'ko': u':핏방울:',
        'pt': ':gota_de_sangue:',
        'it': ':goccia_di_sangue:',
        'fa': u':قطره_خون:',
        'id': ':tetesan_darah:',
        'zh': u':血滴:'
    },
    u'\U0001F4A7': { # 💧
        'en' : ':droplet:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':tropfen:',
        'es': ':gota:',
        'fr': u':goutte_d’eau:',
        'ja': u':水滴:',
        'ko': u':물방울:',
        'pt': ':gota:',
        'it': ':goccia:',
        'fa': u':قطره:',
        'id': ':tetesan_air:',
        'zh': u':水滴:'
    },
    u'\U0001F941': { # 🥁
        'en' : ':drum:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':trommel:',
        'es': ':tambor:',
        'fr': ':batterie:',
        'ja': u':ドラム:',
        'ko': u':드럼:',
        'pt': ':tambor:',
        'it': ':tamburo:',
        'fa': u':طبل:',
        'id': ':drum:',
        'zh': u':鼓:'
    },
    u'\U0001F986': { # 🦆
        'en' : ':duck:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':ente:',
        'es': ':pato:',
        'fr': ':canard:',
        'ja': u':カモ:',
        'ko': u':오리:',
        'pt': ':pato:',
        'it': ':anatra:',
        'fa': u':مرغابی:',
        'id': ':bebek:',
        'zh': u':鸭子:'
    },
    u'\U0001F95F': { # 🥟
        'en' : ':dumpling:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':teigtasche:',
        'es': ':dumpling:',
        'fr': u':boulette_de_pâte:',
        'ja': u':点心:',
        'ko': u':만두:',
        'pt': u':bolinho_asiático:',
        'it': ':raviolo:',
        'fa': u':کوفته:',
        'id': ':dumpling:',
        'zh': u':饺子:'
    },
    u'\U0001F4C0': { # 📀
        'en' : ':dvd:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':dvd:',
        'es': ':disco_dvd:',
        'fr': ':dvd:',
        'ja': ':dvd:',
        'ko': u':디비디:',
        'pt': ':dvd:',
        'it': ':dvd:',
        'fa': u':دی_وی_دی:',
        'id': ':dvd:',
        'zh': ':DVD:'
    },
    u'\U0001F4E7': { # 📧
        'en' : ':e-mail:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':email:', ':e__mail:'],
        'de': ':e-mail:',
        'es': u':correo_electrónico:',
        'fr': ':e-mail:',
        'ja': u':eメール:',
        'ko': u':이메일:',
        'pt': ':e-mail:',
        'it': ':e-mail:',
        'fa': u':ایمیل:',
        'id': ':email:',
        'zh': u':电子邮件:'
    },
    u'\U0001F985': { # 🦅
        'en' : ':eagle:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':adler:',
        'es': u':águila:',
        'fr': ':aigle:',
        'ja': u':ワシ:',
        'ko': u':독수리:',
        'pt': u':águia:',
        'it': ':aquila:',
        'fa': u':عقاب:',
        'id': ':elang:',
        'zh': u':鹰:'
    },
    u'\U0001F442': { # 👂
        'en' : ':ear:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':ohr:',
        'es': ':oreja:',
        'fr': ':oreille:',
        'ja': u':耳:',
        'ko': u':귀:',
        'pt': ':orelha:',
        'it': ':orecchio:',
        'fa': u':گوش:',
        'id': ':telinga:',
        'zh': u':耳朵:'
    },
    u'\U0001F442\U0001F3FF': { # 👂🏿
        'en' : ':ear_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ohr_dunkle_hautfarbe:',
        'es': ':oreja_tono_de_piel_oscuro:',
        'fr': u':oreille_peau_foncée:',
        'ja': u':耳_濃い肌色:',
        'ko': u':귀_검은색_피부:',
        'pt': ':orelha_pele_escura:',
        'it': ':orecchio_carnagione_scura:',
        'fa': u':گوش_پوست_آبنوسی:',
        'id': ':telinga_warna_kulit_gelap:',
        'zh': u':耳朵_较深肤色:'
    },
    u'\U0001F442\U0001F3FB': { # 👂🏻
        'en' : ':ear_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ohr_helle_hautfarbe:',
        'es': ':oreja_tono_de_piel_claro:',
        'fr': ':oreille_peau_claire:',
        'ja': u':耳_薄い肌色:',
        'ko': u':귀_하얀_피부:',
        'pt': ':orelha_pele_clara:',
        'it': ':orecchio_carnagione_chiara:',
        'fa': u':گوش_پوست_سفید:',
        'id': ':telinga_warna_kulit_cerah:',
        'zh': u':耳朵_较浅肤色:'
    },
    u'\U0001F442\U0001F3FE': { # 👂🏾
        'en' : ':ear_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ohr_mitteldunkle_hautfarbe:',
        'es': ':oreja_tono_de_piel_oscuro_medio:',
        'fr': ':oreille_peau_mate:',
        'ja': u':耳_やや濃い肌色:',
        'ko': u':귀_진한_갈색_피부:',
        'pt': ':orelha_pele_morena_escura:',
        'it': ':orecchio_carnagione_abbastanza_scura:',
        'fa': u':گوش_پوست_گندمی:',
        'id': ':telinga_warna_kulit_gelap-sedang:',
        'zh': u':耳朵_中等深肤色:'
    },
    u'\U0001F442\U0001F3FC': { # 👂🏼
        'en' : ':ear_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ohr_mittelhelle_hautfarbe:',
        'es': ':oreja_tono_de_piel_claro_medio:',
        'fr': ':oreille_peau_moyennement_claire:',
        'ja': u':耳_やや薄い肌色:',
        'ko': u':귀_연한_갈색_피부:',
        'pt': ':orelha_pele_morena_clara:',
        'it': ':orecchio_carnagione_abbastanza_chiara:',
        'fa': u':گوش_پوست_روشن:',
        'id': ':telinga_warna_kulit_cerah-sedang:',
        'zh': u':耳朵_中等浅肤色:'
    },
    u'\U0001F442\U0001F3FD': { # 👂🏽
        'en' : ':ear_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ohr_mittlere_hautfarbe:',
        'es': ':oreja_tono_de_piel_medio:',
        'fr': u':oreille_peau_légèrement_mate:',
        'ja': u':耳_中間の肌色:',
        'ko': u':귀_갈색_피부:',
        'pt': ':orelha_pele_morena:',
        'it': ':orecchio_carnagione_olivastra:',
        'fa': u':گوش_پوست_طلایی:',
        'id': ':telinga_warna_kulit_sedang:',
        'zh': u':耳朵_中等肤色:'
    },
    u'\U0001F33D': { # 🌽
        'en' : ':ear_of_corn:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':corn:'],
        'de': ':maiskolben:',
        'es': u':espiga_de_maíz:',
        'fr': u':épi_de_maïs:',
        'ja': u':とうもろこし:',
        'ko': u':옥수수:',
        'pt': ':milho:',
        'it': ':pannocchia:',
        'fa': u':بلال_ذرت:',
        'id': ':bonggol_jagung:',
        'zh': u':玉米:'
    },
    u'\U0001F9BB': { # 🦻
        'en' : ':ear_with_hearing_aid:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':ohr_mit_hörgerät:',
        'es': u':oreja_con_audífono:',
        'fr': u':oreille_appareillée:',
        'ja': u':補聴器を付けた耳:',
        'ko': u':보청기를_낀_귀:',
        'pt': ':ouvido_com_aparelho_auditivo:',
        'it': ':orecchio_con_apparecchio_acustico:',
        'fa': u':سمعک_در_گوش:',
        'id': ':telinga_dengan_alat_bantu_dengar:',
        'zh': u':戴助听器的耳朵:'
    },
    u'\U0001F9BB\U0001F3FF': { # 🦻🏿
        'en' : ':ear_with_hearing_aid_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':ohr_mit_hörhilfe_dunkle_hautfarbe:',
        'es': u':oreja_con_audífono_tono_de_piel_oscuro:',
        'fr': u':oreille_appareillée_peau_foncée:',
        'ja': u':補聴器を付けた耳_濃い肌色:',
        'ko': u':보청기를_낀_귀_검은색_피부:',
        'pt': ':ouvido_com_aparelho_auditivo_pele_escura:',
        'it': ':orecchio_con_apparecchio_acustico_carnagione_scura:',
        'fa': u':سمعک_در_گوش_پوست_آبنوسی:',
        'id': ':telinga_dengan_alat_bantu_dengar_warna_kulit_gelap:',
        'zh': u':戴助听器的耳朵_较深肤色:'
    },
    u'\U0001F9BB\U0001F3FB': { # 🦻🏻
        'en' : ':ear_with_hearing_aid_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':ohr_mit_hörhilfe_helle_hautfarbe:',
        'es': u':oreja_con_audífono_tono_de_piel_claro:',
        'fr': u':oreille_appareillée_peau_claire:',
        'ja': u':補聴器を付けた耳_薄い肌色:',
        'ko': u':보청기를_낀_귀_하얀_피부:',
        'pt': ':ouvido_com_aparelho_auditivo_pele_clara:',
        'it': ':orecchio_con_apparecchio_acustico_carnagione_chiara:',
        'fa': u':سمعک_در_گوش_پوست_سفید:',
        'id': ':telinga_dengan_alat_bantu_dengar_warna_kulit_cerah:',
        'zh': u':戴助听器的耳朵_较浅肤色:'
    },
    u'\U0001F9BB\U0001F3FE': { # 🦻🏾
        'en' : ':ear_with_hearing_aid_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':ohr_mit_hörhilfe_mitteldunkle_hautfarbe:',
        'es': u':oreja_con_audífono_tono_de_piel_oscuro_medio:',
        'fr': u':oreille_appareillée_peau_mate:',
        'ja': u':補聴器を付けた耳_やや濃い肌色:',
        'ko': u':보청기를_낀_귀_진한_갈색_피부:',
        'pt': ':ouvido_com_aparelho_auditivo_pele_morena_escura:',
        'it': ':orecchio_con_apparecchio_acustico_carnagione_abbastanza_scura:',
        'fa': u':سمعک_در_گوش_پوست_گندمی:',
        'id': ':telinga_dengan_alat_bantu_dengar_warna_kulit_gelap-sedang:',
        'zh': u':戴助听器的耳朵_中等深肤色:'
    },
    u'\U0001F9BB\U0001F3FC': { # 🦻🏼
        'en' : ':ear_with_hearing_aid_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':ohr_mit_hörhilfe_mittelhelle_hautfarbe:',
        'es': u':oreja_con_audífono_tono_de_piel_claro_medio:',
        'fr': u':oreille_appareillée_peau_moyennement_claire:',
        'ja': u':補聴器を付けた耳_やや薄い肌色:',
        'ko': u':보청기를_낀_귀_연한_갈색_피부:',
        'pt': ':ouvido_com_aparelho_auditivo_pele_morena_clara:',
        'it': ':orecchio_con_apparecchio_acustico_carnagione_abbastanza_chiara:',
        'fa': u':سمعک_در_گوش_پوست_روشن:',
        'id': ':telinga_dengan_alat_bantu_dengar_warna_kulit_cerah-sedang:',
        'zh': u':戴助听器的耳朵_中等浅肤色:'
    },
    u'\U0001F9BB\U0001F3FD': { # 🦻🏽
        'en' : ':ear_with_hearing_aid_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':ohr_mit_hörhilfe_mittlere_hautfarbe:',
        'es': u':oreja_con_audífono_tono_de_piel_medio:',
        'fr': u':oreille_appareillée_peau_légèrement_mate:',
        'ja': u':補聴器を付けた耳_中間の肌色:',
        'ko': u':보청기를_낀_귀_갈색_피부:',
        'pt': ':ouvido_com_aparelho_auditivo_pele_morena:',
        'it': ':orecchio_con_apparecchio_acustico_carnagione_olivastra:',
        'fa': u':سمعک_در_گوش_پوست_طلایی:',
        'id': ':telinga_dengan_alat_bantu_dengar_warna_kulit_sedang:',
        'zh': u':戴助听器的耳朵_中等肤色:'
    },
    u'\U0001F95A': { # 🥚
        'en' : ':egg:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':egg2:'],
        'de': ':ei:',
        'es': ':huevo:',
        'fr': u':œuf:',
        'ja': u':卵:',
        'ko': u':달걀:',
        'pt': ':ovo:',
        'it': ':uovo:',
        'fa': u':تخم_مرغ:',
        'id': ':telur:',
        'zh': u':蛋:'
    },
    u'\U0001F346': { # 🍆
        'en' : ':eggplant:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':aubergine:',
        'es': ':berenjena:',
        'fr': ':aubergine:',
        'ja': u':ナス:',
        'ko': u':가지:',
        'pt': ':berinjela:',
        'it': ':melanzana:',
        'fa': u':بادمجان:',
        'id': ':terung:',
        'zh': u':茄子:'
    },
    u'\U00002734\U0000FE0F': { # ✴️
        'en' : ':eight-pointed_star:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':eight_pointed_black_star:'],
        'variant': True,
        'de': ':stern_mit_acht_zacken:',
        'es': ':estrella_de_ocho_puntas:',
        'fr': u':étoile_huit_branches:',
        'ja': u':八角星:',
        'ko': u':팔각_별:',
        'pt': ':estrela_de_oito_pontas:',
        'it': ':stella_stilizzata:',
        'fa': u':ستاره_هشت_پر:',
        'id': ':bintang_berujung_delapan:',
        'zh': u':八角星:'
    },
    u'\U00002734': { # ✴
        'en' : ':eight-pointed_star:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':eight_pointed_black_star:'],
        'variant': True,
        'de': ':achtstrahliger_stern:',
        'es': ':estrella_de_ocho_puntas:',
        'fr': u':étoile_huit_branches:',
        'ja': u':八角星:',
        'ko': u':팔각_별:',
        'pt': ':estrela_de_oito_pontas:',
        'it': ':stella_stilizzata:',
        'fa': u':ستاره_هشت_پر:',
        'id': ':bintang_berujung_delapan:',
        'zh': u':八角星:'
    },
    u'\U00002733\U0000FE0F': { # ✳️
        'en' : ':eight-spoked_asterisk:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':eight_spoked_asterisk:'],
        'variant': True,
        'de': ':achtzackiger_stern:',
        'es': ':asterisco_de_ocho_puntas:',
        'fr': u':astérisque_huit_branches:',
        'ja': u':八角アスタリスク:',
        'ko': u':여덟_갈래_별표:',
        'pt': ':asterisco_de_oito_pontas:',
        'it': ':asterisco:',
        'fa': u':ستاره_هشت_پره:',
        'id': ':bintang_berujung_lancip_delapan:',
        'zh': u':八轮辐星号:'
    },
    u'\U00002733': { # ✳
        'en' : ':eight-spoked_asterisk:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':eight_spoked_asterisk:'],
        'variant': True,
        'de': ':achtzackiger_stern:',
        'es': ':asterisco_de_ocho_puntas:',
        'fr': u':astérisque_huit_branches:',
        'ja': u':八角アスタリスク:',
        'ko': u':여덟_갈래_별표:',
        'pt': ':asterisco_de_oito_pontas:',
        'it': ':asterisco:',
        'fa': u':ستاره_هشت_پره:',
        'id': ':bintang_berujung_lancip_delapan:',
        'zh': u':八轮辐星号:'
    },
    u'\U0001F563': { # 🕣
        'en' : ':eight-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock830:'],
        'variant': True,
        'de': ':8.30_uhr:',
        'es': ':ocho_y_media:',
        'fr': ':huit_heures_et_demie:',
        'ja': u':8時半:',
        'ko': u':여덟_시_반:',
        'pt': ':oito_e_meia:',
        'it': ':ore_otto_e_mezza:',
        'fa': u':ساعت_هشت_و_نیم:',
        'id': ':jam_setengah_sembilan:',
        'zh': u':八点半:'
    },
    u'\U0001F557': { # 🕗
        'en' : u':eight_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock8:'],
        'variant': True,
        'de': ':8.00_uhr:',
        'es': ':8_en_punto:',
        'fr': ':huit_heures:',
        'ja': u':8時:',
        'ko': u':여덟_시:',
        'pt': ':8_horas:',
        'it': ':ore_otto:',
        'fa': u':ساعت_هشت:',
        'id': ':jam_delapan_tepat:',
        'zh': u':八点:'
    },
    u'\U000023CF\U0000FE0F': { # ⏏️
        'en' : ':eject_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':eject_symbol:'],
        'variant': True,
        'de': ':auswerfen:',
        'es': ':expulsar:',
        'fr': u':bouton_éjecter:',
        'ja': u':取り出しボタン:',
        'ko': u':꺼냄_버튼:',
        'pt': u':botão_ejetar:',
        'it': ':pulsante_di_espulsione:',
        'fa': u':دکمه_خروج:',
        'id': ':tombol_keluarkan:',
        'zh': u':推出按钮:'
    },
    u'\U000023CF': { # ⏏
        'en' : ':eject_button:',
        'status' : unqualified,
        'E' : 1,
        'alias' : [':eject_symbol:'],
        'variant': True,
        'de': ':auswerfen:',
        'es': ':expulsar:',
        'fr': u':bouton_éjecter:',
        'ja': u':取り出しボタン:',
        'ko': u':꺼냄_버튼:',
        'pt': u':botão_ejetar:',
        'it': ':pulsante_di_espulsione:',
        'fa': u':دکمهٔ_خروج:',
        'id': ':tombol_keluarkan:',
        'zh': u':推出按钮:'
    },
    u'\U0001F50C': { # 🔌
        'en' : ':electric_plug:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':netzstecker:',
        'es': u':enchufe_eléctrico:',
        'fr': u':câble_avec_fiche_électrique:',
        'ja': u':コンセント:',
        'ko': u':전기_플러그:',
        'pt': u':tomada_elétrica:',
        'it': ':spina_elettrica:',
        'fa': u':دوشاخه:',
        'id': ':steker:',
        'zh': u':电源插头:'
    },
    u'\U0001F418': { # 🐘
        'en' : ':elephant:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':elefant:',
        'es': ':elefante:',
        'fr': u':éléphant:',
        'ja': u':ゾウ:',
        'ko': u':코끼리:',
        'pt': ':elefante:',
        'it': ':elefante:',
        'fa': u':فیل:',
        'id': ':gajah:',
        'zh': u':大象:'
    },
    u'\U0001F6D7': { # 🛗
        'en' : ':elevator:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':fahrstuhl:',
        'es': ':ascensor:',
        'fr': ':ascenseur:',
        'ja': u':エレベーター:',
        'ko': u':엘리베이터:',
        'pt': ':elevador:',
        'it': ':ascensore:',
        'fa': u':بالابر:',
        'id': ':elevator:',
        'zh': u':电梯:'
    },
    u'\U0001F566': { # 🕦
        'en' : ':eleven-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock1130:'],
        'variant': True,
        'de': ':11.30_uhr:',
        'es': ':once_y_media:',
        'fr': ':onze_heures_et_demie:',
        'ja': u':11時半:',
        'ko': u':열한_시_반:',
        'pt': ':onze_e_meia:',
        'it': ':ore_undici_e_mezza:',
        'fa': u':ساعت_یازده_و_نیم:',
        'id': ':jam_setengah_dua_belas:',
        'zh': u':十一点半:'
    },
    u'\U0001F55A': { # 🕚
        'en' : u':eleven_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock11:'],
        'variant': True,
        'de': ':11.00_uhr:',
        'es': ':11_en_punto:',
        'fr': ':onze_heures:',
        'ja': u':11時:',
        'ko': u':열한_시:',
        'pt': ':11_horas:',
        'it': ':ore_undici:',
        'fa': u':ساعت_یازده:',
        'id': ':jam_sebelas_tepat:',
        'zh': u':十一点:'
    },
    u'\U0001F9DD': { # 🧝
        'en' : ':elf:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf(e):',
        'es': ':elfo:',
        'fr': ':elfe:',
        'ja': u':エルフ:',
        'ko': u':엘프:',
        'pt': ':elfo:',
        'it': ':elfo:',
        'fa': u':اِلف:',
        'id': ':kurcaci:',
        'zh': u':小精灵:'
    },
    u'\U0001F9DD\U0001F3FF': { # 🧝🏿
        'en' : ':elf_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf(e)_dunkle_hautfarbe:',
        'es': ':elfo_tono_de_piel_oscuro:',
        'fr': u':elfe_peau_foncée:',
        'ja': u':エルフ_濃い肌色:',
        'ko': u':엘프_검은색_피부:',
        'pt': ':elfo_pele_escura:',
        'it': ':elfo_carnagione_scura:',
        'fa': u':اِلف_پوست_آبنوسی:',
        'id': ':kurcaci_warna_kulit_gelap:',
        'zh': u':小精灵_较深肤色:'
    },
    u'\U0001F9DD\U0001F3FB': { # 🧝🏻
        'en' : ':elf_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf(e)_helle_hautfarbe:',
        'es': ':elfo_tono_de_piel_claro:',
        'fr': ':elfe_peau_claire:',
        'ja': u':エルフ_薄い肌色:',
        'ko': u':엘프_하얀_피부:',
        'pt': ':elfo_pele_clara:',
        'it': ':elfo_carnagione_chiara:',
        'fa': u':اِلف_پوست_سفید:',
        'id': ':kurcaci_warna_kulit_cerah:',
        'zh': u':小精灵_较浅肤色:'
    },
    u'\U0001F9DD\U0001F3FE': { # 🧝🏾
        'en' : ':elf_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf(e)_mitteldunkle_hautfarbe:',
        'es': ':elfo_tono_de_piel_oscuro_medio:',
        'fr': ':elfe_peau_mate:',
        'ja': u':エルフ_やや濃い肌色:',
        'ko': u':엘프_진한_갈색_피부:',
        'pt': ':elfo_pele_morena_escura:',
        'it': ':elfo_carnagione_abbastanza_scura:',
        'fa': u':اِلف_پوست_گندمی:',
        'id': ':kurcaci_warna_kulit_gelap-sedang:',
        'zh': u':小精灵_中等深肤色:'
    },
    u'\U0001F9DD\U0001F3FC': { # 🧝🏼
        'en' : ':elf_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf(e)_mittelhelle_hautfarbe:',
        'es': ':elfo_tono_de_piel_claro_medio:',
        'fr': ':elfe_peau_moyennement_claire:',
        'ja': u':エルフ_やや薄い肌色:',
        'ko': u':엘프_연한_갈색_피부:',
        'pt': ':elfo_pele_morena_clara:',
        'it': ':elfo_carnagione_abbastanza_chiara:',
        'fa': u':اِلف_پوست_روشن:',
        'id': ':kurcaci_warna_kulit_cerah-sedang:',
        'zh': u':小精灵_中等浅肤色:'
    },
    u'\U0001F9DD\U0001F3FD': { # 🧝🏽
        'en' : ':elf_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf(e)_mittlere_hautfarbe:',
        'es': ':elfo_tono_de_piel_medio:',
        'fr': u':elfe_peau_légèrement_mate:',
        'ja': u':エルフ_中間の肌色:',
        'ko': u':엘프_갈색_피부:',
        'pt': ':elfo_pele_morena:',
        'it': ':elfo_carnagione_olivastra:',
        'fa': u':اِلف_پوست_طلایی:',
        'id': ':kurcaci_warna_kulit_sedang:',
        'zh': u':小精灵_中等肤色:'
    },
    u'\U0001FAB9': { # 🪹
        'en' : ':empty_nest:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':leeres_nest:',
        'es': u':nido_vacío:',
        'fr': ':nid_vide:',
        'ja': u':空っぽの巣:',
        'ko': u':빈_둥지:',
        'pt': ':ninho_vazio:',
        'it': ':nido_vuoto:',
        'fa': u':آشیانه_خالی:',
        'id': ':sarang_burung_kosong:',
        'zh': u':空巢:'
    },
    u'\U0001F621': { # 😡
        'en' : ':enraged_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':rage:', ':pout:'],
        'de': ':schmollendes_gesicht:',
        'es': ':cara_cabreada:',
        'fr': ':visage_boudeur:',
        'ja': u':ふくれっ面:',
        'ko': u':뾰로통한_얼굴:',
        'pt': ':rosto_furioso:',
        'it': ':faccina_accigliata:',
        'fa': u':خشمگین:',
        'id': ':wajah_sangat_marah:',
        'zh': u':怒火中烧:'
    },
    u'\U00002709\U0000FE0F': { # ✉️
        'en' : ':envelope:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':briefumschlag:',
        'es': ':sobre:',
        'fr': ':enveloppe:',
        'ja': u':封筒:',
        'ko': u':봉투:',
        'pt': ':envelope:',
        'it': ':busta:',
        'fa': u':پاکت_نامه:',
        'id': ':amplop:',
        'zh': u':信封:'
    },
    u'\U00002709': { # ✉
        'en' : ':envelope:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':briefumschlag:',
        'es': ':sobre:',
        'fr': ':enveloppe:',
        'ja': u':封筒:',
        'ko': u':봉투:',
        'pt': ':envelope:',
        'it': ':busta:',
        'fa': u':پاکت_نامه:',
        'id': ':amplop:',
        'zh': u':信封:'
    },
    u'\U0001F4E9': { # 📩
        'en' : ':envelope_with_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':umschlag_mit_pfeil:',
        'es': ':sobre_con_flecha:',
        'fr': u':enveloppe_avec_flèche:',
        'ja': u':メール受信:',
        'ko': u':보낸_편지:',
        'pt': ':envelope_com_seta:',
        'it': ':posta_in_uscita:',
        'fa': u':پاکت_نامه_با_پیکان:',
        'id': ':amplop_dengan_panah:',
        'zh': u':收邮件:'
    },
    u'\U0001F4B6': { # 💶
        'en' : ':euro_banknote:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':euro:'],
        'de': ':euro-banknote:',
        'es': ':billete_de_euro:',
        'fr': ':billet_en_euros:',
        'ja': u':ユーロ札:',
        'ko': u':유로:',
        'pt': ':nota_de_euro:',
        'it': ':banconota_euro:',
        'fa': u':اسکناس_یورو:',
        'id': ':uang_kertas_euro:',
        'zh': u':欧元:'
    },
    u'\U0001F332': { # 🌲
        'en' : ':evergreen_tree:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nadelbaum:',
        'es': u':árbol_de_hoja_perenne:',
        'fr': u':conifère:',
        'ja': u':常緑樹:',
        'ko': u':소나무:',
        'pt': u':conífera:',
        'it': ':albero_sempreverde:',
        'fa': u':همیشه_سبز:',
        'id': ':pohon_hijau_abadi:',
        'zh': u':松树:'
    },
    u'\U0001F411': { # 🐑
        'en' : ':ewe:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sheep:'],
        'de': ':schaf:',
        'es': ':oveja:',
        'fr': ':mouton:',
        'ja': u':羊:',
        'ko': u':양:',
        'pt': ':ovelha:',
        'it': ':pecora:',
        'fa': u':میش:',
        'id': ':domba_betina:',
        'zh': u':母羊:'
    },
    u'\U00002049\U0000FE0F': { # ⁉️
        'en' : ':exclamation_question_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':interrobang:'],
        'variant': True,
        'de': ':ausrufe-_und_fragezeichen:',
        'es': u':exclamación_e_interrogación:',
        'fr': u':points_d’exclamation_et_d’interrogation:',
        'ja': u':感嘆符疑問符:',
        'ko': u':느낌표와_물음표:',
        'pt': u':exclamação_com_interrogação:',
        'it': ':punto_esclamativo_e_interrogativo:',
        'fa': u':علامت_تعجب_و_سؤال:',
        'id': ':tanda_seru_dan_tanya:',
        'zh': u':感叹疑问号:'
    },
    u'\U00002049': { # ⁉
        'en' : ':exclamation_question_mark:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':interrobang:'],
        'variant': True,
        'de': ':ausrufe-_und_fragezeichen:',
        'es': u':exclamación_e_interrogación:',
        'fr': u':points_d’exclamation_et_d’interrogation:',
        'ja': u':感嘆符疑問符:',
        'ko': u':느낌표와_물음표:',
        'pt': u':exclamação_com_interrogação:',
        'it': ':punto_esclamativo_e_interrogativo:',
        'fa': u':علامت_تعجب_و_سؤال:',
        'id': ':tanda_seru_dan_tanya:',
        'zh': u':感叹疑问号:'
    },
    u'\U0001F92F': { # 🤯
        'en' : ':exploding_head:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':explodierender_kopf:',
        'es': ':cabeza_explotando:',
        'fr': u':tête_qui_explose:',
        'ja': u':頭爆発:',
        'ko': u':폭발하는_얼굴:',
        'pt': u':cabeça_explodindo:',
        'it': ':testa_che_esplode:',
        'fa': u':سر_منفجرشده:',
        'id': ':kepala_meledak:',
        'zh': u':爆炸头:'
    },
    u'\U0001F611': { # 😑
        'en' : ':expressionless_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':expressionless:'],
        'de': ':ausdrucksloses_gesicht:',
        'es': u':cara_sin_expresión:',
        'fr': ':visage_sans_expression:',
        'ja': u':無表情:',
        'ko': u':무표정한_얼굴:',
        'pt': ':rosto_inexpressivo:',
        'it': ':faccina_inespressiva:',
        'fa': u':صورت_بی_حالت:',
        'id': ':wajah_tanpa_ekspresi:',
        'zh': u':无语:'
    },
    u'\U0001F441\U0000FE0F': { # 👁️
        'en' : ':eye:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':auge:',
        'es': ':ojo:',
        'fr': u':œil:',
        'ja': u':片目:',
        'ko': u':눈:',
        'pt': ':olho:',
        'it': ':occhio:',
        'fa': u':چشم:',
        'id': ':satu_mata:',
        'zh': u':眼睛:'
    },
    u'\U0001F441': { # 👁
        'en' : ':eye:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':auge:',
        'es': ':ojo:',
        'fr': u':œil:',
        'ja': u':片目:',
        'ko': u':눈:',
        'pt': ':olho:',
        'it': ':occhio:',
        'fa': u':چشم:',
        'id': ':satu_mata:',
        'zh': u':眼睛:'
    },
    u'\U0001F441\U0000FE0F\U0000200D\U0001F5E8\U0000FE0F': { # 👁️‍🗨️
        'en' : ':eye_in_speech_bubble:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':eye_speech_bubble:'],
        'de': ':auge_in_sprechblase:',
        'es': ':ojo_en_bocadillo_de_texto:',
        'fr': u':œil_dans_une_bulle_de_bd:',
        'ja': u':吹き出しの目:',
        'ko': u':말풍선_속_눈:',
        'pt': u':olho_no_balão_de_diálogo:',
        'it': ':occhio_nel_fumetto:',
        'fa': u':چشم_در_حباب_گفتار:',
        'id': ':mata_di_dalam_gelembung_ucapan:',
        'zh': u':眼睛对话框:'
    },
    u'\U0001F441\U0000200D\U0001F5E8\U0000FE0F': { # 👁‍🗨️
        'en' : ':eye_in_speech_bubble:',
        'status' : unqualified,
        'E' : 2,
        'alias' : [':eye_speech_bubble:'],
        'de': ':auge_in_sprechblase:',
        'es': ':ojo_en_bocadillo_de_texto:',
        'fr': u':œil_dans_une_bulle_de_bd:',
        'ja': u':吹き出しの目:',
        'ko': u':말풍선_속_눈:',
        'pt': u':olho_no_balão_de_diálogo:',
        'it': ':occhio_nel_fumetto:',
        'fa': u':چشم_در_حباب_گفتار:',
        'id': ':mata_di_dalam_gelembung_ucapan:',
        'zh': u':眼睛对话框:'
    },
    u'\U0001F441\U0000FE0F\U0000200D\U0001F5E8': { # 👁️‍🗨
        'en' : ':eye_in_speech_bubble:',
        'status' : minimally_qualified,
        'E' : 2,
        'alias' : [':eye_speech_bubble:'],
        'de': ':auge_in_sprechblase:',
        'es': ':ojo_en_bocadillo_de_texto:',
        'fr': u':œil_dans_une_bulle_de_bd:',
        'ja': u':吹き出しの目:',
        'ko': u':말풍선_속_눈:',
        'pt': u':olho_no_balão_de_diálogo:',
        'it': ':occhio_nel_fumetto:',
        'fa': u':چشم_در_حباب_گفتار:',
        'id': ':mata_di_dalam_gelembung_ucapan:',
        'zh': u':眼睛对话框:'
    },
    u'\U0001F441\U0000200D\U0001F5E8': { # 👁‍🗨
        'en' : ':eye_in_speech_bubble:',
        'status' : unqualified,
        'E' : 2,
        'alias' : [':eye_speech_bubble:'],
        'de': ':auge_in_sprechblase:',
        'es': ':ojo_en_bocadillo_de_texto:',
        'fr': u':œil_dans_une_bulle_de_bd:',
        'ja': u':吹き出しの目:',
        'ko': u':말풍선_속_눈:',
        'pt': u':olho_no_balão_de_diálogo:',
        'it': ':occhio_nel_fumetto:',
        'fa': u':چشم_در_حباب_گفتار:',
        'id': ':mata_di_dalam_gelembung_ucapan:',
        'zh': u':眼睛对话框:'
    },
    u'\U0001F440': { # 👀
        'en' : ':eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':augen:',
        'es': ':ojos:',
        'fr': ':yeux:',
        'ja': u':目:',
        'ko': u':왕눈이_눈알:',
        'pt': ':olhos:',
        'it': ':occhi:',
        'fa': u':دو_چشم:',
        'id': ':dua_mata:',
        'zh': u':双眼:'
    },
    u'\U0001F618': { # 😘
        'en' : ':face_blowing_a_kiss:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':kissing_heart:'],
        'de': ':kuss_zuwerfendes_gesicht:',
        'es': ':cara_lanzando_un_beso:',
        'fr': ':visage_envoyant_un_bisou:',
        'ja': u':投げキッス:',
        'ko': u':키스를_보내는_얼굴:',
        'pt': ':rosto_mandando_um_beijo:',
        'it': ':faccina_che_manda_un_bacio:',
        'fa': u':بوسه_فرستادن:',
        'id': ':wajah_memberikan_ciuman_jauh:',
        'zh': u':飞吻:'
    },
    u'\U0001F62E\U0000200D\U0001F4A8': { # 😮‍💨
        'en' : ':face_exhaling:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':gesicht_das_ausatmet:',
        'es': ':cara_exhalando:',
        'fr': ':visage_expirant:',
        'ja': u':息を吐く顔:',
        'ko': u':날숨_쉬는_얼굴:',
        'pt': ':rosto_exalando:',
        'it': ':faccina_che_espira:',
        'fa': u':صورتک_در_حال_بازدم:',
        'id': ':wajah_mengembuskan_napas:',
        'zh': u':呼气:'
    },
    u'\U0001F979': { # 🥹
        'en' : ':face_holding_back_tears:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':gesicht_das_tränen_zurückhält:',
        'es': u':cara_aguantándose_las_lágrimas:',
        'fr': ':visage_retenant_ses_larmes:',
        'ja': u':涙をこらえた顔:',
        'ko': u':눈물을_참는_얼굴:',
        'pt': u':rosto_segurando_as_lágrimas:',
        'it': ':faccina_che_trattiene_le_lacrime:',
        'fa': u':چهره_با_چشمان_پراشک:',
        'id': ':wajah_menahan_air_mata:',
        'zh': u':忍住泪水:'
    },
    u'\U0001F636\U0000200D\U0001F32B\U0000FE0F': { # 😶‍🌫️
        'en' : ':face_in_clouds:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':gesicht_in_wolken:',
        'es': ':cara_en_las_nubes:',
        'fr': ':visage_dans_les_nuages:',
        'ja': u':雲の中の顔:',
        'ko': u':공상에_잠긴_얼굴:',
        'pt': ':rosto_nas_nuvens:',
        'it': ':testa_tra_le_nuvole:',
        'fa': u':صورتک_میان_ابر:',
        'zh': u':迷茫:'
    },
    u'\U0001F636\U0000200D\U0001F32B': { # 😶‍🌫
        'en' : ':face_in_clouds:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':gesicht_in_wolken:',
        'es': ':cara_en_las_nubes:',
        'fr': ':visage_dans_les_nuages:',
        'ja': u':雲の中の顔:',
        'ko': u':공상에_잠긴_얼굴:',
        'pt': ':rosto_nas_nuvens:',
        'it': ':testa_tra_le_nuvole:',
        'fa': u':صورتک_میان_ابر:',
        'zh': u':迷茫:'
    },
    u'\U0001F60B': { # 😋
        'en' : ':face_savoring_food:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':yum:'],
        'de': ':sich_die_lippen_leckendes_gesicht:',
        'es': ':cara_saboreando_comida:',
        'fr': ':miam:',
        'ja': u':にこにこぺろり:',
        'ko': u':맛있는_음식을_음미하는_얼굴:',
        'pt': ':rosto_saboreando_comida:',
        'it': ':faccina_che_si_lecca_i_baffi:',
        'fa': u':صورت_با_زبان_آب_افتاده:',
        'id': ':wajah_menikmati:',
        'zh': u':好吃:'
    },
    u'\U0001F631': { # 😱
        'en' : ':face_screaming_in_fear:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':scream:'],
        'de': ':vor_angst_schreiendes_gesicht:',
        'es': ':cara_gritando_de_miedo:',
        'fr': ':visage_qui_hurle_de_peur:',
        'ja': u':恐怖:',
        'ko': u':공포에_절규하는_얼굴:',
        'pt': ':rosto_gritando_de_medo:',
        'it': ':faccina_terrorizzata:',
        'fa': u':جیغ_ترس:',
        'id': ':wajah_sangat_ketakutan:',
        'zh': u':吓死了:'
    },
    u'\U0001F92E': { # 🤮
        'en' : ':face_vomiting:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':vomiting_face:'],
        'de': ':kotzendes_gesicht:',
        'es': ':cara_vomitando:',
        'fr': ':visage_qui_vomit:',
        'ja': u':嘔吐する顔:',
        'ko': u':토하는_얼굴:',
        'pt': ':rosto_vomitando:',
        'it': ':faccina_che_vomita:',
        'fa': u':درحال_استفراغ:',
        'id': ':wajah_muntah:',
        'zh': u':呕吐:'
    },
    u'\U0001F635': { # 😵
        'en' : ':face_with_crossed-out_eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dizzy_face:'],
        'de': ':benommenes_gesicht:',
        'es': ':cara_mareada:',
        'fr': u':visage_étourdi:',
        'ja': u':めまい:',
        'ko': u':어지러운_얼굴:',
        'pt': ':rosto_atordoado:',
        'it': ':faccina_frastornata:',
        'fa': u':گیج:',
        'id': ':wajah_pusing:',
        'zh': u':晕头转向:'
    },
    u'\U0001FAE4': { # 🫤
        'en' : ':face_with_diagonal_mouth:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':gesicht_mit_schrägem_mund:',
        'es': ':cara_con_boca_diagonal:',
        'fr': ':visage_avec_bouche_en_diagonale:',
        'ja': u':口が斜めの顔:',
        'ko': u':입이_한쪽으로_올라간_얼굴:',
        'pt': ':rosto_com_boca_diagonal:',
        'it': ':faccina_perplessa:',
        'fa': u':صورت_با_دهان_کج:',
        'id': ':wajah_dengan_mulut_diagonal:',
        'zh': u':郁闷:'
    },
    u'\U0001F92D': { # 🤭
        'en' : ':face_with_hand_over_mouth:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':hand_over_mouth:'],
        'de': ':verlegen_kicherndes_gesicht:',
        'es': ':cara_con_mano_sobre_la_boca:',
        'fr': ':visage_avec_une_main_sur_la_bouche:',
        'ja': u':口に手を当てた顔:',
        'ko': u':손으로_입을_가린_얼굴:',
        'pt': u':rosto_com_a_mão_sobre_a_boca:',
        'it': ':faccina_con_mano_sulla_bocca:',
        'fa': u':دست_روی_دهن:',
        'id': ':wajah_dengan_tangan_menutup_mulut:',
        'zh': u':不说:'
    },
    u'\U0001F915': { # 🤕
        'en' : ':face_with_head-bandage:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':face_with_head_bandage:', ':face_with_head__bandage:'],
        'de': ':gesicht_mit_kopfverband:',
        'es': ':cara_con_la_cabeza_vendada:',
        'fr': u':visage_avec_bandage_autour_de_la_tête:',
        'ja': u':包帯を巻いた顔:',
        'ko': u':머리에_붕대를_감은_얼굴:',
        'pt': u':rosto_com_atadura_na_cabeça:',
        'it': ':faccina_con_la_testa_bendata:',
        'fa': u':سر_باندپیچی_شده:',
        'id': ':wajah_diperban_di_kepala:',
        'zh': u':受伤:'
    },
    u'\U0001F637': { # 😷
        'en' : ':face_with_medical_mask:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mask:'],
        'de': ':gesicht_mit_atemschutzmaske:',
        'es': u':cara_con_mascarilla_médica:',
        'fr': ':visage_avec_masque:',
        'ja': u':マスク顔:',
        'ko': u':마스크_낀_얼굴:',
        'pt': u':rosto_com_máscara_médica:',
        'it': ':faccina_con_mascherina:',
        'fa': u':صورت_با_ماسک_پزشکی:',
        'id': ':wajah_bermasker:',
        'zh': u':感冒:'
    },
    u'\U0001F9D0': { # 🧐
        'en' : ':face_with_monocle:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':monocle_face:'],
        'de': ':gesicht_mit_monokel:',
        'es': u':cara_con_monóculo:',
        'fr': ':visage_avec_un_monocle:',
        'ja': u':モノクルを付けた顔:',
        'ko': u':단안경을_쓴_얼굴:',
        'pt': u':rosto_com_monóculo:',
        'it': ':faccina_con_monocolo:',
        'fa': u':صورت_با_عینک_یک_چشمی:',
        'id': ':wajah_dengan_monokel:',
        'zh': u':带单片眼镜的脸:'
    },
    u'\U0001FAE2': { # 🫢
        'en' : ':face_with_open_eyes_and_hand_over_mouth:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':gesicht_mit_offenen_augen_und_hand_über_dem_mund:',
        'es': ':cara_con_ojos_abiertos_y_boca_tapada:',
        'fr': ':visage_avec_yeux_ouverts_et_main_sur_la_bouche:',
        'ja': u':目を開けて口に手を当てた顔:',
        'ko': u':눈을_뜨고_손으로_입을_가린_얼굴:',
        'pt': u':rosto_com_olhos_abertos_e_mão_sobre_a_boca:',
        'it': ':faccina_con_occhi_aperti_e_mano_sulla_bocca:',
        'fa': u':چهره_با_چشمان_باز_و_دست_روی_دهان:',
        'id': ':wajah_dengan_mata_terbuka_dan_tangan_menutupi_mulut:',
        'zh': u':睁眼捂嘴:'
    },
    u'\U0001F62E': { # 😮
        'en' : ':face_with_open_mouth:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':open_mouth:'],
        'de': ':gesicht_mit_offenem_mund:',
        'es': ':cara_con_la_boca_abierta:',
        'fr': ':visage_avec_bouche_ouverte:',
        'ja': u':口が開いた顔:',
        'ko': u':입벌린_얼굴:',
        'pt': ':rosto_com_boca_aberta:',
        'it': ':faccina_con_bocca_aperta:',
        'fa': u':دهان_باز_از_تعجب:',
        'id': ':wajah_dengan_mulut_terbuka:',
        'zh': u':吃惊:'
    },
    u'\U0001FAE3': { # 🫣
        'en' : ':face_with_peeking_eye:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':gesicht_mit_durch_die_finger_linsendem_auge:',
        'es': ':cara_tapada_con_ojo_espiando:',
        'fr': ':visage_qui_regarde_entre_ses_doigts:',
        'ja': u':指の間からのぞき見る顔:',
        'ko': u':한쪽_눈을_가리고_훔쳐보는_얼굴:',
        'pt': ':rosto_com_olho_espiando:',
        'it': ':faccina_che_sbircia_tra_le_dita:',
        'fa': u':چهره_با_نگاه_دزدکی:',
        'id': ':wajah_dengan_mata_mengintip:',
        'zh': u':偷看:'
    },
    u'\U0001F928': { # 🤨
        'en' : ':face_with_raised_eyebrow:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':raised_eyebrow:'],
        'de': ':gesicht_mit_hochgezogenen_augenbrauen:',
        'es': ':cara_con_ceja_alzada:',
        'fr': u':visage_avec_les_sourcils_relevés:',
        'ja': u':眉を上げた顔:',
        'ko': u':눈썹을_치켜올린_얼굴:',
        'pt': ':rosto_com_sobrancelha_levantada:',
        'it': ':faccia_con_sopracciglia_alzate:',
        'fa': u':صورت_با_ابروی_بالاداده:',
        'id': ':wajah_dengan_alis_terangkat:',
        'zh': u':挑眉:'
    },
    u'\U0001F644': { # 🙄
        'en' : ':face_with_rolling_eyes:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':roll_eyes:'],
        'de': ':augen_verdrehendes_gesicht:',
        'es': ':cara_con_ojos_en_blanco:',
        'fr': ':visage_roulant_des_yeux:',
        'ja': u':上を見る顔:',
        'ko': u':눈을_굴리고_있는_얼굴:',
        'pt': ':rosto_com_olhos_revirados:',
        'it': ':faccina_con_occhi_al_cielo:',
        'fa': u':نگاه_کلافه:',
        'id': ':wajah_dengan_mata_ke_atas:',
        'zh': u':翻白眼:'
    },
    u'\U0001F635\U0000200D\U0001F4AB': { # 😵‍💫
        'en' : ':face_with_spiral_eyes:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':gesicht_mit_spiralen_als_augen:',
        'es': ':cara_con_ojos_de_espiral:',
        'fr': ':visage_aux_yeux_en_spirales:',
        'ja': u':目を回した顔:',
        'ko': u':현기증_난_얼굴:',
        'pt': ':rosto_com_olhos_em_espiral:',
        'it': ':faccina_con_occhi_a_spirale:',
        'fa': u':صورتک_با_چشمان_چرخشی:',
        'id': ':wajah_dengan_mata_berputar:',
        'zh': u':晕:'
    },
    u'\U0001F624': { # 😤
        'en' : ':face_with_steam_from_nose:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':triumph:'],
        'de': ':schnaubendes_gesicht:',
        'es': ':cara_resoplando:',
        'fr': u':visage_avec_fumée_sortant_des_narines:',
        'ja': u':勝ち誇った顔:',
        'ko': u':화내며_씩씩거리는_얼굴:',
        'pt': ':rosto_soltando_vapor_pelo_nariz:',
        'it': ':faccina_che_sbuffa:',
        'fa': u':ژست_برندگی_با_دلخوری:',
        'id': ':wajah_bersungguh-sungguh:',
        'zh': u':傲慢:'
    },
    u'\U0001F92C': { # 🤬
        'en' : ':face_with_symbols_on_mouth:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':cursing_face:'],
        'de': u':gesicht_mit_symbolen_über_dem_mund:',
        'es': u':cara_con_símbolos_en_la_boca:',
        'fr': ':visage_avec_des_symboles_dans_la_bouche:',
        'ja': u':ののしる:',
        'ko': u':욕하는_얼굴:',
        'pt': u':rosto_com_símbolos_na_boca:',
        'it': ':faccina_con_simboli_sulla_bocca:',
        'fa': u':صورت_با_نمادهایی_روی_دهان:',
        'id': ':wajah_dengan_simbol_pada_mulut:',
        'zh': u':嘴上有符号的脸:'
    },
    u'\U0001F602': { # 😂
        'en' : ':face_with_tears_of_joy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':joy:'],
        'de': u':gesicht_mit_freudentränen:',
        'es': ':cara_llorando_de_risa:',
        'fr': ':visage_riant_aux_larmes:',
        'ja': u':嬉し泣き:',
        'ko': u':기쁨의_눈물을_흘리는_얼굴:',
        'pt': ':rosto_chorando_de_rir:',
        'it': ':faccina_con_lacrime_di_gioia:',
        'fa': u':روده_بر:',
        'id': ':wajah_gembira_berurai_air_mata:',
        'zh': u':笑哭了:'
    },
    u'\U0001F912': { # 🤒
        'en' : ':face_with_thermometer:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':gesicht_mit_fieberthermometer:',
        'es': u':cara_con_termómetro:',
        'fr': u':visage_avec_thermomètre:',
        'ja': u':熱がある顔:',
        'ko': u':체온계를_물고_있는_얼굴:',
        'pt': u':rosto_com_termômetro:',
        'it': ':faccina_con_termometro:',
        'fa': u':تب_دار:',
        'id': ':wajah_bertermometer:',
        'zh': u':发烧:'
    },
    u'\U0001F61B': { # 😛
        'en' : ':face_with_tongue:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':stuck_out_tongue:'],
        'de': ':gesicht_mit_herausgestreckter_zunge:',
        'es': ':cara_sacando_la_lengua:',
        'fr': ':visage_qui_tire_la_langue:',
        'ja': u':舌を出した顔:',
        'ko': u':혀를_내민_얼굴:',
        'pt': u':rosto_mostrando_a_língua:',
        'it': ':faccina_che_mostra_la_lingua:',
        'fa': u':زبونک:',
        'id': ':wajah_menjulurkan_lidah:',
        'zh': u':吐舌:'
    },
    u'\U0001F636': { # 😶
        'en' : ':face_without_mouth:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':no_mouth:'],
        'de': ':gesicht_ohne_mund:',
        'es': ':cara_sin_boca:',
        'fr': ':visage_sans_bouche:',
        'ja': u':口のない顔:',
        'ko': u':입이_없는_얼굴:',
        'pt': ':rosto_sem_boca:',
        'it': ':faccina_senza_bocca:',
        'fa': u':صورت_بدون_لب:',
        'id': ':wajah_tanpa_mulut:',
        'zh': u':沉默:'
    },
    u'\U0001F3ED': { # 🏭
        'en' : ':factory:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':fabrik:',
        'es': u':fábrica:',
        'fr': ':usine:',
        'ja': u':工場:',
        'ko': u':공장:',
        'pt': u':fábrica:',
        'it': ':fabbrica:',
        'fa': u':کارخانه:',
        'id': ':pabrik:',
        'zh': u':工厂:'
    },
    u'\U0001F9D1\U0000200D\U0001F3ED': { # 🧑‍🏭
        'en' : ':factory_worker:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':fabrikarbeiter(in):',
        'es': ':profesional_industrial:',
        'fr': ':ouvrier_(tous_genres):',
        'ja': u':溶接工:',
        'ko': u':공장_직원:',
        'pt': u':funcionário_de_fábrica:',
        'it': ':persona_che_lavora_in_fabbrica:',
        'fa': u':کارگر_کارخانه:',
        'id': ':pekerja_pabrik:',
        'zh': u':工人:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F3ED': { # 🧑🏿‍🏭
        'en' : ':factory_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':fabrikarbeiter(in)_dunkle_hautfarbe:',
        'es': ':profesional_industrial_tono_de_piel_oscuro:',
        'fr': u':ouvrier_(tous_genres)_peau_foncée:',
        'ja': u':溶接工_濃い肌色:',
        'ko': u':공장_직원_검은색_피부:',
        'pt': u':funcionário_de_fábrica_pele_escura:',
        'it': ':persona_che_lavora_in_fabbrica_carnagione_scura:',
        'fa': u':کارگر_کارخانه_پوست_آبنوسی:',
        'id': ':pekerja_pabrik_warna_kulit_gelap:',
        'zh': u':工人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F3ED': { # 🧑🏻‍🏭
        'en' : ':factory_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':fabrikarbeiter(in)_helle_hautfarbe:',
        'es': ':profesional_industrial_tono_de_piel_claro:',
        'fr': ':ouvrier_(tous_genres)_peau_claire:',
        'ja': u':溶接工_薄い肌色:',
        'ko': u':공장_직원_하얀_피부:',
        'pt': u':funcionário_de_fábrica_pele_clara:',
        'it': ':persona_che_lavora_in_fabbrica_carnagione_chiara:',
        'fa': u':کارگر_کارخانه_پوست_سفید:',
        'id': ':pekerja_pabrik_warna_kulit_cerah:',
        'zh': u':工人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F3ED': { # 🧑🏾‍🏭
        'en' : ':factory_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':fabrikarbeiter(in)_mitteldunkle_hautfarbe:',
        'es': ':profesional_industrial_tono_de_piel_oscuro_medio:',
        'fr': ':ouvrier_(tous_genres)_peau_mate:',
        'ja': u':溶接工_やや濃い肌色:',
        'ko': u':공장_직원_진한_갈색_피부:',
        'pt': u':funcionário_de_fábrica_pele_morena_escura:',
        'it': ':persona_che_lavora_in_fabbrica_carnagione_abbastanza_scura:',
        'fa': u':کارگر_کارخانه_پوست_گندمی:',
        'id': ':pekerja_pabrik_warna_kulit_gelap-sedang:',
        'zh': u':工人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F3ED': { # 🧑🏼‍🏭
        'en' : ':factory_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':fabrikarbeiter(in)_mittelhelle_hautfarbe:',
        'es': ':profesional_industrial_tono_de_piel_claro_medio:',
        'fr': ':ouvrier_(tous_genres)_peau_moyennement_claire:',
        'ja': u':溶接工_やや薄い肌色:',
        'ko': u':공장_직원_연한_갈색_피부:',
        'pt': u':funcionário_de_fábrica_pele_morena_clara:',
        'it': ':persona_che_lavora_in_fabbrica_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_کارخانه_پوست_روشن:',
        'id': ':pekerja_pabrik_warna_kulit_cerah-sedang:',
        'zh': u':工人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F3ED': { # 🧑🏽‍🏭
        'en' : ':factory_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':fabrikarbeiter(in)_mittlere_hautfarbe:',
        'es': ':profesional_industrial_tono_de_piel_medio:',
        'fr': u':ouvrier_(tous_genres)_peau_légèrement_mate:',
        'ja': u':溶接工_中間の肌色:',
        'ko': u':공장_직원_갈색_피부:',
        'pt': u':funcionário_de_fábrica_pele_morena:',
        'it': ':persona_che_lavora_in_fabbrica_carnagione_olivastra:',
        'fa': u':کارگر_کارخانه_پوست_طلایی:',
        'id': ':pekerja_pabrik_warna_kulit_sedang:',
        'zh': u':工人_中等肤色:'
    },
    u'\U0001F9DA': { # 🧚
        'en' : ':fairy:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':märchenfee:',
        'es': ':hada:',
        'fr': u':personnage_féérique:',
        'ja': u':妖精:',
        'ko': u':요정:',
        'pt': ':fada:',
        'it': ':fata:',
        'fa': u':پری:',
        'id': ':peri:',
        'zh': u':精灵:'
    },
    u'\U0001F9DA\U0001F3FF': { # 🧚🏿
        'en' : ':fairy_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':märchenfee_dunkle_hautfarbe:',
        'es': ':hada_tono_de_piel_oscuro:',
        'fr': u':personnage_féérique_peau_foncée:',
        'ja': u':妖精_濃い肌色:',
        'ko': u':요정_검은색_피부:',
        'pt': ':fada_pele_escura:',
        'it': ':fata_carnagione_scura:',
        'fa': u':پری_پوست_آبنوسی:',
        'id': ':peri_warna_kulit_gelap:',
        'zh': u':精灵_较深肤色:'
    },
    u'\U0001F9DA\U0001F3FB': { # 🧚🏻
        'en' : ':fairy_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':märchenfee_helle_hautfarbe:',
        'es': ':hada_tono_de_piel_claro:',
        'fr': u':personnage_féérique_peau_claire:',
        'ja': u':妖精_薄い肌色:',
        'ko': u':요정_하얀_피부:',
        'pt': ':fada_pele_clara:',
        'it': ':fata_carnagione_chiara:',
        'fa': u':پری_پوست_سفید:',
        'id': ':peri_warna_kulit_cerah:',
        'zh': u':精灵_较浅肤色:'
    },
    u'\U0001F9DA\U0001F3FE': { # 🧚🏾
        'en' : ':fairy_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':märchenfee_mitteldunkle_hautfarbe:',
        'es': ':hada_tono_de_piel_oscuro_medio:',
        'fr': u':personnage_féérique_peau_mate:',
        'ja': u':妖精_やや濃い肌色:',
        'ko': u':요정_진한_갈색_피부:',
        'pt': ':fada_pele_morena_escura:',
        'it': ':fata_carnagione_abbastanza_scura:',
        'fa': u':پری_پوست_گندمی:',
        'id': ':peri_warna_kulit_gelap-sedang:',
        'zh': u':精灵_中等深肤色:'
    },
    u'\U0001F9DA\U0001F3FC': { # 🧚🏼
        'en' : ':fairy_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':märchenfee_mittelhelle_hautfarbe:',
        'es': ':hada_tono_de_piel_claro_medio:',
        'fr': u':personnage_féérique_peau_moyennement_claire:',
        'ja': u':妖精_やや薄い肌色:',
        'ko': u':요정_연한_갈색_피부:',
        'pt': ':fada_pele_morena_clara:',
        'it': ':fata_carnagione_abbastanza_chiara:',
        'fa': u':پری_پوست_روشن:',
        'id': ':peri_warna_kulit_cerah-sedang:',
        'zh': u':精灵_中等浅肤色:'
    },
    u'\U0001F9DA\U0001F3FD': { # 🧚🏽
        'en' : ':fairy_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':märchenfee_mittlere_hautfarbe:',
        'es': ':hada_tono_de_piel_medio:',
        'fr': u':personnage_féérique_peau_légèrement_mate:',
        'ja': u':妖精_中間の肌色:',
        'ko': u':요정_갈색_피부:',
        'pt': ':fada_pele_morena:',
        'it': ':fata_carnagione_olivastra:',
        'fa': u':پری_پوست_طلایی:',
        'id': ':peri_warna_kulit_sedang:',
        'zh': u':精灵_中等肤色:'
    },
    u'\U0001F9C6': { # 🧆
        'en' : ':falafel:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':falafel:',
        'es': ':falafel:',
        'fr': ':falafels:',
        'ja': u':ファラフェル:',
        'ko': u':팔라펠:',
        'pt': ':falafel:',
        'it': ':falafel:',
        'fa': u':فلافل:',
        'id': ':falafel:',
        'zh': u':炸豆丸子:'
    },
    u'\U0001F342': { # 🍂
        'en' : ':fallen_leaf:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':laub:',
        'es': u':hojas_caídas:',
        'fr': ':feuille_morte:',
        'ja': u':落ち葉:',
        'ko': u':낙엽:',
        'pt': u':folhas_caídas:',
        'it': ':foglia_caduta:',
        'fa': u':برگ_ریزان:',
        'id': ':daun_berguguran:',
        'zh': u':落叶:'
    },
    u'\U0001F46A': { # 👪
        'en' : ':family:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':familie:',
        'es': ':familia:',
        'fr': ':famille:',
        'ja': u':家族:',
        'ko': u':가족:',
        'pt': u':família:',
        'it': ':famiglia:',
        'fa': u':خانواده:',
        'id': ':keluarga:',
        'zh': u':家庭:'
    },
    u'\U0001F468\U0000200D\U0001F466': { # 👨‍👦
        'en' : ':family_man_boy:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':familie_mann,_junge:',
        'es': u':familia_hombre_y_niño:',
        'fr': u':famille_homme_et_garçon:',
        'ja': u':家族_男性_男の子:',
        'ko': u':가족_남자_남자_아이:',
        'pt': u':família_homem_e_menino:',
        'it': ':famiglia_uomo_e_bambino:',
        'fa': u':خانواده_مرد_پسر:',
        'id': ':keluarga_pria_anak_laki-laki:',
        'zh': u':家庭_男人男孩:'
    },
    u'\U0001F468\U0000200D\U0001F466\U0000200D\U0001F466': { # 👨‍👦‍👦
        'en' : ':family_man_boy_boy:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':familie_mann,_junge_und_junge:',
        'es': u':familia_hombre_niño_niño:',
        'fr': u':famille_homme,_garçon_et_garçon:',
        'ja': u':家族_男性_男の子_男の子:',
        'ko': u':가족_남자_남자_아이_남자_아이:',
        'pt': u':família_homem_menino_e_menino:',
        'it': ':famiglia_uomo_bambino_e_bambino:',
        'fa': u':خانواده_مرد_پسر_و_پسر:',
        'id': ':keluarga_pria_anak_laki-laki_anak_laki-laki:',
        'zh': u':家庭_男人男孩男孩:'
    },
    u'\U0001F468\U0000200D\U0001F467': { # 👨‍👧
        'en' : ':family_man_girl:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':familie_mann,_mädchen:',
        'es': u':familia_hombre_y_niña:',
        'fr': ':famille_homme_et_fille:',
        'ja': u':家族_男性_女の子:',
        'ko': u':가족_남자_여자_아이:',
        'pt': u':família_homem_e_menina:',
        'it': ':famiglia_uomo_e_bambina:',
        'fa': u':خانواده_مرد_دختر:',
        'id': ':keluarga_pria_anak_perempuan:',
        'zh': u':家庭_男人女孩:'
    },
    u'\U0001F468\U0000200D\U0001F467\U0000200D\U0001F466': { # 👨‍👧‍👦
        'en' : ':family_man_girl_boy:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':familie_mann,_mädchen_und_junge:',
        'es': u':familia_hombre_niña_niño:',
        'fr': u':famille_homme,_fille_et_garçon:',
        'ja': u':家族_男性_女の子_男の子:',
        'ko': u':가족_남자_여자_아이_남자_아이:',
        'pt': u':família_homem_menina_e_menino:',
        'it': ':famiglia_uomo_bambina_e_bambino:',
        'fa': u':خانواده_مرد_دختر_و_پسر:',
        'id': ':keluarga_pria_anak_perempuan_anak_laki-laki:',
        'zh': u':家庭_男人女孩男孩:'
    },
    u'\U0001F468\U0000200D\U0001F467\U0000200D\U0001F467': { # 👨‍👧‍👧
        'en' : ':family_man_girl_girl:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':familie_mann,_mädchen_und_mädchen:',
        'es': u':familia_hombre_niña_niña:',
        'fr': ':famille_homme,_fille_et_fille:',
        'ja': u':家族_男性_女の子_女の子:',
        'ko': u':가족_남자_여자_아이_여자_아이:',
        'pt': u':família_homem_menina_e_menina:',
        'it': ':famiglia_uomo_bambina_e_bambina:',
        'fa': u':خانواده_مرد_دختر_و_دختر:',
        'id': ':keluarga_pria_anak_perempuan_anak_perempuan:',
        'zh': u':家庭_男人女孩女孩:'
    },
    u'\U0001F468\U0000200D\U0001F468\U0000200D\U0001F466': { # 👨‍👨‍👦
        'en' : ':family_man_man_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':familie_mann,_mann_und_junge:',
        'es': u':familia_hombre_hombre_niño:',
        'fr': u':famille_homme,_homme_et_garçon:',
        'ja': u':家族_男性_男性_男の子:',
        'ko': u':가족_남자_남자_남자_아이:',
        'pt': u':família_homem_homem_e_menino:',
        'it': ':famiglia_uomo_uomo_e_bambino:',
        'fa': u':خانواده_مرد_مرد_و_پسر:',
        'id': ':keluarga_pria_pria_anak_laki-laki:',
        'zh': u':家庭_男人男人男孩:'
    },
    u'\U0001F468\U0000200D\U0001F468\U0000200D\U0001F466\U0000200D\U0001F466': { # 👨‍👨‍👦‍👦
        'en' : ':family_man_man_boy_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':familie_mann,_mann,_junge_und_junge:',
        'es': u':familia_hombre_hombre_niño_niño:',
        'fr': u':famille_homme,_homme,_garçon_et_garçon:',
        'ja': u':家族_男性_男性_男の子_男の子:',
        'ko': u':가족_남자_남자_남자_아이_남자_아이:',
        'pt': u':família_homem_homem_menino_e_menino:',
        'it': ':famiglia_uomo_uomo_bambino_e_bambino:',
        'fa': u':خانواده_مرد_مرد_پسر_و_پسر:',
        'id': ':keluarga_pria_pria_anak_laki-laki_anak_laki-laki:',
        'zh': u':家庭_男人男人男孩男孩:'
    },
    u'\U0001F468\U0000200D\U0001F468\U0000200D\U0001F467': { # 👨‍👨‍👧
        'en' : ':family_man_man_girl:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_mann,_mann_und_mädchen:',
        'es': u':familia_hombre_hombre_niña:',
        'fr': ':famille_homme,_homme_et_fille:',
        'ja': u':家族_男性_男性_女の子:',
        'ko': u':가족_남자_남자_여자_아이:',
        'pt': u':família_homem_homem_e_menina:',
        'it': ':famiglia_uomo_uomo_e_bambina:',
        'fa': u':خانواده_مرد_مرد_و_دختر:',
        'id': ':keluarga_pria_pria_anak_perempuan:',
        'zh': u':家庭_男人男人女孩:'
    },
    u'\U0001F468\U0000200D\U0001F468\U0000200D\U0001F467\U0000200D\U0001F466': { # 👨‍👨‍👧‍👦
        'en' : ':family_man_man_girl_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_mann,_mann,_mädchen_und_junge:',
        'es': u':familia_hombre_hombre_niña_niño:',
        'fr': u':famille_homme,_homme,_fille_et_garçon:',
        'ja': u':家族_男性_男性_女の子_男の子:',
        'ko': u':가족_남자_남자_여자_아이_남자_아이:',
        'pt': u':família_homem_homem_menina_e_menino:',
        'it': ':famiglia_uomo_uomo_bambina_e_bambino:',
        'fa': u':خانواده_مرد_مرد_دختر_و_پسر:',
        'id': ':keluarga_pria_pria_anak_perempuan_anak_laki-laki:',
        'zh': u':家庭_男人男人女孩男孩:'
    },
    u'\U0001F468\U0000200D\U0001F468\U0000200D\U0001F467\U0000200D\U0001F467': { # 👨‍👨‍👧‍👧
        'en' : ':family_man_man_girl_girl:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_mann,_mann,_mädchen_und_mädchen:',
        'es': u':familia_hombre_hombre_niña_niña:',
        'fr': ':famille_homme,_homme,_fille_et_fille:',
        'ja': u':家族_男性_男性_女の子_女の子:',
        'ko': u':가족_남자_남자_여자_아이_여자_아이:',
        'pt': u':família_homem_homem_menina_e_menina:',
        'it': ':famiglia_uomo_uomo_bambina_e_bambina:',
        'fa': u':خانواده_مرد_مرد_دختر_و_دختر:',
        'id': ':keluarga_pria_pria_anak_perempuan_anak_perempuan:',
        'zh': u':家庭_男人男人女孩女孩:'
    },
    u'\U0001F468\U0000200D\U0001F469\U0000200D\U0001F466': { # 👨‍👩‍👦
        'en' : ':family_man_woman_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':familie_mann,_frau_und_junge:',
        'es': u':familia_hombre_mujer_niño:',
        'fr': u':famille_homme,_femme_et_garçon:',
        'ja': u':家族_男性_女性_男の子:',
        'ko': u':가족_남자_여자_남자_아이:',
        'pt': u':família_homem_mulher_e_menino:',
        'it': ':famiglia_uomo_donna_e_bambino:',
        'fa': u':خانواده_مرد_زن_و_پسر:',
        'id': ':keluarga_pria_wanita_anak_laki-laki:',
        'zh': u':家庭_男人女人男孩:'
    },
    u'\U0001F468\U0000200D\U0001F469\U0000200D\U0001F466\U0000200D\U0001F466': { # 👨‍👩‍👦‍👦
        'en' : ':family_man_woman_boy_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':familie_mann,_frau,_junge_und_junge:',
        'es': u':familia_hombre_mujer_niño_niño:',
        'fr': u':famille_homme,_femme,_garçon_et_garçon:',
        'ja': u':家族_男性_女性_男の子_男の子:',
        'ko': u':가족_남자_여자_남자_아이_남자_아이:',
        'pt': u':família_homem_mulher_menino_e_menino:',
        'it': ':famiglia_uomo_donna_bambino_e_bambino:',
        'fa': u':خانواده_مرد_زن_پسر_و_پسر:',
        'id': ':keluarga_pria_wanita_anak_laki-laki_anak_laki-laki:',
        'zh': u':家庭_男人女人男孩男孩:'
    },
    u'\U0001F468\U0000200D\U0001F469\U0000200D\U0001F467': { # 👨‍👩‍👧
        'en' : ':family_man_woman_girl:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_mann,_frau_und_mädchen:',
        'es': u':familia_hombre_mujer_niña:',
        'fr': ':famille_homme,_femme_et_fille:',
        'ja': u':家族_男性_女性_女の子:',
        'ko': u':가족_남자_여자_여자_아이:',
        'pt': u':família_homem_mulher_e_menina:',
        'it': ':famiglia_uomo_donna_e_bambina:',
        'fa': u':خانواده_مرد_زن_و_دختر:',
        'id': ':keluarga_pria_wanita_anak_perempuan:',
        'zh': u':家庭_男人女人女孩:'
    },
    u'\U0001F468\U0000200D\U0001F469\U0000200D\U0001F467\U0000200D\U0001F466': { # 👨‍👩‍👧‍👦
        'en' : ':family_man_woman_girl_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_mann,_frau,_mädchen_und_junge:',
        'es': u':familia_hombre_mujer_niña_niño:',
        'fr': u':famille_homme,_femme,_fille_et_garçon:',
        'ja': u':家族_男性_女性_女の子_男の子:',
        'ko': u':가족_남자_여자_여자_아이_남자_아이:',
        'pt': u':família_homem_mulher_menina_e_menino:',
        'it': ':famiglia_uomo_donna_bambina_e_bambino:',
        'fa': u':خانواده_مرد_زن_دختر_و_پسر:',
        'id': ':keluarga_pria_wanita_anak_perempuan_anak_laki-laki:',
        'zh': u':家庭_男人女人女孩男孩:'
    },
    u'\U0001F468\U0000200D\U0001F469\U0000200D\U0001F467\U0000200D\U0001F467': { # 👨‍👩‍👧‍👧
        'en' : ':family_man_woman_girl_girl:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_mann,_frau,_mädchen_und_mädchen:',
        'es': u':familia_hombre_mujer_niña_niña:',
        'fr': ':famille_homme,_femme,_fille_et_fille:',
        'ja': u':家族_男性_女性_女の子_女の子:',
        'ko': u':가족_남자_여자_여자_아이_여자_아이:',
        'pt': u':família_homem_mulher_menina_e_menina:',
        'it': ':famiglia_uomo_donna_bambina_e_bambina:',
        'fa': u':خانواده_مرد_زن_دختر_و_دختر:',
        'id': ':keluarga_pria_wanita_anak_perempuan_anak_perempuan:',
        'zh': u':家庭_男人女人女孩女孩:'
    },
    u'\U0001F469\U0000200D\U0001F466': { # 👩‍👦
        'en' : ':family_woman_boy:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':familie_frau,_junge:',
        'es': u':familia_mujer_y_niño:',
        'fr': u':famille_femme_et_garçon:',
        'ja': u':家族_女性_男の子:',
        'ko': u':가족_여자_남자_아이:',
        'pt': u':família_mulher_e_menino:',
        'it': ':famiglia_donna_e_bambino:',
        'fa': u':خانواده_زن_پسر:',
        'id': ':keluarga_wanita_anak_laki-laki:',
        'zh': u':家庭_女人男孩:'
    },
    u'\U0001F469\U0000200D\U0001F466\U0000200D\U0001F466': { # 👩‍👦‍👦
        'en' : ':family_woman_boy_boy:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':familie_frau,_junge_und_junge:',
        'es': u':familia_mujer_niño_niño:',
        'fr': u':famille_femme,_garçon_et_garçon:',
        'ja': u':家族_女性_男の子_男の子:',
        'ko': u':가족_여자_남자_아이_남자_아이:',
        'pt': u':família_mulher_menino_e_menino:',
        'it': ':famiglia_donna_bambino_e_bambino:',
        'fa': u':خانواده_زن_پسر_و_پسر:',
        'id': ':keluarga_wanita_anak_laki-laki_anak_laki-laki:',
        'zh': u':家庭_女人男孩男孩:'
    },
    u'\U0001F469\U0000200D\U0001F467': { # 👩‍👧
        'en' : ':family_woman_girl:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':familie_frau,_mädchen:',
        'es': u':familia_mujer_y_niña:',
        'fr': ':famille_femme_et_fille:',
        'ja': u':家族_女性_女の子:',
        'ko': u':가족_여자_여자_아이:',
        'pt': u':família_mulher_e_menina:',
        'it': ':famiglia_donna_e_bambina:',
        'fa': u':خانواده_زن_دختر:',
        'id': ':keluarga_wanita_anak_perempuan:',
        'zh': u':家庭_女人女孩:'
    },
    u'\U0001F469\U0000200D\U0001F467\U0000200D\U0001F466': { # 👩‍👧‍👦
        'en' : ':family_woman_girl_boy:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':familie_frau,_mädchen_und_junge:',
        'es': u':familia_mujer_niña_niño:',
        'fr': u':famille_femme,_fille_et_garçon:',
        'ja': u':家族_女性_女の子_男の子:',
        'ko': u':가족_여자_여자_아이_남자_아이:',
        'pt': u':família_mulher_menina_e_menino:',
        'it': ':famiglia_donna_bambina_e_bambino:',
        'fa': u':خانواده_زن_دختر_و_پسر:',
        'id': ':keluarga_wanita_anak_perempuan_anak_laki-laki:',
        'zh': u':家庭_女人女孩男孩:'
    },
    u'\U0001F469\U0000200D\U0001F467\U0000200D\U0001F467': { # 👩‍👧‍👧
        'en' : ':family_woman_girl_girl:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':familie_frau,_mädchen_und_mädchen:',
        'es': u':familia_mujer_niña_niña:',
        'fr': ':famille_femme,_fille_et_fille:',
        'ja': u':家族_女性_女の子_女の子:',
        'ko': u':가족_여자_여자_아이_여자_아이:',
        'pt': u':família_mulher_menina_e_menina:',
        'it': ':famiglia_donna_bambina_e_bambina:',
        'fa': u':خانواده_زن_دختر_و_دختر:',
        'id': ':keluarga_wanita_anak_perempuan_anak_perempuan:',
        'zh': u':家庭_女人女孩女孩:'
    },
    u'\U0001F469\U0000200D\U0001F469\U0000200D\U0001F466': { # 👩‍👩‍👦
        'en' : ':family_woman_woman_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':familie_frau,_frau_und_junge:',
        'es': u':familia_mujer_mujer_niño:',
        'fr': u':famille_femme,_femme_et_garçon:',
        'ja': u':家族_女性_女性_男の子:',
        'ko': u':가족_여자_여자_남자_아이:',
        'pt': u':família_mulher_mulher_e_menino:',
        'it': ':famiglia_donna_donna_e_bambino:',
        'fa': u':خانواده_زن_زن_و_پسر:',
        'id': ':keluarga_wanita_wanita_anak_laki-laki:',
        'zh': u':家庭_女人女人男孩:'
    },
    u'\U0001F469\U0000200D\U0001F469\U0000200D\U0001F466\U0000200D\U0001F466': { # 👩‍👩‍👦‍👦
        'en' : ':family_woman_woman_boy_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':familie_frau,_frau,_junge_und_junge:',
        'es': u':familia_mujer_mujer_niño_niño:',
        'fr': u':famille_femme,_femme,_garçon_et_garçon:',
        'ja': u':家族_女性_女性_男の子_男の子:',
        'ko': u':가족_여자_여자_남자_아이_남자_아이:',
        'pt': u':família_mulher_mulher_menino_e_menino:',
        'it': ':famiglia_donna_donna_bambino_e_bambino:',
        'fa': u':خانواده_زن_زن_پسر_و_پسر:',
        'id': ':keluarga_wanita_wanita_anak_laki-laki_anak_laki-laki:',
        'zh': u':家庭_女人女人男孩男孩:'
    },
    u'\U0001F469\U0000200D\U0001F469\U0000200D\U0001F467': { # 👩‍👩‍👧
        'en' : ':family_woman_woman_girl:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_frau,_frau_und_mädchen:',
        'es': u':familia_mujer_mujer_niña:',
        'fr': ':famille_femme,_femme_et_fille:',
        'ja': u':家族_女性_女性_女の子:',
        'ko': u':가족_여자_여자_여자_아이:',
        'pt': u':família_mulher_mulher_e_menina:',
        'it': ':famiglia_donna_donna_e_bambina:',
        'fa': u':خانواده_زن_زن_و_دختر:',
        'id': ':keluarga_wanita_wanita_anak_perempuan:',
        'zh': u':家庭_女人女人女孩:'
    },
    u'\U0001F469\U0000200D\U0001F469\U0000200D\U0001F467\U0000200D\U0001F466': { # 👩‍👩‍👧‍👦
        'en' : ':family_woman_woman_girl_boy:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_frau,_frau,_mädchen_und_junge:',
        'es': u':familia_mujer_mujer_niña_niño:',
        'fr': u':famille_femme,_femme,_fille_et_garçon:',
        'ja': u':家族_女性_女性_女の子_男の子:',
        'ko': u':가족_여자_여자_여자_아이_남자_아이:',
        'pt': u':família_mulher_mulher_menina_e_menino:',
        'it': ':famiglia_donna_donna_bambina_e_bambino:',
        'fa': u':خانواده_زن_زن_دختر_و_پسر:',
        'id': ':keluarga_wanita_wanita_anak_perempuan_anak_laki-laki:',
        'zh': u':家庭_女人女人女孩男孩:'
    },
    u'\U0001F469\U0000200D\U0001F469\U0000200D\U0001F467\U0000200D\U0001F467': { # 👩‍👩‍👧‍👧
        'en' : ':family_woman_woman_girl_girl:',
        'status' : fully_qualified,
        'E' : 2,
        'de': u':familie_frau,_frau,_mädchen_und_mädchen:',
        'es': u':familia_mujer_mujer_niña_niña:',
        'fr': ':famille_femme,_femme,_fille_et_fille:',
        'ja': u':家族_女性_女性_女の子_女の子:',
        'ko': u':가족_여자_여자_여자_아이_여자_아이:',
        'pt': u':família_mulher_mulher_menina_e_menina:',
        'it': ':famiglia_donna_donna_bambina_e_bambina:',
        'fa': u':خانواده_زن_زن_دختر_و_دختر:',
        'id': ':keluarga_wanita_wanita_anak_perempuan_anak_perempuan:',
        'zh': u':家庭_女人女人女孩女孩:'
    },
    u'\U0001F9D1\U0000200D\U0001F33E': { # 🧑‍🌾
        'en' : ':farmer:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':bauer/bäuerin:',
        'es': ':profesional_de_la_agricultura:',
        'fr': ':fermier_(tous_genres):',
        'ja': u':農家:',
        'ko': u':농부:',
        'pt': ':agricultor:',
        'it': ':agricoltore:',
        'fa': u':کشاورز:',
        'id': ':petani:',
        'zh': u':农民:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F33E': { # 🧑🏿‍🌾
        'en' : ':farmer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':bauer/bäuerin_dunkle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_tono_de_piel_oscuro:',
        'fr': u':fermier_(tous_genres)_peau_foncée:',
        'ja': u':農家_濃い肌色:',
        'ko': u':농부_검은색_피부:',
        'pt': ':agricultor_pele_escura:',
        'it': ':agricoltore_carnagione_scura:',
        'fa': u':کشاورز_پوست_آبنوسی:',
        'id': ':petani_warna_kulit_gelap:',
        'zh': u':农民_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F33E': { # 🧑🏻‍🌾
        'en' : ':farmer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':bauer/bäuerin_helle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_tono_de_piel_claro:',
        'fr': ':fermier_(tous_genres)_peau_claire:',
        'ja': u':農家_薄い肌色:',
        'ko': u':농부_하얀_피부:',
        'pt': ':agricultor_pele_clara:',
        'it': ':agricoltore_carnagione_chiara:',
        'fa': u':کشاورز_پوست_سفید:',
        'id': ':petani_warna_kulit_cerah:',
        'zh': u':农民_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F33E': { # 🧑🏾‍🌾
        'en' : ':farmer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':bauer/bäuerin_mitteldunkle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_tono_de_piel_oscuro_medio:',
        'fr': ':fermier_(tous_genres)_peau_mate:',
        'ja': u':農家_やや濃い肌色:',
        'ko': u':농부_진한_갈색_피부:',
        'pt': ':agricultor_pele_morena_escura:',
        'it': ':agricoltore_carnagione_abbastanza_scura:',
        'fa': u':کشاورز_پوست_گندمی:',
        'id': ':petani_warna_kulit_gelap-sedang:',
        'zh': u':农民_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F33E': { # 🧑🏼‍🌾
        'en' : ':farmer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':bauer/bäuerin_mittelhelle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_tono_de_piel_claro_medio:',
        'fr': ':fermier_(tous_genres)_peau_moyennement_claire:',
        'ja': u':農家_やや薄い肌色:',
        'ko': u':농부_연한_갈색_피부:',
        'pt': ':agricultor_pele_morena_clara:',
        'it': ':agricoltore_carnagione_abbastanza_chiara:',
        'fa': u':کشاورز_پوست_روشن:',
        'id': ':petani_warna_kulit_cerah-sedang:',
        'zh': u':农民_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F33E': { # 🧑🏽‍🌾
        'en' : ':farmer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':bauer/bäuerin_mittlere_hautfarbe:',
        'es': ':profesional_de_la_agricultura_tono_de_piel_medio:',
        'fr': u':fermier_(tous_genres)_peau_légèrement_mate:',
        'ja': u':農家_中間の肌色:',
        'ko': u':농부_갈색_피부:',
        'pt': ':agricultor_pele_morena:',
        'it': ':agricoltore_carnagione_olivastra:',
        'fa': u':کشاورز_پوست_طلایی:',
        'id': ':petani_warna_kulit_sedang:',
        'zh': u':农民_中等肤色:'
    },
    u'\U000023E9': { # ⏩
        'en' : ':fast-forward_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fast_forward:'],
        'variant': True,
        'de': ':doppelpfeile_nach_rechts:',
        'es': u':avance_rápido:',
        'fr': ':bouton_avance_rapide:',
        'ja': u':早送りボタン:',
        'ko': u':빨리_감기:',
        'pt': u':botão_avançar:',
        'it': ':pulsante_di_avanzamento_rapido:',
        'fa': u':دکمهٔ_سریع_به_جلو:',
        'id': ':tombol_maju_cepat:',
        'zh': u':快进按钮:'
    },
    u'\U000023EC': { # ⏬
        'en' : ':fast_down_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_double_down:'],
        'de': ':doppelpfeile_nach_unten:',
        'es': u':triángulo_doble_hacia_abajo:',
        'fr': u':double_flèche_vers_le_bas:',
        'ja': u':高速下ボタン:',
        'ko': u':아래쪽_화살표:',
        'pt': u':botão_de_avanço_para_baixo:',
        'it': ':doppia_freccia_in_basso:',
        'fa': u':دکمهٔ_سریع_به_پایین:',
        'id': ':tombol_turun_cepat:',
        'zh': u':快速下降按钮:'
    },
    u'\U000023EA': { # ⏪
        'en' : ':fast_reverse_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':rewind:'],
        'variant': True,
        'de': u':zurückspulen:',
        'es': u':retroceso_rápido:',
        'fr': ':bouton_retour_rapide:',
        'ja': u':早戻しボタン:',
        'ko': u':되감기:',
        'pt': u':botão_de_retroceder:',
        'it': ':pulsante_di_riavvolgimento_rapido:',
        'fa': u':دکمهٔ_سریع_به_عقب:',
        'id': ':tombol_mundur_cepat:',
        'zh': u':快退按钮:'
    },
    u'\U000023EB': { # ⏫
        'en' : ':fast_up_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_double_up:'],
        'de': ':doppelpfeile_nach_oben:',
        'es': u':triángulo_doble_hacia_arriba:',
        'fr': u':double_flèche_vers_le_haut:',
        'ja': u':高速上ボタン:',
        'ko': u':위쪽_화살표:',
        'pt': u':botão_de_avanço_para_cima:',
        'it': ':pulsante_doppia_freccia_in_alto:',
        'fa': u':دکمهٔ_سریع_به_بالا:',
        'id': ':tombol_naik_cepat:',
        'zh': u':快速上升按钮:'
    },
    u'\U0001F4E0': { # 📠
        'en' : ':fax_machine:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fax:'],
        'de': u':faxgerät:',
        'es': u':máquina_de_fax:',
        'fr': ':fax:',
        'ja': u':ファックス:',
        'ko': u':팩스:',
        'pt': ':fax:',
        'it': ':fax:',
        'fa': u':دستگاه_نمابر:',
        'id': ':mesin_faks:',
        'zh': u':传真机:'
    },
    u'\U0001F628': { # 😨
        'en' : ':fearful_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fearful:'],
        'de': u':ängstliches_gesicht:',
        'es': ':cara_asustada:',
        'fr': u':visage_effrayé:',
        'ja': u':青ざめ:',
        'ko': u':두려워하는_얼굴:',
        'pt': ':rosto_amedrontado:',
        'it': ':faccina_impaurita:',
        'fa': u':ترسیده:',
        'id': ':wajah_ketakutan:',
        'zh': u':害怕:'
    },
    u'\U0001FAB6': { # 🪶
        'en' : ':feather:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':feder:',
        'es': ':pluma:',
        'fr': ':plume:',
        'ja': u':羽:',
        'ko': u':깃털:',
        'pt': ':pena:',
        'it': ':piuma:',
        'fa': u':پَر:',
        'id': ':bulu:',
        'zh': u':羽毛:'
    },
    u'\U00002640\U0000FE0F': { # ♀️
        'en' : ':female_sign:',
        'status' : fully_qualified,
        'E' : 4,
        'variant': True,
        'de': ':frauensymbol:',
        'es': ':signo_femenino:',
        'fr': ':symbole_de_la_femme:',
        'ja': u':女性のマーク:',
        'ko': u':여성_기호:',
        'pt': u':símbolo_de_feminino:',
        'it': ':simbolo_genere_femminile:',
        'fa': u':نشان_ناهید:',
        'id': ':simbol_wanita:',
        'zh': u':女性符号:'
    },
    u'\U00002640': { # ♀
        'en' : ':female_sign:',
        'status' : unqualified,
        'E' : 4,
        'variant': True,
        'de': ':frauensymbol:',
        'es': ':signo_femenino:',
        'fr': ':symbole_de_la_femme:',
        'ja': u':女性のマーク:',
        'ko': u':여성_기호:',
        'pt': u':símbolo_de_feminino:',
        'it': ':simbolo_genere_femminile:',
        'fa': u':نشان_ناهید:',
        'id': ':simbol_wanita:',
        'zh': u':女性符号:'
    },
    u'\U0001F3A1': { # 🎡
        'en' : ':ferris_wheel:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':riesenrad:',
        'es': ':noria_de_feria:',
        'fr': ':grande_roue:',
        'ja': u':観覧車:',
        'ko': u':관람차:',
        'pt': ':roda_gigante:',
        'it': ':ruota_panoramica:',
        'fa': u':چرخ_وفلک:',
        'id': ':kincir_ria:',
        'zh': u':摩天轮:'
    },
    u'\U000026F4\U0000FE0F': { # ⛴️
        'en' : ':ferry:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':fähre:',
        'es': ':ferri:',
        'fr': ':ferry:',
        'ja': u':フェリー:',
        'ko': u':페리:',
        'pt': ':balsa:',
        'it': ':traghetto:',
        'fa': u':فرابر:',
        'id': ':kapal_feri:',
        'zh': u':渡轮:'
    },
    u'\U000026F4': { # ⛴
        'en' : ':ferry:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':fähre:',
        'es': ':ferri:',
        'fr': ':ferry:',
        'ja': u':フェリー:',
        'ko': u':페리:',
        'pt': ':balsa:',
        'it': ':traghetto:',
        'fa': u':فرابر:',
        'id': ':kapal_feri:',
        'zh': u':渡轮:'
    },
    u'\U0001F3D1': { # 🏑
        'en' : ':field_hockey:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':field_hockey_stick_and_ball:'],
        'de': ':feldhockey:',
        'es': ':hockey_sobre_hierba:',
        'fr': ':hockey_sur_gazon:',
        'ja': u':ホッケー:',
        'ko': u':필드_하키:',
        'pt': u':hóquei_de_campo:',
        'it': ':hockey_su_prato:',
        'fa': u':هاکی_روی_چمن:',
        'id': ':hoki_lapangan:',
        'zh': u':曲棍球:'
    },
    u'\U0001F5C4\U0000FE0F': { # 🗄️
        'en' : ':file_cabinet:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':aktenschrank:',
        'es': ':archivador:',
        'fr': u':meuble_à_dossiers:',
        'ja': u':ファイルキャビネット:',
        'ko': u':파일_보관_서랍장:',
        'pt': u':gavetas_de_escritório:',
        'it': ':schedario_da_ufficio:',
        'fa': u':کشوی_پرونده:',
        'id': ':lemari_file:',
        'zh': u':文件柜:'
    },
    u'\U0001F5C4': { # 🗄
        'en' : ':file_cabinet:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':aktenschrank:',
        'es': ':archivador:',
        'fr': u':meuble_à_dossiers:',
        'ja': u':ファイルキャビネット:',
        'ko': u':파일_보관_서랍장:',
        'pt': u':gavetas_de_escritório:',
        'it': ':schedario_da_ufficio:',
        'fa': u':کشوی_پرونده:',
        'id': ':lemari_file:',
        'zh': u':文件柜:'
    },
    u'\U0001F4C1': { # 📁
        'en' : ':file_folder:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':ordner:',
        'es': ':carpeta_de_archivos:',
        'fr': ':dossier:',
        'ja': u':フォルダー:',
        'ko': u':폴더:',
        'pt': ':pasta_de_arquivos:',
        'it': ':cartella_file:',
        'fa': u':پوشه:',
        'id': ':folder_file:',
        'zh': u':文件夹:'
    },
    u'\U0001F39E\U0000FE0F': { # 🎞️
        'en' : ':film_frames:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':film_strip:'],
        'variant': True,
        'de': ':filmstreifen:',
        'es': u':fotograma_de_película:',
        'fr': ':pellicule:',
        'ja': u':映画フィルム:',
        'ko': u':영화_프레임:',
        'pt': ':rolo_de_filmes:',
        'it': ':pellicola_cinematografica:',
        'fa': u':حلقه_فیلم:',
        'id': ':frame_film:',
        'zh': u':影片帧:'
    },
    u'\U0001F39E': { # 🎞
        'en' : ':film_frames:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':film_strip:'],
        'variant': True,
        'de': ':filmstreifen:',
        'es': u':fotograma_de_película:',
        'fr': ':pellicule:',
        'ja': u':映画フィルム:',
        'ko': u':영화_프레임:',
        'pt': ':rolo_de_filmes:',
        'it': ':pellicola_cinematografica:',
        'fa': u':حلقهٔ_فیلم:',
        'id': ':frame_film:',
        'zh': u':影片帧:'
    },
    u'\U0001F4FD\U0000FE0F': { # 📽️
        'en' : ':film_projector:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':filmprojektor:',
        'es': ':proyector_de_cine:',
        'fr': u':projecteur_cinématographique:',
        'ja': u':映写機:',
        'ko': u':영화_프로젝터:',
        'pt': ':projetor_de_filmes:',
        'it': ':proiettore_cinematografico:',
        'fa': u':پروژکتور:',
        'id': ':proyektor_film:',
        'zh': u':电影放映机:'
    },
    u'\U0001F4FD': { # 📽
        'en' : ':film_projector:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':filmprojektor:',
        'es': ':proyector_de_cine:',
        'fr': u':projecteur_cinématographique:',
        'ja': u':映写機:',
        'ko': u':영화_프로젝터:',
        'pt': ':projetor_de_filmes:',
        'it': ':proiettore_cinematografico:',
        'fa': u':پروژکتور:',
        'id': ':proyektor_film:',
        'zh': u':电影放映机:'
    },
    u'\U0001F525': { # 🔥
        'en' : ':fire:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':feuer:',
        'es': ':fuego:',
        'fr': ':feu:',
        'ja': u':火:',
        'ko': u':불:',
        'pt': ':fogo:',
        'it': ':fuoco:',
        'fa': u':آتش:',
        'id': ':api:',
        'zh': u':火焰:'
    },
    u'\U0001F692': { # 🚒
        'en' : ':fire_engine:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':feuerwehrauto:',
        'es': ':coche_de_bomberos:',
        'fr': ':camion_de_pompier:',
        'ja': u':消防車:',
        'ko': u':소방차:',
        'pt': ':carro_do_corpo_de_bombeiros:',
        'it': ':camion_dei_pompieri:',
        'fa': u':ماشین_آتش_نشانی:',
        'id': ':mobil_pemadam_kebakaran:',
        'zh': u':消防车:'
    },
    u'\U0001F9EF': { # 🧯
        'en' : ':fire_extinguisher:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':feuerlöscher:',
        'es': ':extintor:',
        'fr': ':extincteur:',
        'ja': u':消火器:',
        'ko': u':소화기:',
        'pt': u':extintor_de_incêndio:',
        'it': ':estintore:',
        'fa': u':کپسول_آتش_نشانی:',
        'id': ':alat_pemadam_api_ringan:',
        'zh': u':灭火器:'
    },
    u'\U0001F9E8': { # 🧨
        'en' : ':firecracker:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':feuerwerkskörper:',
        'es': ':petardo:',
        'fr': u':pétard:',
        'ja': u':爆竹:',
        'ko': u':폭죽:',
        'pt': ':bombinha:',
        'it': ':petardo:',
        'fa': u':ترقه:',
        'id': ':petasan:',
        'zh': u':爆竹:'
    },
    u'\U0001F9D1\U0000200D\U0001F692': { # 🧑‍🚒
        'en' : ':firefighter:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':feuerwehrmann/-frau:',
        'es': ':bombero:',
        'fr': ':pompier:',
        'ja': u':消防士:',
        'ko': u':소방관:',
        'pt': ':bombeiro:',
        'it': ':pompiere:',
        'fa': u':مأمور_آتش_نشانی:',
        'id': ':pemadam_kebakaran:',
        'zh': u':消防员:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F692': { # 🧑🏿‍🚒
        'en' : ':firefighter_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':feuerwehrmann/-frau_dunkle_hautfarbe:',
        'es': ':bombero_tono_de_piel_oscuro:',
        'fr': u':pompier_peau_foncée:',
        'ja': u':消防士_濃い肌色:',
        'ko': u':소방관_검은색_피부:',
        'pt': ':bombeiro_pele_escura:',
        'it': ':pompiere_carnagione_scura:',
        'fa': u':مأمور_آتش_نشانی_پوست_آبنوسی:',
        'id': ':pemadam_kebakaran_warna_kulit_gelap:',
        'zh': u':消防员_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F692': { # 🧑🏻‍🚒
        'en' : ':firefighter_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':feuerwehrmann/-frau_helle_hautfarbe:',
        'es': ':bombero_tono_de_piel_claro:',
        'fr': ':pompier_peau_claire:',
        'ja': u':消防士_薄い肌色:',
        'ko': u':소방관_하얀_피부:',
        'pt': ':bombeiro_pele_clara:',
        'it': ':pompiere_carnagione_chiara:',
        'fa': u':مأمور_آتش_نشانی_پوست_سفید:',
        'id': ':pemadam_kebakaran_warna_kulit_cerah:',
        'zh': u':消防员_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F692': { # 🧑🏾‍🚒
        'en' : ':firefighter_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':feuerwehrmann/-frau_mitteldunkle_hautfarbe:',
        'es': ':bombero_tono_de_piel_oscuro_medio:',
        'fr': ':pompier_peau_mate:',
        'ja': u':消防士_やや濃い肌色:',
        'ko': u':소방관_진한_갈색_피부:',
        'pt': ':bombeiro_pele_morena_escura:',
        'it': ':pompiere_carnagione_abbastanza_scura:',
        'fa': u':مأمور_آتش_نشانی_پوست_گندمی:',
        'id': ':pemadam_kebakaran_warna_kulit_gelap-sedang:',
        'zh': u':消防员_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F692': { # 🧑🏼‍🚒
        'en' : ':firefighter_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':feuerwehrmann/-frau_mittelhelle_hautfarbe:',
        'es': ':bombero_tono_de_piel_claro_medio:',
        'fr': ':pompier_peau_moyennement_claire:',
        'ja': u':消防士_やや薄い肌色:',
        'ko': u':소방관_연한_갈색_피부:',
        'pt': ':bombeiro_pele_morena_clara:',
        'it': ':pompiere_carnagione_abbastanza_chiara:',
        'fa': u':مأمور_آتش_نشانی_پوست_روشن:',
        'id': ':pemadam_kebakaran_warna_kulit_cerah-sedang:',
        'zh': u':消防员_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F692': { # 🧑🏽‍🚒
        'en' : ':firefighter_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':feuerwehrmann/-frau_mittlere_hautfarbe:',
        'es': ':bombero_tono_de_piel_medio:',
        'fr': u':pompier_peau_légèrement_mate:',
        'ja': u':消防士_中間の肌色:',
        'ko': u':소방관_갈색_피부:',
        'pt': ':bombeiro_pele_morena:',
        'it': ':pompiere_carnagione_olivastra:',
        'fa': u':مأمور_آتش_نشانی_پوست_طلایی:',
        'id': ':pemadam_kebakaran_warna_kulit_sedang:',
        'zh': u':消防员_中等肤色:'
    },
    u'\U0001F386': { # 🎆
        'en' : ':fireworks:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':feuerwerk:',
        'es': ':fuegos_artificiales:',
        'fr': u':feu_d’artifice:',
        'ja': u':打ち上げ花火:',
        'ko': u':불꽃놀이:',
        'pt': u':fogos_de_artifício:',
        'it': u':fuochi_d’artificio:',
        'fa': u':آتش_بازی:',
        'id': ':kembang_api:',
        'zh': u':焰火:'
    },
    u'\U0001F313': { # 🌓
        'en' : ':first_quarter_moon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':zunehmender_halbmond:',
        'es': ':luna_en_cuarto_creciente:',
        'fr': ':premier_quartier_de_lune:',
        'ja': u':上弦の月:',
        'ko': u':오른쪽_반달:',
        'pt': ':quarto_crescente:',
        'it': ':primo_quarto_di_luna:',
        'fa': u':یک_چهارم_نخست:',
        'id': ':bulan_perbani_awal:',
        'zh': u':上弦月:'
    },
    u'\U0001F31B': { # 🌛
        'en' : ':first_quarter_moon_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':first_quarter_moon_with_face:'],
        'de': ':mondsichel_mit_gesicht_links:',
        'es': ':luna_de_cuarto_creciente_con_cara:',
        'fr': ':premier_quartier_de_lune_avec_visage:',
        'ja': u':顔のある上弦の月:',
        'ko': u':얼굴이_있는_초승달:',
        'pt': ':rosto_da_lua_de_quarto_crescente:',
        'it': ':faccina_primo_quarto_di_luna:',
        'fa': u':صورت_یک_چهارم_اول:',
        'id': ':wajah_bulan_perbani_awal:',
        'zh': u':微笑的上弦月:'
    },
    u'\U0001F41F': { # 🐟
        'en' : ':fish:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':fisch:',
        'es': ':pez:',
        'fr': ':poisson:',
        'ja': u':魚:',
        'ko': u':물고기:',
        'pt': ':peixe:',
        'it': ':pesce:',
        'fa': u':ماهی:',
        'id': ':ikan:',
        'zh': u':鱼:'
    },
    u'\U0001F365': { # 🍥
        'en' : ':fish_cake_with_swirl:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fish_cake:'],
        'de': ':fischfrikadelle:',
        'es': u':pastel_de_pescado_japonés:',
        'fr': ':croquette_de_poisson:',
        'ja': u':なると:',
        'ko': u':어묵:',
        'pt': ':bolinho_de_peixe:',
        'it': ':tortino_di_pesce_a_spirale:',
        'fa': u':کیک_ماهی:',
        'id': ':kue_ikan_dengan_desain_pusaran:',
        'zh': u':鱼板:'
    },
    u'\U0001F3A3': { # 🎣
        'en' : ':fishing_pole:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fishing_pole_and_fish:'],
        'de': ':angel_mit_fisch:',
        'es': u':caña_de_pescar:',
        'fr': u':pêche_à_la_ligne:',
        'ja': u':釣り:',
        'ko': u':낚싯대:',
        'pt': ':pesca:',
        'it': ':canna_da_pesca:',
        'fa': u':چوب_ماهیگیری:',
        'id': ':tongkat_pancing:',
        'zh': u':钓鱼竿:'
    },
    u'\U0001F560': { # 🕠
        'en' : ':five-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock530:'],
        'variant': True,
        'de': ':5.30_uhr:',
        'es': ':cinco_y_media:',
        'fr': ':cinq_heures_et_demie:',
        'ja': u':5時半:',
        'ko': u':다섯_시_반:',
        'pt': ':cinco_e_meia:',
        'it': ':ore_cinque_e_mezza:',
        'fa': u':ساعت_پنج_و_نیم:',
        'id': ':jam_setengah_enam:',
        'zh': u':五点半:'
    },
    u'\U0001F554': { # 🕔
        'en' : u':five_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock5:'],
        'variant': True,
        'de': ':5.00_uhr:',
        'es': ':5_en_punto:',
        'fr': ':cinq_heures:',
        'ja': u':5時:',
        'ko': u':다섯_시:',
        'pt': ':5_horas:',
        'it': ':ore_cinque:',
        'fa': u':ساعت_پنج:',
        'id': ':jam_lima_tepat:',
        'zh': u':五点:'
    },
    u'\U000026F3': { # ⛳
        'en' : ':flag_in_hole:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':golf:'],
        'variant': True,
        'de': ':golffahne:',
        'es': u':banderín_en_hoyo:',
        'fr': ':drapeau_de_golf:',
        'ja': u':ゴルフ:',
        'ko': u':골프:',
        'pt': ':bandeira_no_buraco:',
        'it': ':bandiera_in_buca:',
        'fa': u':پرچم_در_سوراخ:',
        'id': ':bendera_di_lubang_golf:',
        'zh': u':高尔夫球洞:'
    },
    u'\U0001F9A9': { # 🦩
        'en' : ':flamingo:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':flamingo:',
        'es': ':flamenco:',
        'fr': ':flamant:',
        'ja': u':フラミンゴ:',
        'ko': u':홍학:',
        'pt': ':flamingo:',
        'it': ':fenicottero:',
        'fa': u':فلامینگو:',
        'id': ':flamingo:',
        'zh': u':火烈鸟:'
    },
    u'\U0001F526': { # 🔦
        'en' : ':flashlight:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':taschenlampe:',
        'es': ':linterna:',
        'fr': ':torche:',
        'ja': u':懐中電灯:',
        'ko': u':손전등:',
        'pt': ':lanterna:',
        'it': ':torcia:',
        'fa': u':چراغ_قوه:',
        'id': ':lampu_senter:',
        'zh': u':手电筒:'
    },
    u'\U0001F97F': { # 🥿
        'en' : ':flat_shoe:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':flacher_schuh:',
        'es': ':bailarina:',
        'fr': ':chaussure_plate:',
        'ja': u':フラットシューズ:',
        'ko': u':플랫_슈즈:',
        'pt': ':sapatilha:',
        'it': ':ballerina:',
        'fa': u':کفش_بی_پاشنه:',
        'id': ':sepatu_flat:',
        'zh': u':平底鞋:'
    },
    u'\U0001FAD3': { # 🫓
        'en' : ':flatbread:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':fladenbrot:',
        'es': ':pan_sin_levadura:',
        'fr': ':galette:',
        'ja': u':フラットブレッド:',
        'ko': u':플랫브레드:',
        'pt': u':pão_sírio:',
        'it': ':focaccia:',
        'fa': u':نان_مسطح:',
        'id': ':roti_pipih:',
        'zh': u':扁面包:'
    },
    u'\U0000269C\U0000FE0F': { # ⚜️
        'en' : ':fleur-de-lis:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':fleur__de__lis:', ':fleur_de_lis:'],
        'variant': True,
        'de': ':lilie:',
        'es': ':flor_de_lis:',
        'fr': ':fleur_de_lys:',
        'ja': u':フルール・ド・リス:',
        'ko': u':백합_문장:',
        'pt': ':flor-de-lis:',
        'it': ':giglio_araldico:',
        'fa': u':نماد_گل_زنبق:',
        'id': ':fleur-de-lis:',
        'zh': u':百合花饰:'
    },
    u'\U0000269C': { # ⚜
        'en' : ':fleur-de-lis:',
        'status' : unqualified,
        'E' : 1,
        'alias' : [':fleur__de__lis:', ':fleur_de_lis:'],
        'variant': True,
        'de': ':lilie:',
        'es': ':flor_de_lis:',
        'fr': ':fleur_de_lys:',
        'ja': u':フルール・ド・リス:',
        'ko': u':백합_문장:',
        'pt': ':flor-de-lis:',
        'it': ':giglio_araldico:',
        'fa': u':نماد_گل_زنبق:',
        'id': ':fleur-de-lis:',
        'zh': u':百合花饰:'
    },
    u'\U0001F4AA': { # 💪
        'en' : ':flexed_biceps:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':muscle:'],
        'de': ':angespannter_bizeps:',
        'es': u':bíceps_flexionado:',
        'fr': u':biceps_contracté:',
        'ja': u':力こぶ:',
        'ko': u':알통:',
        'pt': u':bíceps:',
        'it': ':bicipite:',
        'fa': u':عضلهٔ_بازو:',
        'id': ':lengan_berotot:',
        'zh': u':肌肉:'
    },
    u'\U0001F4AA\U0001F3FF': { # 💪🏿
        'en' : ':flexed_biceps_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':angespannter_bizeps_dunkle_hautfarbe:',
        'es': u':bíceps_flexionado_tono_de_piel_oscuro:',
        'fr': u':biceps_contracté_peau_foncée:',
        'ja': u':力こぶ_濃い肌色:',
        'ko': u':알통_검은색_피부:',
        'pt': u':bíceps_pele_escura:',
        'it': ':bicipite_carnagione_scura:',
        'fa': u':عضلهٔ_بازو_پوست_آبنوسی:',
        'id': ':lengan_berotot_warna_kulit_gelap:',
        'zh': u':肌肉_较深肤色:'
    },
    u'\U0001F4AA\U0001F3FB': { # 💪🏻
        'en' : ':flexed_biceps_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':angespannter_bizeps_helle_hautfarbe:',
        'es': u':bíceps_flexionado_tono_de_piel_claro:',
        'fr': u':biceps_contracté_peau_claire:',
        'ja': u':力こぶ_薄い肌色:',
        'ko': u':알통_하얀_피부:',
        'pt': u':bíceps_pele_clara:',
        'it': ':bicipite_carnagione_chiara:',
        'fa': u':عضلهٔ_بازو_پوست_سفید:',
        'id': ':lengan_berotot_warna_kulit_cerah:',
        'zh': u':肌肉_较浅肤色:'
    },
    u'\U0001F4AA\U0001F3FE': { # 💪🏾
        'en' : ':flexed_biceps_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':angespannter_bizeps_mitteldunkle_hautfarbe:',
        'es': u':bíceps_flexionado_tono_de_piel_oscuro_medio:',
        'fr': u':biceps_contracté_peau_mate:',
        'ja': u':力こぶ_やや濃い肌色:',
        'ko': u':알통_진한_갈색_피부:',
        'pt': u':bíceps_pele_morena_escura:',
        'it': ':bicipite_carnagione_abbastanza_scura:',
        'fa': u':عضلهٔ_بازو_پوست_گندمی:',
        'id': ':lengan_berotot_warna_kulit_gelap-sedang:',
        'zh': u':肌肉_中等深肤色:'
    },
    u'\U0001F4AA\U0001F3FC': { # 💪🏼
        'en' : ':flexed_biceps_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':angespannter_bizeps_mittelhelle_hautfarbe:',
        'es': u':bíceps_flexionado_tono_de_piel_claro_medio:',
        'fr': u':biceps_contracté_peau_moyennement_claire:',
        'ja': u':力こぶ_やや薄い肌色:',
        'ko': u':알통_연한_갈색_피부:',
        'pt': u':bíceps_pele_morena_clara:',
        'it': ':bicipite_carnagione_abbastanza_chiara:',
        'fa': u':عضلهٔ_بازو_پوست_روشن:',
        'id': ':lengan_berotot_warna_kulit_cerah-sedang:',
        'zh': u':肌肉_中等浅肤色:'
    },
    u'\U0001F4AA\U0001F3FD': { # 💪🏽
        'en' : ':flexed_biceps_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':angespannter_bizeps_mittlere_hautfarbe:',
        'es': u':bíceps_flexionado_tono_de_piel_medio:',
        'fr': u':biceps_contracté_peau_légèrement_mate:',
        'ja': u':力こぶ_中間の肌色:',
        'ko': u':알통_갈색_피부:',
        'pt': u':bíceps_pele_morena:',
        'it': ':bicipite_carnagione_olivastra:',
        'fa': u':عضلهٔ_بازو_پوست_طلایی:',
        'id': ':lengan_berotot_warna_kulit_sedang:',
        'zh': u':肌肉_中等肤色:'
    },
    u'\U0001F4BE': { # 💾
        'en' : ':floppy_disk:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':diskette:',
        'es': ':disquete:',
        'fr': ':disquette:',
        'ja': u':フロッピー:',
        'ko': u':플로피_디스크:',
        'pt': ':disquete:',
        'it': ':floppy_disc:',
        'fa': u':فلاپی_دیسک:',
        'id': ':disket:',
        'zh': u':软盘:'
    },
    u'\U0001F3B4': { # 🎴
        'en' : ':flower_playing_cards:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':japanische_blumenkarte:',
        'es': ':cartas_de_flores:',
        'fr': ':jeu_des_fleurs:',
        'ja': u':花札:',
        'ko': u':화투:',
        'pt': ':carta_de_flores:',
        'it': ':carta_da_gioco_hanafuda:',
        'fa': u':کارت_بازی_گل_دار:',
        'id': ':kartu_bunga:',
        'zh': u':花札:'
    },
    u'\U0001F633': { # 😳
        'en' : ':flushed_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':flushed:'],
        'de': u':errötetes_gesicht_mit_großen_augen:',
        'es': ':cara_sonrojada:',
        'fr': ':visage_qui_rougit:',
        'ja': u':赤面:',
        'ko': u':상기된_얼굴:',
        'pt': ':rosto_ruborizado:',
        'it': ':faccina_imbarazzata:',
        'fa': u':سرخ_شده:',
        'id': ':wajah_tersipu:',
        'zh': u':脸红:'
    },
    u'\U0001FA88': { # 🪈
        'en' : ':flute:',
        'status' : fully_qualified,
        'E' : 15,
        'de': u':flöte:',
        'es': ':flauta:',
        'fr': u':flûte:',
        'ja': u':笛:',
        'ko': u':플루트:',
        'pt': ':flauta:',
        'it': ':flauto:',
        'fa': u':فلوت:',
        'id': ':seruling:',
        'zh': u':长笛:'
    },
    u'\U0001FAB0': { # 🪰
        'en' : ':fly:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':fliege:',
        'es': ':mosca:',
        'fr': ':mouche:',
        'ja': u':ハエ:',
        'ko': u':파리:',
        'pt': ':mosca:',
        'it': ':mosca:',
        'fa': u':مگس:',
        'id': ':lalat:',
        'zh': u':苍蝇:'
    },
    u'\U0001F94F': { # 🥏
        'en' : ':flying_disc:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frisbee:',
        'es': ':disco_volador:',
        'fr': ':disque_volant:',
        'ja': u':フリスビー:',
        'ko': u':원반:',
        'pt': ':frisbee:',
        'it': ':frisbee:',
        'fa': u':فریزبی:',
        'id': ':lempar_cakram:',
        'zh': u':飞盘:'
    },
    u'\U0001F6F8': { # 🛸
        'en' : ':flying_saucer:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':fliegende_untertasse:',
        'es': ':platillo_volante:',
        'fr': ':soucoupe_volante:',
        'ja': u':空飛ぶ円盤:',
        'ko': u':비행접시:',
        'pt': ':disco_voador:',
        'it': ':disco_volante:',
        'fa': u':بشقاب_پرنده:',
        'id': ':piring_terbang:',
        'zh': u':飞碟:'
    },
    u'\U0001F32B\U0000FE0F': { # 🌫️
        'en' : ':fog:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':nebel:',
        'es': ':niebla:',
        'fr': ':brouillard:',
        'ja': u':霧:',
        'ko': u':안개:',
        'pt': ':neblina:',
        'it': ':nebbia:',
        'fa': u':مه:',
        'id': ':kabut:',
        'zh': u':雾:'
    },
    u'\U0001F32B': { # 🌫
        'en' : ':fog:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':nebel:',
        'es': ':niebla:',
        'fr': ':brouillard:',
        'ja': u':霧:',
        'ko': u':안개:',
        'pt': ':nevoeiro:',
        'it': ':nebbia:',
        'fa': u':مه:',
        'id': ':kabut:',
        'zh': u':雾:'
    },
    u'\U0001F301': { # 🌁
        'en' : ':foggy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':neblig:',
        'es': ':bruma:',
        'fr': ':brume:',
        'ja': u':霧の都会:',
        'ko': u':자욱한_안개:',
        'pt': ':enevoado:',
        'it': ':nebbioso:',
        'fa': u':مه_آلود:',
        'id': ':berkabut:',
        'zh': u':有雾:'
    },
    u'\U0001F64F': { # 🙏
        'en' : ':folded_hands:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pray:'],
        'de': u':zusammengelegte_handflächen:',
        'es': u':manos_en_oración:',
        'fr': u':mains_en_prière:',
        'ja': u':祈り:',
        'ko': u':기도:',
        'pt': u':mãos_juntas:',
        'it': ':mani_giunte:',
        'fa': u':خواهش_می_کنم:',
        'id': ':melipat_tangan:',
        'zh': u':双手合十:'
    },
    u'\U0001F64F\U0001F3FF': { # 🙏🏿
        'en' : ':folded_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':betende_hände_dunkle_hautfarbe:',
        'es': u':manos_en_oración_tono_de_piel_oscuro:',
        'fr': u':mains_en_prière_peau_foncée:',
        'ja': u':祈り_濃い肌色:',
        'ko': u':기도_검은색_피부:',
        'pt': u':mãos_juntas_pele_escura:',
        'it': ':mani_giunte_carnagione_scura:',
        'fa': u':خواهش_می_کنم_پوست_آبنوسی:',
        'id': ':melipat_tangan_warna_kulit_gelap:',
        'zh': u':双手合十_较深肤色:'
    },
    u'\U0001F64F\U0001F3FB': { # 🙏🏻
        'en' : ':folded_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':betende_hände_helle_hautfarbe:',
        'es': u':manos_en_oración_tono_de_piel_claro:',
        'fr': u':mains_en_prière_peau_claire:',
        'ja': u':祈り_薄い肌色:',
        'ko': u':기도_하얀_피부:',
        'pt': u':mãos_juntas_pele_clara:',
        'it': ':mani_giunte_carnagione_chiara:',
        'fa': u':خواهش_می_کنم_پوست_سفید:',
        'id': ':melipat_tangan_warna_kulit_cerah:',
        'zh': u':双手合十_较浅肤色:'
    },
    u'\U0001F64F\U0001F3FE': { # 🙏🏾
        'en' : ':folded_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':betende_hände_mitteldunkle_hautfarbe:',
        'es': u':manos_en_oración_tono_de_piel_oscuro_medio:',
        'fr': u':mains_en_prière_peau_mate:',
        'ja': u':祈り_やや濃い肌色:',
        'ko': u':기도_진한_갈색_피부:',
        'pt': u':mãos_juntas_pele_morena_escura:',
        'it': ':mani_giunte_carnagione_abbastanza_scura:',
        'fa': u':خواهش_می_کنم_پوست_گندمی:',
        'id': ':melipat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':双手合十_中等深肤色:'
    },
    u'\U0001F64F\U0001F3FC': { # 🙏🏼
        'en' : ':folded_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':betende_hände_mittelhelle_hautfarbe:',
        'es': u':manos_en_oración_tono_de_piel_claro_medio:',
        'fr': u':mains_en_prière_peau_moyennement_claire:',
        'ja': u':祈り_やや薄い肌色:',
        'ko': u':기도_연한_갈색_피부:',
        'pt': u':mãos_juntas_pele_morena_clara:',
        'it': ':mani_giunte_carnagione_abbastanza_chiara:',
        'fa': u':خواهش_می_کنم_پوست_روشن:',
        'id': ':melipat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':双手合十_中等浅肤色:'
    },
    u'\U0001F64F\U0001F3FD': { # 🙏🏽
        'en' : ':folded_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':betende_hände_mittlere_hautfarbe:',
        'es': u':manos_en_oración_tono_de_piel_medio:',
        'fr': u':mains_en_prière_peau_légèrement_mate:',
        'ja': u':祈り_中間の肌色:',
        'ko': u':기도_갈색_피부:',
        'pt': u':mãos_juntas_pele_morena:',
        'it': ':mani_giunte_carnagione_olivastra:',
        'fa': u':خواهش_می_کنم_پوست_طلایی:',
        'id': ':melipat_tangan_warna_kulit_sedang:',
        'zh': u':双手合十_中等肤色:'
    },
    u'\U0001FAAD': { # 🪭
        'en' : ':folding_hand_fan:',
        'status' : fully_qualified,
        'E' : 15,
        'de': u':faltfächer:',
        'es': ':abanico_abierto:',
        'fr': u':éventail:',
        'ja': u':扇子:',
        'ko': u':접이식_손_부채:',
        'pt': u':leque_dobrável:',
        'it': ':ventaglio:',
        'fa': u':بادبزن:',
        'id': ':kipas_tangan_lipat:',
        'zh': u':折扇:'
    },
    u'\U0001FAD5': { # 🫕
        'en' : ':fondue:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':fondue:',
        'es': ':fondue:',
        'fr': ':fondue:',
        'ja': u':フォンデュ:',
        'ko': u':퐁듀:',
        'pt': ':fondue:',
        'it': ':fonduta:',
        'fa': u':فوندو:',
        'id': ':fondue:',
        'zh': u':奶酪火锅:'
    },
    u'\U0001F9B6': { # 🦶
        'en' : ':foot:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':fuß:',
        'es': ':pie:',
        'fr': ':pied:',
        'ja': u':足:',
        'ko': u':한쪽_발:',
        'pt': u':pé:',
        'it': ':piede:',
        'fa': u':پا:',
        'id': ':telapak_kaki:',
        'zh': u':脚:'
    },
    u'\U0001F9B6\U0001F3FF': { # 🦶🏿
        'en' : ':foot_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':fuß_dunkle_hautfarbe:',
        'es': ':pie_tono_de_piel_oscuro:',
        'fr': u':pied_peau_foncée:',
        'ja': u':足_濃い肌色:',
        'ko': u':한쪽_발_검은색_피부:',
        'pt': u':pé_pele_escura:',
        'it': ':piede_carnagione_scura:',
        'fa': u':پا_پوست_آبنوسی:',
        'id': ':telapak_kaki_warna_kulit_gelap:',
        'zh': u':脚_较深肤色:'
    },
    u'\U0001F9B6\U0001F3FB': { # 🦶🏻
        'en' : ':foot_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':fuß_helle_hautfarbe:',
        'es': ':pie_tono_de_piel_claro:',
        'fr': ':pied_peau_claire:',
        'ja': u':足_薄い肌色:',
        'ko': u':한쪽_발_하얀_피부:',
        'pt': u':pé_pele_clara:',
        'it': ':piede_carnagione_chiara:',
        'fa': u':پا_پوست_سفید:',
        'id': ':telapak_kaki_warna_kulit_cerah:',
        'zh': u':脚_较浅肤色:'
    },
    u'\U0001F9B6\U0001F3FE': { # 🦶🏾
        'en' : ':foot_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':fuß_mitteldunkle_hautfarbe:',
        'es': ':pie_tono_de_piel_oscuro_medio:',
        'fr': ':pied_peau_mate:',
        'ja': u':足_やや濃い肌色:',
        'ko': u':한쪽_발_진한_갈색_피부:',
        'pt': u':pé_pele_morena_escura:',
        'it': ':piede_carnagione_abbastanza_scura:',
        'fa': u':پا_پوست_گندمی:',
        'id': ':telapak_kaki_warna_kulit_gelap-sedang:',
        'zh': u':脚_中等深肤色:'
    },
    u'\U0001F9B6\U0001F3FC': { # 🦶🏼
        'en' : ':foot_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':fuß_mittelhelle_hautfarbe:',
        'es': ':pie_tono_de_piel_claro_medio:',
        'fr': ':pied_peau_moyennement_claire:',
        'ja': u':足_やや薄い肌色:',
        'ko': u':한쪽_발_연한_갈색_피부:',
        'pt': u':pé_pele_morena_clara:',
        'it': ':piede_carnagione_abbastanza_chiara:',
        'fa': u':پا_پوست_روشن:',
        'id': ':telapak_kaki_warna_kulit_cerah-sedang:',
        'zh': u':脚_中等浅肤色:'
    },
    u'\U0001F9B6\U0001F3FD': { # 🦶🏽
        'en' : ':foot_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':fuß_mittlere_hautfarbe:',
        'es': ':pie_tono_de_piel_medio:',
        'fr': u':pied_peau_légèrement_mate:',
        'ja': u':足_中間の肌色:',
        'ko': u':한쪽_발_갈색_피부:',
        'pt': u':pé_pele_morena:',
        'it': ':piede_carnagione_olivastra:',
        'fa': u':پا_پوست_طلایی:',
        'id': ':telapak_kaki_warna_kulit_sedang:',
        'zh': u':脚_中等肤色:'
    },
    u'\U0001F463': { # 👣
        'en' : ':footprints:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':fußabdrücke:',
        'es': ':huellas_de_pies:',
        'fr': ':traces_de_pas:',
        'ja': u':足あと:',
        'ko': u':발자국:',
        'pt': ':pegadas:',
        'it': ':impronta_di_piedi:',
        'fa': u':رد_پا:',
        'id': ':jejak_kaki:',
        'zh': u':脚印:'
    },
    u'\U0001F374': { # 🍴
        'en' : ':fork_and_knife:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':messer_und_gabel:',
        'es': ':tenedor_y_cuchillo:',
        'fr': ':fourchette_et_couteau:',
        'ja': u':ナイフとフォーク:',
        'ko': u':포크와_나이프:',
        'pt': ':garfo_e_faca:',
        'it': ':forchetta_e_coltello:',
        'fa': u':کارد_و_چنگال:',
        'id': ':garpu_dan_pisau:',
        'zh': u':刀叉:'
    },
    u'\U0001F37D\U0000FE0F': { # 🍽️
        'en' : ':fork_and_knife_with_plate:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':plate_with_cutlery:'],
        'variant': True,
        'de': ':teller_mit_messer_und_gabel:',
        'es': ':cuchillo_y_tenedor_con_un_plato:',
        'fr': ':fourchette_et_couteau_avec_assiette:',
        'ja': u':ナイフとフォークと皿:',
        'ko': u':포크와_나이프가_있는_접시:',
        'pt': ':prato_com_talheres:',
        'it': ':piatto_e_posate:',
        'fa': u':بشقاب_و_کارد_و_چنگال:',
        'id': ':garpu_dan_pisau_dengan_piring:',
        'zh': u':餐具:'
    },
    u'\U0001F37D': { # 🍽
        'en' : ':fork_and_knife_with_plate:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':plate_with_cutlery:'],
        'variant': True,
        'de': ':teller_mit_messer_und_gabel:',
        'es': ':cuchillo_y_tenedor_con_un_plato:',
        'fr': ':fourchette_et_couteau_avec_assiette:',
        'ja': u':ナイフとフォークと皿:',
        'ko': u':포크와_나이프가_있는_접시:',
        'pt': ':prato_com_talheres:',
        'it': ':piatto_e_posate:',
        'fa': u':بشقاب_و_کارد_و_چنگال:',
        'id': ':garpu_dan_pisau_dengan_piring:',
        'zh': u':餐具:'
    },
    u'\U0001F960': { # 🥠
        'en' : ':fortune_cookie:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':glückskeks:',
        'es': ':galleta_de_la_fortuna:',
        'fr': ':biscuit_chinois:',
        'ja': u':フォーチュンクッキー:',
        'ko': u':포츈_쿠키:',
        'pt': ':biscoito_da_sorte:',
        'it': ':biscotto_della_fortuna:',
        'fa': u':شیرینی_شانس:',
        'id': ':kue_keberuntungan:',
        'zh': u':幸运饼干:'
    },
    u'\U000026F2': { # ⛲
        'en' : ':fountain:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':springbrunnen:',
        'es': ':fuente:',
        'fr': ':fontaine:',
        'ja': u':噴水:',
        'ko': u':분수:',
        'pt': ':fonte:',
        'it': ':fontana:',
        'fa': u':فواره:',
        'id': ':air_mancur:',
        'zh': u':喷泉:'
    },
    u'\U0001F58B\U0000FE0F': { # 🖋️
        'en' : ':fountain_pen:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':lower_left_fountain_pen:'],
        'variant': True,
        'de': u':füllhalter:',
        'es': u':estilográfica:',
        'fr': ':stylo_plume:',
        'ja': u':万年筆:',
        'ko': u':만년필:',
        'pt': ':caneta_tinteiro:',
        'it': ':penna_stilografica:',
        'fa': u':خودنویس:',
        'id': ':pena_tinta:',
        'zh': u':钢笔:'
    },
    u'\U0001F58B': { # 🖋
        'en' : ':fountain_pen:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':lower_left_fountain_pen:'],
        'variant': True,
        'de': u':füllhalter:',
        'es': u':estilográfica:',
        'fr': ':stylo_plume:',
        'ja': u':万年筆:',
        'ko': u':만년필:',
        'pt': ':caneta_tinteiro:',
        'it': ':penna_stilografica:',
        'fa': u':خودنویس:',
        'id': ':pena_tinta:',
        'zh': u':钢笔:'
    },
    u'\U0001F55F': { # 🕟
        'en' : ':four-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock430:'],
        'variant': True,
        'de': ':4.30_uhr:',
        'es': ':cuatro_y_media:',
        'fr': ':quatre_heures_et_demie:',
        'ja': u':4時半:',
        'ko': u':네_시_반:',
        'pt': ':quatro_e_meia:',
        'it': ':ore_quattro_e_mezza:',
        'fa': u':ساعت_چهار_و_نیم:',
        'id': ':jam_setengah_lima:',
        'zh': u':四点半:'
    },
    u'\U0001F340': { # 🍀
        'en' : ':four_leaf_clover:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':glücksklee:',
        'es': u':trébol_de_cuatro_hojas:',
        'fr': u':trèfle_à_quatre_feuilles:',
        'ja': u':四つ葉のクローバー:',
        'ko': u':네잎클로버:',
        'pt': ':trevo_de_quatro_folhas:',
        'it': ':quadrifoglio:',
        'fa': u':شبدر_چهاربرگ:',
        'id': ':empat_daun_semanggi:',
        'zh': u':四叶草:'
    },
    u'\U0001F553': { # 🕓
        'en' : u':four_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock4:'],
        'variant': True,
        'de': ':4.00_uhr:',
        'es': ':4_en_punto:',
        'fr': ':quatre_heures:',
        'ja': u':4時:',
        'ko': u':네_시:',
        'pt': ':4_horas:',
        'it': ':ore_quattro:',
        'fa': u':ساعت_چهار:',
        'id': ':jam_empat_tepat:',
        'zh': u':四点:'
    },
    u'\U0001F98A': { # 🦊
        'en' : ':fox:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':fox_face:'],
        'de': ':fuchs:',
        'es': ':zorro:',
        'fr': ':renard:',
        'ja': u':キツネの顔:',
        'ko': u':여우_얼굴:',
        'pt': ':rosto_de_raposa:',
        'it': ':volpe:',
        'fa': u':روباه:',
        'id': ':rubah:',
        'zh': u':狐狸:'
    },
    u'\U0001F5BC\U0000FE0F': { # 🖼️
        'en' : ':framed_picture:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':frame_with_picture:'],
        'variant': True,
        'de': ':gerahmtes_bild:',
        'es': ':cuadro_enmarcado:',
        'fr': ':cadre_avec_image:',
        'ja': u':絵画:',
        'ko': u':그림_액자:',
        'pt': ':quadro_emoldurado:',
        'it': ':quadro_incorniciato:',
        'fa': u':عکس_در_قاب:',
        'id': ':bingkai_bergambar:',
        'zh': u':带框的画:'
    },
    u'\U0001F5BC': { # 🖼
        'en' : ':framed_picture:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':frame_with_picture:'],
        'variant': True,
        'de': ':gerahmtes_bild:',
        'es': ':cuadro_enmarcado:',
        'fr': ':cadre_avec_image:',
        'ja': u':絵画:',
        'ko': u':그림_액자:',
        'pt': ':quadro_emoldurado:',
        'it': ':quadro_incorniciato:',
        'fa': u':عکس_در_قاب:',
        'id': ':bingkai_bergambar:',
        'zh': u':带框的画:'
    },
    u'\U0001F35F': { # 🍟
        'en' : ':french_fries:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fries:'],
        'de': ':pommes_frites:',
        'es': ':patatas_fritas:',
        'fr': ':frites:',
        'ja': u':フライドポテト:',
        'ko': u':감자튀김:',
        'pt': ':batata_frita:',
        'it': ':patatine:',
        'fa': u':سیب_زمینی_سرخ_کرده:',
        'id': ':kentang_goreng:',
        'zh': u':薯条:'
    },
    u'\U0001F364': { # 🍤
        'en' : ':fried_shrimp:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':frittierte_garnele:',
        'es': ':gamba_frita:',
        'fr': ':beignet_de_crevette:',
        'ja': u':エビフライ:',
        'ko': u':새우튀김:',
        'pt': u':camarão_frito:',
        'it': ':gambero_fritto:',
        'fa': u':میگو_سوخاری:',
        'id': ':udang_goreng:',
        'zh': u':天妇罗:'
    },
    u'\U0001F438': { # 🐸
        'en' : ':frog:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':frosch:',
        'es': ':rana:',
        'fr': ':grenouille:',
        'ja': u':カエルの顔:',
        'ko': u':개구리_얼굴:',
        'pt': ':sapo:',
        'it': ':rana:',
        'fa': u':قورباغه:',
        'id': ':katak:',
        'zh': u':青蛙:'
    },
    u'\U0001F425': { # 🐥
        'en' : ':front-facing_baby_chick:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hatched_chick:'],
        'de': u':küken_von_vorne:',
        'es': ':pollito_de_frente:',
        'fr': ':poussin_de_face:',
        'ja': u':前を向いているひよこ:',
        'ko': u':정면을_향해_날개를_편_병아리:',
        'pt': ':pintinho_de_frente:',
        'it': ':pulcino_visto_di_fronte:',
        'fa': u':جوجه_از_روبرو:',
        'id': ':itik_bayi_menghadap_ke_depan:',
        'zh': u':正面朝向的小鸡:'
    },
    u'\U00002639\U0000FE0F': { # ☹️
        'en' : ':frowning_face:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':white_frowning_face:'],
        'variant': True,
        'de': u':düsteres_gesicht:',
        'es': u':cara_con_el_ceño_fruncido:',
        'fr': u':visage_mécontent:',
        'ja': u':困った顔:',
        'ko': u':찡그린_얼굴:',
        'pt': ':rosto_descontente:',
        'it': ':faccina_imbronciata:',
        'fa': u':اخمو:',
        'id': ':wajah_cemberut:',
        'zh': u':不满:'
    },
    u'\U00002639': { # ☹
        'en' : ':frowning_face:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':white_frowning_face:'],
        'variant': True,
        'de': u':düsteres_gesicht:',
        'es': u':cara_con_el_ceño_fruncido:',
        'fr': u':visage_mécontent:',
        'ja': u':困った顔:',
        'ko': u':찡그린_얼굴:',
        'pt': ':rosto_descontente:',
        'it': ':faccina_imbronciata:',
        'fa': u':اخمو:',
        'id': ':wajah_cemberut:',
        'zh': u':不满:'
    },
    u'\U0001F626': { # 😦
        'en' : ':frowning_face_with_open_mouth:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':frowning:'],
        'de': ':entsetztes_gesicht:',
        'es': u':cara_con_el_ceño_fruncido_y_la_boca_abierta:',
        'fr': u':visage_mécontent_avec_bouche_ouverte:',
        'ja': u':あきれ顔:',
        'ko': u':입_벌리고_찌푸린_얼굴:',
        'pt': ':rosto_franzido_com_boca_aberta:',
        'it': ':faccina_imbronciata_con_bocca_aperta:',
        'fa': u':چهره_درهم_کشیده_با_دهان_باز:',
        'id': ':wajah_mengerutkan_kening_dengan_mulut_terbuka:',
        'zh': u':啊:'
    },
    u'\U000026FD': { # ⛽
        'en' : ':fuel_pump:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fuelpump:'],
        'variant': True,
        'de': u':tanksäule:',
        'es': ':surtidor_de_gasolina:',
        'fr': u':pompe_à_essence:',
        'ja': u':ガソリンスタンド:',
        'ko': u':주유소:',
        'pt': ':posto_de_gasolina:',
        'it': ':stazione_di_servizio:',
        'fa': u':پمپ_بنزین:',
        'id': ':pompa_bahan_bakar:',
        'zh': u':油泵:'
    },
    u'\U0001F315': { # 🌕
        'en' : ':full_moon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':vollmond:',
        'es': ':luna_llena:',
        'fr': ':pleine_lune:',
        'ja': u':満月:',
        'ko': u':보름달:',
        'pt': ':lua_cheia:',
        'it': ':luna_piena:',
        'fa': u':ماه_کامل:',
        'id': ':bulan_purnama:',
        'zh': u':满月:'
    },
    u'\U0001F31D': { # 🌝
        'en' : ':full_moon_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':full_moon_with_face:'],
        'de': ':vollmond_mit_gesicht:',
        'es': ':luna_llena_con_cara:',
        'fr': ':pleine_lune_avec_visage:',
        'ja': u':顔のある満月:',
        'ko': u':얼굴이_있는_보름달:',
        'pt': ':rosto_da_lua_cheia:',
        'it': ':faccina_luna_piena:',
        'fa': u':صورت_ماه_کامل:',
        'id': ':wajah_bulan_purnama:',
        'zh': u':微笑的月亮:'
    },
    u'\U000026B1\U0000FE0F': { # ⚱️
        'en' : ':funeral_urn:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':urne:',
        'es': ':urna_funeraria:',
        'fr': u':urne_funéraire:',
        'ja': u':骨壺:',
        'ko': u':납골_단지:',
        'pt': u':urna_funerária:',
        'it': ':urna_funeraria:',
        'fa': u':خاکستردان:',
        'id': ':guci_abu:',
        'zh': u':骨灰缸:'
    },
    u'\U000026B1': { # ⚱
        'en' : ':funeral_urn:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':urne:',
        'es': ':urna_funeraria:',
        'fr': u':urne_funéraire:',
        'ja': u':骨壺:',
        'ko': u':납골_단지:',
        'pt': u':urna_funerária:',
        'it': ':urna_funeraria:',
        'fa': u':خاکستردان:',
        'id': ':guci_abu:',
        'zh': u':骨灰缸:'
    },
    u'\U0001F3B2': { # 🎲
        'en' : ':game_die:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':spielwürfel:',
        'es': ':dado:',
        'fr': u':dés:',
        'ja': u':サイコロ:',
        'ko': u':주사위:',
        'pt': ':jogo_de_dado:',
        'it': ':dado:',
        'fa': u':تاس_بازی:',
        'id': ':dadu:',
        'zh': u':骰子:'
    },
    u'\U0001F9C4': { # 🧄
        'en' : ':garlic:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':knoblauch:',
        'es': ':ajo:',
        'fr': ':ail:',
        'ja': u':ニンニク:',
        'ko': u':마늘:',
        'pt': ':alho:',
        'it': ':aglio:',
        'fa': u':سیر:',
        'id': ':bawang_putih:',
        'zh': u':蒜:'
    },
    u'\U00002699\U0000FE0F': { # ⚙️
        'en' : ':gear:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':zahnrad:',
        'es': ':engranaje:',
        'fr': u':roue_dentée:',
        'ja': u':歯車:',
        'ko': u':톱니바퀴:',
        'pt': ':engrenagem:',
        'it': ':ingranaggio:',
        'fa': u':چرخ_دنده:',
        'id': ':roda_gigi:',
        'zh': u':齿轮:'
    },
    u'\U00002699': { # ⚙
        'en' : ':gear:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':zahnrad:',
        'es': ':engranaje:',
        'fr': u':roue_dentée:',
        'ja': u':歯車:',
        'ko': u':톱니바퀴:',
        'pt': ':engrenagem:',
        'it': ':ingranaggio:',
        'fa': u':چرخ_دنده:',
        'id': ':roda_gigi:',
        'zh': u':齿轮:'
    },
    u'\U0001F48E': { # 💎
        'en' : ':gem_stone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':gem:'],
        'de': ':edelstein:',
        'es': ':piedra_preciosa:',
        'fr': u':pierre_précieuse:',
        'ja': u':宝石:',
        'ko': u':원석:',
        'pt': ':pedra_preciosa:',
        'it': ':gemma:',
        'fa': u':جواهر:',
        'id': ':batu_permata:',
        'zh': u':宝石:'
    },
    u'\U0001F9DE': { # 🧞
        'en' : ':genie:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':flaschengeist:',
        'es': ':genio:',
        'fr': u':génie:',
        'ja': u':精霊:',
        'ko': u':지니:',
        'pt': u':gênio:',
        'it': ':genio:',
        'fa': u':جن:',
        'id': ':jin:',
        'zh': u':妖怪:'
    },
    u'\U0001F47B': { # 👻
        'en' : ':ghost:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':gespenst:',
        'es': ':fantasma:',
        'fr': u':fantôme:',
        'ja': u':お化け:',
        'ko': u':유령:',
        'pt': ':fantasma:',
        'it': ':fantasma:',
        'fa': u':روح:',
        'id': ':hantu:',
        'zh': u':鬼:'
    },
    u'\U0001FADA': { # 🫚
        'en' : ':ginger_root:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':ingwer:',
        'es': u':raíz_de_jengibre:',
        'fr': ':racine_de_gingembre:',
        'ja': u':ショウガ:',
        'ko': u':생강_뿌리:',
        'pt': ':gengibre:',
        'it': ':radice_di_zenzero:',
        'fa': u':زنجبیل:',
        'id': ':akar_jahe:',
        'zh': u':姜:'
    },
    u'\U0001F992': { # 🦒
        'en' : ':giraffe:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':giraffe:',
        'es': ':jirafa:',
        'fr': ':girafe:',
        'ja': u':キリン:',
        'ko': u':기린:',
        'pt': ':girafa:',
        'it': ':giraffa:',
        'fa': u':زرافه:',
        'id': ':jerapah:',
        'zh': u':长颈鹿:'
    },
    u'\U0001F467': { # 👧
        'en' : ':girl:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':mädchen:',
        'es': u':niña:',
        'fr': ':fille:',
        'ja': u':女の子:',
        'ko': u':여자_아이:',
        'pt': ':menina:',
        'it': ':bambina:',
        'fa': u':دختر:',
        'id': ':anak_perempuan:',
        'zh': u':女孩:'
    },
    u'\U0001F467\U0001F3FF': { # 👧🏿
        'en' : ':girl_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':mädchen_dunkle_hautfarbe:',
        'es': u':niña_tono_de_piel_oscuro:',
        'fr': u':fille_peau_foncée:',
        'ja': u':女の子_濃い肌色:',
        'ko': u':여자_아이_검은색_피부:',
        'pt': ':menina_pele_escura:',
        'it': ':bambina_carnagione_scura:',
        'fa': u':دختر_پوست_آبنوسی:',
        'id': ':anak_perempuan_warna_kulit_gelap:',
        'zh': u':女孩_较深肤色:'
    },
    u'\U0001F467\U0001F3FB': { # 👧🏻
        'en' : ':girl_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':mädchen_helle_hautfarbe:',
        'es': u':niña_tono_de_piel_claro:',
        'fr': ':fille_peau_claire:',
        'ja': u':女の子_薄い肌色:',
        'ko': u':여자_아이_하얀_피부:',
        'pt': ':menina_pele_clara:',
        'it': ':bambina_carnagione_chiara:',
        'fa': u':دختر_پوست_سفید:',
        'id': ':anak_perempuan_warna_kulit_cerah:',
        'zh': u':女孩_较浅肤色:'
    },
    u'\U0001F467\U0001F3FE': { # 👧🏾
        'en' : ':girl_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':mädchen_mitteldunkle_hautfarbe:',
        'es': u':niña_tono_de_piel_oscuro_medio:',
        'fr': ':fille_peau_mate:',
        'ja': u':女の子_やや濃い肌色:',
        'ko': u':여자_아이_진한_갈색_피부:',
        'pt': ':menina_pele_morena_escura:',
        'it': ':bambina_carnagione_abbastanza_scura:',
        'fa': u':دختر_پوست_گندمی:',
        'id': ':anak_perempuan_warna_kulit_gelap-sedang:',
        'zh': u':女孩_中等深肤色:'
    },
    u'\U0001F467\U0001F3FC': { # 👧🏼
        'en' : ':girl_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':mädchen_mittelhelle_hautfarbe:',
        'es': u':niña_tono_de_piel_claro_medio:',
        'fr': ':fille_peau_moyennement_claire:',
        'ja': u':女の子_やや薄い肌色:',
        'ko': u':여자_아이_연한_갈색_피부:',
        'pt': ':menina_pele_morena_clara:',
        'it': ':bambina_carnagione_abbastanza_chiara:',
        'fa': u':دختر_پوست_روشن:',
        'id': ':anak_perempuan_warna_kulit_cerah-sedang:',
        'zh': u':女孩_中等浅肤色:'
    },
    u'\U0001F467\U0001F3FD': { # 👧🏽
        'en' : ':girl_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':mädchen_mittlere_hautfarbe:',
        'es': u':niña_tono_de_piel_medio:',
        'fr': u':fille_peau_légèrement_mate:',
        'ja': u':女の子_中間の肌色:',
        'ko': u':여자_아이_갈색_피부:',
        'pt': ':menina_pele_morena:',
        'it': ':bambina_carnagione_olivastra:',
        'fa': u':دختر_پوست_طلایی:',
        'id': ':anak_perempuan_warna_kulit_sedang:',
        'zh': u':女孩_中等肤色:'
    },
    u'\U0001F95B': { # 🥛
        'en' : ':glass_of_milk:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':milk_glass:'],
        'de': ':glas_milch:',
        'es': ':vaso_de_leche:',
        'fr': ':verre_de_lait:',
        'ja': u':牛乳入りのコップ:',
        'ko': u':우유_한잔:',
        'pt': ':copo_de_leite:',
        'it': ':bicchiere_di_latte:',
        'fa': u':لیوان_شیر:',
        'id': ':gelas_susu:',
        'zh': u':一杯奶:'
    },
    u'\U0001F453': { # 👓
        'en' : ':glasses:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':eyeglasses:'],
        'variant': True,
        'de': ':brille:',
        'es': ':gafas:',
        'fr': ':lunettes_de_vue:',
        'ja': u':メガネ:',
        'ko': u':안경:',
        'pt': u':óculos:',
        'it': ':occhiali_da_vista:',
        'fa': u':عینک_طبی:',
        'id': ':kacamata:',
        'zh': u':眼镜:'
    },
    u'\U0001F30E': { # 🌎
        'en' : ':globe_showing_Americas:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':earth_americas:'],
        'variant': True,
        'de': ':globus_mit_amerika:',
        'es': u':globo_terráqueo_mostrando_américa:',
        'fr': u':globe_tourné_sur_les_amériques:',
        'ja': u':地球(アメリカ大陸):',
        'ko': u':미대륙이_보이는_지구:',
        'pt': u':globo_mostrando_as_américas:',
        'it': ':america:',
        'fa': u':نقشهٔ_قارهٔ_امریکا_روی_کره:',
        'id': ':bola_dunia_amerika:',
        'zh': u':地球上的美洲:'
    },
    u'\U0001F30F': { # 🌏
        'en' : ':globe_showing_Asia-Australia:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':earth_asia:'],
        'variant': True,
        'de': ':globus_mit_asien_und_australien:',
        'es': u':globo_terráqueo_mostrando_asia_y_australia:',
        'fr': u':globe_tourné_sur_l’asie_et_l’australie:',
        'ja': u':地球(アジアとオーストラリア):',
        'ko': u':아시아와_호주가_보이는_지구:',
        'pt': u':globo_mostrando_ásia_e_oceania:',
        'it': ':asia_e_australia:',
        'fa': u':نقشهٔ_آسیا-اقیانوسیه_روی_کره:',
        'id': ':bola_dunia_asia-australia:',
        'zh': u':地球上的亚洲澳洲:'
    },
    u'\U0001F30D': { # 🌍
        'en' : ':globe_showing_Europe-Africa:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':earth_africa:'],
        'variant': True,
        'de': ':globus_mit_europa_und_afrika:',
        'es': u':globo_terráqueo_mostrando_europa_y_áfrica:',
        'fr': u':globe_tourné_sur_l’afrique_et_l’europe:',
        'ja': u':地球(ヨーロッパとアフリカ):',
        'ko': u':유럽과_아프리카가_보이는_지구:',
        'pt': u':globo_mostrando_europa_e_áfrica:',
        'it': ':europa_e_africa:',
        'fa': u':نقشهٔ_اروپا-افریقا_روی_کره:',
        'id': ':bola_dunia_eropa-afrika:',
        'zh': u':地球上的欧洲非洲:'
    },
    u'\U0001F310': { # 🌐
        'en' : ':globe_with_meridians:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':globus_mit_meridianen:',
        'es': u':globo_terráqueo_con_meridianos:',
        'fr': u':globe_avec_méridiens:',
        'ja': u':子午線のある地球:',
        'ko': u':자오선_지구:',
        'pt': ':globo_com_meridianos:',
        'it': ':globo_con_meridiani:',
        'fa': u':کره_با_نصف_النهارها:',
        'id': ':bola_dunia_dengan_garis_meridian:',
        'zh': u':带经纬线的地球:'
    },
    u'\U0001F9E4': { # 🧤
        'en' : ':gloves:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':handschuhe:',
        'es': ':guantes:',
        'fr': ':gants:',
        'ja': u':手袋:',
        'ko': u':장갑:',
        'pt': ':luvas:',
        'it': ':guanti:',
        'fa': u':دستکش:',
        'id': ':sarung_tangan:',
        'zh': u':手套:'
    },
    u'\U0001F31F': { # 🌟
        'en' : ':glowing_star:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':star2:'],
        'de': ':funkelnder_stern:',
        'es': ':estrella_brillante:',
        'fr': u':étoile_brillante:',
        'ja': u':きらきら星:',
        'ko': u':반짝이는_별:',
        'pt': ':estrela_brilhante:',
        'it': ':stella_che_brilla:',
        'fa': u':ستاره_درخشان:',
        'id': ':bintang_bersinar:',
        'zh': u':闪亮的星星:'
    },
    u'\U0001F945': { # 🥅
        'en' : ':goal_net:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tor:',
        'es': u':portería:',
        'fr': ':cage:',
        'ja': u':ゴールネット:',
        'ko': u':골대:',
        'pt': ':gol:',
        'it': ':porta_da_calcio:',
        'fa': u':دروازه:',
        'id': ':gawang:',
        'zh': u':球门:'
    },
    u'\U0001F410': { # 🐐
        'en' : ':goat:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ziege:',
        'es': ':cabra:',
        'fr': u':chèvre:',
        'ja': u':山羊:',
        'ko': u':염소:',
        'pt': ':cabra:',
        'it': ':capra:',
        'fa': u':بز:',
        'id': ':kambing:',
        'zh': u':山羊:'
    },
    u'\U0001F47A': { # 👺
        'en' : ':goblin:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':japanese_goblin:'],
        'de': ':kobold:',
        'es': u':demonio_japonés_tengu:',
        'fr': ':monstre_japonais:',
        'ja': u':天狗:',
        'ko': u':코주부_도깨비_가면:',
        'pt': u':duende_japonês:',
        'it': ':goblin:',
        'fa': u':جن_کوتوله:',
        'id': ':topeng_hidung_panjang:',
        'zh': u':小妖精:'
    },
    u'\U0001F97D': { # 🥽
        'en' : ':goggles:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':schutzbrille:',
        'es': u':gafas_de_protección:',
        'fr': ':lunettes:',
        'ja': u':ゴーグル:',
        'ko': u':고글:',
        'pt': u':óculos_de_proteção:',
        'it': ':maschera:',
        'fa': u':عینک_ایمنی:',
        'id': ':kacamata_renang:',
        'zh': u':护目镜:'
    },
    u'\U0001FABF': { # 🪿
        'en' : ':goose:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':gans:',
        'es': ':oca:',
        'fr': ':oie:',
        'ja': u':ガチョウ:',
        'ko': u':거위:',
        'pt': ':ganso:',
        'it': ':oca:',
        'fa': u':غاز:',
        'id': ':angsa_leher_pendek:',
        'zh': u':鹅:'
    },
    u'\U0001F98D': { # 🦍
        'en' : ':gorilla:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':gorilla:',
        'es': ':gorila:',
        'fr': ':gorille:',
        'ja': u':ゴリラ:',
        'ko': u':고릴라:',
        'pt': ':gorila:',
        'it': ':gorilla:',
        'fa': u':گوریل:',
        'id': ':gorila:',
        'zh': u':大猩猩:'
    },
    u'\U0001F393': { # 🎓
        'en' : ':graduation_cap:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mortar_board:'],
        'variant': True,
        'de': ':doktorhut:',
        'es': ':birrete:',
        'fr': ':toque_universitaire:',
        'ja': u':角帽:',
        'ko': u':졸업_모자:',
        'pt': u':chapéu_de_formatura:',
        'it': ':cappello_da_laureato:',
        'fa': u':کلاه_فارغ_التحصیلی:',
        'id': ':topi_wisuda:',
        'zh': u':毕业帽:'
    },
    u'\U0001F347': { # 🍇
        'en' : ':grapes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':trauben:',
        'es': ':uvas:',
        'fr': ':raisin:',
        'ja': u':ぶどう:',
        'ko': u':포도:',
        'pt': ':uvas:',
        'it': ':uva:',
        'fa': u':انگور:',
        'id': ':anggur:',
        'zh': u':葡萄:'
    },
    u'\U0001F34F': { # 🍏
        'en' : ':green_apple:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':grüner_apfel:',
        'es': ':manzana_verde:',
        'fr': ':pomme_verte:',
        'ja': u':青リンゴ:',
        'ko': u':초록_사과:',
        'pt': u':maçã_verde:',
        'it': ':mela_verde:',
        'fa': u':سیب_سبز:',
        'id': ':apel_hijau:',
        'zh': u':青苹果:'
    },
    u'\U0001F4D7': { # 📗
        'en' : ':green_book:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':grünes_buch:',
        'es': ':libro_verde:',
        'fr': ':livre_vert:',
        'ja': u':緑の本:',
        'ko': u':초록색_책:',
        'pt': ':livro_verde:',
        'it': ':libro_verde:',
        'fa': u':کتاب_سبز:',
        'id': ':buku_hijau:',
        'zh': u':绿色书本:'
    },
    u'\U0001F7E2': { # 🟢
        'en' : ':green_circle:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':grüner_punkt:',
        'es': u':círculo_verde:',
        'fr': ':disque_vert:',
        'ja': u':緑の丸:',
        'ko': u':녹색_원:',
        'pt': u':círculo_verde:',
        'it': ':cerchio_verde:',
        'fa': u':دایره_سبز:',
        'id': ':lingkaran_hijau:',
        'zh': u':绿色圆:'
    },
    u'\U0001F49A': { # 💚
        'en' : ':green_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':grünes_herz:',
        'es': u':corazón_verde:',
        'fr': u':cœur_vert:',
        'ja': u':緑のハート:',
        'ko': u':초록색_하트:',
        'pt': u':coração_verde:',
        'it': ':cuore_verde:',
        'fa': u':قلب_سبز:',
        'id': ':hati_hijau:',
        'zh': u':绿心:'
    },
    u'\U0001F957': { # 🥗
        'en' : ':green_salad:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':salat:',
        'es': ':ensalada:',
        'fr': ':salade_verte:',
        'ja': u':グリーンサラダ:',
        'ko': u':야채샐러드:',
        'pt': ':salada_verde:',
        'it': ':insalata_verde:',
        'fa': u':سالاد_سبزیجات:',
        'id': ':salad_hijau:',
        'zh': u':绿色沙拉:'
    },
    u'\U0001F7E9': { # 🟩
        'en' : ':green_square:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':grünes_quadrat:',
        'es': ':cuadrado_verde:',
        'fr': u':carré_vert:',
        'ja': u':緑の四角:',
        'ko': u':녹색_사각형:',
        'pt': ':quadrado_verde:',
        'it': ':quadrato_verde:',
        'fa': u':مربع_سبز:',
        'id': ':persegi_hijau:',
        'zh': u':绿色方块:'
    },
    u'\U0001FA76': { # 🩶
        'en' : ':grey_heart:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':graues_herz:',
        'es': u':corazón_gris:',
        'fr': u':cœur_gris:',
        'ja': u':灰色のハート:',
        'ko': u':회색_하트:',
        'pt': u':coração_cinza:',
        'it': ':cuore_grigio:',
        'fa': u':قلب_خاکستری:',
        'id': ':hati_abu-abu:',
        'zh': u':灰心:'
    },
    u'\U0001F62C': { # 😬
        'en' : ':grimacing_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':grimacing:'],
        'de': ':grimassen_schneidendes_gesicht:',
        'es': ':cara_haciendo_una_mueca:',
        'fr': u':visage_grimaçant:',
        'ja': u':しかめ面:',
        'ko': u':찌푸린_얼굴:',
        'pt': ':rosto_expressando_desagrado:',
        'it': ':faccina_con_smorfia:',
        'fa': u':دهن_کجی:',
        'id': ':wajah_menyeringai:',
        'zh': u':龇牙咧嘴:'
    },
    u'\U0001F63A': { # 😺
        'en' : ':grinning_cat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':smiley_cat:'],
        'de': ':grinsende_katze:',
        'es': ':gato_sonriendo:',
        'fr': ':chat_qui_sourit:',
        'ja': u':にっこり笑う猫:',
        'ko': u':활짝_웃는_고양이_얼굴:',
        'pt': ':rosto_de_gato_sorrindo:',
        'it': ':gatto_che_sorride:',
        'fa': u':گربهٔ_خندان:',
        'id': ':wajah_kucing_tersenyum_lebar:',
        'zh': u':大笑的猫:'
    },
    u'\U0001F638': { # 😸
        'en' : ':grinning_cat_with_smiling_eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':smile_cat:'],
        'de': ':grinsende_katze_mit_lachenden_augen:',
        'es': ':gato_sonriendo_con_ojos_sonrientes:',
        'fr': ':chat_qui_sourit_avec_des_yeux_rieurs:',
        'ja': u':にやっと笑う猫:',
        'ko': u':미소_짓는_눈으로_활짝_웃는_고양이_얼굴:',
        'pt': ':rosto_de_gato_sorrindo_com_olhos_sorridentes:',
        'it': ':gatto_che_sogghigna:',
        'fa': u':گربه_با_چشم_های_خندان:',
        'id': ':wajah_kucing_gembira_dengan_mata_bahagia:',
        'zh': u':微笑的猫:'
    },
    u'\U0001F600': { # 😀
        'en' : ':grinning_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':grinning:'],
        'de': ':grinsendes_gesicht:',
        'es': ':cara_sonriendo:',
        'fr': ':visage_rieur:',
        'ja': u':にっこり笑う:',
        'ko': u':활짝_웃는_얼굴:',
        'pt': ':rosto_risonho:',
        'it': ':faccina_con_un_gran_sorriso:',
        'fa': u':خنده:',
        'id': ':wajah_gembira:',
        'zh': u':嘿嘿:'
    },
    u'\U0001F603': { # 😃
        'en' : ':grinning_face_with_big_eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':smiley:'],
        'de': u':grinsendes_gesicht_mit_großen_augen:',
        'es': ':cara_sonriendo_con_ojos_grandes:',
        'fr': ':visage_souriant_avec_de_grands_yeux:',
        'ja': u':わーい:',
        'ko': u':눈을_크게_뜨고_웃는_얼굴:',
        'pt': ':rosto_risonho_com_olhos_bem_abertos:',
        'it': ':faccina_con_un_gran_sorriso_e_occhi_spalancati:',
        'fa': u':صورت_خندان:',
        'id': ':wajah_tersenyum_lebar:',
        'zh': u':哈哈:'
    },
    u'\U0001F604': { # 😄
        'en' : ':grinning_face_with_smiling_eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':smile:'],
        'de': ':grinsendes_gesicht_mit_lachenden_augen:',
        'es': ':cara_sonriendo_con_ojos_sonrientes:',
        'fr': u':visage_très_souriant_aux_yeux_rieurs:',
        'ja': u':笑顔:',
        'ko': u':미소_짓는_눈으로_활짝_웃는_얼굴:',
        'pt': ':rosto_risonho_com_olhos_sorridentes:',
        'it': ':faccina_con_sorriso_e_occhi_sorridenti:',
        'fa': u':خندان:',
        'id': ':wajah_tersenyum_lebar_dan_mata_tertutup:',
        'zh': u':大笑:'
    },
    u'\U0001F605': { # 😅
        'en' : ':grinning_face_with_sweat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sweat_smile:'],
        'de': u':grinsendes_gesicht_mit_schweißtropfen:',
        'es': u':cara_sonriendo_con_sudor_frío:',
        'fr': ':visage_souriant_avec_une_goutte_de_sueur:',
        'ja': u':冷や汗笑顔:',
        'ko': u':땀_흘리며_웃는_얼굴:',
        'pt': ':rosto_risonho_com_gota_de_suor:',
        'it': ':faccina_con_un_gran_sorriso_e_goccia_di_sudore:',
        'fa': u':صورت_خندان_و_عرق_کرده:',
        'id': ':wajah_tersenyum_lebar_dan_berkeringat:',
        'zh': u':苦笑:'
    },
    u'\U0001F606': { # 😆
        'en' : ':grinning_squinting_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':satisfied:', ':laughing:'],
        'de': ':grinsegesicht_mit_zugekniffenen_augen:',
        'es': ':cara_sonriendo_con_los_ojos_cerrados:',
        'fr': u':visage_souriant_avec_yeux_plissés:',
        'ja': u':きゃー:',
        'ko': u':눈웃음짓는_얼굴:',
        'pt': ':rosto_risonho_com_olhos_semicerrados:',
        'it': ':sorriso_a_bocca_aperta_con_occhi_chiusi:',
        'fa': u':قاه_قاه:',
        'id': ':wajah_tersenyum_lebar_dan_memejamkan_mata:',
        'zh': u':斜眼笑:'
    },
    u'\U0001F497': { # 💗
        'en' : ':growing_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heartpulse:'],
        'de': ':wachsendes_herz:',
        'es': u':corazón_creciente:',
        'fr': u':cœur_grandissant:',
        'ja': u':大きくなるハート:',
        'ko': u':커지는_하트:',
        'pt': u':coração_crescendo:',
        'it': ':cuore_che_cresce:',
        'fa': u':قلب_هیجان_زده:',
        'id': ':hati_membesar:',
        'zh': u':搏动的心:'
    },
    u'\U0001F482': { # 💂
        'en' : ':guard:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wache:',
        'es': ':guardia:',
        'fr': ':garde:',
        'ja': u':衛兵:',
        'ko': u':근위병:',
        'pt': ':guarda:',
        'it': ':guardia:',
        'fa': u':گارد_نظامی:',
        'id': ':penjaga:',
        'zh': u':卫兵:'
    },
    u'\U0001F482\U0001F3FF': { # 💂🏿
        'en' : ':guard_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':wachmann/wachfrau_dunkle_hautfarbe:',
        'es': ':guardia_tono_de_piel_oscuro:',
        'fr': u':garde_peau_foncée:',
        'ja': u':衛兵_濃い肌色:',
        'ko': u':근위병_검은색_피부:',
        'pt': ':guarda_pele_escura:',
        'it': ':guardia_carnagione_scura:',
        'fa': u':گارد_نظامی_پوست_آبنوسی:',
        'id': ':penjaga_warna_kulit_gelap:',
        'zh': u':卫兵_较深肤色:'
    },
    u'\U0001F482\U0001F3FB': { # 💂🏻
        'en' : ':guard_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':wachmann/wachfrau_helle_hautfarbe:',
        'es': ':guardia_tono_de_piel_claro:',
        'fr': ':garde_peau_claire:',
        'ja': u':衛兵_薄い肌色:',
        'ko': u':근위병_하얀_피부:',
        'pt': ':guarda_pele_clara:',
        'it': ':guardia_carnagione_chiara:',
        'fa': u':گارد_نظامی_پوست_سفید:',
        'id': ':penjaga_warna_kulit_cerah:',
        'zh': u':卫兵_较浅肤色:'
    },
    u'\U0001F482\U0001F3FE': { # 💂🏾
        'en' : ':guard_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':wachmann/wachfrau_mitteldunkle_hautfarbe:',
        'es': ':guardia_tono_de_piel_oscuro_medio:',
        'fr': ':garde_peau_mate:',
        'ja': u':衛兵_やや濃い肌色:',
        'ko': u':근위병_진한_갈색_피부:',
        'pt': ':guarda_pele_morena_escura:',
        'it': ':guardia_carnagione_abbastanza_scura:',
        'fa': u':گارد_نظامی_پوست_گندمی:',
        'id': ':penjaga_warna_kulit_gelap-sedang:',
        'zh': u':卫兵_中等深肤色:'
    },
    u'\U0001F482\U0001F3FC': { # 💂🏼
        'en' : ':guard_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':wachmann/wachfrau_mittelhelle_hautfarbe:',
        'es': ':guardia_tono_de_piel_claro_medio:',
        'fr': ':garde_peau_moyennement_claire:',
        'ja': u':衛兵_やや薄い肌色:',
        'ko': u':근위병_연한_갈색_피부:',
        'pt': ':guarda_pele_morena_clara:',
        'it': ':guardia_carnagione_abbastanza_chiara:',
        'fa': u':گارد_نظامی_پوست_روشن:',
        'id': ':penjaga_warna_kulit_cerah-sedang:',
        'zh': u':卫兵_中等浅肤色:'
    },
    u'\U0001F482\U0001F3FD': { # 💂🏽
        'en' : ':guard_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':wachmann/wachfrau_mittlere_hautfarbe:',
        'es': ':guardia_tono_de_piel_medio:',
        'fr': u':garde_peau_légèrement_mate:',
        'ja': u':衛兵_中間の肌色:',
        'ko': u':근위병_갈색_피부:',
        'pt': ':guarda_pele_morena:',
        'it': ':guardia_carnagione_olivastra:',
        'fa': u':گارد_نظامی_پوست_طلایی:',
        'id': ':penjaga_warna_kulit_sedang:',
        'zh': u':卫兵_中等肤色:'
    },
    u'\U0001F9AE': { # 🦮
        'en' : ':guide_dog:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':blindenhund:',
        'es': u':perro_guía:',
        'fr': ':chien_guide:',
        'ja': u':盲導犬:',
        'ko': u':안내견:',
        'pt': u':cão-guia:',
        'it': ':cane_guida:',
        'fa': u':سگ_راهنما:',
        'id': ':anjing_pemandu:',
        'zh': u':导盲犬:'
    },
    u'\U0001F3B8': { # 🎸
        'en' : ':guitar:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':gitarre:',
        'es': ':guitarra:',
        'fr': ':guitare:',
        'ja': u':ギター:',
        'ko': u':기타:',
        'pt': ':guitarra:',
        'it': ':chitarra:',
        'fa': u':گیتار:',
        'id': ':gitar:',
        'zh': u':吉他:'
    },
    u'\U0001FAAE': { # 🪮
        'en' : ':hair_pick:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':haarkamm:',
        'es': ':peineta:',
        'fr': ':peigne_afro:',
        'ja': u':アフロコーム:',
        'ko': u':머리_빗:',
        'pt': ':pente_de_cabelo:',
        'it': ':pettine_afro:',
        'fa': u':شانه_جداکننده:',
        'id': ':sisir_garpu:',
        'zh': u':发夹:'
    },
    u'\U0001F354': { # 🍔
        'en' : ':hamburger:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':hamburger:',
        'es': ':hamburguesa:',
        'fr': ':hamburger:',
        'ja': u':ハンバーガー:',
        'ko': u':햄버거:',
        'pt': u':hambúrguer:',
        'it': ':hamburger:',
        'fa': u':همبرگر:',
        'id': ':hamburger:',
        'zh': u':汉堡:'
    },
    u'\U0001F528': { # 🔨
        'en' : ':hammer:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':hammer:',
        'es': ':martillo:',
        'fr': ':marteau:',
        'ja': u':ハンマー:',
        'ko': u':망치:',
        'pt': ':martelo:',
        'it': ':martello:',
        'fa': u':چکش:',
        'id': ':palu:',
        'zh': u':锤子:'
    },
    u'\U00002692\U0000FE0F': { # ⚒️
        'en' : ':hammer_and_pick:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':hammer_und_pickel:',
        'es': ':martillo_y_pico:',
        'fr': ':marteau_et_pioche:',
        'ja': u':ハンマーとつるはし:',
        'ko': u':망치와_곡괭이:',
        'pt': ':martelo_e_picareta:',
        'it': ':piccone_e_martello:',
        'fa': u':چکش_و_کلنگ:',
        'id': ':palu_dan_beliung:',
        'zh': u':锤子与镐:'
    },
    u'\U00002692': { # ⚒
        'en' : ':hammer_and_pick:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':hammer_und_pickel:',
        'es': ':martillo_y_pico:',
        'fr': ':marteau_et_pioche:',
        'ja': u':ハンマーとつるはし:',
        'ko': u':망치와_곡괭이:',
        'pt': ':martelo_e_picareta:',
        'it': ':piccone_e_martello:',
        'fa': u':چکش_و_کلنگ:',
        'id': ':palu_dan_beliung:',
        'zh': u':锤子与镐:'
    },
    u'\U0001F6E0\U0000FE0F': { # 🛠️
        'en' : ':hammer_and_wrench:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':hammer_und_schraubenschlüssel:',
        'es': ':martillo_y_llave_inglesa:',
        'fr': u':marteau_et_clé_à_molette:',
        'ja': u':ハンマーとレンチ:',
        'ko': u':망치와_렌치:',
        'pt': ':martelo_e_chave-inglesa:',
        'it': ':martello_e_chiave_inglese:',
        'fa': u':چکش_و_آچار:',
        'id': ':palu_dan_kunci_inggris:',
        'zh': u':锤子与扳手:'
    },
    u'\U0001F6E0': { # 🛠
        'en' : ':hammer_and_wrench:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':hammer_und_schraubenschlüssel:',
        'es': ':martillo_y_llave_inglesa:',
        'fr': u':marteau_et_clé_à_molette:',
        'ja': u':ハンマーとレンチ:',
        'ko': u':망치와_렌치:',
        'pt': ':martelo_e_chave-inglesa:',
        'it': ':martello_e_chiave_inglese:',
        'fa': u':چکش_و_آچار:',
        'id': ':palu_dan_kunci_inggris:',
        'zh': u':锤子与扳手:'
    },
    u'\U0001FAAC': { # 🪬
        'en' : ':hamsa:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':hamsa:',
        'es': ':hamsa:',
        'fr': ':main_de_fatma:',
        'ja': u':ハムサ:',
        'ko': u':함사:',
        'pt': u':hamsá:',
        'it': ':mano_di_fatima:',
        'fa': u':خمسه:',
        'id': ':hamsa:',
        'zh': u':法蒂玛之手:'
    },
    u'\U0001F439': { # 🐹
        'en' : ':hamster:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':hamster:',
        'es': u':hámster:',
        'fr': ':hamster:',
        'ja': u':ハムスターの顔:',
        'ko': u':햄스터_얼굴:',
        'pt': ':rosto_de_hamster:',
        'it': ':criceto:',
        'fa': u':همستر:',
        'id': ':hamster:',
        'zh': u':仓鼠:'
    },
    u'\U0001F590\U0000FE0F': { # 🖐️
        'en' : ':hand_with_fingers_splayed:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':raised_hand_with_fingers_splayed:'],
        'variant': True,
        'de': ':hand_mit_gespreizten_fingern:',
        'es': ':mano_abierta:',
        'fr': u':main_levée_doigts_écartés:',
        'ja': u':開いた手:',
        'ko': u':쫙_편_손바닥:',
        'pt': u':mão_aberta_com_os_dedos_separados:',
        'it': ':mano_aperta:',
        'fa': u':دست_با_انگشتان_باز:',
        'id': ':telapak_tangan_terbuka:',
        'zh': u':手掌:'
    },
    u'\U0001F590': { # 🖐
        'en' : ':hand_with_fingers_splayed:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':raised_hand_with_fingers_splayed:'],
        'variant': True,
        'de': ':hand_mit_gespreizten_fingern:',
        'es': ':mano_abierta:',
        'fr': u':main_levée_doigts_écartés:',
        'ja': u':開いた手:',
        'ko': u':쫙_편_손바닥:',
        'pt': u':mão_aberta_com_os_dedos_separados:',
        'it': ':mano_aperta:',
        'fa': u':دست_با_انگشتان_باز:',
        'id': ':telapak_tangan_terbuka:',
        'zh': u':手掌:'
    },
    u'\U0001F590\U0001F3FF': { # 🖐🏿
        'en' : ':hand_with_fingers_splayed_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':hand_mit_gespreizten_fingern_dunkle_hautfarbe:',
        'es': ':mano_abierta_tono_de_piel_oscuro:',
        'fr': u':main_levée_doigts_écartés_peau_foncée:',
        'ja': u':開いた手_濃い肌色:',
        'ko': u':쫙_편_손바닥_검은색_피부:',
        'pt': u':mão_aberta_com_os_dedos_separados_pele_escura:',
        'it': ':mano_aperta_carnagione_scura:',
        'fa': u':دست_با_انگشتان_باز_پوست_آبنوسی:',
        'id': ':telapak_tangan_terbuka_warna_kulit_gelap:',
        'zh': u':手掌_较深肤色:'
    },
    u'\U0001F590\U0001F3FB': { # 🖐🏻
        'en' : ':hand_with_fingers_splayed_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':hand_mit_gespreizten_fingern_helle_hautfarbe:',
        'es': ':mano_abierta_tono_de_piel_claro:',
        'fr': u':main_levée_doigts_écartés_peau_claire:',
        'ja': u':開いた手_薄い肌色:',
        'ko': u':쫙_편_손바닥_하얀_피부:',
        'pt': u':mão_aberta_com_os_dedos_separados_pele_clara:',
        'it': ':mano_aperta_carnagione_chiara:',
        'fa': u':دست_با_انگشتان_باز_پوست_سفید:',
        'id': ':telapak_tangan_terbuka_warna_kulit_cerah:',
        'zh': u':手掌_较浅肤色:'
    },
    u'\U0001F590\U0001F3FE': { # 🖐🏾
        'en' : ':hand_with_fingers_splayed_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':hand_mit_gespreizten_fingern_mitteldunkle_hautfarbe:',
        'es': ':mano_abierta_tono_de_piel_oscuro_medio:',
        'fr': u':main_levée_doigts_écartés_peau_mate:',
        'ja': u':開いた手_やや濃い肌色:',
        'ko': u':쫙_편_손바닥_진한_갈색_피부:',
        'pt': u':mão_aberta_com_os_dedos_separados_pele_morena_escura:',
        'it': ':mano_aperta_carnagione_abbastanza_scura:',
        'fa': u':دست_با_انگشتان_باز_پوست_گندمی:',
        'id': ':telapak_tangan_terbuka_warna_kulit_gelap-sedang:',
        'zh': u':手掌_中等深肤色:'
    },
    u'\U0001F590\U0001F3FC': { # 🖐🏼
        'en' : ':hand_with_fingers_splayed_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':hand_mit_gespreizten_fingern_mittelhelle_hautfarbe:',
        'es': ':mano_abierta_tono_de_piel_claro_medio:',
        'fr': u':main_levée_doigts_écartés_peau_moyennement_claire:',
        'ja': u':開いた手_やや薄い肌色:',
        'ko': u':쫙_편_손바닥_연한_갈색_피부:',
        'pt': u':mão_aberta_com_os_dedos_separados_pele_morena_clara:',
        'it': ':mano_aperta_carnagione_abbastanza_chiara:',
        'fa': u':دست_با_انگشتان_باز_پوست_روشن:',
        'id': ':telapak_tangan_terbuka_warna_kulit_cerah-sedang:',
        'zh': u':手掌_中等浅肤色:'
    },
    u'\U0001F590\U0001F3FD': { # 🖐🏽
        'en' : ':hand_with_fingers_splayed_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':hand_mit_gespreizten_fingern_mittlere_hautfarbe:',
        'es': ':mano_abierta_tono_de_piel_medio:',
        'fr': u':main_levée_doigts_écartés_peau_légèrement_mate:',
        'ja': u':開いた手_中間の肌色:',
        'ko': u':쫙_편_손바닥_갈색_피부:',
        'pt': u':mão_aberta_com_os_dedos_separados_pele_morena:',
        'it': ':mano_aperta_carnagione_olivastra:',
        'fa': u':دست_با_انگشتان_باز_پوست_طلایی:',
        'id': ':telapak_tangan_terbuka_warna_kulit_sedang:',
        'zh': u':手掌_中等肤色:'
    },
    u'\U0001FAF0': { # 🫰
        'en' : ':hand_with_index_finger_and_thumb_crossed:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':hand_mit_gekreuztem_zeigefinger_und_daumen:',
        'es': u':mano_con_dedo_índice_y_pulgar_cruzados:',
        'fr': u':main_avec_index_et_pouce_croisés:',
        'ja': u':親指と人差し指をクロス:',
        'ko': u':엄지와_중지를_교차한_손:',
        'pt': u':mão_com_dedo_indicador_e_polegar_cruzados:',
        'it': ':mano_con_indice_e_pollice_incrociati:',
        'fa': u':دست_با_انگشت_اشاره_و_شست_متقاطع:',
        'id': ':tangan_dengan_jari_telunjuk_dan_ibu_jari_menyilang:',
        'zh': u':食指与拇指交叉的手:'
    },
    u'\U0001FAF0\U0001F3FF': { # 🫰🏿
        'en' : ':hand_with_index_finger_and_thumb_crossed_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF0\U0001F3FB': { # 🫰🏻
        'en' : ':hand_with_index_finger_and_thumb_crossed_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF0\U0001F3FE': { # 🫰🏾
        'en' : ':hand_with_index_finger_and_thumb_crossed_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF0\U0001F3FC': { # 🫰🏼
        'en' : ':hand_with_index_finger_and_thumb_crossed_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF0\U0001F3FD': { # 🫰🏽
        'en' : ':hand_with_index_finger_and_thumb_crossed_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F45C': { # 👜
        'en' : ':handbag:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':handtasche:',
        'es': ':bolso:',
        'fr': u':sac_à_main:',
        'ja': u':ハンドバッグ:',
        'ko': u':핸드백:',
        'pt': u':bolsa_de_mão:',
        'it': ':borsa:',
        'fa': u':کیف_دوشی:',
        'id': ':tas_jinjing:',
        'zh': u':手提包:'
    },
    u'\U0001F91D': { # 🤝
        'en' : ':handshake:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':handschlag:',
        'es': u':apretón_de_manos:',
        'fr': u':poignée_de_main:',
        'ja': u':握手:',
        'ko': u':악수:',
        'pt': u':aperto_de_mãos:',
        'it': ':stretta_di_mano:',
        'fa': u':دست_دادن:',
        'id': ':jabat_tangan:',
        'zh': u':握手:'
    },
    u'\U0001F91D\U0001F3FF': { # 🤝🏿
        'en' : ':handshake_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FF\U0000200D\U0001FAF2\U0001F3FB': { # 🫱🏿‍🫲🏻
        'en' : ':handshake_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FF\U0000200D\U0001FAF2\U0001F3FE': { # 🫱🏿‍🫲🏾
        'en' : ':handshake_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FF\U0000200D\U0001FAF2\U0001F3FC': { # 🫱🏿‍🫲🏼
        'en' : ':handshake_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FF\U0000200D\U0001FAF2\U0001F3FD': { # 🫱🏿‍🫲🏽
        'en' : ':handshake_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F91D\U0001F3FB': { # 🤝🏻
        'en' : ':handshake_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FB\U0000200D\U0001FAF2\U0001F3FF': { # 🫱🏻‍🫲🏿
        'en' : ':handshake_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FB\U0000200D\U0001FAF2\U0001F3FE': { # 🫱🏻‍🫲🏾
        'en' : ':handshake_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FB\U0000200D\U0001FAF2\U0001F3FC': { # 🫱🏻‍🫲🏼
        'en' : ':handshake_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FB\U0000200D\U0001FAF2\U0001F3FD': { # 🫱🏻‍🫲🏽
        'en' : ':handshake_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F91D\U0001F3FE': { # 🤝🏾
        'en' : ':handshake_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FE\U0000200D\U0001FAF2\U0001F3FF': { # 🫱🏾‍🫲🏿
        'en' : ':handshake_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FE\U0000200D\U0001FAF2\U0001F3FB': { # 🫱🏾‍🫲🏻
        'en' : ':handshake_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FE\U0000200D\U0001FAF2\U0001F3FC': { # 🫱🏾‍🫲🏼
        'en' : ':handshake_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FE\U0000200D\U0001FAF2\U0001F3FD': { # 🫱🏾‍🫲🏽
        'en' : ':handshake_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F91D\U0001F3FC': { # 🤝🏼
        'en' : ':handshake_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FC\U0000200D\U0001FAF2\U0001F3FF': { # 🫱🏼‍🫲🏿
        'en' : ':handshake_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FC\U0000200D\U0001FAF2\U0001F3FB': { # 🫱🏼‍🫲🏻
        'en' : ':handshake_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FC\U0000200D\U0001FAF2\U0001F3FE': { # 🫱🏼‍🫲🏾
        'en' : ':handshake_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FC\U0000200D\U0001FAF2\U0001F3FD': { # 🫱🏼‍🫲🏽
        'en' : ':handshake_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F91D\U0001F3FD': { # 🤝🏽
        'en' : ':handshake_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FD\U0000200D\U0001FAF2\U0001F3FF': { # 🫱🏽‍🫲🏿
        'en' : ':handshake_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FD\U0000200D\U0001FAF2\U0001F3FB': { # 🫱🏽‍🫲🏻
        'en' : ':handshake_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FD\U0000200D\U0001FAF2\U0001F3FE': { # 🫱🏽‍🫲🏾
        'en' : ':handshake_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FD\U0000200D\U0001FAF2\U0001F3FC': { # 🫱🏽‍🫲🏼
        'en' : ':handshake_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F423': { # 🐣
        'en' : ':hatching_chick:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':schlüpfendes_küken:',
        'es': u':pollito_rompiendo_el_cascarón:',
        'fr': u':poussin_qui_éclôt:',
        'ja': u':卵からかえったひよこ:',
        'ko': u':알에서_깬_병아리:',
        'pt': ':pintinho_chocando:',
        'it': ':pulcino_che_nasce:',
        'fa': u':جوجه_ازتخم_بیرون_آمده:',
        'id': ':itik_menetas:',
        'zh': u':小鸡破壳:'
    },
    u'\U0001F3A7': { # 🎧
        'en' : ':headphone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':headphones:'],
        'variant': True,
        'de': u':kopfhörer:',
        'es': ':auricular:',
        'fr': ':casque:',
        'ja': u':ヘッドホン:',
        'ko': u':헤드폰:',
        'pt': ':fones_de_ouvido:',
        'it': ':cuffie:',
        'fa': u':هدفون:',
        'id': ':headphone:',
        'zh': u':耳机:'
    },
    u'\U0001FAA6': { # 🪦
        'en' : ':headstone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':grabstein:',
        'es': u':lápida:',
        'fr': ':pierre_tombale:',
        'ja': u':墓石:',
        'ko': u':묘비:',
        'pt': u':lápide:',
        'it': ':lapide:',
        'fa': u':سنگ_قبر:',
        'id': ':batu_nisan:',
        'zh': u':墓碑:'
    },
    u'\U0001F9D1\U0000200D\U00002695\U0000FE0F': { # 🧑‍⚕️
        'en' : ':health_worker:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin:',
        'es': ':profesional_sanitario:',
        'fr': u':professionnel_de_la_santé_(tous_genres):',
        'ja': u':医者:',
        'ko': u':의료인:',
        'pt': u':profissional_de_saúde:',
        'it': u':persona_che_lavora_nella_sanità:',
        'fa': u':مأمور_بهداشت:',
        'id': ':petugas_kesehatan:',
        'zh': u':卫生工作者:'
    },
    u'\U0001F9D1\U0000200D\U00002695': { # 🧑‍⚕
        'en' : ':health_worker:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin:',
        'es': ':profesional_sanitario:',
        'fr': u':professionnel_de_la_santé_(tous_genres):',
        'ja': u':医者:',
        'ko': u':의료인:',
        'pt': u':profissional_de_saúde:',
        'it': u':persona_che_lavora_nella_sanità:',
        'fa': u':مأمور_بهداشت:',
        'id': ':petugas_kesehatan:',
        'zh': u':卫生工作者:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002695\U0000FE0F': { # 🧑🏿‍⚕️
        'en' : ':health_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_dunkle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_oscuro:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_foncée:',
        'ja': u':医者_濃い肌色:',
        'ko': u':의료인_검은색_피부:',
        'pt': u':profissional_de_saúde_pele_escura:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_scura:',
        'fa': u':مأمور_بهداشت_پوست_آبنوسی:',
        'id': ':petugas_kesehatan_warna_kulit_gelap:',
        'zh': u':卫生工作者_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002695': { # 🧑🏿‍⚕
        'en' : ':health_worker_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_dunkle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_oscuro:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_foncée:',
        'ja': u':医者_濃い肌色:',
        'ko': u':의료인_검은색_피부:',
        'pt': u':profissional_de_saúde_pele_escura:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_scura:',
        'fa': u':مأمور_بهداشت_پوست_آبنوسی:',
        'id': ':petugas_kesehatan_warna_kulit_gelap:',
        'zh': u':卫生工作者_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002695\U0000FE0F': { # 🧑🏻‍⚕️
        'en' : ':health_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_helle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_claro:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_claire:',
        'ja': u':医者_薄い肌色:',
        'ko': u':의료인_하얀_피부:',
        'pt': u':profissional_de_saúde_pele_clara:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_chiara:',
        'fa': u':مأمور_بهداشت_پوست_سفید:',
        'id': ':petugas_kesehatan_warna_kulit_cerah:',
        'zh': u':卫生工作者_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002695': { # 🧑🏻‍⚕
        'en' : ':health_worker_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_helle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_claro:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_claire:',
        'ja': u':医者_薄い肌色:',
        'ko': u':의료인_하얀_피부:',
        'pt': u':profissional_de_saúde_pele_clara:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_chiara:',
        'fa': u':مأمور_بهداشت_پوست_سفید:',
        'id': ':petugas_kesehatan_warna_kulit_cerah:',
        'zh': u':卫生工作者_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002695\U0000FE0F': { # 🧑🏾‍⚕️
        'en' : ':health_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_mitteldunkle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_oscuro_medio:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_mate:',
        'ja': u':医者_やや濃い肌色:',
        'ko': u':의료인_진한_갈색_피부:',
        'pt': u':profissional_de_saúde_pele_morena_escura:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_abbastanza_scura:',
        'fa': u':مأمور_بهداشت_پوست_گندمی:',
        'id': ':petugas_kesehatan_warna_kulit_gelap-sedang:',
        'zh': u':卫生工作者_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002695': { # 🧑🏾‍⚕
        'en' : ':health_worker_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_mitteldunkle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_oscuro_medio:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_mate:',
        'ja': u':医者_やや濃い肌色:',
        'ko': u':의료인_진한_갈색_피부:',
        'pt': u':profissional_de_saúde_pele_morena_escura:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_abbastanza_scura:',
        'fa': u':مأمور_بهداشت_پوست_گندمی:',
        'id': ':petugas_kesehatan_warna_kulit_gelap-sedang:',
        'zh': u':卫生工作者_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002695\U0000FE0F': { # 🧑🏼‍⚕️
        'en' : ':health_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_mittelhelle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_claro_medio:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_moyennement_claire:',
        'ja': u':医者_やや薄い肌色:',
        'ko': u':의료인_연한_갈색_피부:',
        'pt': u':profissional_de_saúde_pele_morena_clara:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_abbastanza_chiara:',
        'fa': u':مأمور_بهداشت_پوست_روشن:',
        'id': ':petugas_kesehatan_warna_kulit_cerah-sedang:',
        'zh': u':卫生工作者_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002695': { # 🧑🏼‍⚕
        'en' : ':health_worker_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_mittelhelle_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_claro_medio:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_moyennement_claire:',
        'ja': u':医者_やや薄い肌色:',
        'ko': u':의료인_연한_갈색_피부:',
        'pt': u':profissional_de_saúde_pele_morena_clara:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_abbastanza_chiara:',
        'fa': u':مأمور_بهداشت_پوست_روشن:',
        'id': ':petugas_kesehatan_warna_kulit_cerah-sedang:',
        'zh': u':卫生工作者_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002695\U0000FE0F': { # 🧑🏽‍⚕️
        'en' : ':health_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_mittlere_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_medio:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_légèrement_mate:',
        'ja': u':医者_中間の肌色:',
        'ko': u':의료인_갈색_피부:',
        'pt': u':profissional_de_saúde_pele_morena:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_olivastra:',
        'fa': u':مأمور_بهداشت_پوست_طلایی:',
        'id': ':petugas_kesehatan_warna_kulit_sedang:',
        'zh': u':卫生工作者_中等肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002695': { # 🧑🏽‍⚕
        'en' : ':health_worker_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': u':arzt/ärztin_mittlere_hautfarbe:',
        'es': ':profesional_sanitario_tono_de_piel_medio:',
        'fr': u':professionnel_de_la_santé_(tous_genres)_peau_légèrement_mate:',
        'ja': u':医者_中間の肌色:',
        'ko': u':의료인_갈색_피부:',
        'pt': u':profissional_de_saúde_pele_morena:',
        'it': u':persona_che_lavora_nella_sanità_carnagione_olivastra:',
        'fa': u':مأمور_بهداشت_پوست_طلایی:',
        'id': ':petugas_kesehatan_warna_kulit_sedang:',
        'zh': u':卫生工作者_中等肤色:'
    },
    u'\U0001F649': { # 🙉
        'en' : ':hear-no-evil_monkey:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hear_no_evil:'],
        'de': ':sich_die_ohren_zuhaltendes_affengesicht:',
        'es': u':mono_con_los_oídos_tapados:',
        'fr': ':singe_ne_rien_entendre:',
        'ja': u':聞かざる:',
        'ko': u':귀를_막고_있는_원숭이:',
        'pt': u':macaco_que_não_ouve_nada:',
        'it': ':non_sento:',
        'fa': u':میمون_شرنشنو:',
        'id': ':tidak_mendengar:',
        'zh': u':非礼勿听:'
    },
    u'\U0001F49F': { # 💟
        'en' : ':heart_decoration:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':herzdekoration:',
        'es': u':adorno_de_corazón:',
        'fr': u':décoration_avec_cœur:',
        'ja': u':ハートデコ:',
        'ko': u':하트_장식:',
        'pt': u':coração_decorativo:',
        'it': ':decorazione_con_cuore:',
        'fa': u':قلب_تزئینی:',
        'id': ':dekorasi_hati:',
        'zh': u':心型装饰:'
    },
    u'\U00002763\U0000FE0F': { # ❣️
        'en' : ':heart_exclamation:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':heavy_heart_exclamation:', ':heavy_heart_exclamation_mark_ornament:'],
        'variant': True,
        'de': ':herz_als_ausrufezeichen:',
        'es': u':exclamación_de_corazón:',
        'fr': u':cœur_point_d’exclamation:',
        'ja': u':ハートのびっくり:',
        'ko': u':하트_모양_느낌표:',
        'pt': u':exclamação_de_coração:',
        'it': ':punto_esclamativo_a_cuore:',
        'fa': u':علامت_تعجب_قلبی:',
        'id': ':tanda_seru_berbentuk_hati:',
        'zh': u':心叹号:'
    },
    u'\U00002763': { # ❣
        'en' : ':heart_exclamation:',
        'status' : unqualified,
        'E' : 1,
        'alias' : [':heavy_heart_exclamation:', ':heavy_heart_exclamation_mark_ornament:'],
        'variant': True,
        'de': ':herz_als_ausrufezeichen:',
        'es': u':exclamación_de_corazón:',
        'fr': u':cœur_point_d’exclamation:',
        'ja': u':ハートのびっくり:',
        'ko': u':하트_모양_느낌표:',
        'pt': u':exclamação_de_coração:',
        'it': ':punto_esclamativo_a_cuore:',
        'fa': u':علامت_تعجب_قلبی:',
        'id': ':tanda_seru_berbentuk_hati:',
        'zh': u':心叹号:'
    },
    u'\U0001FAF6': { # 🫶
        'en' : ':heart_hands:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':hände_die_herz_bilden:',
        'es': u':manos_formando_un_corazón:',
        'fr': u':mains_qui_forment_un_cœur:',
        'ja': u':ハート形の手:',
        'ko': u':손_하트:',
        'pt': u':mãos_de_coração:',
        'it': ':mani_a_cuore:',
        'fa': u':شکل_قلب_با_دست:',
        'id': ':tangan_membentuk_hati:',
        'zh': u':做成心形的双手:'
    },
    u'\U0001FAF6\U0001F3FF': { # 🫶🏿
        'en' : ':heart_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF6\U0001F3FB': { # 🫶🏻
        'en' : ':heart_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF6\U0001F3FE': { # 🫶🏾
        'en' : ':heart_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF6\U0001F3FC': { # 🫶🏼
        'en' : ':heart_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF6\U0001F3FD': { # 🫶🏽
        'en' : ':heart_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U00002764\U0000FE0F\U0000200D\U0001F525': { # ❤️‍🔥
        'en' : ':heart_on_fire:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':herz_in_flammen:',
        'es': u':corazón_en_llamas:',
        'fr': u':cœur_enflammé:',
        'ja': u':燃えるハート:',
        'ko': u':불_난_하트:',
        'pt': u':coração_em_chamas:',
        'it': ':cuore_in_fiamme:',
        'fa': u':قلب_در_آتش:',
        'id': ':hati_berapi-api:',
        'zh': u':火上之心:'
    },
    u'\U00002764\U0000200D\U0001F525': { # ❤‍🔥
        'en' : ':heart_on_fire:',
        'status' : unqualified,
        'E' : 13.1,
        'de': ':herz_in_flammen:',
        'es': u':corazón_en_llamas:',
        'fr': u':cœur_enflammé:',
        'ja': u':燃えるハート:',
        'ko': u':불_난_하트:',
        'pt': u':coração_em_chamas:',
        'it': ':cuore_in_fiamme:',
        'fa': u':قلب_در_آتش:',
        'id': ':hati_berapi-api:',
        'zh': u':火上之心:'
    },
    u'\U00002665\U0000FE0F': { # ♥️
        'en' : ':heart_suit:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hearts:'],
        'variant': True,
        'de': ':herz:',
        'es': ':palo_de_corazones:',
        'fr': u':cœur_cartes:',
        'ja': u':ハート:',
        'ko': u':하트:',
        'pt': ':naipe_de_copas:',
        'it': ':cuori:',
        'fa': u':خال_دل:',
        'id': ':hati:',
        'zh': u':红桃:'
    },
    u'\U00002665': { # ♥
        'en' : ':heart_suit:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':hearts:'],
        'variant': True,
        'de': ':herz:',
        'es': ':palo_de_corazones:',
        'fr': u':cœur_cartes:',
        'ja': u':ハート:',
        'ko': u':하트:',
        'pt': ':naipe_de_copas:',
        'it': ':cuori:',
        'fa': u':خال_دل:',
        'id': ':hati:',
        'zh': u':红桃:'
    },
    u'\U0001F498': { # 💘
        'en' : ':heart_with_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cupid:'],
        'de': ':herz_mit_pfeil:',
        'es': u':corazón_con_flecha:',
        'fr': u':cœur_et_flèche:',
        'ja': u':ハートに矢:',
        'ko': u':화살이_꽂힌_하트:',
        'pt': u':coração_com_flecha:',
        'it': ':cuore_con_freccia:',
        'fa': u':قلب_تیرخورده:',
        'id': ':hati_terpanah:',
        'zh': u':心中箭了:'
    },
    u'\U0001F49D': { # 💝
        'en' : ':heart_with_ribbon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':gift_heart:'],
        'de': ':herz_mit_schleife:',
        'es': u':corazón_con_lazo:',
        'fr': u':cœur_avec_ruban:',
        'ja': u':ハートにリボン:',
        'ko': u':리본_달린_하트:',
        'pt': u':coração_com_fita:',
        'it': ':cuore_con_fiocco:',
        'fa': u':قلب_با_روبان:',
        'id': ':hati_berpita:',
        'zh': u':系有缎带的心:'
    },
    u'\U0001F4B2': { # 💲
        'en' : ':heavy_dollar_sign:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':dollarzeichen_extrafett:',
        'es': u':símbolo_de_dólar:',
        'fr': ':symbole_dollar:',
        'ja': u':ドル記号:',
        'ko': u':미국_달러:',
        'pt': u':cifrão:',
        'it': ':dollaro:',
        'fa': u':نماد_دلار:',
        'id': ':tanda_dolar_tebal:',
        'zh': u':粗美元符号:'
    },
    u'\U0001F7F0': { # 🟰
        'en' : ':heavy_equals_sign:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':gleichheitszeichen_extrafett:',
        'es': ':signo_igual_grueso:',
        'fr': u':signe_égal_gras:',
        'ja': u':太字の等号:',
        'ko': u':등호_기호:',
        'pt': ':sinal_de_igual:',
        'it': ':segno_di_uguaglianza:',
        'fa': u':علامت_تساوی_پررنگ:',
        'id': ':tanda_sama_dengan_tebal:',
        'zh': u':粗等号:'
    },
    u'\U0001F994': { # 🦔
        'en' : ':hedgehog:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':igel:',
        'es': ':erizo:',
        'fr': u':hérisson:',
        'ja': u':ハリネズミ:',
        'ko': u':고슴도치:',
        'pt': ':porco-espinho:',
        'it': ':riccio:',
        'fa': u':جوجه_تیغی:',
        'id': ':landak:',
        'zh': u':刺猬:'
    },
    u'\U0001F681': { # 🚁
        'en' : ':helicopter:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':hubschrauber:',
        'es': u':helicóptero:',
        'fr': u':hélicoptère:',
        'ja': u':ヘリコプター:',
        'ko': u':헬리콥터:',
        'pt': u':helicóptero:',
        'it': ':elicottero:',
        'fa': u':هلیکوپتر:',
        'id': ':helikopter:',
        'zh': u':直升机:'
    },
    u'\U0001F33F': { # 🌿
        'en' : ':herb:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':kräuter:',
        'es': ':hierba:',
        'fr': ':feuille:',
        'ja': u':ハーブ:',
        'ko': u':풀:',
        'pt': ':erva:',
        'it': ':pianta:',
        'fa': u':گیاه_دارویی:',
        'id': ':herba:',
        'zh': u':药草:'
    },
    u'\U0001F33A': { # 🌺
        'en' : ':hibiscus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':hibiskus:',
        'es': ':flor_de_hibisco:',
        'fr': ':hibiscus:',
        'ja': u':ハイビスカス:',
        'ko': u':무궁화:',
        'pt': ':hibisco:',
        'it': ':ibisco:',
        'fa': u':گل_ختمی:',
        'id': ':kembang_sepatu:',
        'zh': u':芙蓉:'
    },
    u'\U0001F460': { # 👠
        'en' : ':high-heeled_shoe:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':high_heel:'],
        'de': u':stöckelschuh:',
        'es': u':zapato_de_tacón:',
        'fr': u':chaussure_à_talon_haut:',
        'ja': u':ハイヒール:',
        'ko': u':하이힐:',
        'pt': ':sapato_de_salto_alto:',
        'it': ':scarpa_con_il_tacco:',
        'fa': u':کفش_پاشنه_بلند:',
        'id': ':sepatu_hak_tinggi:',
        'zh': u':高跟鞋:'
    },
    u'\U0001F684': { # 🚄
        'en' : ':high-speed_train:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bullettrain_side:'],
        'de': ':hochgeschwindigkeitszug_mit_spitzer_nase:',
        'es': ':tren_de_alta_velocidad:',
        'fr': ':tgv:',
        'ja': u':新幹線:',
        'ko': u':고속열차:',
        'pt': ':trem_de_alta_velocidade:',
        'it': u':treno_alta_velocità:',
        'fa': u':قطار_سریع_السیر:',
        'id': ':kereta_ekspres:',
        'zh': u':高速列车:'
    },
    u'\U000026A1': { # ⚡
        'en' : ':high_voltage:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':zap:'],
        'variant': True,
        'de': ':hochspannung:',
        'es': ':alto_voltaje:',
        'fr': ':haute_tension:',
        'ja': u':高電圧:',
        'ko': u':고압_주의:',
        'pt': u':alta_tensão:',
        'it': ':alta_tensione:',
        'fa': u':ولتاژ_بالا:',
        'id': ':tegangan_tinggi:',
        'zh': u':高压:'
    },
    u'\U0001F97E': { # 🥾
        'en' : ':hiking_boot:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':wanderstiefel:',
        'es': ':bota_de_senderismo:',
        'fr': u':chaussure_de_randonnée:',
        'ja': u':ハイキングシューズ:',
        'ko': u':등산화:',
        'pt': ':bota_de_trekking:',
        'it': ':stivale_da_trekking:',
        'fa': u':چکمه_راه_پیمایی:',
        'id': ':sepatu_boot_untuk_mendaki:',
        'zh': u':登山鞋:'
    },
    u'\U0001F6D5': { # 🛕
        'en' : ':hindu_temple:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':hindutempel:',
        'es': u':templo_hindú:',
        'fr': ':temple_hindou:',
        'ja': u':ヒンドゥー教の寺院:',
        'ko': u':힌두교_사원:',
        'pt': ':templo_hindu:',
        'it': u':tempio_indù:',
        'fa': u':معبد_هندو:',
        'id': ':pura:',
        'zh': u':印度寺庙:'
    },
    u'\U0001F99B': { # 🦛
        'en' : ':hippopotamus:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':nilpferd:',
        'es': u':hipopótamo:',
        'fr': ':hippopotame:',
        'ja': u':カバ:',
        'ko': u':하마:',
        'pt': u':hipopótamo:',
        'it': ':ippopotamo:',
        'fa': u':اسب_آبی:',
        'id': ':kuda_nil:',
        'zh': u':河马:'
    },
    u'\U0001F573\U0000FE0F': { # 🕳️
        'en' : ':hole:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':loch:',
        'es': ':agujero:',
        'fr': ':trou:',
        'ja': u':穴:',
        'ko': u':구멍:',
        'pt': ':buraco:',
        'it': ':buco:',
        'fa': u':چاله:',
        'id': ':lubang:',
        'zh': u':洞:'
    },
    u'\U0001F573': { # 🕳
        'en' : ':hole:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':loch:',
        'es': ':agujero:',
        'fr': ':trou:',
        'ja': u':穴:',
        'ko': u':구멍:',
        'pt': ':buraco:',
        'it': ':buco:',
        'fa': u':چاله:',
        'id': ':lubang:',
        'zh': u':洞:'
    },
    u'\U00002B55': { # ⭕
        'en' : ':hollow_red_circle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':o:'],
        'variant': True,
        'de': ':hohler_roter_kreis:',
        'es': u':círculo_rojo_hueco:',
        'fr': ':cercle_rouge:',
        'ja': u':太い丸:',
        'ko': u':크고_진한_동그라미:',
        'pt': u':círculo_grande_oco:',
        'it': ':cerchio_rosso_vuoto:',
        'fa': u':دایره_قرمز_توخالی:',
        'id': ':lingkaran_besar_tebal:',
        'zh': u':红色空心圆圈:'
    },
    u'\U0001F36F': { # 🍯
        'en' : ':honey_pot:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':honigtopf:',
        'es': ':tarro_de_miel:',
        'fr': ':pot_de_miel:',
        'ja': u':はちみつ:',
        'ko': u':꿀:',
        'pt': ':pote_de_mel:',
        'it': ':barattolo_di_miele:',
        'fa': u':ظرف_عسل:',
        'id': ':toples_madu:',
        'zh': u':蜂蜜:'
    },
    u'\U0001F41D': { # 🐝
        'en' : ':honeybee:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bee:'],
        'de': ':biene:',
        'es': ':abeja:',
        'fr': ':abeille:',
        'ja': u':ミツバチ:',
        'ko': u':꿀벌:',
        'pt': ':abelha:',
        'it': ':ape:',
        'fa': u':زنبور_عسل:',
        'id': ':lebah_madu:',
        'zh': u':蜜蜂:'
    },
    u'\U0001FA9D': { # 🪝
        'en' : ':hook:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':haken:',
        'es': ':gancho:',
        'fr': ':crochet:',
        'ja': u':フック:',
        'ko': u':갈고리:',
        'pt': ':gancho:',
        'it': ':gancio:',
        'fa': u':قلاب:',
        'id': ':kait:',
        'zh': u':挂钩:'
    },
    u'\U0001F6A5': { # 🚥
        'en' : ':horizontal_traffic_light:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':traffic_light:'],
        'de': ':horizontale_verkehrsampel:',
        'es': u':semáforo_horizontal:',
        'fr': ':feu_tricolore_horizontal:',
        'ja': u':信号横:',
        'ko': u':가로_신호등:',
        'pt': u':semáforo_horizontal:',
        'it': ':semaforo_orizzontale:',
        'fa': u':چراغ_راهنمایی_افقی:',
        'id': ':lampu_lalu_lintas_horizontal:',
        'zh': u':横向的红绿灯:'
    },
    u'\U0001F40E': { # 🐎
        'en' : ':horse:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':racehorse:'],
        'de': ':pferd:',
        'es': ':caballo:',
        'fr': ':cheval:',
        'ja': u':馬:',
        'ko': u':말:',
        'pt': ':cavalo:',
        'it': ':cavallo:',
        'fa': u':اسب:',
        'id': ':kuda:',
        'zh': u':马:'
    },
    u'\U0001F434': { # 🐴
        'en' : ':horse_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':horse:'],
        'de': ':pferdegesicht:',
        'es': ':cara_de_caballo:',
        'fr': u':tête_de_cheval:',
        'ja': u':馬の顔:',
        'ko': u':말_얼굴:',
        'pt': ':rosto_de_cavalo:',
        'it': ':muso_di_cavallo:',
        'fa': u':صورت_اسب:',
        'id': ':wajah_kuda:',
        'zh': u':马头:'
    },
    u'\U0001F3C7': { # 🏇
        'en' : ':horse_racing:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':pferderennen:',
        'es': ':carrera_de_caballos:',
        'fr': ':course_hippique:',
        'ja': u':競馬:',
        'ko': u':승마:',
        'pt': ':corrida_de_cavalos:',
        'it': ':ippica:',
        'fa': u':مسابقه_اسب_سواری:',
        'id': ':balap_kuda:',
        'zh': u':赛马:'
    },
    u'\U0001F3C7\U0001F3FF': { # 🏇🏿
        'en' : ':horse_racing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':pferderennen_dunkle_hautfarbe:',
        'es': ':carrera_de_caballos_tono_de_piel_oscuro:',
        'fr': u':course_hippique_peau_foncée:',
        'ja': u':競馬_濃い肌色:',
        'ko': u':승마_검은색_피부:',
        'pt': ':corrida_de_cavalos_pele_escura:',
        'it': ':ippica_carnagione_scura:',
        'fa': u':مسابقه_اسب_سواری_پوست_آبنوسی:',
        'id': ':balap_kuda_warna_kulit_gelap:',
        'zh': u':赛马_较深肤色:'
    },
    u'\U0001F3C7\U0001F3FB': { # 🏇🏻
        'en' : ':horse_racing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':pferderennen_helle_hautfarbe:',
        'es': ':carrera_de_caballos_tono_de_piel_claro:',
        'fr': ':course_hippique_peau_claire:',
        'ja': u':競馬_薄い肌色:',
        'ko': u':승마_하얀_피부:',
        'pt': ':corrida_de_cavalos_pele_clara:',
        'it': ':ippica_carnagione_chiara:',
        'fa': u':مسابقه_اسب_سواری_پوست_سفید:',
        'id': ':balap_kuda_warna_kulit_cerah:',
        'zh': u':赛马_较浅肤色:'
    },
    u'\U0001F3C7\U0001F3FE': { # 🏇🏾
        'en' : ':horse_racing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':pferderennen_mitteldunkle_hautfarbe:',
        'es': ':carrera_de_caballos_tono_de_piel_oscuro_medio:',
        'fr': ':course_hippique_peau_mate:',
        'ja': u':競馬_やや濃い肌色:',
        'ko': u':승마_진한_갈색_피부:',
        'pt': ':corrida_de_cavalos_pele_morena_escura:',
        'it': ':ippica_carnagione_abbastanza_scura:',
        'fa': u':مسابقه_اسب_سواری_پوست_گندمی:',
        'id': ':balap_kuda_warna_kulit_gelap-sedang:',
        'zh': u':赛马_中等深肤色:'
    },
    u'\U0001F3C7\U0001F3FC': { # 🏇🏼
        'en' : ':horse_racing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':pferderennen_mittelhelle_hautfarbe:',
        'es': ':carrera_de_caballos_tono_de_piel_claro_medio:',
        'fr': ':course_hippique_peau_moyennement_claire:',
        'ja': u':競馬_やや薄い肌色:',
        'ko': u':승마_연한_갈색_피부:',
        'pt': ':corrida_de_cavalos_pele_morena_clara:',
        'it': ':ippica_carnagione_abbastanza_chiara:',
        'fa': u':مسابقه_اسب_سواری_پوست_روشن:',
        'id': ':balap_kuda_warna_kulit_cerah-sedang:',
        'zh': u':赛马_中等浅肤色:'
    },
    u'\U0001F3C7\U0001F3FD': { # 🏇🏽
        'en' : ':horse_racing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':pferderennen_mittlere_hautfarbe:',
        'es': ':carrera_de_caballos_tono_de_piel_medio:',
        'fr': u':course_hippique_peau_légèrement_mate:',
        'ja': u':競馬_中間の肌色:',
        'ko': u':승마_갈색_피부:',
        'pt': ':corrida_de_cavalos_pele_morena:',
        'it': ':ippica_carnagione_olivastra:',
        'fa': u':مسابقه_اسب_سواری_پوست_طلایی:',
        'id': ':balap_kuda_warna_kulit_sedang:',
        'zh': u':赛马_中等肤色:'
    },
    u'\U0001F3E5': { # 🏥
        'en' : ':hospital:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':krankenhaus:',
        'es': ':hospital:',
        'fr': u':hôpital:',
        'ja': u':病院:',
        'ko': u':병원:',
        'pt': ':hospital:',
        'it': ':ospedale:',
        'fa': u':بیمارستان:',
        'id': ':rumah_sakit:',
        'zh': u':医院:'
    },
    u'\U00002615': { # ☕
        'en' : ':hot_beverage:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':coffee:'],
        'variant': True,
        'de': u':heißgetränk:',
        'es': ':bebida_caliente:',
        'fr': ':boisson_chaude:',
        'ja': u':温かい飲み物:',
        'ko': u':뜨거운_음료:',
        'pt': u':café:',
        'it': ':bevanda_calda:',
        'fa': u':نوشیدنی_گرم:',
        'id': ':minuman_hangat:',
        'zh': u':热饮:'
    },
    u'\U0001F32D': { # 🌭
        'en' : ':hot_dog:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':hotdog:'],
        'de': ':hotdog:',
        'es': ':perrito_caliente:',
        'fr': ':hot_dog:',
        'ja': u':ホットドッグ:',
        'ko': u':핫도그:',
        'pt': ':cachorro-quente:',
        'it': ':hot_dog:',
        'fa': u':هات_داگ:',
        'id': ':hot_dog:',
        'zh': u':热狗:'
    },
    u'\U0001F975': { # 🥵
        'en' : ':hot_face:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':schwitzendes_gesicht:',
        'es': ':cara_con_calor:',
        'fr': ':visage_rouge_et_chaud:',
        'ja': u':暑い顔:',
        'ko': u':더운_얼굴:',
        'pt': ':rosto_fervendo_de_calor:',
        'it': ':faccina_accaldata:',
        'fa': u':خیلی_گرم:',
        'id': ':wajah_kepanasan:',
        'zh': u':脸发烧:'
    },
    u'\U0001F336\U0000FE0F': { # 🌶️
        'en' : ':hot_pepper:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':peperoni:',
        'es': ':chile_picante:',
        'fr': ':piment_rouge:',
        'ja': u':とうがらし:',
        'ko': u':홍고추:',
        'pt': ':pimenta:',
        'it': ':peperoncino:',
        'fa': u':فلفل_قرمز:',
        'id': ':cabai_pedas:',
        'zh': u':红辣椒:'
    },
    u'\U0001F336': { # 🌶
        'en' : ':hot_pepper:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':peperoni:',
        'es': ':chile_picante:',
        'fr': ':piment_rouge:',
        'ja': u':とうがらし:',
        'ko': u':홍고추:',
        'pt': ':pimenta:',
        'it': ':peperoncino:',
        'fa': u':فلفل_قرمز:',
        'id': ':cabai_pedas:',
        'zh': u':红辣椒:'
    },
    u'\U00002668\U0000FE0F': { # ♨️
        'en' : ':hot_springs:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hotsprings:'],
        'variant': True,
        'de': u':heiße_quellen:',
        'es': ':aguas_termales:',
        'fr': ':sources_chaudes:',
        'ja': u':温泉マーク:',
        'ko': u':온천:',
        'pt': ':chamas:',
        'it': ':sorgenti_termali:',
        'fa': u':چشمه_آب_گرم:',
        'id': ':sumber_air_panas:',
        'zh': u':温泉:'
    },
    u'\U00002668': { # ♨
        'en' : ':hot_springs:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':hotsprings:'],
        'variant': True,
        'de': u':heiße_quellen:',
        'es': ':aguas_termales:',
        'fr': ':sources_chaudes:',
        'ja': u':温泉マーク:',
        'ko': u':온천:',
        'pt': ':chamas:',
        'it': ':sorgenti_termali:',
        'fa': u':چشمهٔ_آب_گرم:',
        'id': ':sumber_air_panas:',
        'zh': u':温泉:'
    },
    u'\U0001F3E8': { # 🏨
        'en' : ':hotel:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':hotel:',
        'es': ':hotel:',
        'fr': u':hôtel:',
        'ja': u':ホテル:',
        'ko': u':호텔:',
        'pt': ':hotel:',
        'it': ':hotel:',
        'fa': u':هتل:',
        'id': ':hotel:',
        'zh': u':酒店:'
    },
    u'\U0000231B': { # ⌛
        'en' : ':hourglass_done:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hourglass:'],
        'variant': True,
        'de': ':sanduhr:',
        'es': ':reloj_de_arena_sin_tiempo:',
        'fr': ':sablier:',
        'ja': u':砂時計:',
        'ko': u':시간이_다_된_모래시계:',
        'pt': ':ampulheta:',
        'it': ':clessidra:',
        'fa': u':ساعت_شنی:',
        'id': ':jam_pasir:',
        'zh': u':沙漏:'
    },
    u'\U000023F3': { # ⏳
        'en' : ':hourglass_not_done:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hourglass_flowing_sand:'],
        'variant': True,
        'de': ':laufende_sanduhr:',
        'es': ':reloj_de_arena_con_tiempo:',
        'fr': ':sablier_avec_sable_qui_coule:',
        'ja': u':砂が落ちている砂時計:',
        'ko': u':시간이_남은_모래시계:',
        'pt': ':ampulheta_contando_o_tempo:',
        'it': ':clessidra_che_scorre:',
        'fa': u':ساعت_شنی_با_شن_روان:',
        'id': ':jam_pasir_yang_bergerak:',
        'zh': u':沙正往下流的沙漏:'
    },
    u'\U0001F3E0': { # 🏠
        'en' : ':house:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':haus:',
        'es': ':casa:',
        'fr': ':maison:',
        'ja': u':家:',
        'ko': u':집:',
        'pt': ':casa:',
        'it': ':casa:',
        'fa': u':خانه:',
        'id': ':rumah:',
        'zh': u':房子:'
    },
    u'\U0001F3E1': { # 🏡
        'en' : ':house_with_garden:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':haus_mit_garten:',
        'es': u':casa_con_jardín:',
        'fr': ':maison_avec_jardin:',
        'ja': u':庭付きの家:',
        'ko': u':정원이_있는_집:',
        'pt': ':casa_com_jardim:',
        'it': ':casa_con_giardino:',
        'fa': u':خانهٔ_حیاط_دار:',
        'id': ':rumah_dengan_taman:',
        'zh': u':别墅:'
    },
    u'\U0001F3D8\U0000FE0F': { # 🏘️
        'en' : ':houses:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':house_buildings:'],
        'variant': True,
        'de': u':wohnhäuser:',
        'es': ':casas:',
        'fr': ':maisons:',
        'ja': u':住宅街:',
        'ko': u':주택_건물:',
        'pt': ':casas:',
        'it': ':case:',
        'fa': u':منازل:',
        'id': ':perumahan:',
        'zh': u':房屋建筑:'
    },
    u'\U0001F3D8': { # 🏘
        'en' : ':houses:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':house_buildings:'],
        'variant': True,
        'de': u':wohnhäuser:',
        'es': ':casas:',
        'fr': ':maisons:',
        'ja': u':住宅街:',
        'ko': u':주택_건물:',
        'pt': ':casas:',
        'it': ':case:',
        'fa': u':منازل:',
        'id': ':perumahan:',
        'zh': u':房屋建筑:'
    },
    u'\U0001F4AF': { # 💯
        'en' : ':hundred_points:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':100:'],
        'de': ':100_punkte:',
        'es': ':cien_puntos:',
        'fr': ':cent_points:',
        'ja': u':100点満点:',
        'ko': u':백점:',
        'pt': ':cem_pontos:',
        'it': ':100_punti:',
        'fa': u':۱۰۰_امتیاز:',
        'id': ':nilai_seratus:',
        'zh': u':一百分:'
    },
    u'\U0001F62F': { # 😯
        'en' : ':hushed_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':hushed:'],
        'de': ':verdutztes_gesicht:',
        'es': ':cara_estupefacta:',
        'fr': u':visage_ébahi:',
        'ja': u':ぽかーん:',
        'ko': u':숨죽인_얼굴:',
        'pt': ':rosto_surpreso:',
        'it': ':faccina_sorpresa:',
        'fa': u':مات_و_مبهوت:',
        'id': ':wajah_hening:',
        'zh': u':缄默:'
    },
    u'\U0001F6D6': { # 🛖
        'en' : ':hut:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':hütte:',
        'es': u':cabaña:',
        'fr': ':hutte:',
        'ja': u':わらぶき小屋:',
        'ko': u':오두막:',
        'pt': ':cabana:',
        'it': ':capanna:',
        'fa': u':کلبه:',
        'id': ':pondok:',
        'zh': u':小屋:'
    },
    u'\U0001FABB': { # 🪻
        'en' : ':hyacinth:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':hyazinthe:',
        'es': ':campanilla:',
        'fr': ':jacinthe:',
        'ja': u':ヒヤシンス:',
        'ko': u':히아신스:',
        'pt': ':jacinto:',
        'it': ':giacinto:',
        'fa': u':سنبل:',
        'id': ':hyacinthus:',
        'zh': u':风信子:'
    },
    u'\U0001F9CA': { # 🧊
        'en' : ':ice:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':ice_cube:'],
        'de': u':eiswürfel:',
        'es': ':cubito_de_hielo:',
        'fr': u':glaçon:',
        'ja': u':角氷:',
        'ko': u':얼음:',
        'pt': ':cubo_de_gelo:',
        'it': ':cubetto_di_ghiaccio:',
        'fa': u':قالب_یخ:',
        'id': ':es_batu:',
        'zh': u':冰块:'
    },
    u'\U0001F368': { # 🍨
        'en' : ':ice_cream:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':eiscreme:',
        'es': ':helado:',
        'fr': ':glace:',
        'ja': u':アイスクリーム:',
        'ko': u':아이스크림:',
        'pt': ':sorvete:',
        'it': ':coppa_di_gelato:',
        'fa': u':بستنی:',
        'id': ':es_krim:',
        'zh': u':冰淇淋:'
    },
    u'\U0001F3D2': { # 🏒
        'en' : ':ice_hockey:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':ice_hockey_stick_and_puck:'],
        'de': ':eishockey:',
        'es': ':hockey_sobre_hielo:',
        'fr': ':hockey_sur_glace:',
        'ja': u':アイスホッケー:',
        'ko': u':아이스_하키와_퍽:',
        'pt': u':hóquei_no_gelo:',
        'it': ':hockey_su_ghiaccio:',
        'fa': u':هاکی_روی_یخ:',
        'id': ':hoki_es:',
        'zh': u':冰球:'
    },
    u'\U000026F8\U0000FE0F': { # ⛸️
        'en' : ':ice_skate:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schlittschuh:',
        'es': u':patín_de_hielo:',
        'fr': u':patin_à_glace:',
        'ja': u':アイススケート:',
        'ko': u':아이스_스케이트:',
        'pt': ':patins_de_gelo:',
        'it': ':pattinaggio_su_ghiaccio:',
        'fa': u':اسکی_روی_یخ:',
        'id': ':seluncur_es:',
        'zh': u':滑冰:'
    },
    u'\U000026F8': { # ⛸
        'en' : ':ice_skate:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schlittschuh:',
        'es': u':patín_de_hielo:',
        'fr': u':patin_à_glace:',
        'ja': u':アイススケート:',
        'ko': u':아이스_스케이트:',
        'pt': ':patins_de_gelo:',
        'it': ':pattinaggio_su_ghiaccio:',
        'fa': u':اسکی_روی_یخ:',
        'id': ':seluncur_es:',
        'zh': u':滑冰:'
    },
    u'\U0001FAAA': { # 🪪
        'en' : ':identification_card:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':ausweis:',
        'es': u':carné_de_identidad:',
        'fr': u':carte_d’identité:',
        'ja': u':身分証:',
        'ko': u':신분증:',
        'pt': u':cartão_de_identificação:',
        'it': u':carta_d’identità:',
        'fa': u':کارت_شناسایی:',
        'id': ':kartu_identitas:',
        'zh': u':身份证:'
    },
    u'\U0001F4E5': { # 📥
        'en' : ':inbox_tray:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':posteingang:',
        'es': ':bandeja_de_entrada:',
        'fr': u':boîte_de_réception:',
        'ja': u':受信トレイ:',
        'ko': u':받은_편지함:',
        'pt': ':bandeja_de_entrada:',
        'it': ':posta_ricevuta:',
        'fa': u':صندوق_ورودی:',
        'id': ':baki_kotak_masuk:',
        'zh': u':收件箱:'
    },
    u'\U0001F4E8': { # 📨
        'en' : ':incoming_envelope:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':eingehender_briefumschlag:',
        'es': ':sobre_entrante:',
        'fr': u':message_reçu:',
        'ja': u':メール受信中:',
        'ko': u':받은_편지:',
        'pt': ':envelope_chegando:',
        'it': ':posta_in_arrivo:',
        'fa': u':پاکت_نامهٔ_ورودی:',
        'id': ':amplop_datang:',
        'zh': u':来信:'
    },
    u'\U0001FAF5': { # 🫵
        'en' : ':index_pointing_at_the_viewer:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':auf_betrachter_zeigender_zeigefinger:',
        'es': u':dedo_índice_apuntándote_a_ti:',
        'fr': u':index_pointant_vers_l’utilisateur:',
        'ja': u':人を指差している手:',
        'ko': u':보는_사람을_가리키는_검지:',
        'pt': ':indicador_apontando_para_o_visualizador:',
        'it': u':indice_verso_l’osservatore:',
        'fa': u':اشاره_به_بیننده:',
        'id': ':jari_telunjuk_menunjuk_penonton:',
        'zh': u':指向观察者的食指:'
    },
    u'\U0001FAF5\U0001F3FF': { # 🫵🏿
        'en' : ':index_pointing_at_the_viewer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF5\U0001F3FB': { # 🫵🏻
        'en' : ':index_pointing_at_the_viewer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF5\U0001F3FE': { # 🫵🏾
        'en' : ':index_pointing_at_the_viewer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF5\U0001F3FC': { # 🫵🏼
        'en' : ':index_pointing_at_the_viewer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF5\U0001F3FD': { # 🫵🏽
        'en' : ':index_pointing_at_the_viewer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0000261D\U0000FE0F': { # ☝️
        'en' : ':index_pointing_up:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':point_up:'],
        'variant': True,
        'de': ':nach_oben_weisender_zeigefinger_von_vorne:',
        'es': u':dedo_índice_hacia_arriba:',
        'fr': ':index_pointant_vers_le_haut:',
        'ja': u':上指差し:',
        'ko': u':위쪽을_가리키는_손:',
        'pt': ':indicador_apontando_para_cima:',
        'it': u':indice_verso_l’alto:',
        'fa': u':اشاره_به_بالا:',
        'id': ':menunjuk_ke_atas:',
        'zh': u':食指向上指:'
    },
    u'\U0000261D': { # ☝
        'en' : ':index_pointing_up:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':point_up:'],
        'variant': True,
        'de': ':nach_oben_weisender_zeigefinger_von_vorne:',
        'es': u':dedo_índice_hacia_arriba:',
        'fr': ':index_pointant_vers_le_haut:',
        'ja': u':上指差し:',
        'ko': u':위쪽을_가리키는_손:',
        'pt': ':indicador_apontando_para_cima:',
        'it': u':indice_verso_l’alto:',
        'fa': u':اشاره_به_بالا:',
        'id': ':menunjuk_ke_atas:',
        'zh': u':食指向上指:'
    },
    u'\U0000261D\U0001F3FF': { # ☝🏿
        'en' : ':index_pointing_up_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_vorne_dunkle_hautfarbe:',
        'es': u':dedo_índice_hacia_arriba_tono_de_piel_oscuro:',
        'fr': u':index_pointant_vers_le_haut_peau_foncée:',
        'ja': u':上指差し_濃い肌色:',
        'ko': u':위쪽을_가리키는_손_검은색_피부:',
        'pt': ':indicador_apontando_para_cima_pele_escura:',
        'it': u':indice_verso_l’alto_carnagione_scura:',
        'fa': u':اشاره_به_بالا_پوست_آبنوسی:',
        'id': ':menunjuk_ke_atas_warna_kulit_gelap:',
        'zh': u':食指向上指_较深肤色:'
    },
    u'\U0000261D\U0001F3FB': { # ☝🏻
        'en' : ':index_pointing_up_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_vorne_helle_hautfarbe:',
        'es': u':dedo_índice_hacia_arriba_tono_de_piel_claro:',
        'fr': ':index_pointant_vers_le_haut_peau_claire:',
        'ja': u':上指差し_薄い肌色:',
        'ko': u':위쪽을_가리키는_손_하얀_피부:',
        'pt': ':indicador_apontando_para_cima_pele_clara:',
        'it': u':indice_verso_l’alto_carnagione_chiara:',
        'fa': u':اشاره_به_بالا_پوست_سفید:',
        'id': ':menunjuk_ke_atas_warna_kulit_cerah:',
        'zh': u':食指向上指_较浅肤色:'
    },
    u'\U0000261D\U0001F3FE': { # ☝🏾
        'en' : ':index_pointing_up_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_vorne_mitteldunkle_hautfarbe:',
        'es': u':dedo_índice_hacia_arriba_tono_de_piel_oscuro_medio:',
        'fr': ':index_pointant_vers_le_haut_peau_mate:',
        'ja': u':上指差し_やや濃い肌色:',
        'ko': u':위쪽을_가리키는_손_진한_갈색_피부:',
        'pt': ':indicador_apontando_para_cima_pele_morena_escura:',
        'it': u':indice_verso_l’alto_carnagione_abbastanza_scura:',
        'fa': u':اشاره_به_بالا_پوست_گندمی:',
        'id': ':menunjuk_ke_atas_warna_kulit_gelap-sedang:',
        'zh': u':食指向上指_中等深肤色:'
    },
    u'\U0000261D\U0001F3FC': { # ☝🏼
        'en' : ':index_pointing_up_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_vorne_mittelhelle_hautfarbe:',
        'es': u':dedo_índice_hacia_arriba_tono_de_piel_claro_medio:',
        'fr': ':index_pointant_vers_le_haut_peau_moyennement_claire:',
        'ja': u':上指差し_やや薄い肌色:',
        'ko': u':위쪽을_가리키는_손_연한_갈색_피부:',
        'pt': ':indicador_apontando_para_cima_pele_morena_clara:',
        'it': u':indice_verso_l’alto_carnagione_abbastanza_chiara:',
        'fa': u':اشاره_به_بالا_پوست_روشن:',
        'id': ':menunjuk_ke_atas_warna_kulit_cerah-sedang:',
        'zh': u':食指向上指_中等浅肤色:'
    },
    u'\U0000261D\U0001F3FD': { # ☝🏽
        'en' : ':index_pointing_up_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nach_oben_weisender_zeigefinger_von_vorne_mittlere_hautfarbe:',
        'es': u':dedo_índice_hacia_arriba_tono_de_piel_medio:',
        'fr': u':index_pointant_vers_le_haut_peau_légèrement_mate:',
        'ja': u':上指差し_中間の肌色:',
        'ko': u':위쪽을_가리키는_손_갈색_피부:',
        'pt': ':indicador_apontando_para_cima_pele_morena:',
        'it': u':indice_verso_l’alto_carnagione_olivastra:',
        'fa': u':اشاره_به_بالا_پوست_طلایی:',
        'id': ':menunjuk_ke_atas_warna_kulit_sedang:',
        'zh': u':食指向上指_中等肤色:'
    },
    u'\U0000267E\U0000FE0F': { # ♾️
        'en' : ':infinity:',
        'status' : fully_qualified,
        'E' : 11,
        'variant': True,
        'de': ':unendlichkeit:',
        'es': ':infinito:',
        'fr': ':infini:',
        'ja': u':無限大:',
        'ko': u':무한:',
        'pt': ':infinito:',
        'it': u':simbolo_dell’infinito:',
        'fa': u':بی_نهایت:',
        'id': ':tak_terhingga:',
        'zh': u':无穷大:'
    },
    u'\U0000267E': { # ♾
        'en' : ':infinity:',
        'status' : unqualified,
        'E' : 11,
        'variant': True,
        'de': ':unendlichkeit:',
        'es': ':infinito:',
        'fr': ':infini:',
        'ja': u':無限大:',
        'ko': u':무한:',
        'pt': ':infinito:',
        'it': u':simbolo_dell’infinito:',
        'fa': u':بی_نهایت:',
        'id': ':tak_terhingga:',
        'zh': u':无穷大:'
    },
    u'\U00002139\U0000FE0F': { # ℹ️
        'en' : ':information:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':information_source:'],
        'variant': True,
        'de': ':buchstabe_i_in_blauem_quadrat:',
        'es': u':información:',
        'fr': u':source_d’informations:',
        'ja': u':iマーク:',
        'ko': u':정보_출처:',
        'pt': u':informações:',
        'it': ':punto_informazioni:',
        'fa': u':اطلاعات:',
        'id': ':informasi:',
        'zh': u':信息:'
    },
    u'\U00002139': { # ℹ
        'en' : ':information:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':information_source:'],
        'variant': True,
        'de': ':buchstabe_i_in_blauem_quadrat:',
        'es': u':información:',
        'fr': u':source_d’informations:',
        'ja': u':iマーク:',
        'ko': u':정보_출처:',
        'pt': u':informações:',
        'it': ':punto_informazioni:',
        'fa': u':اطلاعات:',
        'id': ':informasi:',
        'zh': u':信息:'
    },
    u'\U0001F524': { # 🔤
        'en' : ':input_latin_letters:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':abc:'],
        'de': ':eingabesymbol_lateinische_buchstaben:',
        'es': ':alfabeto_latino:',
        'fr': ':alphabet_latin:',
        'ja': u':英字の入力:',
        'ko': u':라틴어_알파벳:',
        'pt': ':letras_latinas:',
        'it': ':pulsante_con_lettere_latine:',
        'fa': u':ورودی_حروف_لاتین:',
        'id': ':masukan_huruf_latin:',
        'zh': u':输入拉丁字母:'
    },
    u'\U0001F521': { # 🔡
        'en' : ':input_latin_lowercase:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':abcd:'],
        'de': ':eingabesymbol_lateinische_kleinbuchstaben:',
        'es': u':letras_latinas_minúsculas:',
        'fr': ':minuscules:',
        'ja': u':英小文字の入力:',
        'ko': u':소문자:',
        'pt': u':letras_latinas_minúsculas:',
        'it': ':pulsante_con_lettere_latine_minuscole:',
        'fa': u':ورودی_حروف_کوچک:',
        'id': ':masukan_huruf_kecil_latin:',
        'zh': u':输入小写拉丁字母:'
    },
    u'\U0001F520': { # 🔠
        'en' : ':input_latin_uppercase:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':capital_abcd:'],
        'de': u':eingabesymbol_lateinische_großbuchstaben:',
        'es': u':letras_latinas_mayúsculas:',
        'fr': ':majuscules:',
        'ja': u':英大文字の入力:',
        'ko': u':대문자:',
        'pt': u':letras_latinas_maiúsculas:',
        'it': ':pulsante_con_lettere_latine_maiuscole:',
        'fa': u':ورودی_حروف_بزرگ:',
        'id': ':masukan_huruf_kapital_latin:',
        'zh': u':输入大写拉丁字母:'
    },
    u'\U0001F522': { # 🔢
        'en' : ':input_numbers:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':1234:'],
        'de': ':eingabesymbol_zahlen:',
        'es': u':números:',
        'fr': ':saisie_de_chiffres:',
        'ja': u':数字の入力:',
        'ko': u':숫자:',
        'pt': u':números:',
        'it': ':pulsante_con_numeri:',
        'fa': u':ورودی_عددی:',
        'id': ':masukan_angka:',
        'zh': u':输入数字:'
    },
    u'\U0001F523': { # 🔣
        'en' : ':input_symbols:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':symbols:'],
        'de': ':eingabesymbol_sonderzeichen:',
        'es': u':símbolos:',
        'fr': ':saisie_de_symboles:',
        'ja': u':記号の入力:',
        'ko': u':기호:',
        'pt': u':símbolos:',
        'it': ':pulsante_con_simboli:',
        'fa': u':ورودی_نماد:',
        'id': ':masukan_simbol:',
        'zh': u':输入符号:'
    },
    u'\U0001F383': { # 🎃
        'en' : ':jack-o-lantern:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':jack_o_lantern:'],
        'de': u':halloweenkürbis:',
        'es': ':calabaza_de_halloween:',
        'fr': ':citrouille:',
        'ja': u':ハロウィンかぼちゃ:',
        'ko': u':할로윈:',
        'pt': u':abóbora_de_halloween:',
        'it': ':zucca_di_halloween:',
        'fa': u':فانوس_کدو_تنبل:',
        'id': ':jack-o-lantern:',
        'zh': u':南瓜灯:'
    },
    u'\U0001FAD9': { # 🫙
        'en' : ':jar:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':einmachglas:',
        'es': ':tarro:',
        'fr': ':bocal:',
        'ja': u':瓶:',
        'ko': u':작은_병:',
        'pt': ':jarro:',
        'it': ':barattolo:',
        'fa': u':شیشه_دهان_گشاد:',
        'id': ':toples:',
        'zh': u':罐:'
    },
    u'\U0001F456': { # 👖
        'en' : ':jeans:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':jeans:',
        'es': ':vaqueros:',
        'fr': ':jean:',
        'ja': u':ジーンズ:',
        'ko': u':바지:',
        'pt': ':jeans:',
        'it': ':jeans:',
        'fa': u':شلوار_جین:',
        'id': ':celana_jeans:',
        'zh': u':牛仔裤:'
    },
    u'\U0001FABC': { # 🪼
        'en' : ':jellyfish:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':qualle:',
        'es': ':medusa:',
        'fr': u':méduse:',
        'ja': u':クラゲ:',
        'ko': u':해파리:',
        'pt': u':água-viva:',
        'it': ':medusa:',
        'fa': u':عروس_دریایی:',
        'id': ':ubur-ubur:',
        'zh': u':水母:'
    },
    u'\U0001F0CF': { # 🃏
        'en' : ':joker:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':black_joker:'],
        'de': ':jokerkarte:',
        'es': u':comodín:',
        'fr': ':carte_joker:',
        'ja': u':ジョーカー:',
        'ko': u':조커:',
        'pt': ':curinga:',
        'it': ':jolly:',
        'fa': u':جوکر:',
        'id': ':joker:',
        'zh': u':大小王:'
    },
    u'\U0001F579\U0000FE0F': { # 🕹️
        'en' : ':joystick:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':joystick:',
        'es': ':joystick:',
        'fr': ':manette_de_jeu:',
        'ja': u':ジョイスティック:',
        'ko': u':조이스틱:',
        'pt': ':joystick:',
        'it': ':joystick:',
        'fa': u':دسته_بازی:',
        'id': ':joystick:',
        'zh': u':游戏操控杆:'
    },
    u'\U0001F579': { # 🕹
        'en' : ':joystick:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':joystick:',
        'es': ':joystick:',
        'fr': ':manette_de_jeu:',
        'ja': u':ジョイスティック:',
        'ko': u':조이스틱:',
        'pt': ':joystick:',
        'it': ':joystick:',
        'fa': u':دسته_بازی:',
        'id': ':joystick:',
        'zh': u':游戏操控杆:'
    },
    u'\U0001F9D1\U0000200D\U00002696\U0000FE0F': { # 🧑‍⚖️
        'en' : ':judge:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':richter(in):',
        'es': ':fiscal:',
        'fr': ':juge:',
        'ja': u':裁判官:',
        'ko': u':판사:',
        'pt': ':juiz_no_tribunal:',
        'it': ':giudice:',
        'fa': u':قاضی:',
        'id': ':hakim:',
        'zh': u':法官:'
    },
    u'\U0001F9D1\U0000200D\U00002696': { # 🧑‍⚖
        'en' : ':judge:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':richter(in):',
        'es': ':fiscal:',
        'fr': ':juge:',
        'ja': u':裁判官:',
        'ko': u':판사:',
        'pt': ':juiz_no_tribunal:',
        'it': ':giudice:',
        'fa': u':قاضی:',
        'id': ':hakim:',
        'zh': u':法官:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002696\U0000FE0F': { # 🧑🏿‍⚖️
        'en' : ':judge_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':richter(in)_dunkle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_oscuro:',
        'fr': u':juge_peau_foncée:',
        'ja': u':裁判官_濃い肌色:',
        'ko': u':판사_검은색_피부:',
        'pt': ':juiz_no_tribunal_pele_escura:',
        'it': ':giudice_carnagione_scura:',
        'fa': u':قاضی_پوست_آبنوسی:',
        'id': ':hakim_warna_kulit_gelap:',
        'zh': u':法官_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002696': { # 🧑🏿‍⚖
        'en' : ':judge_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':richter(in)_dunkle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_oscuro:',
        'fr': u':juge_peau_foncée:',
        'ja': u':裁判官_濃い肌色:',
        'ko': u':판사_검은색_피부:',
        'pt': ':juiz_no_tribunal_pele_escura:',
        'it': ':giudice_carnagione_scura:',
        'fa': u':قاضی_پوست_آبنوسی:',
        'id': ':hakim_warna_kulit_gelap:',
        'zh': u':法官_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002696\U0000FE0F': { # 🧑🏻‍⚖️
        'en' : ':judge_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':richter(in)_helle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_claro:',
        'fr': ':juge_peau_claire:',
        'ja': u':裁判官_薄い肌色:',
        'ko': u':판사_하얀_피부:',
        'pt': ':juiz_no_tribunal_pele_clara:',
        'it': ':giudice_carnagione_chiara:',
        'fa': u':قاضی_پوست_سفید:',
        'id': ':hakim_warna_kulit_cerah:',
        'zh': u':法官_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002696': { # 🧑🏻‍⚖
        'en' : ':judge_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':richter(in)_helle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_claro:',
        'fr': ':juge_peau_claire:',
        'ja': u':裁判官_薄い肌色:',
        'ko': u':판사_하얀_피부:',
        'pt': ':juiz_no_tribunal_pele_clara:',
        'it': ':giudice_carnagione_chiara:',
        'fa': u':قاضی_پوست_سفید:',
        'id': ':hakim_warna_kulit_cerah:',
        'zh': u':法官_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002696\U0000FE0F': { # 🧑🏾‍⚖️
        'en' : ':judge_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':richter(in)_mitteldunkle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_oscuro_medio:',
        'fr': ':juge_peau_mate:',
        'ja': u':裁判官_やや濃い肌色:',
        'ko': u':판사_진한_갈색_피부:',
        'pt': ':juiz_no_tribunal_pele_morena_escura:',
        'it': ':giudice_carnagione_abbastanza_scura:',
        'fa': u':قاضی_پوست_گندمی:',
        'id': ':hakim_warna_kulit_gelap-sedang:',
        'zh': u':法官_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002696': { # 🧑🏾‍⚖
        'en' : ':judge_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':richter(in)_mitteldunkle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_oscuro_medio:',
        'fr': ':juge_peau_mate:',
        'ja': u':裁判官_やや濃い肌色:',
        'ko': u':판사_진한_갈색_피부:',
        'pt': ':juiz_no_tribunal_pele_morena_escura:',
        'it': ':giudice_carnagione_abbastanza_scura:',
        'fa': u':قاضی_پوست_گندمی:',
        'id': ':hakim_warna_kulit_gelap-sedang:',
        'zh': u':法官_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002696\U0000FE0F': { # 🧑🏼‍⚖️
        'en' : ':judge_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':richter(in)_mittelhelle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_claro_medio:',
        'fr': ':juge_peau_moyennement_claire:',
        'ja': u':裁判官_やや薄い肌色:',
        'ko': u':판사_연한_갈색_피부:',
        'pt': ':juiz_no_tribunal_pele_morena_clara:',
        'it': ':giudice_carnagione_abbastanza_chiara:',
        'fa': u':قاضی_پوست_روشن:',
        'id': ':hakim_warna_kulit_cerah-sedang:',
        'zh': u':法官_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002696': { # 🧑🏼‍⚖
        'en' : ':judge_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':richter(in)_mittelhelle_hautfarbe:',
        'es': ':fiscal_tono_de_piel_claro_medio:',
        'fr': ':juge_peau_moyennement_claire:',
        'ja': u':裁判官_やや薄い肌色:',
        'ko': u':판사_연한_갈색_피부:',
        'pt': ':juiz_no_tribunal_pele_morena_clara:',
        'it': ':giudice_carnagione_abbastanza_chiara:',
        'fa': u':قاضی_پوست_روشن:',
        'id': ':hakim_warna_kulit_cerah-sedang:',
        'zh': u':法官_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002696\U0000FE0F': { # 🧑🏽‍⚖️
        'en' : ':judge_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':richter(in)_mittlere_hautfarbe:',
        'es': ':fiscal_tono_de_piel_medio:',
        'fr': u':juge_peau_légèrement_mate:',
        'ja': u':裁判官_中間の肌色:',
        'ko': u':판사_갈색_피부:',
        'pt': ':juiz_no_tribunal_pele_morena:',
        'it': ':giudice_carnagione_olivastra:',
        'fa': u':قاضی_پوست_طلایی:',
        'id': ':hakim_warna_kulit_sedang:',
        'zh': u':法官_中等肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002696': { # 🧑🏽‍⚖
        'en' : ':judge_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':richter(in)_mittlere_hautfarbe:',
        'es': ':fiscal_tono_de_piel_medio:',
        'fr': u':juge_peau_légèrement_mate:',
        'ja': u':裁判官_中間の肌色:',
        'ko': u':판사_갈색_피부:',
        'pt': ':juiz_no_tribunal_pele_morena:',
        'it': ':giudice_carnagione_olivastra:',
        'fa': u':قاضی_پوست_طلایی:',
        'id': ':hakim_warna_kulit_sedang:',
        'zh': u':法官_中等肤色:'
    },
    u'\U0001F54B': { # 🕋
        'en' : ':kaaba:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':kaaba:',
        'es': ':kaaba:',
        'fr': ':kaaba:',
        'ja': u':カーバ:',
        'ko': u':카바:',
        'pt': u':caaba_islã:',
        'it': ':kaaba:',
        'fa': u':کعبه:',
        'id': u':ka’bah:',
        'zh': u':克尔白:'
    },
    u'\U0001F998': { # 🦘
        'en' : ':kangaroo:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':känguru:',
        'es': ':canguro:',
        'fr': ':kangourou:',
        'ja': u':カンガルー:',
        'ko': u':캥거루:',
        'pt': ':canguru:',
        'it': ':canguro:',
        'fa': u':کانگورو:',
        'id': ':kanguru:',
        'zh': u':袋鼠:'
    },
    u'\U0001F511': { # 🔑
        'en' : ':key:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':schlüssel:',
        'es': ':llave:',
        'fr': u':clé:',
        'ja': u':鍵:',
        'ko': u':열쇠:',
        'pt': ':chave:',
        'it': ':chiave:',
        'fa': u':کلید:',
        'id': ':kunci:',
        'zh': u':钥匙:'
    },
    u'\U00002328\U0000FE0F': { # ⌨️
        'en' : ':keyboard:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':tastatur:',
        'es': ':teclado:',
        'fr': ':clavier:',
        'ja': u':キーボード:',
        'ko': u':키보드:',
        'pt': ':teclado:',
        'it': ':tastiera:',
        'fa': u':صفحه_کلید:',
        'id': ':keyboard:',
        'zh': u':键盘:'
    },
    u'\U00002328': { # ⌨
        'en' : ':keyboard:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':tastatur:',
        'es': ':teclado:',
        'fr': ':clavier:',
        'ja': u':キーボード:',
        'ko': u':키보드:',
        'pt': ':teclado:',
        'it': ':tastiera:',
        'fa': u':صفحه_کلید:',
        'id': ':keyboard:',
        'zh': u':键盘:'
    },
    u'\U00000023\U0000FE0F\U000020E3': { # #️⃣
        'en' : ':keycap_#:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hash:'],
        'de': ':taste_#:',
        'es': ':teclas_#:',
        'fr': ':touches_#:',
        'ja': u':囲み数字_#:',
        'ko': u':키_캡_#:',
        'pt': ':tecla_#:',
        'it': ':tasto_#:',
        'fa': u':جلد_کلید_#:',
        'id': ':keycap_#:',
        'zh': u':按键_#:'
    },
    u'\U00000023\U000020E3': { # #⃣
        'en' : ':keycap_#:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':hash:']
    },
    u'\U0000002A\U0000FE0F\U000020E3': { # *️⃣
        'en' : ':keycap_*:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':asterisk:'],
        'de': ':taste_*:',
        'es': ':teclas_*:',
        'fr': ':touches_*:',
        'ja': u':囲み数字_*:',
        'ko': u':키_캡_*:',
        'pt': ':tecla_*:',
        'it': ':tasto_*:',
        'fa': u':جلد_کلید_*:',
        'id': ':keycap_*:',
        'zh': u':按键_*:'
    },
    u'\U0000002A\U000020E3': { # *⃣
        'en' : ':keycap_*:',
        'status' : unqualified,
        'E' : 2,
        'alias' : [':asterisk:']
    },
    u'\U00000030\U0000FE0F\U000020E3': { # 0️⃣
        'en' : ':keycap_0:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':zero:'],
        'de': ':taste_0:',
        'es': ':teclas_0:',
        'fr': ':touches_0:',
        'ja': u':囲み数字_0:',
        'ko': u':키_캡_0:',
        'pt': ':tecla_0:',
        'it': ':tasto_0:',
        'fa': u':جلد_کلید_0:',
        'id': ':keycap_0:',
        'zh': u':按键_0:'
    },
    u'\U00000030\U000020E3': { # 0⃣
        'en' : ':keycap_0:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':zero:']
    },
    u'\U00000031\U0000FE0F\U000020E3': { # 1️⃣
        'en' : ':keycap_1:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':one:'],
        'de': ':taste_1:',
        'es': ':teclas_1:',
        'fr': ':touches_1:',
        'ja': u':囲み数字_1:',
        'ko': u':키_캡_1:',
        'pt': ':tecla_1:',
        'it': ':tasto_1:',
        'fa': u':جلد_کلید_1:',
        'id': ':keycap_1:',
        'zh': u':按键_1:'
    },
    u'\U00000031\U000020E3': { # 1⃣
        'en' : ':keycap_1:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':one:']
    },
    u'\U0001F51F': { # 🔟
        'en' : ':keycap_10:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ten:', ':keycap_ten:'],
        'de': ':taste_10:',
        'es': ':teclas_10:',
        'fr': ':touches_10:',
        'ja': u':囲み数字_10:',
        'ko': u':키_캡_10:',
        'pt': ':tecla_10:',
        'it': ':tasto_10:',
        'fa': u':جلد_کلید_10:',
        'id': ':keycap_10:',
        'zh': u':按键_10:'
    },
    u'\U00000032\U0000FE0F\U000020E3': { # 2️⃣
        'en' : ':keycap_2:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':two:'],
        'de': ':taste_2:',
        'es': ':teclas_2:',
        'fr': ':touches_2:',
        'ja': u':囲み数字_2:',
        'ko': u':키_캡_2:',
        'pt': ':tecla_2:',
        'it': ':tasto_2:',
        'fa': u':جلد_کلید_2:',
        'id': ':keycap_2:',
        'zh': u':按键_2:'
    },
    u'\U00000032\U000020E3': { # 2⃣
        'en' : ':keycap_2:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':two:']
    },
    u'\U00000033\U0000FE0F\U000020E3': { # 3️⃣
        'en' : ':keycap_3:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':three:'],
        'de': ':taste_3:',
        'es': ':teclas_3:',
        'fr': ':touches_3:',
        'ja': u':囲み数字_3:',
        'ko': u':키_캡_3:',
        'pt': ':tecla_3:',
        'it': ':tasto_3:',
        'fa': u':جلد_کلید_3:',
        'id': ':keycap_3:',
        'zh': u':按键_3:'
    },
    u'\U00000033\U000020E3': { # 3⃣
        'en' : ':keycap_3:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':three:']
    },
    u'\U00000034\U0000FE0F\U000020E3': { # 4️⃣
        'en' : ':keycap_4:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':four:'],
        'de': ':taste_4:',
        'es': ':teclas_4:',
        'fr': ':touches_4:',
        'ja': u':囲み数字_4:',
        'ko': u':키_캡_4:',
        'pt': ':tecla_4:',
        'it': ':tasto_4:',
        'fa': u':جلد_کلید_4:',
        'id': ':keycap_4:',
        'zh': u':按键_4:'
    },
    u'\U00000034\U000020E3': { # 4⃣
        'en' : ':keycap_4:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':four:']
    },
    u'\U00000035\U0000FE0F\U000020E3': { # 5️⃣
        'en' : ':keycap_5:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':five:'],
        'de': ':taste_5:',
        'es': ':teclas_5:',
        'fr': ':touches_5:',
        'ja': u':囲み数字_5:',
        'ko': u':키_캡_5:',
        'pt': ':tecla_5:',
        'it': ':tasto_5:',
        'fa': u':جلد_کلید_5:',
        'id': ':keycap_5:',
        'zh': u':按键_5:'
    },
    u'\U00000035\U000020E3': { # 5⃣
        'en' : ':keycap_5:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':five:']
    },
    u'\U00000036\U0000FE0F\U000020E3': { # 6️⃣
        'en' : ':keycap_6:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':six:'],
        'de': ':taste_6:',
        'es': ':teclas_6:',
        'fr': ':touches_6:',
        'ja': u':囲み数字_6:',
        'ko': u':키_캡_6:',
        'pt': ':tecla_6:',
        'it': ':tasto_6:',
        'fa': u':جلد_کلید_6:',
        'id': ':keycap_6:',
        'zh': u':按键_6:'
    },
    u'\U00000036\U000020E3': { # 6⃣
        'en' : ':keycap_6:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':six:']
    },
    u'\U00000037\U0000FE0F\U000020E3': { # 7️⃣
        'en' : ':keycap_7:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':seven:'],
        'de': ':taste_7:',
        'es': ':teclas_7:',
        'fr': ':touches_7:',
        'ja': u':囲み数字_7:',
        'ko': u':키_캡_7:',
        'pt': ':tecla_7:',
        'it': ':tasto_7:',
        'fa': u':جلد_کلید_7:',
        'id': ':keycap_7:',
        'zh': u':按键_7:'
    },
    u'\U00000037\U000020E3': { # 7⃣
        'en' : ':keycap_7:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':seven:']
    },
    u'\U00000038\U0000FE0F\U000020E3': { # 8️⃣
        'en' : ':keycap_8:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':eight:'],
        'de': ':taste_8:',
        'es': ':teclas_8:',
        'fr': ':touches_8:',
        'ja': u':囲み数字_8:',
        'ko': u':키_캡_8:',
        'pt': ':tecla_8:',
        'it': ':tasto_8:',
        'fa': u':جلد_کلید_8:',
        'id': ':keycap_8:',
        'zh': u':按键_8:'
    },
    u'\U00000038\U000020E3': { # 8⃣
        'en' : ':keycap_8:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':eight:']
    },
    u'\U00000039\U0000FE0F\U000020E3': { # 9️⃣
        'en' : ':keycap_9:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':nine:'],
        'de': ':taste_9:',
        'es': ':teclas_9:',
        'fr': ':touches_9:',
        'ja': u':囲み数字_9:',
        'ko': u':키_캡_9:',
        'pt': ':tecla_9:',
        'it': ':tasto_9:',
        'fa': u':جلد_کلید_9:',
        'id': ':keycap_9:',
        'zh': u':按键_9:'
    },
    u'\U00000039\U000020E3': { # 9⃣
        'en' : ':keycap_9:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':nine:']
    },
    u'\U0001FAAF': { # 🪯
        'en' : ':khanda:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':khanda:',
        'es': ':khanda:',
        'fr': ':khanda:',
        'ja': u':カンダ:',
        'ko': u':칸다:',
        'pt': ':khanda:',
        'it': ':khanda:',
        'fa': u':خندا:',
        'id': ':khanda:',
        'zh': u':坎达:'
    },
    u'\U0001F6F4': { # 🛴
        'en' : ':kick_scooter:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tretroller:',
        'es': ':patinete:',
        'fr': ':trottinette:',
        'ja': u':キックボード:',
        'ko': u':킥보드:',
        'pt': ':patinete:',
        'it': ':monopattino:',
        'fa': u':چرخ_پایی:',
        'id': ':otoped:',
        'zh': u':滑板车:'
    },
    u'\U0001F458': { # 👘
        'en' : ':kimono:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kimono:',
        'es': ':kimono:',
        'fr': ':kimono:',
        'ja': u':着物:',
        'ko': u':기모노:',
        'pt': ':quimono:',
        'it': ':kimono:',
        'fa': u':کیمونو:',
        'id': ':kimono:',
        'zh': u':和服:'
    },
    u'\U0001F48F': { # 💏
        'en' : ':kiss:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':couplekiss:'],
        'de': u':sich_küssendes_paar:',
        'es': ':beso:',
        'fr': ':bisou:',
        'ja': u':2人でキス:',
        'ko': u':키스:',
        'pt': ':beijo:',
        'it': ':bacio_tra_coppia:',
        'fa': u':بوسه:',
        'id': ':berciuman:',
        'zh': u':亲吻:'
    },
    u'\U0001F48F\U0001F3FF': { # 💏🏿
        'en' : ':kiss_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_dunkle_hautfarbe:',
        'es': ':beso_tono_de_piel_oscuro:',
        'fr': u':bisou__peau_foncée:',
        'pt': ':beijo_pele_escura:',
        'it': ':bacio_tra_coppia_carnagione_scura:'
    },
    u'\U0001F48F\U0001F3FB': { # 💏🏻
        'en' : ':kiss_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_helle_hautfarbe:',
        'es': ':beso_tono_de_piel_claro:',
        'fr': ':bisou__peau_claire:',
        'pt': ':beijo_pele_clara:',
        'it': ':bacio_tra_coppia_carnagione_chiara:'
    },
    u'\U0001F468\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468': { # 👨‍❤️‍💋‍👨
        'en' : ':kiss_man_man:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':couplekiss_man_man:'],
        'de': u':sich_küssendes_paar_mann,_mann:',
        'es': ':beso_hombre_y_hombre:',
        'fr': ':bisou_homme_et_homme:',
        'ja': u':2人でキス_男性_男性:',
        'ko': u':키스_남자_남자:',
        'pt': ':beijo_homem_e_homem:',
        'it': ':bacio_tra_coppia_uomo_e_uomo:',
        'fa': u':بوسه_مرد_مرد:',
        'id': ':berciuman_pria_pria:',
        'zh': u':亲吻_男人男人:'
    },
    u'\U0001F468\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468': { # 👨‍❤‍💋‍👨
        'en' : ':kiss_man_man:',
        'status' : minimally_qualified,
        'E' : 2,
        'alias' : [':couplekiss_man_man:']
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏿‍❤️‍💋‍👨🏿
        'en' : ':kiss_man_man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_und_dunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro:',
        'fr': u':bisou__homme_homme_et_peau_foncée:',
        'ja': u':2人でキス_男性_男性_濃い肌色:',
        'ko': u':키스_남자_남자_검은색_피부:',
        'pt': ':beijo_homem_homem_e_pele_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_e_carnagione_scura:',
        'fa': u':بوسه_مرد_مرد_و_پوست_آبنوسی:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap:',
        'zh': u':亲吻_男人男人较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏿‍❤‍💋‍👨🏿
        'en' : ':kiss_man_man_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏿‍❤️‍💋‍👨🏻
        'en' : ':kiss_man_man_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':bisou__homme_homme_peau_foncée_et_peau_claire:',
        'ja': u':2人でキス_男性_男性_濃い肌色_薄い肌色:',
        'ko': u':키스_남자_남자_검은색_피부_하얀_피부:',
        'pt': ':beijo_homem_homem_pele_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_scura_e_carnagione_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':亲吻_男人男人较深肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏿‍❤‍💋‍👨🏻
        'en' : ':kiss_man_man_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏿‍❤️‍💋‍👨🏾
        'en' : ':kiss_man_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__homme_homme_peau_foncée_et_peau_mate:',
        'ja': u':2人でキス_男性_男性_濃い肌色_やや濃い肌色:',
        'ko': u':키스_남자_남자_검은색_피부_진한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_escura_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_男人男人较深肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏿‍❤‍💋‍👨🏾
        'en' : ':kiss_man_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏿‍❤️‍💋‍👨🏼
        'en' : ':kiss_man_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':bisou__homme_homme_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':2人でキス_男性_男性_濃い肌色_やや薄い肌色:',
        'ko': u':키스_남자_남자_검은색_피부_연한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_男人男人较深肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏿‍❤‍💋‍👨🏼
        'en' : ':kiss_man_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏿‍❤️‍💋‍👨🏽
        'en' : ':kiss_man_man_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':bisou__homme_homme_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':2人でキス_男性_男性_濃い肌色_中間の肌色:',
        'ko': u':키스_남자_남자_검은색_피부_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_مرد_مرد_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':亲吻_男人男人较深肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏿‍❤‍💋‍👨🏽
        'en' : ':kiss_man_man_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏻‍❤️‍💋‍👨🏻
        'en' : ':kiss_man_man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_und_helle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro:',
        'fr': ':bisou__homme_homme_et_peau_claire:',
        'ja': u':2人でキス_男性_男性_薄い肌色:',
        'ko': u':키스_남자_남자_하얀_피부:',
        'pt': ':beijo_homem_homem_e_pele_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_e_carnagione_chiara:',
        'fa': u':بوسه_مرد_مرد_و_پوست_سفید:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah:',
        'zh': u':亲吻_男人男人较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏻‍❤‍💋‍👨🏻
        'en' : ':kiss_man_man_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏻‍❤️‍💋‍👨🏿
        'en' : ':kiss_man_man_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':bisou__homme_homme_peau_claire_et_peau_foncée:',
        'ja': u':2人でキス_男性_男性_薄い肌色_濃い肌色:',
        'ko': u':키스_남자_남자_하얀_피부_검은색_피부:',
        'pt': ':beijo_homem_homem_pele_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_chiara_e_carnagione_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':亲吻_男人男人较浅肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏻‍❤‍💋‍👨🏿
        'en' : ':kiss_man_man_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏻‍❤️‍💋‍👨🏾
        'en' : ':kiss_man_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__homme_homme_peau_claire_et_peau_mate:',
        'ja': u':2人でキス_男性_男性_薄い肌色_やや濃い肌色:',
        'ko': u':키스_남자_남자_하얀_피부_진한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_سفید_و_پوست_گندمی:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_男人男人较浅肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏻‍❤‍💋‍👨🏾
        'en' : ':kiss_man_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏻‍❤️‍💋‍👨🏼
        'en' : ':kiss_man_man_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': ':bisou__homme_homme_peau_claire_et_peau_moyennement_claire:',
        'ja': u':2人でキス_男性_男性_薄い肌色_やや薄い肌色:',
        'ko': u':키스_남자_남자_하얀_피부_연한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_clara_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_سفید_و_پوست_روشن:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_男人男人较浅肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏻‍❤‍💋‍👨🏼
        'en' : ':kiss_man_man_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏻‍❤️‍💋‍👨🏽
        'en' : ':kiss_man_man_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':bisou__homme_homme_peau_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_男性_男性_薄い肌色_中間の肌色:',
        'ko': u':키스_남자_남자_하얀_피부_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_مرد_مرد_پوست_سفید_و_پوست_طلایی:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':亲吻_男人男人较浅肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏻‍❤‍💋‍👨🏽
        'en' : ':kiss_man_man_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏾‍❤️‍💋‍👨🏾
        'en' : ':kiss_man_man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_und_mitteldunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__homme_homme_et_peau_mate:',
        'ja': u':2人でキス_男性_男性_やや濃い肌色:',
        'ko': u':키스_남자_남자_진한_갈색_피부:',
        'pt': ':beijo_homem_homem_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_مرد_مرد_و_پوست_گندمی:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_男人男人中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏾‍❤‍💋‍👨🏾
        'en' : ':kiss_man_man_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏾‍❤️‍💋‍👨🏿
        'en' : ':kiss_man_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__homme_homme_peau_mate_et_peau_foncée:',
        'ja': u':2人でキス_男性_男性_やや濃い肌色_濃い肌色:',
        'ko': u':키스_남자_남자_진한_갈색_피부_검은색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_escura_e_pele_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_男人男人中等深肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏾‍❤‍💋‍👨🏿
        'en' : ':kiss_man_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏾‍❤️‍💋‍👨🏻
        'en' : ':kiss_man_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': ':bisou__homme_homme_peau_mate_et_peau_claire:',
        'ja': u':2人でキス_男性_男性_やや濃い肌色_薄い肌色:',
        'ko': u':키스_남자_남자_진한_갈색_피부_하얀_피부:',
        'pt': ':beijo_homem_homem_pele_morena_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_گندمی_و_پوست_سفید:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_男人男人中等深肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏾‍❤‍💋‍👨🏻
        'en' : ':kiss_man_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏾‍❤️‍💋‍👨🏼
        'en' : ':kiss_man_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': ':bisou__homme_homme_peau_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_男性_男性_やや濃い肌色_やや薄い肌色:',
        'ko': u':키스_남자_남자_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_گندمی_و_پوست_روشن:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_男人男人中等深肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏾‍❤‍💋‍👨🏼
        'en' : ':kiss_man_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏾‍❤️‍💋‍👨🏽
        'en' : ':kiss_man_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':bisou__homme_homme_peau_mate_et_peau_légèrement_mate:',
        'ja': u':2人でキス_男性_男性_やや濃い肌色_中間の肌色:',
        'ko': u':키스_남자_남자_진한_갈색_피부_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_مرد_مرد_پوست_گندمی_و_پوست_طلایی:',
        'id': ':berciuman_pria_pria_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_男人男人中等深肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏾‍❤‍💋‍👨🏽
        'en' : ':kiss_man_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏼‍❤️‍💋‍👨🏼
        'en' : ':kiss_man_man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_und_mittelhelle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_medio:',
        'fr': ':bisou__homme_homme_et_peau_moyennement_claire:',
        'ja': u':2人でキス_男性_男性_やや薄い肌色:',
        'ko': u':키스_남자_남자_연한_갈색_피부:',
        'pt': ':beijo_homem_homem_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_مرد_مرد_و_پوست_روشن:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_男人男人中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏼‍❤‍💋‍👨🏼
        'en' : ':kiss_man_man_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏼‍❤️‍💋‍👨🏿
        'en' : ':kiss_man_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__homme_homme_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':2人でキス_男性_男性_やや薄い肌色_濃い肌色:',
        'ko': u':키스_남자_남자_연한_갈색_피부_검은색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_男人男人中等浅肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏼‍❤‍💋‍👨🏿
        'en' : ':kiss_man_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏼‍❤️‍💋‍👨🏻
        'en' : ':kiss_man_man_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': ':bisou__homme_homme_peau_moyennement_claire_et_peau_claire:',
        'ja': u':2人でキス_男性_男性_やや薄い肌色_薄い肌色:',
        'ko': u':키스_남자_남자_연한_갈색_피부_하얀_피부:',
        'pt': ':beijo_homem_homem_pele_morena_clara_e_pele_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_روشن_و_پوست_سفید:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_男人男人中等浅肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏼‍❤‍💋‍👨🏻
        'en' : ':kiss_man_man_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏼‍❤️‍💋‍👨🏾
        'en' : ':kiss_man_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__homme_homme_peau_moyennement_claire_et_peau_mate:',
        'ja': u':2人でキス_男性_男性_やや薄い肌色_やや濃い肌色:',
        'ko': u':키스_남자_남자_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_روشن_و_پوست_گندمی:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_男人男人中等浅肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏼‍❤‍💋‍👨🏾
        'en' : ':kiss_man_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏼‍❤️‍💋‍👨🏽
        'en' : ':kiss_man_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':bisou__homme_homme_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_男性_男性_やや薄い肌色_中間の肌色:',
        'ko': u':키스_남자_남자_연한_갈색_피부_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_مرد_مرد_پوست_روشن_و_پوست_طلایی:',
        'id': ':berciuman_pria_pria_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_男人男人中等浅肤色中等肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏼‍❤‍💋‍👨🏽
        'en' : ':kiss_man_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏽‍❤️‍💋‍👨🏽
        'en' : ':kiss_man_man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_und_mittlere_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_medio:',
        'fr': u':bisou__homme_homme_et_peau_légèrement_mate:',
        'ja': u':2人でキス_男性_男性_中間の肌色:',
        'ko': u':키스_남자_남자_갈색_피부:',
        'pt': ':beijo_homem_homem_e_pele_morena:',
        'it': ':bacio_tra_coppia_uomo_uomo_e_carnagione_olivastra:',
        'fa': u':بوسه_مرد_مرد_و_پوست_طلایی:',
        'id': ':berciuman_pria_pria_warna_kulit_sedang:',
        'zh': u':亲吻_男人男人中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👨🏽‍❤‍💋‍👨🏽
        'en' : ':kiss_man_man_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏽‍❤️‍💋‍👨🏿
        'en' : ':kiss_man_man_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__homme_homme_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':2人でキス_男性_男性_中間の肌色_濃い肌色:',
        'ko': u':키스_남자_남자_갈색_피부_검은색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_e_pele_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':berciuman_pria_pria_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':亲吻_男人男人中等肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👨🏽‍❤‍💋‍👨🏿
        'en' : ':kiss_man_man_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏽‍❤️‍💋‍👨🏻
        'en' : ':kiss_man_man_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':bisou__homme_homme_peau_légèrement_mate_et_peau_claire:',
        'ja': u':2人でキス_男性_男性_中間の肌色_薄い肌色:',
        'ko': u':키스_남자_남자_갈색_피부_하얀_피부:',
        'pt': ':beijo_homem_homem_pele_morena_e_pele_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_طلایی_و_پوست_سفید:',
        'id': ':berciuman_pria_pria_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':亲吻_男人男人中等肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👨🏽‍❤‍💋‍👨🏻
        'en' : ':kiss_man_man_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏽‍❤️‍💋‍👨🏾
        'en' : ':kiss_man_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__homme_homme_peau_légèrement_mate_et_peau_mate:',
        'ja': u':2人でキス_男性_男性_中間の肌色_やや濃い肌色:',
        'ko': u':키스_남자_남자_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_مرد_مرد_پوست_طلایی_و_پوست_گندمی:',
        'id': ':berciuman_pria_pria_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_男人男人中等肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👨🏽‍❤‍💋‍👨🏾
        'en' : ':kiss_man_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏽‍❤️‍💋‍👨🏼
        'en' : ':kiss_man_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mann_mann_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_hombre_hombre_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':bisou__homme_homme_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_男性_男性_中間の肌色_やや薄い肌色:',
        'ko': u':키스_남자_남자_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_homem_homem_pele_morena_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_uomo_uomo_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_مرد_مرد_پوست_طلایی_و_پوست_روشن:',
        'id': ':berciuman_pria_pria_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_男人男人中等肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👨🏽‍❤‍💋‍👨🏼
        'en' : ':kiss_man_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F48B': { # 💋
        'en' : ':kiss_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':kiss:'],
        'de': ':kussabdruck:',
        'es': ':marca_de_beso:',
        'fr': u':trace_de_rouge_à_lèvres:',
        'ja': u':キスマーク:',
        'ko': u':입술:',
        'pt': ':marca_de_beijo:',
        'it': ':impronta_della_bocca:',
        'fa': u':بوسه_ماتیکی:',
        'id': ':tanda_ciuman:',
        'zh': u':唇印:'
    },
    u'\U0001F48F\U0001F3FE': { # 💏🏾
        'en' : ':kiss_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mitteldunkle_hautfarbe:',
        'es': ':beso_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__peau_mate:',
        'pt': ':beijo_pele_morena_escura:',
        'it': ':bacio_tra_coppia_carnagione_abbastanza_scura:'
    },
    u'\U0001F48F\U0001F3FC': { # 💏🏼
        'en' : ':kiss_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mittelhelle_hautfarbe:',
        'es': ':beso_tono_de_piel_claro_medio:',
        'fr': ':bisou__peau_moyennement_claire:',
        'pt': ':beijo_pele_morena_clara:',
        'it': ':bacio_tra_coppia_carnagione_abbastanza_chiara:'
    },
    u'\U0001F48F\U0001F3FD': { # 💏🏽
        'en' : ':kiss_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_mittlere_hautfarbe:',
        'es': ':beso_tono_de_piel_medio:',
        'fr': u':bisou__peau_légèrement_mate:',
        'pt': ':beijo_pele_morena:',
        'it': ':bacio_tra_coppia_carnagione_olivastra:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏿‍❤️‍💋‍🧑🏻
        'en' : ':kiss_person_person_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':bisou__adulte_adulte_peau_foncée_et_peau_claire:',
        'ja': u':2人でキス_大人_大人_濃い肌色_薄い肌色:',
        'ko': u':키스_사람_사람_검은색_피부_하얀_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_scura_e_carnagione_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':亲吻_成人成人较深肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏿‍❤‍💋‍🧑🏻
        'en' : ':kiss_person_person_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏿‍❤️‍💋‍🧑🏾
        'en' : ':kiss_person_person_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__adulte_adulte_peau_foncée_et_peau_mate:',
        'ja': u':2人でキス_大人_大人_濃い肌色_やや濃い肌色:',
        'ko': u':키스_사람_사람_검은색_피부_진한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_escura_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_成人成人较深肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏿‍❤‍💋‍🧑🏾
        'en' : ':kiss_person_person_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏿‍❤️‍💋‍🧑🏼
        'en' : ':kiss_person_person_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':bisou__adulte_adulte_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':2人でキス_大人_大人_濃い肌色_やや薄い肌色:',
        'ko': u':키스_사람_사람_검은색_피부_연한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_成人成人较深肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏿‍❤‍💋‍🧑🏼
        'en' : ':kiss_person_person_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏿‍❤️‍💋‍🧑🏽
        'en' : ':kiss_person_person_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':bisou__adulte_adulte_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':2人でキス_大人_大人_濃い肌色_中間の肌色:',
        'ko': u':키스_사람_사람_검은색_피부_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':亲吻_成人成人较深肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏿‍❤‍💋‍🧑🏽
        'en' : ':kiss_person_person_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏻‍❤️‍💋‍🧑🏿
        'en' : ':kiss_person_person_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':bisou__adulte_adulte_peau_claire_et_peau_foncée:',
        'ja': u':2人でキス_大人_大人_薄い肌色_濃い肌色:',
        'ko': u':키스_사람_사람_하얀_피부_검은색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_chiara_e_carnagione_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':亲吻_成人成人较浅肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏻‍❤‍💋‍🧑🏿
        'en' : ':kiss_person_person_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏻‍❤️‍💋‍🧑🏾
        'en' : ':kiss_person_person_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__adulte_adulte_peau_claire_et_peau_mate:',
        'ja': u':2人でキス_大人_大人_薄い肌色_やや濃い肌色:',
        'ko': u':키스_사람_사람_하얀_피부_진한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_سفید_و_پوست_گندمی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_成人成人较浅肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏻‍❤‍💋‍🧑🏾
        'en' : ':kiss_person_person_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏻‍❤️‍💋‍🧑🏼
        'en' : ':kiss_person_person_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': ':bisou__adulte_adulte_peau_claire_et_peau_moyennement_claire:',
        'ja': u':2人でキス_大人_大人_薄い肌色_やや薄い肌色:',
        'ko': u':키스_사람_사람_하얀_피부_연한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_clara_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_سفید_و_پوست_روشن:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_成人成人较浅肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏻‍❤‍💋‍🧑🏼
        'en' : ':kiss_person_person_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏻‍❤️‍💋‍🧑🏽
        'en' : ':kiss_person_person_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':bisou__adulte_adulte_peau_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_大人_大人_薄い肌色_中間の肌色:',
        'ko': u':키스_사람_사람_하얀_피부_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_سفید_و_پوست_طلایی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':亲吻_成人成人较浅肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏻‍❤‍💋‍🧑🏽
        'en' : ':kiss_person_person_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏾‍❤️‍💋‍🧑🏿
        'en' : ':kiss_person_person_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__adulte_adulte_peau_mate_et_peau_foncée:',
        'ja': u':2人でキス_大人_大人_やや濃い肌色_濃い肌色:',
        'ko': u':키스_사람_사람_진한_갈색_피부_검은색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_escura_e_pele_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_成人成人中等深肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏾‍❤‍💋‍🧑🏿
        'en' : ':kiss_person_person_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏾‍❤️‍💋‍🧑🏻
        'en' : ':kiss_person_person_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': ':bisou__adulte_adulte_peau_mate_et_peau_claire:',
        'ja': u':2人でキス_大人_大人_やや濃い肌色_薄い肌色:',
        'ko': u':키스_사람_사람_진한_갈색_피부_하얀_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_سفید:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_成人成人中等深肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏾‍❤‍💋‍🧑🏻
        'en' : ':kiss_person_person_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏾‍❤️‍💋‍🧑🏼
        'en' : ':kiss_person_person_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': ':bisou__adulte_adulte_peau_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_大人_大人_やや濃い肌色_やや薄い肌色:',
        'ko': u':키스_사람_사람_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_روشن:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_成人成人中等深肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏾‍❤‍💋‍🧑🏼
        'en' : ':kiss_person_person_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏾‍❤️‍💋‍🧑🏽
        'en' : ':kiss_person_person_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':bisou__adulte_adulte_peau_mate_et_peau_légèrement_mate:',
        'ja': u':2人でキス_大人_大人_やや濃い肌色_中間の肌色:',
        'ko': u':키스_사람_사람_진한_갈색_피부_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_گندمی_و_پوست_طلایی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_成人成人中等深肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏾‍❤‍💋‍🧑🏽
        'en' : ':kiss_person_person_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏼‍❤️‍💋‍🧑🏿
        'en' : ':kiss_person_person_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__adulte_adulte_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':2人でキス_大人_大人_やや薄い肌色_濃い肌色:',
        'ko': u':키스_사람_사람_연한_갈색_피부_검은색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_成人成人中等浅肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏼‍❤‍💋‍🧑🏿
        'en' : ':kiss_person_person_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏼‍❤️‍💋‍🧑🏻
        'en' : ':kiss_person_person_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': ':bisou__adulte_adulte_peau_moyennement_claire_et_peau_claire:',
        'ja': u':2人でキス_大人_大人_やや薄い肌色_薄い肌色:',
        'ko': u':키스_사람_사람_연한_갈색_피부_하얀_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_clara_e_pele_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_روشن_و_پوست_سفید:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_成人成人中等浅肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏼‍❤‍💋‍🧑🏻
        'en' : ':kiss_person_person_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏼‍❤️‍💋‍🧑🏾
        'en' : ':kiss_person_person_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__adulte_adulte_peau_moyennement_claire_et_peau_mate:',
        'ja': u':2人でキス_大人_大人_やや薄い肌色_やや濃い肌色:',
        'ko': u':키스_사람_사람_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_روشن_و_پوست_گندمی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_成人成人中等浅肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏼‍❤‍💋‍🧑🏾
        'en' : ':kiss_person_person_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏼‍❤️‍💋‍🧑🏽
        'en' : ':kiss_person_person_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':bisou__adulte_adulte_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_大人_大人_やや薄い肌色_中間の肌色:',
        'ko': u':키스_사람_사람_연한_갈색_피부_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_روشن_و_پوست_طلایی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_成人成人中等浅肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏼‍❤‍💋‍🧑🏽
        'en' : ':kiss_person_person_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏽‍❤️‍💋‍🧑🏿
        'en' : ':kiss_person_person_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__adulte_adulte_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':2人でキス_大人_大人_中間の肌色_濃い肌色:',
        'ko': u':키스_사람_사람_갈색_피부_검은색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_e_pele_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':亲吻_成人成人中等肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏽‍❤‍💋‍🧑🏿
        'en' : ':kiss_person_person_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏽‍❤️‍💋‍🧑🏻
        'en' : ':kiss_person_person_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':bisou__adulte_adulte_peau_légèrement_mate_et_peau_claire:',
        'ja': u':2人でキス_大人_大人_中間の肌色_薄い肌色:',
        'ko': u':키스_사람_사람_갈색_피부_하얀_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_e_pele_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_سفید:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':亲吻_成人成人中等肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏽‍❤‍💋‍🧑🏻
        'en' : ':kiss_person_person_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏽‍❤️‍💋‍🧑🏾
        'en' : ':kiss_person_person_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__adulte_adulte_peau_légèrement_mate_et_peau_mate:',
        'ja': u':2人でキス_大人_大人_中間の肌色_やや濃い肌色:',
        'ko': u':키스_사람_사람_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_گندمی:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_成人成人中等肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏽‍❤‍💋‍🧑🏾
        'en' : ':kiss_person_person_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏽‍❤️‍💋‍🧑🏼
        'en' : ':kiss_person_person_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_erwachsener_erwachsener_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_persona_adulta_persona_adulta_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':bisou__adulte_adulte_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_大人_大人_中間の肌色_やや薄い肌色:',
        'ko': u':키스_사람_사람_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_pessoa_pessoa_pele_morena_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_persona_persona_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_بزرگسال_بزرگسال_پوست_طلایی_و_پوست_روشن:',
        'id': ':berciuman_dewasa_dewasa_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_成人成人中等肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏽‍❤‍💋‍🧑🏼
        'en' : ':kiss_person_person_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468': { # 👩‍❤️‍💋‍👨
        'en' : ':kiss_woman_man:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':couplekiss_man_woman:'],
        'de': u':sich_küssendes_paar_frau,_mann:',
        'es': ':beso_mujer_y_hombre:',
        'fr': ':bisou_femme_et_homme:',
        'ja': u':2人でキス_女性_男性:',
        'ko': u':키스_여자_남자:',
        'pt': ':beijo_mulher_e_homem:',
        'it': ':bacio_tra_coppia_donna_e_uomo:',
        'fa': u':بوسه_زن_مرد:',
        'id': ':berciuman_wanita_pria:',
        'zh': u':亲吻_女人男人:'
    },
    u'\U0001F469\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468': { # 👩‍❤‍💋‍👨
        'en' : ':kiss_woman_man:',
        'status' : minimally_qualified,
        'E' : 2,
        'alias' : [':couplekiss_man_woman:']
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏿‍❤️‍💋‍👨🏿
        'en' : ':kiss_woman_man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_und_dunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_homme_et_peau_foncée:',
        'ja': u':2人でキス_女性_男性_濃い肌色:',
        'ko': u':키스_여자_남자_검은색_피부:',
        'pt': ':beijo_mulher_homem_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_e_carnagione_scura:',
        'fa': u':بوسه_زن_مرد_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap:',
        'zh': u':亲吻_女人男人较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏿‍❤‍💋‍👨🏿
        'en' : ':kiss_woman_man_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏿‍❤️‍💋‍👨🏻
        'en' : ':kiss_woman_man_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':bisou__femme_homme_peau_foncée_et_peau_claire:',
        'ja': u':2人でキス_女性_男性_濃い肌色_薄い肌色:',
        'ko': u':키스_여자_남자_검은색_피부_하얀_피부:',
        'pt': ':beijo_mulher_homem_pele_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_scura_e_carnagione_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':亲吻_女人男人较深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏿‍❤‍💋‍👨🏻
        'en' : ':kiss_woman_man_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏿‍❤️‍💋‍👨🏾
        'en' : ':kiss_woman_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__femme_homme_peau_foncée_et_peau_mate:',
        'ja': u':2人でキス_女性_男性_濃い肌色_やや濃い肌色:',
        'ko': u':키스_여자_남자_검은색_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_escura_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_مرد_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人男人较深肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏿‍❤‍💋‍👨🏾
        'en' : ':kiss_woman_man_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏿‍❤️‍💋‍👨🏼
        'en' : ':kiss_woman_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':bisou__femme_homme_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_男性_濃い肌色_やや薄い肌色:',
        'ko': u':키스_여자_남자_검은색_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人男人较深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏿‍❤‍💋‍👨🏼
        'en' : ':kiss_woman_man_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏿‍❤️‍💋‍👨🏽
        'en' : ':kiss_woman_man_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':bisou__femme_homme_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_男性_濃い肌色_中間の肌色:',
        'ko': u':키스_여자_남자_검은색_피부_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_مرد_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':亲吻_女人男人较深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏿‍❤‍💋‍👨🏽
        'en' : ':kiss_woman_man_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏻‍❤️‍💋‍👨🏻
        'en' : ':kiss_woman_man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_und_helle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro:',
        'fr': ':bisou__femme_homme_et_peau_claire:',
        'ja': u':2人でキス_女性_男性_薄い肌色:',
        'ko': u':키스_여자_남자_하얀_피부:',
        'pt': ':beijo_mulher_homem_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_e_carnagione_chiara:',
        'fa': u':بوسه_زن_مرد_و_پوست_سفید:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah:',
        'zh': u':亲吻_女人男人较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏻‍❤‍💋‍👨🏻
        'en' : ':kiss_woman_man_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏻‍❤️‍💋‍👨🏿
        'en' : ':kiss_woman_man_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_homme_peau_claire_et_peau_foncée:',
        'ja': u':2人でキス_女性_男性_薄い肌色_濃い肌色:',
        'ko': u':키스_여자_남자_하얀_피부_검은색_피부:',
        'pt': ':beijo_mulher_homem_pele_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_chiara_e_carnagione_scura:',
        'fa': u':بوسه_زن_مرد_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':亲吻_女人男人较浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏻‍❤‍💋‍👨🏿
        'en' : ':kiss_woman_man_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏻‍❤️‍💋‍👨🏾
        'en' : ':kiss_woman_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__femme_homme_peau_claire_et_peau_mate:',
        'ja': u':2人でキス_女性_男性_薄い肌色_やや濃い肌色:',
        'ko': u':키스_여자_남자_하얀_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_مرد_پوست_سفید_و_پوست_گندمی:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人男人较浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏻‍❤‍💋‍👨🏾
        'en' : ':kiss_woman_man_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏻‍❤️‍💋‍👨🏼
        'en' : ':kiss_woman_man_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': ':bisou__femme_homme_peau_claire_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_男性_薄い肌色_やや薄い肌色:',
        'ko': u':키스_여자_남자_하얀_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_clara_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_سفید_و_پوست_روشن:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人男人较浅肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏻‍❤‍💋‍👨🏼
        'en' : ':kiss_woman_man_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏻‍❤️‍💋‍👨🏽
        'en' : ':kiss_woman_man_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':bisou__femme_homme_peau_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_男性_薄い肌色_中間の肌色:',
        'ko': u':키스_여자_남자_하얀_피부_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_مرد_پوست_سفید_و_پوست_طلایی:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':亲吻_女人男人较浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏻‍❤‍💋‍👨🏽
        'en' : ':kiss_woman_man_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏾‍❤️‍💋‍👨🏾
        'en' : ':kiss_woman_man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_und_mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__femme_homme_et_peau_mate:',
        'ja': u':2人でキス_女性_男性_やや濃い肌色:',
        'ko': u':키스_여자_남자_진한_갈색_피부:',
        'pt': ':beijo_mulher_homem_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_مرد_و_پوست_گندمی:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人男人中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏾‍❤‍💋‍👨🏾
        'en' : ':kiss_woman_man_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏾‍❤️‍💋‍👨🏿
        'en' : ':kiss_woman_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_homme_peau_mate_et_peau_foncée:',
        'ja': u':2人でキス_女性_男性_やや濃い肌色_濃い肌色:',
        'ko': u':키스_여자_남자_진한_갈색_피부_검은색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_escura_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':بوسه_زن_مرد_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_女人男人中等深肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏾‍❤‍💋‍👨🏿
        'en' : ':kiss_woman_man_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏾‍❤️‍💋‍👨🏻
        'en' : ':kiss_woman_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': ':bisou__femme_homme_peau_mate_et_peau_claire:',
        'ja': u':2人でキス_女性_男性_やや濃い肌色_薄い肌色:',
        'ko': u':키스_여자_남자_진한_갈색_피부_하얀_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_گندمی_و_پوست_سفید:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_女人男人中等深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏾‍❤‍💋‍👨🏻
        'en' : ':kiss_woman_man_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏾‍❤️‍💋‍👨🏼
        'en' : ':kiss_woman_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': ':bisou__femme_homme_peau_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_男性_やや濃い肌色_やや薄い肌色:',
        'ko': u':키스_여자_남자_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_گندمی_و_پوست_روشن:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人男人中等深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏾‍❤‍💋‍👨🏼
        'en' : ':kiss_woman_man_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏾‍❤️‍💋‍👨🏽
        'en' : ':kiss_woman_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':bisou__femme_homme_peau_mate_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_男性_やや濃い肌色_中間の肌色:',
        'ko': u':키스_여자_남자_진한_갈색_피부_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_مرد_پوست_گندمی_و_پوست_طلایی:',
        'id': ':berciuman_wanita_pria_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_女人男人中等深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏾‍❤‍💋‍👨🏽
        'en' : ':kiss_woman_man_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏼‍❤️‍💋‍👨🏼
        'en' : ':kiss_woman_man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_und_mittelhelle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_medio:',
        'fr': ':bisou__femme_homme_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_男性_やや薄い肌色:',
        'ko': u':키스_여자_남자_연한_갈색_피부:',
        'pt': ':beijo_mulher_homem_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_مرد_و_پوست_روشن:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人男人中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏼‍❤‍💋‍👨🏼
        'en' : ':kiss_woman_man_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏼‍❤️‍💋‍👨🏿
        'en' : ':kiss_woman_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_homme_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':2人でキス_女性_男性_やや薄い肌色_濃い肌色:',
        'ko': u':키스_여자_남자_연한_갈색_피부_검은색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':بوسه_زن_مرد_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_女人男人中等浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏼‍❤‍💋‍👨🏿
        'en' : ':kiss_woman_man_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏼‍❤️‍💋‍👨🏻
        'en' : ':kiss_woman_man_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': ':bisou__femme_homme_peau_moyennement_claire_et_peau_claire:',
        'ja': u':2人でキス_女性_男性_やや薄い肌色_薄い肌色:',
        'ko': u':키스_여자_남자_연한_갈색_피부_하얀_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_clara_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_روشن_و_پوست_سفید:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_女人男人中等浅肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏼‍❤‍💋‍👨🏻
        'en' : ':kiss_woman_man_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏼‍❤️‍💋‍👨🏾
        'en' : ':kiss_woman_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__femme_homme_peau_moyennement_claire_et_peau_mate:',
        'ja': u':2人でキス_女性_男性_やや薄い肌色_やや濃い肌色:',
        'ko': u':키스_여자_남자_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_مرد_پوست_روشن_و_پوست_گندمی:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人男人中等浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏼‍❤‍💋‍👨🏾
        'en' : ':kiss_woman_man_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏼‍❤️‍💋‍👨🏽
        'en' : ':kiss_woman_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':bisou__femme_homme_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_男性_やや薄い肌色_中間の肌色:',
        'ko': u':키스_여자_남자_연한_갈색_피부_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_مرد_پوست_روشن_و_پوست_طلایی:',
        'id': ':berciuman_wanita_pria_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_女人男人中等浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏼‍❤‍💋‍👨🏽
        'en' : ':kiss_woman_man_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏽‍❤️‍💋‍👨🏽
        'en' : ':kiss_woman_man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_und_mittlere_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_medio:',
        'fr': u':bisou__femme_homme_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_男性_中間の肌色:',
        'ko': u':키스_여자_남자_갈색_피부:',
        'pt': ':beijo_mulher_homem_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_uomo_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_مرد_و_پوست_طلایی:',
        'id': ':berciuman_wanita_pria_warna_kulit_sedang:',
        'zh': u':亲吻_女人男人中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FD': { # 👩🏽‍❤‍💋‍👨🏽
        'en' : ':kiss_woman_man_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏽‍❤️‍💋‍👨🏿
        'en' : ':kiss_woman_man_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_homme_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':2人でキス_女性_男性_中間の肌色_濃い肌色:',
        'ko': u':키스_여자_남자_갈색_피부_검은색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':بوسه_زن_مرد_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_pria_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':亲吻_女人男人中等肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FF': { # 👩🏽‍❤‍💋‍👨🏿
        'en' : ':kiss_woman_man_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏽‍❤️‍💋‍👨🏻
        'en' : ':kiss_woman_man_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':bisou__femme_homme_peau_légèrement_mate_et_peau_claire:',
        'ja': u':2人でキス_女性_男性_中間の肌色_薄い肌色:',
        'ko': u':키스_여자_남자_갈색_피부_하얀_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_طلایی_و_پوست_سفید:',
        'id': ':berciuman_wanita_pria_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':亲吻_女人男人中等肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FB': { # 👩🏽‍❤‍💋‍👨🏻
        'en' : ':kiss_woman_man_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏽‍❤️‍💋‍👨🏾
        'en' : ':kiss_woman_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__femme_homme_peau_légèrement_mate_et_peau_mate:',
        'ja': u':2人でキス_女性_男性_中間の肌色_やや濃い肌色:',
        'ko': u':키스_여자_남자_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_مرد_پوست_طلایی_و_پوست_گندمی:',
        'id': ':berciuman_wanita_pria_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人男人中等肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FE': { # 👩🏽‍❤‍💋‍👨🏾
        'en' : ':kiss_woman_man_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏽‍❤️‍💋‍👨🏼
        'en' : ':kiss_woman_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_mann_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_hombre_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':bisou__femme_homme_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_男性_中間の肌色_やや薄い肌色:',
        'ko': u':키스_여자_남자_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_homem_pele_morena_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_uomo_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_مرد_پوست_طلایی_و_پوست_روشن:',
        'id': ':berciuman_wanita_pria_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人男人中等肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F468\U0001F3FC': { # 👩🏽‍❤‍💋‍👨🏼
        'en' : ':kiss_woman_man_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469': { # 👩‍❤️‍💋‍👩
        'en' : ':kiss_woman_woman:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [':couplekiss_woman_woman:'],
        'de': u':sich_küssendes_paar_frau,_frau:',
        'es': ':beso_mujer_y_mujer:',
        'fr': ':bisou_femme_et_femme:',
        'ja': u':2人でキス_女性_女性:',
        'ko': u':키스_여자_여자:',
        'pt': ':beijo_mulher_e_mulher:',
        'it': ':bacio_tra_coppia_donna_e_donna:',
        'fa': u':بوسه_زن_زن:',
        'id': ':berciuman_wanita_wanita:',
        'zh': u':亲吻_女人女人:'
    },
    u'\U0001F469\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469': { # 👩‍❤‍💋‍👩
        'en' : ':kiss_woman_woman:',
        'status' : minimally_qualified,
        'E' : 2,
        'alias' : [':couplekiss_woman_woman:']
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏿‍❤️‍💋‍👩🏿
        'en' : ':kiss_woman_woman_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_und_dunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_femme_et_peau_foncée:',
        'ja': u':2人でキス_女性_女性_濃い肌色:',
        'ko': u':키스_여자_여자_검은색_피부:',
        'pt': ':beijo_mulher_mulher_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_donna_e_carnagione_scura:',
        'fa': u':بوسه_زن_زن_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap:',
        'zh': u':亲吻_女人女人较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏿‍❤‍💋‍👩🏿
        'en' : ':kiss_woman_woman_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏿‍❤️‍💋‍👩🏻
        'en' : ':kiss_woman_woman_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_dunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_claro:',
        'fr': u':bisou__femme_femme_peau_foncée_et_peau_claire:',
        'ja': u':2人でキス_女性_女性_濃い肌色_薄い肌色:',
        'ko': u':키스_여자_여자_검은색_피부_하얀_피부:',
        'pt': ':beijo_mulher_mulher_pele_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_scura_e_carnagione_chiara:',
        'fa': u':بوسه_زن_زن_پوست_آبنوسی_و_پوست_سفید:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':亲吻_女人女人较深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏿‍❤‍💋‍👩🏻
        'en' : ':kiss_woman_woman_dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏿‍❤️‍💋‍👩🏾
        'en' : ':kiss_woman_woman_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_dunkle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__femme_femme_peau_foncée_et_peau_mate:',
        'ja': u':2人でキス_女性_女性_濃い肌色_やや濃い肌色:',
        'ko': u':키스_여자_여자_검은색_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_escura_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_زن_پوست_آبنوسی_و_پوست_گندمی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人女人较深肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏿‍❤‍💋‍👩🏾
        'en' : ':kiss_woman_woman_dark_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏿‍❤️‍💋‍👩🏼
        'en' : ':kiss_woman_woman_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_dunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_claro_medio:',
        'fr': u':bisou__femme_femme_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_女性_濃い肌色_やや薄い肌色:',
        'ko': u':키스_여자_여자_검은색_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_زن_پوست_آبنوسی_و_پوست_روشن:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人女人较深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏿‍❤‍💋‍👩🏼
        'en' : ':kiss_woman_woman_dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏿‍❤️‍💋‍👩🏽
        'en' : ':kiss_woman_woman_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_dunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_tono_de_piel_medio:',
        'fr': u':bisou__femme_femme_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_女性_濃い肌色_中間の肌色:',
        'ko': u':키스_여자_여자_검은색_피부_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_زن_پوست_آبنوسی_و_پوست_طلایی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':亲吻_女人女人较深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏿‍❤‍💋‍👩🏽
        'en' : ':kiss_woman_woman_dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏻‍❤️‍💋‍👩🏻
        'en' : ':kiss_woman_woman_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_und_helle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro:',
        'fr': ':bisou__femme_femme_et_peau_claire:',
        'ja': u':2人でキス_女性_女性_薄い肌色:',
        'ko': u':키스_여자_여자_하얀_피부:',
        'pt': ':beijo_mulher_mulher_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_donna_e_carnagione_chiara:',
        'fa': u':بوسه_زن_زن_و_پوست_سفید:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah:',
        'zh': u':亲吻_女人女人较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏻‍❤‍💋‍👩🏻
        'en' : ':kiss_woman_woman_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏻‍❤️‍💋‍👩🏿
        'en' : ':kiss_woman_woman_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_helle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_femme_peau_claire_et_peau_foncée:',
        'ja': u':2人でキス_女性_女性_薄い肌色_濃い肌色:',
        'ko': u':키스_여자_여자_하얀_피부_검은색_피부:',
        'pt': ':beijo_mulher_mulher_pele_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_chiara_e_carnagione_scura:',
        'fa': u':بوسه_زن_زن_پوست_سفید_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':亲吻_女人女人较浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏻‍❤‍💋‍👩🏿
        'en' : ':kiss_woman_woman_light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏻‍❤️‍💋‍👩🏾
        'en' : ':kiss_woman_woman_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_helle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__femme_femme_peau_claire_et_peau_mate:',
        'ja': u':2人でキス_女性_女性_薄い肌色_やや濃い肌色:',
        'ko': u':키스_여자_여자_하얀_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_زن_پوست_سفید_و_پوست_گندمی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人女人较浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏻‍❤‍💋‍👩🏾
        'en' : ':kiss_woman_woman_light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏻‍❤️‍💋‍👩🏼
        'en' : ':kiss_woman_woman_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_helle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_tono_de_piel_claro_medio:',
        'fr': ':bisou__femme_femme_peau_claire_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_女性_薄い肌色_やや薄い肌色:',
        'ko': u':키스_여자_여자_하얀_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_clara_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_زن_پوست_سفید_و_پوست_روشن:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人女人较浅肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏻‍❤‍💋‍👩🏼
        'en' : ':kiss_woman_woman_light_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏻‍❤️‍💋‍👩🏽
        'en' : ':kiss_woman_woman_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_helle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_tono_de_piel_medio:',
        'fr': u':bisou__femme_femme_peau_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_女性_薄い肌色_中間の肌色:',
        'ko': u':키스_여자_여자_하얀_피부_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_زن_پوست_سفید_و_پوست_طلایی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':亲吻_女人女人较浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏻‍❤‍💋‍👩🏽
        'en' : ':kiss_woman_woman_light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏾‍❤️‍💋‍👩🏾
        'en' : ':kiss_woman_woman_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_und_mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__femme_femme_et_peau_mate:',
        'ja': u':2人でキス_女性_女性_やや濃い肌色:',
        'ko': u':키스_여자_여자_진한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_donna_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_زن_و_پوست_گندمی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人女人中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏾‍❤‍💋‍👩🏾
        'en' : ':kiss_woman_woman_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏾‍❤️‍💋‍👩🏿
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mitteldunkle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_femme_peau_mate_et_peau_foncée:',
        'ja': u':2人でキス_女性_女性_やや濃い肌色_濃い肌色:',
        'ko': u':키스_여자_여자_진한_갈색_피부_검은색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_escura_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':بوسه_زن_زن_پوست_گندمی_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_女人女人中等深肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏾‍❤‍💋‍👩🏿
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏾‍❤️‍💋‍👩🏻
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mitteldunkle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_claro:',
        'fr': ':bisou__femme_femme_peau_mate_et_peau_claire:',
        'ja': u':2人でキス_女性_女性_やや濃い肌色_薄い肌色:',
        'ko': u':키스_여자_여자_진한_갈색_피부_하얀_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_escura_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':بوسه_زن_زن_پوست_گندمی_و_پوست_سفید:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_女人女人中等深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏾‍❤‍💋‍👩🏻
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏾‍❤️‍💋‍👩🏼
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mitteldunkle_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_claro_medio:',
        'fr': ':bisou__femme_femme_peau_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_女性_やや濃い肌色_やや薄い肌色:',
        'ko': u':키스_여자_여자_진한_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_escura_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_زن_پوست_گندمی_و_پوست_روشن:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人女人中等深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏾‍❤‍💋‍👩🏼
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏾‍❤️‍💋‍👩🏽
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mitteldunkle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_oscuro_medio_tono_de_piel_medio:',
        'fr': u':bisou__femme_femme_peau_mate_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_女性_やや濃い肌色_中間の肌色:',
        'ko': u':키스_여자_여자_진한_갈색_피부_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_escura_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_زن_پوست_گندمی_و_پوست_طلایی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_女人女人中等深肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏾‍❤‍💋‍👩🏽
        'en' : ':kiss_woman_woman_medium-dark_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏼‍❤️‍💋‍👩🏼
        'en' : ':kiss_woman_woman_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_und_mittelhelle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_medio:',
        'fr': ':bisou__femme_femme_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_女性_やや薄い肌色:',
        'ko': u':키스_여자_여자_연한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_donna_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_زن_و_پوست_روشن:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人女人中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏼‍❤‍💋‍👩🏼
        'en' : ':kiss_woman_woman_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏼‍❤️‍💋‍👩🏿
        'en' : ':kiss_woman_woman_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittelhelle_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_femme_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':2人でキス_女性_女性_やや薄い肌色_濃い肌色:',
        'ko': u':키스_여자_여자_연한_갈색_피부_검은색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_clara_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':بوسه_زن_زن_پوست_روشن_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':亲吻_女人女人中等浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏼‍❤‍💋‍👩🏿
        'en' : ':kiss_woman_woman_medium-light_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏼‍❤️‍💋‍👩🏻
        'en' : ':kiss_woman_woman_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittelhelle_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_claro:',
        'fr': ':bisou__femme_femme_peau_moyennement_claire_et_peau_claire:',
        'ja': u':2人でキス_女性_女性_やや薄い肌色_薄い肌色:',
        'ko': u':키스_여자_여자_연한_갈색_피부_하얀_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_clara_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':بوسه_زن_زن_پوست_روشن_و_پوست_سفید:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':亲吻_女人女人中等浅肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏼‍❤‍💋‍👩🏻
        'en' : ':kiss_woman_woman_medium-light_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏼‍❤️‍💋‍👩🏾
        'en' : ':kiss_woman_woman_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittelhelle_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_oscuro_medio:',
        'fr': ':bisou__femme_femme_peau_moyennement_claire_et_peau_mate:',
        'ja': u':2人でキス_女性_女性_やや薄い肌色_やや濃い肌色:',
        'ko': u':키스_여자_여자_연한_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_clara_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_زن_پوست_روشن_و_پوست_گندمی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人女人中等浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏼‍❤‍💋‍👩🏾
        'en' : ':kiss_woman_woman_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏼‍❤️‍💋‍👩🏽
        'en' : ':kiss_woman_woman_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittelhelle_hautfarbe,mittlere_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_claro_medio_tono_de_piel_medio:',
        'fr': u':bisou__femme_femme_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_女性_やや薄い肌色_中間の肌色:',
        'ko': u':키스_여자_여자_연한_갈색_피부_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_clara_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_زن_پوست_روشن_و_پوست_طلایی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':亲吻_女人女人中等浅肤色中等肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏼‍❤‍💋‍👩🏽
        'en' : ':kiss_woman_woman_medium-light_skin_tone_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏽‍❤️‍💋‍👩🏽
        'en' : ':kiss_woman_woman_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_und_mittlere_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_medio:',
        'fr': u':bisou__femme_femme_et_peau_légèrement_mate:',
        'ja': u':2人でキス_女性_女性_中間の肌色:',
        'ko': u':키스_여자_여자_갈색_피부:',
        'pt': ':beijo_mulher_mulher_e_pele_morena:',
        'it': ':bacio_tra_coppia_donna_donna_e_carnagione_olivastra:',
        'fa': u':بوسه_زن_زن_و_پوست_طلایی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_sedang:',
        'zh': u':亲吻_女人女人中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FD': { # 👩🏽‍❤‍💋‍👩🏽
        'en' : ':kiss_woman_woman_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏽‍❤️‍💋‍👩🏿
        'en' : ':kiss_woman_woman_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittlere_hautfarbe,dunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_medio_tono_de_piel_oscuro:',
        'fr': u':bisou__femme_femme_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':2人でキス_女性_女性_中間の肌色_濃い肌色:',
        'ko': u':키스_여자_여자_갈색_피부_검은색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_e_pele_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':بوسه_زن_زن_پوست_طلایی_و_پوست_آبنوسی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':亲吻_女人女人中等肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FF': { # 👩🏽‍❤‍💋‍👩🏿
        'en' : ':kiss_woman_woman_medium_skin_tone_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏽‍❤️‍💋‍👩🏻
        'en' : ':kiss_woman_woman_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittlere_hautfarbe,helle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_medio_tono_de_piel_claro:',
        'fr': u':bisou__femme_femme_peau_légèrement_mate_et_peau_claire:',
        'ja': u':2人でキス_女性_女性_中間の肌色_薄い肌色:',
        'ko': u':키스_여자_여자_갈색_피부_하얀_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_e_pele_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':بوسه_زن_زن_پوست_طلایی_و_پوست_سفید:',
        'id': ':berciuman_wanita_wanita_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':亲吻_女人女人中等肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FB': { # 👩🏽‍❤‍💋‍👩🏻
        'en' : ':kiss_woman_woman_medium_skin_tone_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏽‍❤️‍💋‍👩🏾
        'en' : ':kiss_woman_woman_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittlere_hautfarbe,mitteldunkle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_medio_tono_de_piel_oscuro_medio:',
        'fr': u':bisou__femme_femme_peau_légèrement_mate_et_peau_mate:',
        'ja': u':2人でキス_女性_女性_中間の肌色_やや濃い肌色:',
        'ko': u':키스_여자_여자_갈색_피부_진한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_e_pele_morena_escura:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':بوسه_زن_زن_پوست_طلایی_و_پوست_گندمی:',
        'id': ':berciuman_wanita_wanita_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':亲吻_女人女人中等肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FE': { # 👩🏽‍❤‍💋‍👩🏾
        'en' : ':kiss_woman_woman_medium_skin_tone_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000FE0F\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏽‍❤️‍💋‍👩🏼
        'en' : ':kiss_woman_woman_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': u':sich_küssendes_paar_frau_frau_mittlere_hautfarbe,mittelhelle_hautfarbe:',
        'es': ':beso_mujer_mujer_tono_de_piel_medio_tono_de_piel_claro_medio:',
        'fr': u':bisou__femme_femme_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':2人でキス_女性_女性_中間の肌色_やや薄い肌色:',
        'ko': u':키스_여자_여자_갈색_피부_연한_갈색_피부:',
        'pt': ':beijo_mulher_mulher_pele_morena_e_pele_morena_clara:',
        'it': ':bacio_tra_coppia_donna_donna_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':بوسه_زن_زن_پوست_طلایی_و_پوست_روشن:',
        'id': ':berciuman_wanita_wanita_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':亲吻_女人女人中等肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002764\U0000200D\U0001F48B\U0000200D\U0001F469\U0001F3FC': { # 👩🏽‍❤‍💋‍👩🏼
        'en' : ':kiss_woman_woman_medium_skin_tone_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13.1
    },
    u'\U0001F63D': { # 😽
        'en' : ':kissing_cat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':küssende_katze:',
        'es': ':gato_besando:',
        'fr': ':chat_qui_fait_un_bisou:',
        'ja': u':猫のキス:',
        'ko': u':키스하는_고양이_얼굴:',
        'pt': ':rosto_de_gato_mandando_um_beijo:',
        'it': ':gatto_che_manda_baci:',
        'fa': u':گربه_و_بوسهٔ_خجالتی:',
        'id': ':wajah_kucing_memberikan_ciuman_dengan_mata_tertutup:',
        'zh': u':亲亲猫:'
    },
    u'\U0001F617': { # 😗
        'en' : ':kissing_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':kissing:'],
        'de': u':küssendes_gesicht:',
        'es': ':cara_besando:',
        'fr': ':visage_faisant_un_bisou:',
        'ja': u':キス:',
        'ko': u':키스하는_얼굴:',
        'pt': ':rosto_beijando:',
        'it': ':faccina_che_bacia:',
        'fa': u':بوسیدن:',
        'id': ':wajah_memberikan_ciuman:',
        'zh': u':亲亲:'
    },
    u'\U0001F61A': { # 😚
        'en' : ':kissing_face_with_closed_eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':kissing_closed_eyes:'],
        'de': u':küssendes_gesicht_mit_geschlossenen_augen:',
        'es': ':cara_besando_con_los_ojos_cerrados:',
        'fr': u':visage_faisant_un_bisou_avec_les_yeux_fermés:',
        'ja': u':ちゅっ:',
        'ko': u':눈을_감은_채로_키스하는_얼굴:',
        'pt': ':rosto_beijando_com_olhos_fechados:',
        'it': ':faccina_che_bacia_con_occhi_chiusi:',
        'fa': u':بوسهٔ_خجالتی:',
        'id': ':wajah_memberikan_ciuman_dengan_mata_tertutup:',
        'zh': u':羞涩亲亲:'
    },
    u'\U0001F619': { # 😙
        'en' : ':kissing_face_with_smiling_eyes:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':kissing_smiling_eyes:'],
        'de': u':küssendes_gesicht_mit_lächelnden_augen:',
        'es': ':cara_besando_con_ojos_sonrientes:',
        'fr': ':visage_aux_yeux_rieurs_faisant_un_bisou:',
        'ja': u':にっこりキス:',
        'ko': u':미소_짓는_눈으로_키스하는_얼굴:',
        'pt': ':rosto_beijando_com_olhos_sorridentes:',
        'it': ':faccina_che_bacia_con_occhi_sorridenti:',
        'fa': u':لبخند_و_بوسه:',
        'id': ':wajah_memberikan_ciuman_dengan_mata_bahagia:',
        'zh': u':微笑亲亲:'
    },
    u'\U0001F52A': { # 🔪
        'en' : ':kitchen_knife:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hocho:', ':knife:'],
        'de': u':küchenmesser:',
        'es': ':cuchillo_de_cocina:',
        'fr': ':couteau_de_cuisine:',
        'ja': u':包丁:',
        'ko': u':식칼:',
        'pt': ':faca_de_cozinha:',
        'it': ':coltello_da_cucina:',
        'fa': u':چاقوی_آشپزخانه:',
        'id': ':pisau_dapur:',
        'zh': u':菜刀:'
    },
    u'\U0001FA81': { # 🪁
        'en' : ':kite:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':drachen:',
        'es': ':cometa:',
        'fr': ':cerf-volant:',
        'ja': u':たこ:',
        'ko': u':연:',
        'pt': ':pipa:',
        'it': ':aquilone:',
        'fa': u':بادبادک:',
        'id': ':layang-layang:',
        'zh': u':风筝:'
    },
    u'\U0001F95D': { # 🥝
        'en' : ':kiwi_fruit:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':kiwi:',
        'es': ':kiwi:',
        'fr': ':kiwi:',
        'ja': u':キウイフルーツ:',
        'ko': u':키위:',
        'pt': ':kiwi:',
        'it': ':kiwi:',
        'fa': u':کیوی:',
        'id': ':buah_kiwi:',
        'zh': u':猕猴桃:'
    },
    u'\U0001FAA2': { # 🪢
        'en' : ':knot:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':knoten:',
        'es': ':nudo:',
        'fr': u':nœud:',
        'ja': u':結び目:',
        'ko': u':매듭:',
        'pt': u':nó:',
        'it': ':nodo:',
        'fa': u':گره:',
        'id': ':simpul:',
        'zh': u':结:'
    },
    u'\U0001F428': { # 🐨
        'en' : ':koala:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':koala:',
        'es': ':koala:',
        'fr': ':koala:',
        'ja': u':コアラ:',
        'ko': u':코알라:',
        'pt': ':coala:',
        'it': ':koala:',
        'fa': u':کوآلا:',
        'id': ':koala:',
        'zh': u':考拉:'
    },
    u'\U0001F97C': { # 🥼
        'en' : ':lab_coat:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':laborkittel:',
        'es': ':bata_de_laboratorio:',
        'fr': ':blouse_blanche:',
        'ja': u':白衣:',
        'ko': u':실험실_가운:',
        'pt': ':jaleco:',
        'it': ':camice:',
        'fa': u':روپوش_آزمایشگاه:',
        'id': ':jas_laboratorium:',
        'zh': u':白大褂:'
    },
    u'\U0001F3F7\U0000FE0F': { # 🏷️
        'en' : ':label:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':etikett:',
        'es': ':etiqueta:',
        'fr': u':étiquette:',
        'ja': u':荷札:',
        'ko': u':라벨:',
        'pt': ':etiqueta:',
        'it': ':etichetta:',
        'fa': u':برچسب:',
        'id': ':label:',
        'zh': u':标签:'
    },
    u'\U0001F3F7': { # 🏷
        'en' : ':label:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':etikett:',
        'es': ':etiqueta:',
        'fr': u':étiquette:',
        'ja': u':荷札:',
        'ko': u':라벨:',
        'pt': ':etiqueta:',
        'it': ':etichetta:',
        'fa': u':برچسب:',
        'id': ':label:',
        'zh': u':标签:'
    },
    u'\U0001F94D': { # 🥍
        'en' : ':lacrosse:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':lacrosse:',
        'es': ':lacrosse:',
        'fr': ':crosse:',
        'ja': u':ラクロス:',
        'ko': u':라크로스:',
        'pt': ':lacrosse:',
        'it': ':lacrosse:',
        'fa': u':لاکراس:',
        'id': ':lacrosse:',
        'zh': u':袋棍球:'
    },
    u'\U0001FA9C': { # 🪜
        'en' : ':ladder:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':leiter:',
        'es': ':escalera:',
        'fr': u':échelle:',
        'ja': u':はしご:',
        'ko': u':사다리:',
        'pt': ':escada:',
        'it': ':scala:',
        'fa': u':نردبان:',
        'id': ':tangga:',
        'zh': u':梯子:'
    },
    u'\U0001F41E': { # 🐞
        'en' : ':lady_beetle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':beetle:'],
        'de': u':marienkäfer:',
        'es': ':mariquita:',
        'fr': ':coccinelle:',
        'ja': u':テントウムシ:',
        'ko': u':무당벌레:',
        'pt': ':joaninha:',
        'it': ':coccinella:',
        'fa': u':کفشدوزک:',
        'id': ':kumbang_betina:',
        'zh': u':瓢虫:'
    },
    u'\U0001F4BB': { # 💻
        'en' : ':laptop:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':computer:'],
        'variant': True,
        'de': ':laptop:',
        'es': u':ordenador_portátil:',
        'fr': ':ordinateur_portable:',
        'ja': u':ノートパソコン:',
        'ko': u':노트북:',
        'pt': ':laptop:',
        'it': ':computer_portatile:',
        'fa': u':رایانهٔ_کیفی:',
        'id': ':komputer_laptop:',
        'zh': u':笔记本电脑:'
    },
    u'\U0001F537': { # 🔷
        'en' : ':large_blue_diamond:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':große_blaue_raute:',
        'es': ':rombo_azul_grande:',
        'fr': ':grand_losange_bleu:',
        'ja': u':大きい青のひし形:',
        'ko': u':큰_파란색_마름모:',
        'pt': ':losango_azul_grande:',
        'it': ':rombo_blu_grande:',
        'fa': u':لوزی_آبی_بزرگ:',
        'id': ':wajik_biru_besar:',
        'zh': u':蓝色大菱形:'
    },
    u'\U0001F536': { # 🔶
        'en' : ':large_orange_diamond:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':große_orangefarbene_raute:',
        'es': ':rombo_naranja_grande:',
        'fr': ':grand_losange_orange:',
        'ja': u':大きいオレンジのひし形:',
        'ko': u':큰_주황색_마름모:',
        'pt': ':losango_laranja_grande:',
        'it': ':rombo_arancione_grande:',
        'fa': u':لوزی_نارنجی_بزرگ:',
        'id': ':wajik_oranye_besar:',
        'zh': u':橙色大菱形:'
    },
    u'\U0001F317': { # 🌗
        'en' : ':last_quarter_moon:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':abnehmender_halbmond:',
        'es': ':luna_en_cuarto_menguante:',
        'fr': ':dernier_quartier_de_lune:',
        'ja': u':下弦の月:',
        'ko': u':왼쪽_반달:',
        'pt': ':quarto_minguante:',
        'it': ':ultimo_quarto_di_luna:',
        'fa': u':یک_چهارم_پایان:',
        'id': ':bulan_perbani_akhir:',
        'zh': u':下弦月:'
    },
    u'\U0001F31C': { # 🌜
        'en' : ':last_quarter_moon_face:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':last_quarter_moon_with_face:'],
        'variant': True,
        'de': ':mondsichel_mit_gesicht_rechts:',
        'es': ':luna_de_cuarto_menguante_con_cara:',
        'fr': ':dernier_quartier_de_lune_avec_visage:',
        'ja': u':顔のある下弦の月:',
        'ko': u':그믐달:',
        'pt': ':rosto_da_lua_de_quarto_minguante:',
        'it': ':faccina_ultimo_quarto_di_luna:',
        'fa': u':صورت_یک_چهارم_آخر:',
        'id': ':wajah_bulan_perbani_akhir:',
        'zh': u':微笑的下弦月:'
    },
    u'\U000023EE\U0000FE0F': { # ⏮️
        'en' : ':last_track_button:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':previous_track_button:', ':black_left__pointing_double_triangle_with_vertical_bar:'],
        'variant': True,
        'de': ':vorheriger_titel:',
        'es': ':pista_anterior:',
        'fr': u':bouton_piste_précédente:',
        'ja': u':前の曲ボタン:',
        'ko': u':마지막_트랙_버튼:',
        'pt': u':botão_de_faixa_anterior:',
        'it': ':pulsante_traccia_precedente:',
        'fa': u':دکمه_آهنگ_قبلی:',
        'id': ':tombol_lagu_terakhir:',
        'zh': u':上一个音轨按钮:'
    },
    u'\U000023EE': { # ⏮
        'en' : ':last_track_button:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':previous_track_button:', ':black_left__pointing_double_triangle_with_vertical_bar:'],
        'variant': True,
        'de': ':vorheriger_titel:',
        'es': ':pista_anterior:',
        'fr': u':bouton_piste_précédente:',
        'ja': u':前の曲ボタン:',
        'ko': u':마지막_트랙_버튼:',
        'pt': u':botão_de_faixa_anterior:',
        'it': ':pulsante_traccia_precedente:',
        'fa': u':دکمهٔ_آهنگ_قبلی:',
        'id': ':tombol_lagu_terakhir:',
        'zh': u':上一个音轨按钮:'
    },
    u'\U0000271D\U0000FE0F': { # ✝️
        'en' : ':latin_cross:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':römisches_kreuz:',
        'es': ':cruz_latina:',
        'fr': ':croix_latine:',
        'ja': u':十字架:',
        'ko': u':라틴_십자가:',
        'pt': ':cruz_latina:',
        'it': ':croce_latina:',
        'fa': u':صلیب:',
        'id': ':salib_latin:',
        'zh': u':十字架:'
    },
    u'\U0000271D': { # ✝
        'en' : ':latin_cross:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':lateinisches_kreuz:',
        'es': ':cruz_latina:',
        'fr': ':croix_latine:',
        'ja': u':十字架:',
        'ko': u':라틴_십자가:',
        'pt': ':cruz_latina:',
        'it': ':croce_latina:',
        'fa': u':صلیب:',
        'id': ':salib_latin:',
        'zh': u':十字架:'
    },
    u'\U0001F343': { # 🍃
        'en' : ':leaf_fluttering_in_wind:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':leaves:'],
        'de': u':blätter_im_wind:',
        'es': ':hojas_revoloteando_al_viento:',
        'fr': ':feuille_virevoltante:',
        'ja': u':風に揺れる葉:',
        'ko': u':바람에_흔들리는_나뭇잎:',
        'pt': ':folha_ao_vento:',
        'it': ':foglia_al_vento:',
        'fa': u':رقص_برگ_در_باد:',
        'id': ':daun_tertiup_angin:',
        'zh': u':风吹叶落:'
    },
    u'\U0001F96C': { # 🥬
        'en' : ':leafy_green:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':blattgemüse:',
        'es': ':verdura_de_hoja_verde:',
        'fr': u':légume_à_feuilles_vertes:',
        'ja': u':葉野菜:',
        'ko': u':녹색_채소:',
        'pt': ':verdura:',
        'it': ':verdure_a_foglia:',
        'fa': u':برگ_سبز:',
        'id': ':selada_hijau:',
        'zh': u':绿叶蔬菜:'
    },
    u'\U0001F4D2': { # 📒
        'en' : ':ledger:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':spiralblock:',
        'es': ':libro_de_contabilidad:',
        'fr': ':carnet_de_compte:',
        'ja': u':リングノート:',
        'ko': u':노트:',
        'pt': u':livro_contábil:',
        'it': ':quaderno_ad_anelli:',
        'fa': u':دفتر_سیمی:',
        'id': ':buku_besar:',
        'zh': u':账本:'
    },
    u'\U0001F91B': { # 🤛
        'en' : ':left-facing_fist:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':fist_left:'],
        'de': ':faust_nach_links:',
        'es': u':puño_hacia_la_izquierda:',
        'fr': u':poing_à_gauche:',
        'ja': u':左向きのこぶし:',
        'ko': u':왼쪽을_향하는_주먹:',
        'pt': ':punho_esquerdo:',
        'it': ':pugno_a_sinistra:',
        'fa': u':مشت_به_چپ:',
        'id': ':tinju_kiri:',
        'zh': u':朝左的拳头:'
    },
    u'\U0001F91B\U0001F3FF': { # 🤛🏿
        'en' : ':left-facing_fist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_links_dunkle_hautfarbe:',
        'es': u':puño_hacia_la_izquierda_tono_de_piel_oscuro:',
        'fr': u':poing_à_gauche_peau_foncée:',
        'ja': u':左向きのこぶし_濃い肌色:',
        'ko': u':왼쪽을_향하는_주먹_검은색_피부:',
        'pt': ':punho_esquerdo_pele_escura:',
        'it': ':pugno_a_sinistra_carnagione_scura:',
        'fa': u':مشت_به_چپ_پوست_آبنوسی:',
        'id': ':tinju_kiri_warna_kulit_gelap:',
        'zh': u':朝左的拳头_较深肤色:'
    },
    u'\U0001F91B\U0001F3FB': { # 🤛🏻
        'en' : ':left-facing_fist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_links_helle_hautfarbe:',
        'es': u':puño_hacia_la_izquierda_tono_de_piel_claro:',
        'fr': u':poing_à_gauche_peau_claire:',
        'ja': u':左向きのこぶし_薄い肌色:',
        'ko': u':왼쪽을_향하는_주먹_하얀_피부:',
        'pt': ':punho_esquerdo_pele_clara:',
        'it': ':pugno_a_sinistra_carnagione_chiara:',
        'fa': u':مشت_به_چپ_پوست_سفید:',
        'id': ':tinju_kiri_warna_kulit_cerah:',
        'zh': u':朝左的拳头_较浅肤色:'
    },
    u'\U0001F91B\U0001F3FE': { # 🤛🏾
        'en' : ':left-facing_fist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_links_mitteldunkle_hautfarbe:',
        'es': u':puño_hacia_la_izquierda_tono_de_piel_oscuro_medio:',
        'fr': u':poing_à_gauche_peau_mate:',
        'ja': u':左向きのこぶし_やや濃い肌色:',
        'ko': u':왼쪽을_향하는_주먹_진한_갈색_피부:',
        'pt': ':punho_esquerdo_pele_morena_escura:',
        'it': ':pugno_a_sinistra_carnagione_abbastanza_scura:',
        'fa': u':مشت_به_چپ_پوست_گندمی:',
        'id': ':tinju_kiri_warna_kulit_gelap-sedang:',
        'zh': u':朝左的拳头_中等深肤色:'
    },
    u'\U0001F91B\U0001F3FC': { # 🤛🏼
        'en' : ':left-facing_fist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_links_mittelhelle_hautfarbe:',
        'es': u':puño_hacia_la_izquierda_tono_de_piel_claro_medio:',
        'fr': u':poing_à_gauche_peau_moyennement_claire:',
        'ja': u':左向きのこぶし_やや薄い肌色:',
        'ko': u':왼쪽을_향하는_주먹_연한_갈색_피부:',
        'pt': ':punho_esquerdo_pele_morena_clara:',
        'it': ':pugno_a_sinistra_carnagione_abbastanza_chiara:',
        'fa': u':مشت_به_چپ_پوست_روشن:',
        'id': ':tinju_kiri_warna_kulit_cerah-sedang:',
        'zh': u':朝左的拳头_中等浅肤色:'
    },
    u'\U0001F91B\U0001F3FD': { # 🤛🏽
        'en' : ':left-facing_fist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_links_mittlere_hautfarbe:',
        'es': u':puño_hacia_la_izquierda_tono_de_piel_medio:',
        'fr': u':poing_à_gauche_peau_légèrement_mate:',
        'ja': u':左向きのこぶし_中間の肌色:',
        'ko': u':왼쪽을_향하는_주먹_갈색_피부:',
        'pt': ':punho_esquerdo_pele_morena:',
        'it': ':pugno_a_sinistra_carnagione_olivastra:',
        'fa': u':مشت_به_چپ_پوست_طلایی:',
        'id': ':tinju_kiri_warna_kulit_sedang:',
        'zh': u':朝左的拳头_中等肤色:'
    },
    u'\U00002194\U0000FE0F': { # ↔️
        'en' : ':left-right_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':left_right_arrow:'],
        'variant': True,
        'de': ':pfeil_nach_links_und_rechts:',
        'es': ':flecha_izquierda_y_derecha:',
        'fr': u':flèche_gauche_droite:',
        'ja': u':左右矢印:',
        'ko': u':좌우향_화살표:',
        'pt': ':seta_para_esquerda_e_direita:',
        'it': ':freccia_sinistra-destra:',
        'fa': u':پیکان_دوطرفه:',
        'id': ':tanda_panah_kiri_kanan:',
        'zh': u':左右箭头:'
    },
    u'\U00002194': { # ↔
        'en' : ':left-right_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':left_right_arrow:'],
        'variant': True,
        'de': ':pfeil_nach_links_und_rechts:',
        'es': ':flecha_izquierda_y_derecha:',
        'fr': u':flèche_gauche_droite:',
        'ja': u':左右矢印:',
        'ko': u':좌우향_화살표:',
        'pt': ':seta_para_esquerda_e_direita:',
        'it': ':freccia_sinistra-destra:',
        'fa': u':پیکان_دوطرفه:',
        'id': ':tanda_panah_kiri_kanan:',
        'zh': u':左右箭头:'
    },
    u'\U00002B05\U0000FE0F': { # ⬅️
        'en' : ':left_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_left:'],
        'variant': True,
        'de': ':pfeil_nach_links:',
        'es': ':flecha_hacia_la_izquierda:',
        'fr': u':flèche_gauche:',
        'ja': u':左矢印:',
        'ko': u':좌향_화살표:',
        'pt': ':seta_para_a_esquerda:',
        'it': ':freccia_rivolta_a_sinistra:',
        'fa': u':پیکان_چپ:',
        'id': ':tanda_panah_kiri:',
        'zh': u':向左箭头:'
    },
    u'\U00002B05': { # ⬅
        'en' : ':left_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_left:'],
        'variant': True,
        'de': ':pfeil_nach_links:',
        'es': ':flecha_hacia_la_izquierda:',
        'fr': u':flèche_gauche:',
        'ja': u':左矢印:',
        'ko': u':좌향_화살표:',
        'pt': ':seta_para_a_esquerda:',
        'it': ':freccia_rivolta_a_sinistra:',
        'fa': u':پیکان_چپ:',
        'id': ':tanda_panah_kiri:',
        'zh': u':向左箭头:'
    },
    u'\U000021AA\U0000FE0F': { # ↪️
        'en' : ':left_arrow_curving_right:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_right_hook:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_rechts:',
        'es': u':flecha_izquierda_curvándose_a_la_derecha:',
        'fr': u':flèche_courbe_droite:',
        'ja': u':左カーブ矢印:',
        'ko': u':오른쪽으로_꺾어지는_좌향_화살표:',
        'pt': ':seta_curva_da_esquerda_para_a_direita:',
        'it': ':freccia_curva_a_destra:',
        'fa': u':پیکان_خمیده_چپ:',
        'id': ':tanda_panah_kanan_melengkung_ke_kanan:',
        'zh': u':左转弯箭头:'
    },
    u'\U000021AA': { # ↪
        'en' : ':left_arrow_curving_right:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_right_hook:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_rechts:',
        'es': u':flecha_izquierda_curvándose_a_la_derecha:',
        'fr': u':flèche_courbe_droite:',
        'ja': u':左カーブ矢印:',
        'ko': u':오른쪽으로_꺾어지는_좌향_화살표:',
        'pt': ':seta_curva_da_esquerda_para_a_direita:',
        'it': ':freccia_curva_a_destra:',
        'fa': u':پیکان_خمیده_چپ:',
        'id': ':tanda_panah_kanan_melengkung_ke_kanan:',
        'zh': u':左转弯箭头:'
    },
    u'\U0001F6C5': { # 🛅
        'en' : ':left_luggage:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':gepäckaufbewahrung:',
        'es': ':consigna:',
        'fr': ':consigne:',
        'ja': u':手荷物預かり:',
        'ko': u':화물_서비스:',
        'pt': u':depósito_de_bagagem:',
        'it': ':simbolo_del_deposito_bagagli:',
        'fa': u':امانت_بار:',
        'id': ':koper_tertinggal:',
        'zh': u':寄存行李:'
    },
    u'\U0001F5E8\U0000FE0F': { # 🗨️
        'en' : ':left_speech_bubble:',
        'status' : fully_qualified,
        'E' : 2,
        'variant': True,
        'de': ':sprechblase_links:',
        'es': u':bocadillo_de_diálogo_por_la_izquierda:',
        'fr': ':bulle_de_parole_gauche:',
        'ja': u':吹き出し左:',
        'ko': u':왼쪽_말풍선:',
        'pt': u':balão_de_diálogo_à_esquerda:',
        'it': ':nuvoletta_nera:',
        'fa': u':حباب_گفتار_چپ:',
        'id': ':gelembung_ucapan_kiri:',
        'zh': u':朝左的话语气泡:'
    },
    u'\U0001F5E8': { # 🗨
        'en' : ':left_speech_bubble:',
        'status' : unqualified,
        'E' : 2,
        'variant': True,
        'de': ':sprechblase_links:',
        'es': u':bocadillo_de_diálogo_por_la_izquierda:',
        'fr': ':bulle_de_parole_gauche:',
        'ja': u':吹き出し左:',
        'ko': u':왼쪽_말풍선:',
        'pt': u':balão_de_diálogo_à_esquerda:',
        'it': ':nuvoletta_nera:',
        'fa': u':حباب_گفتار_چپ:',
        'id': ':gelembung_ucapan_kiri:',
        'zh': u':朝左的话语气泡:'
    },
    u'\U0001FAF2': { # 🫲
        'en' : ':leftwards_hand:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':nach_links_weisende_hand:',
        'es': ':mano_hacia_la_izquierda:',
        'fr': ':main_vers_la_gauche:',
        'ja': u':左に向けた手:',
        'ko': u':왼쪽으로_향하는_손바닥:',
        'pt': u':mão_para_a_esquerda:',
        'it': ':mano_rivolta_a_sinistra:',
        'fa': u':دست_به_سمت_چپ:',
        'id': ':tangan_menghadap_kiri:',
        'zh': u':向左的手:'
    },
    u'\U0001FAF2\U0001F3FF': { # 🫲🏿
        'en' : ':leftwards_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF2\U0001F3FB': { # 🫲🏻
        'en' : ':leftwards_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF2\U0001F3FE': { # 🫲🏾
        'en' : ':leftwards_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF2\U0001F3FC': { # 🫲🏼
        'en' : ':leftwards_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF2\U0001F3FD': { # 🫲🏽
        'en' : ':leftwards_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF7': { # 🫷
        'en' : ':leftwards_pushing_hand:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':nach_links_schiebende_hand:',
        'es': ':mano_empujando_hacia_la_izquierda:',
        'fr': ':main_qui_pousse_vers_la_gauche:',
        'ja': u':左向きに押している手:',
        'ko': u':왼쪽으로_밀치는_손:',
        'pt': u':mão_empurrando_para_a_esquerda:',
        'it': ':mano_che_spinge_a_sinistra:',
        'fa': u':دست_فشاردهنده_به_سمت_چپ:',
        'id': ':tangan_mendorong_ke_kiri:',
        'zh': u':向左推:'
    },
    u'\U0001FAF7\U0001F3FF': { # 🫷🏿
        'en' : ':leftwards_pushing_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF7\U0001F3FB': { # 🫷🏻
        'en' : ':leftwards_pushing_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF7\U0001F3FE': { # 🫷🏾
        'en' : ':leftwards_pushing_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF7\U0001F3FC': { # 🫷🏼
        'en' : ':leftwards_pushing_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF7\U0001F3FD': { # 🫷🏽
        'en' : ':leftwards_pushing_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001F9B5': { # 🦵
        'en' : ':leg:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bein:',
        'es': ':pierna:',
        'fr': ':jambe:',
        'ja': u':脚:',
        'ko': u':한쪽_다리:',
        'pt': ':perna:',
        'it': ':gamba:',
        'fa': u':لنگ:',
        'id': ':tungkai:',
        'zh': u':腿:'
    },
    u'\U0001F9B5\U0001F3FF': { # 🦵🏿
        'en' : ':leg_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bein_dunkle_hautfarbe:',
        'es': ':pierna_tono_de_piel_oscuro:',
        'fr': u':jambe_peau_foncée:',
        'ja': u':脚_濃い肌色:',
        'ko': u':한쪽_다리_검은색_피부:',
        'pt': ':perna_pele_escura:',
        'it': ':gamba_carnagione_scura:',
        'fa': u':لنگ_پوست_آبنوسی:',
        'id': ':tungkai_warna_kulit_gelap:',
        'zh': u':腿_较深肤色:'
    },
    u'\U0001F9B5\U0001F3FB': { # 🦵🏻
        'en' : ':leg_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bein_helle_hautfarbe:',
        'es': ':pierna_tono_de_piel_claro:',
        'fr': ':jambe_peau_claire:',
        'ja': u':脚_薄い肌色:',
        'ko': u':한쪽_다리_하얀_피부:',
        'pt': ':perna_pele_clara:',
        'it': ':gamba_carnagione_chiara:',
        'fa': u':لنگ_پوست_سفید:',
        'id': ':tungkai_warna_kulit_cerah:',
        'zh': u':腿_较浅肤色:'
    },
    u'\U0001F9B5\U0001F3FE': { # 🦵🏾
        'en' : ':leg_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bein_mitteldunkle_hautfarbe:',
        'es': ':pierna_tono_de_piel_oscuro_medio:',
        'fr': ':jambe_peau_mate:',
        'ja': u':脚_やや濃い肌色:',
        'ko': u':한쪽_다리_진한_갈색_피부:',
        'pt': ':perna_pele_morena_escura:',
        'it': ':gamba_carnagione_abbastanza_scura:',
        'fa': u':لنگ_پوست_گندمی:',
        'id': ':tungkai_warna_kulit_gelap-sedang:',
        'zh': u':腿_中等深肤色:'
    },
    u'\U0001F9B5\U0001F3FC': { # 🦵🏼
        'en' : ':leg_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bein_mittelhelle_hautfarbe:',
        'es': ':pierna_tono_de_piel_claro_medio:',
        'fr': ':jambe_peau_moyennement_claire:',
        'ja': u':脚_やや薄い肌色:',
        'ko': u':한쪽_다리_연한_갈색_피부:',
        'pt': ':perna_pele_morena_clara:',
        'it': ':gamba_carnagione_abbastanza_chiara:',
        'fa': u':لنگ_پوست_روشن:',
        'id': ':tungkai_warna_kulit_cerah-sedang:',
        'zh': u':腿_中等浅肤色:'
    },
    u'\U0001F9B5\U0001F3FD': { # 🦵🏽
        'en' : ':leg_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bein_mittlere_hautfarbe:',
        'es': ':pierna_tono_de_piel_medio:',
        'fr': u':jambe_peau_légèrement_mate:',
        'ja': u':脚_中間の肌色:',
        'ko': u':한쪽_다리_갈색_피부:',
        'pt': ':perna_pele_morena:',
        'it': ':gamba_carnagione_olivastra:',
        'fa': u':لنگ_پوست_طلایی:',
        'id': ':tungkai_warna_kulit_sedang:',
        'zh': u':腿_中等肤色:'
    },
    u'\U0001F34B': { # 🍋
        'en' : ':lemon:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':zitrone:',
        'es': u':limón:',
        'fr': ':citron:',
        'ja': u':レモン:',
        'ko': u':레몬:',
        'pt': u':limão:',
        'it': ':limone:',
        'fa': u':لیمو_ترش:',
        'id': ':lemon:',
        'zh': u':柠檬:'
    },
    u'\U0001F406': { # 🐆
        'en' : ':leopard:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':leopard:',
        'es': ':leopardo:',
        'fr': u':léopard:',
        'ja': u':ヒョウ:',
        'ko': u':표범:',
        'pt': ':leopardo:',
        'it': ':leopardo:',
        'fa': u':پلنگ:',
        'id': ':macan_tutul:',
        'zh': u':豹子:'
    },
    u'\U0001F39A\U0000FE0F': { # 🎚️
        'en' : ':level_slider:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schieberegler:',
        'es': ':control_de_volumen:',
        'fr': ':curseur_de_niveau:',
        'ja': u':レベルスライダー:',
        'ko': u':레벨_슬라이더:',
        'pt': ':controle_de_volume:',
        'it': ':cursore_del_volume:',
        'fa': u':درجه_تنظیم_کننده:',
        'id': ':penggeser_tingkat:',
        'zh': u':电平滑块:'
    },
    u'\U0001F39A': { # 🎚
        'en' : ':level_slider:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schieberegler:',
        'es': ':control_de_volumen:',
        'fr': ':curseur_de_niveau:',
        'ja': u':レベルスライダー:',
        'ko': u':레벨_슬라이더:',
        'pt': ':controle_de_volume:',
        'it': ':cursore_del_volume:',
        'fa': u':درجهٔ_تنظیم_کننده:',
        'id': ':penggeser_tingkat:',
        'zh': u':电平滑块:'
    },
    u'\U0001FA75': { # 🩵
        'en' : ':light_blue_heart:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':hellblaues_herz:',
        'es': u':corazón_azul_claro:',
        'fr': u':cœur_bleu_clair:',
        'ja': u':薄い青のハート:',
        'ko': u':밝은_파란색_하트:',
        'pt': u':coração_azul-claro:',
        'it': ':cuore_azzurro:',
        'fa': u':قلب_آبی_کم_رنگ:',
        'id': ':hati_biru_muda:',
        'zh': u':浅蓝色的心:'
    },
    u'\U0001F4A1': { # 💡
        'en' : ':light_bulb:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bulb:'],
        'de': u':glühbirne:',
        'es': ':bombilla:',
        'fr': ':ampoule:',
        'ja': u':電球:',
        'ko': u':전구:',
        'pt': u':lâmpada:',
        'it': ':lampadina:',
        'fa': u':لامپ:',
        'id': ':bohlam:',
        'zh': u':灯泡:'
    },
    u'\U0001F688': { # 🚈
        'en' : ':light_rail:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':s-bahn:',
        'es': ':tren_ligero:',
        'fr': u':métro_léger:',
        'ja': u':ライトレール:',
        'ko': u':경전철:',
        'pt': ':trem_urbano:',
        'it': ':metrotranvia:',
        'fa': u':قطار_سبک_شهری:',
        'id': ':light_rail:',
        'zh': u':轻轨:'
    },
    u'\U0001F3FB': { # 🏻
        'en' : ':light_skin_tone:',
        'status' : component,
        'E' : 1,
        'alias' : [':emoji_modifier_fitzpatrick_type__1__2:'],
        'de': ':helle_hautfarbe:',
        'es': ':tono_de_piel_claro:',
        'fr': ':peau_claire:',
        'ja': u':薄い肌色:',
        'ko': u':하얀_피부:',
        'pt': ':pele_clara:',
        'it': ':carnagione_chiara:',
        'fa': u':پوست_سفید:',
        'id': ':warna_kulit_cerah:',
        'zh': u':较浅肤色:'
    },
    u'\U0001F517': { # 🔗
        'en' : ':link:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':linksymbol:',
        'es': u':eslabón:',
        'fr': u':chaînons:',
        'ja': u':リンクシンボル:',
        'ko': u':링크:',
        'pt': ':link:',
        'it': ':collegamento:',
        'fa': u':حلقهٔ_زنجیر:',
        'id': ':tautan:',
        'zh': u':链接:'
    },
    u'\U0001F587\U0000FE0F': { # 🖇️
        'en' : ':linked_paperclips:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':paperclips:'],
        'variant': True,
        'de': u':verhakte_büroklammern:',
        'es': ':clips_unidos:',
        'fr': ':trombones:',
        'ja': u':つながったクリップ:',
        'ko': u':이어져_있는_클립:',
        'pt': ':clipes_de_papel_conectados:',
        'it': ':graffette_attaccate:',
        'fa': u':زنجیره_گیره:',
        'id': ':klip_kertas_tertaut:',
        'zh': u':连起来的两个回形针:'
    },
    u'\U0001F587': { # 🖇
        'en' : ':linked_paperclips:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':paperclips:'],
        'variant': True,
        'de': u':verhakte_büroklammern:',
        'es': ':clips_unidos:',
        'fr': ':trombones:',
        'ja': u':つながったクリップ:',
        'ko': u':이어져_있는_클립:',
        'pt': ':clipes_de_papel_conectados:',
        'it': ':graffette_attaccate:',
        'fa': u':زنجیرهٔ_گیره:',
        'id': ':klip_kertas_tertaut:',
        'zh': u':连起来的两个回形针:'
    },
    u'\U0001F981': { # 🦁
        'en' : ':lion:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':lion_face:'],
        'de': u':löwe:',
        'es': u':león:',
        'fr': u':tête_de_lion:',
        'ja': u':ライオンの顔:',
        'ko': u':사자_얼굴:',
        'pt': u':rosto_de_leão:',
        'it': ':leone:',
        'fa': u':شیر:',
        'id': ':singa:',
        'zh': u':狮子:'
    },
    u'\U0001F484': { # 💄
        'en' : ':lipstick:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':lippenstift:',
        'es': ':pintalabios:',
        'fr': u':rouge_à_lèvres:',
        'ja': u':口紅:',
        'ko': u':립스틱:',
        'pt': ':batom:',
        'it': ':rossetto:',
        'fa': u':رژلب:',
        'id': ':lipstik:',
        'zh': u':唇膏:'
    },
    u'\U0001F6AE': { # 🚮
        'en' : ':litter_in_bin_sign:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':put_litter_in_its_place:'],
        'de': ':symbol_papierkorb:',
        'es': u':señal_de_usar_papelera:',
        'fr': u':icône_poubelle:',
        'ja': u':ゴミ箱:',
        'ko': u':쓰레기는_쓰레기통에:',
        'pt': u':símbolo_de_lixeira:',
        'it': ':simbolo_per_la_raccolta_dei_rifiuti:',
        'fa': u':علامت_ریختن_زباله_در_زباله_دان:',
        'id': ':tanda_membuang_sampah:',
        'zh': u':倒垃圾:'
    },
    u'\U0001F98E': { # 🦎
        'en' : ':lizard:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':eidechse:',
        'es': ':lagarto:',
        'fr': u':lézard:',
        'ja': u':トカゲ:',
        'ko': u':도마뱀:',
        'pt': ':lagartixa:',
        'it': ':lucertola:',
        'fa': u':مارمولک:',
        'id': ':kadal:',
        'zh': u':蜥蜴:'
    },
    u'\U0001F999': { # 🦙
        'en' : ':llama:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':lama:',
        'es': ':llama:',
        'fr': ':lama:',
        'ja': u':ラマ:',
        'ko': u':라마:',
        'pt': ':lhama:',
        'it': ':lama:',
        'fa': u':لاما:',
        'id': ':llama:',
        'zh': u':美洲鸵:'
    },
    u'\U0001F99E': { # 🦞
        'en' : ':lobster:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':hummer:',
        'es': ':bogavante:',
        'fr': ':homard:',
        'ja': u':ザリガニ:',
        'ko': u':바닷가재:',
        'pt': ':lagosta:',
        'it': ':aragosta:',
        'fa': u':لابستر:',
        'id': ':lobster:',
        'zh': u':龙虾:'
    },
    u'\U0001F512': { # 🔒
        'en' : ':locked:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':lock:'],
        'variant': True,
        'de': ':geschlossenes_schloss:',
        'es': ':candado_cerrado:',
        'fr': u':cadenas_fermé:',
        'ja': u':閉じた錠:',
        'ko': u':자물쇠:',
        'pt': ':cadeado:',
        'it': ':lucchetto_chiuso:',
        'fa': u':قفل:',
        'id': ':gembok:',
        'zh': u':合上的锁:'
    },
    u'\U0001F510': { # 🔐
        'en' : ':locked_with_key:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':closed_lock_with_key:'],
        'de': u':schloss_mit_schlüssel:',
        'es': ':candado_cerrado_y_llave:',
        'fr': u':cadenas_fermé_avec_clé:',
        'ja': u':閉じた錠と鍵:',
        'ko': u':자물쇠와_열쇠:',
        'pt': ':cadeado_fechado_com_chave:',
        'it': ':lucchetto_chiuso_con_chiave:',
        'fa': u':قفل_و_کلید:',
        'id': ':gembok_terkunci_dengan_kunci:',
        'zh': u':钥匙和锁:'
    },
    u'\U0001F50F': { # 🔏
        'en' : ':locked_with_pen:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':lock_with_ink_pen:'],
        'de': u':schloss_mit_füller:',
        'es': u':candado_con_pluma_estilográfica:',
        'fr': u':cadenas_fermé_avec_stylo:',
        'ja': u':閉じた錠とペン:',
        'ko': u':자물쇠와_펜:',
        'pt': ':cadeado_com_caneta:',
        'it': ':lucchetto_con_penna_stilo:',
        'fa': u':قفل_با_قلم:',
        'id': ':gembok_terkunci_dengan_pena:',
        'zh': u':墨水笔和锁:'
    },
    u'\U0001F682': { # 🚂
        'en' : ':locomotive:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':steam_locomotive:'],
        'de': ':dampflokomotive:',
        'es': ':locomotora_de_vapor:',
        'fr': ':locomotive:',
        'ja': u':蒸気機関車:',
        'ko': u':기관차:',
        'pt': ':locomotiva:',
        'it': ':locomotiva:',
        'fa': u':لوکوموتیو:',
        'id': ':lokomotif:',
        'zh': u':蒸汽火车:'
    },
    u'\U0001F36D': { # 🍭
        'en' : ':lollipop:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':lutscher:',
        'es': ':piruleta:',
        'fr': ':sucette:',
        'ja': u':ぺろぺろキャンディ:',
        'ko': u':롤리팝:',
        'pt': ':pirulito:',
        'it': ':lecca_lecca:',
        'fa': u':آب_نبات_چوبی:',
        'id': ':permen_lolipop:',
        'zh': u':棒棒糖:'
    },
    u'\U0001FA98': { # 🪘
        'en' : ':long_drum:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':afrikanische_trommel:',
        'es': ':tamboril:',
        'fr': u':djembé:',
        'ja': u':コンガ:',
        'ko': u':긴_북:',
        'pt': ':tambor_comprido:',
        'it': ':tamburo_lungo:',
        'fa': u':طبل_بلند:',
        'id': ':gendang:',
        'zh': u':长鼓:'
    },
    u'\U0001F9F4': { # 🧴
        'en' : ':lotion_bottle:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':creme:',
        'es': ':bote_de_crema:',
        'fr': ':bouteille_de_lotion:',
        'ja': u':ローション:',
        'ko': u':로션:',
        'pt': u':frasco_de_loção:',
        'it': ':flacone:',
        'fa': u':بطری_لوسیون:',
        'id': ':botol_losion:',
        'zh': u':乳液瓶:'
    },
    u'\U0001FAB7': { # 🪷
        'en' : ':lotus:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':lotusblüte:',
        'es': ':loto:',
        'fr': ':lotus:',
        'ja': u':ハスの花:',
        'ko': u':연꽃:',
        'pt': u':lótus:',
        'it': ':loto:',
        'fa': u':نیلوفر:',
        'id': ':teratai:',
        'zh': u':莲花:'
    },
    u'\U0001F62D': { # 😭
        'en' : ':loudly_crying_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sob:'],
        'de': ':heulendes_gesicht:',
        'es': ':cara_llorando_fuerte:',
        'fr': u':visage_qui_pleure_à_chaudes_larmes:',
        'ja': u':大泣き:',
        'ko': u':엉엉_우는_얼굴:',
        'pt': ':rosto_chorando_aos_berros:',
        'it': ':faccina_disperata:',
        'fa': u':هق_هق_گریه:',
        'id': ':wajah_menangis_keras:',
        'zh': u':放声大哭:'
    },
    u'\U0001F4E2': { # 📢
        'en' : ':loudspeaker:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':lautsprecher:',
        'es': ':altavoz_de_mano:',
        'fr': ':haut-parleur:',
        'ja': u':拡声器:',
        'ko': u':확성기:',
        'pt': ':buzina:',
        'it': ':altoparlante:',
        'fa': u':بلندگو:',
        'id': ':pengeras_suara:',
        'zh': u':喇叭:'
    },
    u'\U0001F91F': { # 🤟
        'en' : ':love-you_gesture:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':love_you_gesture:'],
        'de': ':ich-liebe-dich-geste:',
        'es': ':gesto_de_te_quiero:',
        'fr': u':signe_je_t’aime:',
        'ja': u':アイラブユー:',
        'ko': u':사랑을_표시하는_손:',
        'pt': ':gesto_de_te_amo:',
        'it': ':gesto_ti_amo:',
        'fa': u':علامت_دوستت_دارم:',
        'id': ':gerakan_sayang_kamu:',
        'zh': u':爱你的手势:'
    },
    u'\U0001F91F\U0001F3FF': { # 🤟🏿
        'en' : ':love-you_gesture_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':ich-liebe-dich-geste_dunkle_hautfarbe:',
        'es': ':gesto_de_te_quiero_tono_de_piel_oscuro:',
        'fr': u':signe_je_t’aime_peau_foncée:',
        'ja': u':アイラブユー_濃い肌色:',
        'ko': u':사랑을_표시하는_손_검은색_피부:',
        'pt': ':gesto_de_te_amo_pele_escura:',
        'it': ':gesto_ti_amo_carnagione_scura:',
        'fa': u':علامت_دوستت_دارم_پوست_آبنوسی:',
        'id': ':gerakan_sayang_kamu_warna_kulit_gelap:',
        'zh': u':爱你的手势_较深肤色:'
    },
    u'\U0001F91F\U0001F3FB': { # 🤟🏻
        'en' : ':love-you_gesture_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':ich-liebe-dich-geste_helle_hautfarbe:',
        'es': ':gesto_de_te_quiero_tono_de_piel_claro:',
        'fr': u':signe_je_t’aime_peau_claire:',
        'ja': u':アイラブユー_薄い肌色:',
        'ko': u':사랑을_표시하는_손_하얀_피부:',
        'pt': ':gesto_de_te_amo_pele_clara:',
        'it': ':gesto_ti_amo_carnagione_chiara:',
        'fa': u':علامت_دوستت_دارم_پوست_سفید:',
        'id': ':gerakan_sayang_kamu_warna_kulit_cerah:',
        'zh': u':爱你的手势_较浅肤色:'
    },
    u'\U0001F91F\U0001F3FE': { # 🤟🏾
        'en' : ':love-you_gesture_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':ich-liebe-dich-geste_mitteldunkle_hautfarbe:',
        'es': ':gesto_de_te_quiero_tono_de_piel_oscuro_medio:',
        'fr': u':signe_je_t’aime_peau_mate:',
        'ja': u':アイラブユー_やや濃い肌色:',
        'ko': u':사랑을_표시하는_손_진한_갈색_피부:',
        'pt': ':gesto_de_te_amo_pele_morena_escura:',
        'it': ':gesto_ti_amo_carnagione_abbastanza_scura:',
        'fa': u':علامت_دوستت_دارم_پوست_گندمی:',
        'id': ':gerakan_sayang_kamu_warna_kulit_gelap-sedang:',
        'zh': u':爱你的手势_中等深肤色:'
    },
    u'\U0001F91F\U0001F3FC': { # 🤟🏼
        'en' : ':love-you_gesture_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':ich-liebe-dich-geste_mittelhelle_hautfarbe:',
        'es': ':gesto_de_te_quiero_tono_de_piel_claro_medio:',
        'fr': u':signe_je_t’aime_peau_moyennement_claire:',
        'ja': u':アイラブユー_やや薄い肌色:',
        'ko': u':사랑을_표시하는_손_연한_갈색_피부:',
        'pt': ':gesto_de_te_amo_pele_morena_clara:',
        'it': ':gesto_ti_amo_carnagione_abbastanza_chiara:',
        'fa': u':علامت_دوستت_دارم_پوست_روشن:',
        'id': ':gerakan_sayang_kamu_warna_kulit_cerah-sedang:',
        'zh': u':爱你的手势_中等浅肤色:'
    },
    u'\U0001F91F\U0001F3FD': { # 🤟🏽
        'en' : ':love-you_gesture_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':ich-liebe-dich-geste_mittlere_hautfarbe:',
        'es': ':gesto_de_te_quiero_tono_de_piel_medio:',
        'fr': u':signe_je_t’aime_peau_légèrement_mate:',
        'ja': u':アイラブユー_中間の肌色:',
        'ko': u':사랑을_표시하는_손_갈색_피부:',
        'pt': ':gesto_de_te_amo_pele_morena:',
        'it': ':gesto_ti_amo_carnagione_olivastra:',
        'fa': u':علامت_دوستت_دارم_پوست_طلایی:',
        'id': ':gerakan_sayang_kamu_warna_kulit_sedang:',
        'zh': u':爱你的手势_中等肤色:'
    },
    u'\U0001F3E9': { # 🏩
        'en' : ':love_hotel:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':stundenhotel:',
        'es': ':hotel_del_amor:',
        'fr': ':love_hotel:',
        'ja': u':ラブホテル:',
        'ko': u':모텔:',
        'pt': ':motel:',
        'it': ':love_hotel:',
        'fa': u':هتل_عشق_ورزی:',
        'id': ':hotel_cinta:',
        'zh': u':情人酒店:'
    },
    u'\U0001F48C': { # 💌
        'en' : ':love_letter:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':liebesbrief:',
        'es': ':carta_de_amor:',
        'fr': u':lettre_d’amour:',
        'ja': u':ラブレター:',
        'ko': u':러브레터:',
        'pt': ':carta_de_amor:',
        'it': u':lettera_d’amore:',
        'fa': u':نامهٔ_عاشقانه:',
        'id': ':surat_cinta:',
        'zh': u':情书:'
    },
    u'\U0001FAAB': { # 🪫
        'en' : ':low_battery:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':schwache_batterie:',
        'es': u':batería_baja:',
        'fr': ':pile_faible:',
        'ja': u':バッテリー残量低下:',
        'ko': u':배터리_부족:',
        'pt': ':pouca_bateria:',
        'it': ':batteria_scarica:',
        'fa': u':باتری_ضعیف:',
        'id': ':baterai_lemah:',
        'zh': u':电池电量不足:'
    },
    u'\U0001F9F3': { # 🧳
        'en' : ':luggage:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':gepäck:',
        'es': ':equipaje:',
        'fr': ':bagage:',
        'ja': u':スーツケース:',
        'ko': u':여행용_가방:',
        'pt': ':mala:',
        'it': ':valigia:',
        'fa': u':چمدان:',
        'id': ':koper:',
        'zh': u':行李箱:'
    },
    u'\U0001FAC1': { # 🫁
        'en' : ':lungs:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':lunge:',
        'es': ':pulmones:',
        'fr': ':poumons:',
        'ja': u':肺:',
        'ko': u':폐:',
        'pt': u':pulmões:',
        'it': ':polmoni:',
        'fa': u':ریه:',
        'id': ':paru-paru:',
        'zh': u':肺:'
    },
    u'\U0001F925': { # 🤥
        'en' : ':lying_face:',
        'status' : fully_qualified,
        'E' : 3,
        'de': u':lügendes_gesicht:',
        'es': ':cara_de_mentiroso:',
        'fr': ':visage_de_menteur:',
        'ja': u':うそつきの顔:',
        'ko': u':거짓말하는_얼굴:',
        'pt': ':rosto_de_mentiroso:',
        'it': ':faccina_bugiarda:',
        'fa': u':صورت_دروغگو:',
        'id': ':bohong:',
        'zh': u':说谎:'
    },
    u'\U0001F9D9': { # 🧙
        'en' : ':mage:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier(in):',
        'es': ':persona_maga:',
        'fr': ':mage:',
        'ja': u':魔法使い:',
        'ko': u':마법사:',
        'pt': ':mago:',
        'it': ':mago:',
        'fa': u':ساحر:',
        'id': ':magi:',
        'zh': u':法师:'
    },
    u'\U0001F9D9\U0001F3FF': { # 🧙🏿
        'en' : ':mage_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier(in)_dunkle_hautfarbe:',
        'es': ':persona_maga_tono_de_piel_oscuro:',
        'fr': u':mage_peau_foncée:',
        'ja': u':魔法使い_濃い肌色:',
        'ko': u':마법사_검은색_피부:',
        'pt': ':mago_pele_escura:',
        'it': ':mago_carnagione_scura:',
        'fa': u':ساحر_پوست_آبنوسی:',
        'id': ':magi_warna_kulit_gelap:',
        'zh': u':法师_较深肤色:'
    },
    u'\U0001F9D9\U0001F3FB': { # 🧙🏻
        'en' : ':mage_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier(in)_helle_hautfarbe:',
        'es': ':persona_maga_tono_de_piel_claro:',
        'fr': ':mage_peau_claire:',
        'ja': u':魔法使い_薄い肌色:',
        'ko': u':마법사_하얀_피부:',
        'pt': ':mago_pele_clara:',
        'it': ':mago_carnagione_chiara:',
        'fa': u':ساحر_پوست_سفید:',
        'id': ':magi_warna_kulit_cerah:',
        'zh': u':法师_较浅肤色:'
    },
    u'\U0001F9D9\U0001F3FE': { # 🧙🏾
        'en' : ':mage_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_maga_tono_de_piel_oscuro_medio:',
        'fr': ':mage_peau_mate:',
        'ja': u':魔法使い_やや濃い肌色:',
        'ko': u':마법사_진한_갈색_피부:',
        'pt': ':mago_pele_morena_escura:',
        'it': ':mago_carnagione_abbastanza_scura:',
        'fa': u':ساحر_پوست_گندمی:',
        'id': ':magi_warna_kulit_gelap-sedang:',
        'zh': u':法师_中等深肤色:'
    },
    u'\U0001F9D9\U0001F3FC': { # 🧙🏼
        'en' : ':mage_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier(in)_mittelhelle_hautfarbe:',
        'es': ':persona_maga_tono_de_piel_claro_medio:',
        'fr': ':mage_peau_moyennement_claire:',
        'ja': u':魔法使い_やや薄い肌色:',
        'ko': u':마법사_연한_갈색_피부:',
        'pt': ':mago_pele_morena_clara:',
        'it': ':mago_carnagione_abbastanza_chiara:',
        'fa': u':ساحر_پوست_روشن:',
        'id': ':magi_warna_kulit_cerah-sedang:',
        'zh': u':法师_中等浅肤色:'
    },
    u'\U0001F9D9\U0001F3FD': { # 🧙🏽
        'en' : ':mage_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier(in)_mittlere_hautfarbe:',
        'es': ':persona_maga_tono_de_piel_medio:',
        'fr': u':mage_peau_légèrement_mate:',
        'ja': u':魔法使い_中間の肌色:',
        'ko': u':마법사_갈색_피부:',
        'pt': ':mago_pele_morena:',
        'it': ':mago_carnagione_olivastra:',
        'fa': u':ساحر_پوست_طلایی:',
        'id': ':magi_warna_kulit_sedang:',
        'zh': u':法师_中等肤色:'
    },
    u'\U0001FA84': { # 🪄
        'en' : ':magic_wand:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':zauberstab:',
        'es': u':varita_mágica:',
        'fr': ':baguette_magique:',
        'ja': u':魔法の杖:',
        'ko': u':마술_지팡이:',
        'pt': u':varinha_mágica:',
        'it': ':bacchetta_magica:',
        'fa': u':عصای_سحرآمیز:',
        'id': ':tongkat_ajaib:',
        'zh': u':魔棒:'
    },
    u'\U0001F9F2': { # 🧲
        'en' : ':magnet:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':magnet:',
        'es': u':imán:',
        'fr': ':aimant:',
        'ja': u':u字型磁石:',
        'ko': u':자석:',
        'pt': u':ímã:',
        'it': ':calamita:',
        'fa': u':آهن_ربا:',
        'id': ':magnet:',
        'zh': u':磁铁:'
    },
    u'\U0001F50D': { # 🔍
        'en' : ':magnifying_glass_tilted_left:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mag:'],
        'variant': True,
        'de': ':lupe_nach_links:',
        'es': ':lupa_orientada_hacia_la_izquierda:',
        'fr': u':loupe_orientée_à_gauche:',
        'ja': u':虫眼鏡左:',
        'ko': u':왼쪽으로_향한_돋보기:',
        'pt': ':lupa_para_a_esquerda:',
        'it': ':lente_di_ingrandimento_rivolta_a_sinistra:',
        'fa': u':ذره_بین_روبه_چپ:',
        'id': ':kaca_pembesar_arah_kiri:',
        'zh': u':左斜的放大镜:'
    },
    u'\U0001F50E': { # 🔎
        'en' : ':magnifying_glass_tilted_right:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mag_right:'],
        'de': ':lupe_nach_rechts:',
        'es': ':lupa_orientada_hacia_la_derecha:',
        'fr': u':loupe_orientée_à_droite:',
        'ja': u':虫眼鏡右:',
        'ko': u':오른쪽으로_향한_돋보기:',
        'pt': ':lupa_para_a_direita:',
        'it': ':lente_di_ingrandimento_rivolta_a_destra:',
        'fa': u':ذره_بین_روبه_راست:',
        'id': ':kaca_pembesar_arah_kanan:',
        'zh': u':右斜的放大镜:'
    },
    u'\U0001F004': { # 🀄
        'en' : ':mahjong_red_dragon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mahjong:'],
        'variant': True,
        'de': ':mahjong-stein:',
        'es': u':dragón_rojo_de_mahjong:',
        'fr': ':dragon_rouge_mahjong:',
        'ja': u':麻雀:',
        'ko': u':마작:',
        'pt': u':dragão_vermelho_de_mahjong:',
        'it': ':tessera_mahjong:',
        'fa': u':ماژونگ_اژدهای_قرمز:',
        'id': ':naga_merah_mahyong:',
        'zh': u':红中:'
    },
    u'\U00002642\U0000FE0F': { # ♂️
        'en' : ':male_sign:',
        'status' : fully_qualified,
        'E' : 4,
        'variant': True,
        'de': u':männersymbol:',
        'es': ':signo_masculino:',
        'fr': u':symbole_de_l’homme:',
        'ja': u':男性のマーク:',
        'ko': u':남성_기호:',
        'pt': u':símbolo_de_masculino:',
        'it': ':simbolo_genere_maschile:',
        'fa': u':نشان_مریخ:',
        'id': ':simbol_pria:',
        'zh': u':男性符号:'
    },
    u'\U00002642': { # ♂
        'en' : ':male_sign:',
        'status' : unqualified,
        'E' : 4,
        'variant': True,
        'de': u':männersymbol:',
        'es': ':signo_masculino:',
        'fr': u':symbole_de_l’homme:',
        'ja': u':男性のマーク:',
        'ko': u':남성_기호:',
        'pt': u':símbolo_de_masculino:',
        'it': ':simbolo_genere_maschile:',
        'fa': u':نشان_مریخ:',
        'id': ':simbol_pria:',
        'zh': u':男性符号:'
    },
    u'\U0001F9A3': { # 🦣
        'en' : ':mammoth:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mammut:',
        'es': ':mamut:',
        'fr': ':mammouth:',
        'ja': u':マンモス:',
        'ko': u':매머드:',
        'pt': ':mamute:',
        'it': ':mammut:',
        'fa': u':ماموت:',
        'id': ':mamut:',
        'zh': u':猛犸:'
    },
    u'\U0001F468': { # 👨
        'en' : ':man:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':mann:',
        'es': ':hombre:',
        'fr': ':homme:',
        'ja': u':男性:',
        'ko': u':남자:',
        'pt': ':homem:',
        'it': ':uomo:',
        'fa': u':مرد:',
        'id': ':pria:',
        'zh': u':男人:'
    },
    u'\U0001F468\U0000200D\U0001F3A8': { # 👨‍🎨
        'en' : ':man_artist:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstler:',
        'es': ':artista_hombre:',
        'fr': ':artiste_homme:',
        'ja': u':男性の芸術家:',
        'ko': u':남자_화가:',
        'pt': u':artista_plástico:',
        'it': ':artista_uomo:',
        'fa': u':هنرمند_مرد:',
        'id': ':seniman_pria:',
        'zh': u':男艺术家:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F3A8': { # 👨🏿‍🎨
        'en' : ':man_artist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstler_dunkle_hautfarbe:',
        'es': ':artista_hombre_tono_de_piel_oscuro:',
        'fr': u':artiste_homme_peau_foncée:',
        'ja': u':男性の芸術家_濃い肌色:',
        'ko': u':남자_화가_검은색_피부:',
        'pt': u':artista_plástico_pele_escura:',
        'it': ':artista_uomo_carnagione_scura:',
        'fa': u':هنرمند_مرد_پوست_آبنوسی:',
        'id': ':seniman_pria_warna_kulit_gelap:',
        'zh': u':男艺术家_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F3A8': { # 👨🏻‍🎨
        'en' : ':man_artist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstler_helle_hautfarbe:',
        'es': ':artista_hombre_tono_de_piel_claro:',
        'fr': ':artiste_homme_peau_claire:',
        'ja': u':男性の芸術家_薄い肌色:',
        'ko': u':남자_화가_하얀_피부:',
        'pt': u':artista_plástico_pele_clara:',
        'it': ':artista_uomo_carnagione_chiara:',
        'fa': u':هنرمند_مرد_پوست_سفید:',
        'id': ':seniman_pria_warna_kulit_cerah:',
        'zh': u':男艺术家_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F3A8': { # 👨🏾‍🎨
        'en' : ':man_artist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstler_mitteldunkle_hautfarbe:',
        'es': ':artista_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':artiste_homme_peau_mate:',
        'ja': u':男性の芸術家_やや濃い肌色:',
        'ko': u':남자_화가_진한_갈색_피부:',
        'pt': u':artista_plástico_pele_morena_escura:',
        'it': ':artista_uomo_carnagione_abbastanza_scura:',
        'fa': u':هنرمند_مرد_پوست_گندمی:',
        'id': ':seniman_pria_warna_kulit_gelap-sedang:',
        'zh': u':男艺术家_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F3A8': { # 👨🏼‍🎨
        'en' : ':man_artist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstler_mittelhelle_hautfarbe:',
        'es': ':artista_hombre_tono_de_piel_claro_medio:',
        'fr': ':artiste_homme_peau_moyennement_claire:',
        'ja': u':男性の芸術家_やや薄い肌色:',
        'ko': u':남자_화가_연한_갈색_피부:',
        'pt': u':artista_plástico_pele_morena_clara:',
        'it': ':artista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':هنرمند_مرد_پوست_روشن:',
        'id': ':seniman_pria_warna_kulit_cerah-sedang:',
        'zh': u':男艺术家_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F3A8': { # 👨🏽‍🎨
        'en' : ':man_artist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstler_mittlere_hautfarbe:',
        'es': ':artista_hombre_tono_de_piel_medio:',
        'fr': u':artiste_homme_peau_légèrement_mate:',
        'ja': u':男性の芸術家_中間の肌色:',
        'ko': u':남자_화가_갈색_피부:',
        'pt': u':artista_plástico_pele_morena:',
        'it': ':artista_uomo_carnagione_olivastra:',
        'fa': u':هنرمند_مرد_پوست_طلایی:',
        'id': ':seniman_pria_warna_kulit_sedang:',
        'zh': u':男艺术家_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F680': { # 👨‍🚀
        'en' : ':man_astronaut:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronaut:',
        'es': ':astronauta_hombre:',
        'fr': ':astronaute_homme:',
        'ja': u':男性宇宙飛行士:',
        'ko': u':남자_우주비행사:',
        'pt': ':astronauta_homem:',
        'it': ':astronauta_uomo:',
        'fa': u':فضانورد_مرد:',
        'id': ':antariksawan_pria:',
        'zh': u':男宇航员:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F680': { # 👨🏿‍🚀
        'en' : ':man_astronaut_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronaut_dunkle_hautfarbe:',
        'es': ':astronauta_hombre_tono_de_piel_oscuro:',
        'fr': u':astronaute_homme_peau_foncée:',
        'ja': u':男性宇宙飛行士_濃い肌色:',
        'ko': u':남자_우주비행사_검은색_피부:',
        'pt': ':astronauta_homem_pele_escura:',
        'it': ':astronauta_uomo_carnagione_scura:',
        'fa': u':فضانورد_مرد_پوست_آبنوسی:',
        'id': ':antariksawan_pria_warna_kulit_gelap:',
        'zh': u':男宇航员_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F680': { # 👨🏻‍🚀
        'en' : ':man_astronaut_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronaut_helle_hautfarbe:',
        'es': ':astronauta_hombre_tono_de_piel_claro:',
        'fr': ':astronaute_homme_peau_claire:',
        'ja': u':男性宇宙飛行士_薄い肌色:',
        'ko': u':남자_우주비행사_하얀_피부:',
        'pt': ':astronauta_homem_pele_clara:',
        'it': ':astronauta_uomo_carnagione_chiara:',
        'fa': u':فضانورد_مرد_پوست_سفید:',
        'id': ':antariksawan_pria_warna_kulit_cerah:',
        'zh': u':男宇航员_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F680': { # 👨🏾‍🚀
        'en' : ':man_astronaut_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronaut_mitteldunkle_hautfarbe:',
        'es': ':astronauta_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':astronaute_homme_peau_mate:',
        'ja': u':男性宇宙飛行士_やや濃い肌色:',
        'ko': u':남자_우주비행사_진한_갈색_피부:',
        'pt': ':astronauta_homem_pele_morena_escura:',
        'it': ':astronauta_uomo_carnagione_abbastanza_scura:',
        'fa': u':فضانورد_مرد_پوست_گندمی:',
        'id': ':antariksawan_pria_warna_kulit_gelap-sedang:',
        'zh': u':男宇航员_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F680': { # 👨🏼‍🚀
        'en' : ':man_astronaut_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronaut_mittelhelle_hautfarbe:',
        'es': ':astronauta_hombre_tono_de_piel_claro_medio:',
        'fr': ':astronaute_homme_peau_moyennement_claire:',
        'ja': u':男性宇宙飛行士_やや薄い肌色:',
        'ko': u':남자_우주비행사_연한_갈색_피부:',
        'pt': ':astronauta_homem_pele_morena_clara:',
        'it': ':astronauta_uomo_carnagione_abbastanza_chiara:',
        'fa': u':فضانورد_مرد_پوست_روشن:',
        'id': ':antariksawan_pria_warna_kulit_cerah-sedang:',
        'zh': u':男宇航员_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F680': { # 👨🏽‍🚀
        'en' : ':man_astronaut_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronaut_mittlere_hautfarbe:',
        'es': ':astronauta_hombre_tono_de_piel_medio:',
        'fr': u':astronaute_homme_peau_légèrement_mate:',
        'ja': u':男性宇宙飛行士_中間の肌色:',
        'ko': u':남자_우주비행사_갈색_피부:',
        'pt': ':astronauta_homem_pele_morena:',
        'it': ':astronauta_uomo_carnagione_olivastra:',
        'fa': u':فضانورد_مرد_پوست_طلایی:',
        'id': ':antariksawan_pria_warna_kulit_sedang:',
        'zh': u':男宇航员_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F9B2': { # 👨‍🦲
        'en' : ':man_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':bald_man:'],
        'de': ':mann_glatze:',
        'es': ':hombre_sin_pelo:',
        'fr': ':homme_chauve:',
        'ja': u':男性_はげ頭:',
        'ko': u':남자_대머리:',
        'pt': ':homem_careca:',
        'it': ':uomo_calvo:',
        'fa': u':مرد_تاس:',
        'id': ':pria_gundul:',
        'zh': u':男人_秃顶:'
    },
    u'\U0001F9D4\U0000200D\U00002642\U0000FE0F': { # 🧔‍♂️
        'en' : ':man_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':mann_bart:',
        'es': ':hombre_barba:',
        'fr': ':homme_barbu:',
        'ja': u':あごひげの男性:',
        'ko': u':수염_난_남자:',
        'pt': ':homem_barbudo:',
        'it': ':uomo_con_la_barba:',
        'fa': u':مرد_ریش:',
        'id': ':pria_janggut:',
        'zh': u':有络腮胡子的男人:'
    },
    u'\U0001F9D4\U0000200D\U00002642': { # 🧔‍♂
        'en' : ':man_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':mann_bart:',
        'es': ':hombre_barba:',
        'fr': ':homme_barbu:',
        'ja': u':あごひげの男性:',
        'ko': u':수염_난_남자:',
        'pt': ':homem_barbudo:',
        'it': ':uomo_con_la_barba:',
        'fa': u':مرد_ریش:',
        'id': ':pria_janggut:',
        'zh': u':有络腮胡子的男人:'
    },
    u'\U0001F6B4\U0000200D\U00002642\U0000FE0F': { # 🚴‍♂️
        'en' : ':man_biking:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':biking_man:'],
        'de': ':radfahrer:',
        'es': ':hombre_en_bicicleta:',
        'fr': ':cycliste_homme:',
        'ja': u':自転車に乗る男:',
        'ko': u':자전거_타는_남자:',
        'pt': ':homem_ciclista:',
        'it': ':ciclista_uomo:',
        'fa': u':دوچرخه_سوار_مرد:',
        'id': ':pria_bersepeda:',
        'zh': u':男生骑自行车:'
    },
    u'\U0001F6B4\U0000200D\U00002642': { # 🚴‍♂
        'en' : ':man_biking:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':biking_man:'],
        'de': ':radfahrer:',
        'es': ':hombre_en_bicicleta:',
        'fr': ':cycliste_homme:',
        'ja': u':自転車に乗る男:',
        'ko': u':자전거_타는_남자:',
        'pt': ':homem_ciclista:',
        'it': ':ciclista_uomo:',
        'fa': u':دوچرخه_سوار_مرد:',
        'id': ':pria_bersepeda:',
        'zh': u':男生骑自行车:'
    },
    u'\U0001F6B4\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🚴🏿‍♂️
        'en' : ':man_biking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrer_dunkle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_oscuro:',
        'fr': u':cycliste_homme_peau_foncée:',
        'ja': u':自転車に乗る男_濃い肌色:',
        'ko': u':자전거_타는_남자_검은색_피부:',
        'pt': ':homem_ciclista_pele_escura:',
        'it': ':ciclista_uomo_carnagione_scura:',
        'fa': u':دوچرخه_سوار_مرد_پوست_آبنوسی:',
        'id': ':pria_bersepeda_warna_kulit_gelap:',
        'zh': u':男生骑自行车_较深肤色:'
    },
    u'\U0001F6B4\U0001F3FF\U0000200D\U00002642': { # 🚴🏿‍♂
        'en' : ':man_biking_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrer_dunkle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_oscuro:',
        'fr': u':cycliste_homme_peau_foncée:',
        'ja': u':自転車に乗る男_濃い肌色:',
        'ko': u':자전거_타는_남자_검은색_피부:',
        'pt': ':homem_ciclista_pele_escura:',
        'it': ':ciclista_uomo_carnagione_scura:',
        'fa': u':دوچرخه_سوار_مرد_پوست_آبنوسی:',
        'id': ':pria_bersepeda_warna_kulit_gelap:',
        'zh': u':男生骑自行车_较深肤色:'
    },
    u'\U0001F6B4\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🚴🏻‍♂️
        'en' : ':man_biking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrer_helle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_claro:',
        'fr': ':cycliste_homme_peau_claire:',
        'ja': u':自転車に乗る男_薄い肌色:',
        'ko': u':자전거_타는_남자_하얀_피부:',
        'pt': ':homem_ciclista_pele_clara:',
        'it': ':ciclista_uomo_carnagione_chiara:',
        'fa': u':دوچرخه_سوار_مرد_پوست_سفید:',
        'id': ':pria_bersepeda_warna_kulit_cerah:',
        'zh': u':男生骑自行车_较浅肤色:'
    },
    u'\U0001F6B4\U0001F3FB\U0000200D\U00002642': { # 🚴🏻‍♂
        'en' : ':man_biking_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrer_helle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_claro:',
        'fr': ':cycliste_homme_peau_claire:',
        'ja': u':自転車に乗る男_薄い肌色:',
        'ko': u':자전거_타는_남자_하얀_피부:',
        'pt': ':homem_ciclista_pele_clara:',
        'it': ':ciclista_uomo_carnagione_chiara:',
        'fa': u':دوچرخه_سوار_مرد_پوست_سفید:',
        'id': ':pria_bersepeda_warna_kulit_cerah:',
        'zh': u':男生骑自行车_较浅肤色:'
    },
    u'\U0001F6B4\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🚴🏾‍♂️
        'en' : ':man_biking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrer_mitteldunkle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_oscuro_medio:',
        'fr': ':cycliste_homme_peau_mate:',
        'ja': u':自転車に乗る男_やや濃い肌色:',
        'ko': u':자전거_타는_남자_진한_갈색_피부:',
        'pt': ':homem_ciclista_pele_morena_escura:',
        'it': ':ciclista_uomo_carnagione_abbastanza_scura:',
        'fa': u':دوچرخه_سوار_مرد_پوست_گندمی:',
        'id': ':pria_bersepeda_warna_kulit_gelap-sedang:',
        'zh': u':男生骑自行车_中等深肤色:'
    },
    u'\U0001F6B4\U0001F3FE\U0000200D\U00002642': { # 🚴🏾‍♂
        'en' : ':man_biking_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrer_mitteldunkle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_oscuro_medio:',
        'fr': ':cycliste_homme_peau_mate:',
        'ja': u':自転車に乗る男_やや濃い肌色:',
        'ko': u':자전거_타는_남자_진한_갈색_피부:',
        'pt': ':homem_ciclista_pele_morena_escura:',
        'it': ':ciclista_uomo_carnagione_abbastanza_scura:',
        'fa': u':دوچرخه_سوار_مرد_پوست_گندمی:',
        'id': ':pria_bersepeda_warna_kulit_gelap-sedang:',
        'zh': u':男生骑自行车_中等深肤色:'
    },
    u'\U0001F6B4\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🚴🏼‍♂️
        'en' : ':man_biking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrer_mittelhelle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_claro_medio:',
        'fr': ':cycliste_homme_peau_moyennement_claire:',
        'ja': u':自転車に乗る男_やや薄い肌色:',
        'ko': u':자전거_타는_남자_연한_갈색_피부:',
        'pt': ':homem_ciclista_pele_morena_clara:',
        'it': ':ciclista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':دوچرخه_سوار_مرد_پوست_روشن:',
        'id': ':pria_bersepeda_warna_kulit_cerah-sedang:',
        'zh': u':男生骑自行车_中等浅肤色:'
    },
    u'\U0001F6B4\U0001F3FC\U0000200D\U00002642': { # 🚴🏼‍♂
        'en' : ':man_biking_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrer_mittelhelle_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_claro_medio:',
        'fr': ':cycliste_homme_peau_moyennement_claire:',
        'ja': u':自転車に乗る男_やや薄い肌色:',
        'ko': u':자전거_타는_남자_연한_갈색_피부:',
        'pt': ':homem_ciclista_pele_morena_clara:',
        'it': ':ciclista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':دوچرخه_سوار_مرد_پوست_روشن:',
        'id': ':pria_bersepeda_warna_kulit_cerah-sedang:',
        'zh': u':男生骑自行车_中等浅肤色:'
    },
    u'\U0001F6B4\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🚴🏽‍♂️
        'en' : ':man_biking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrer_mittlere_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_medio:',
        'fr': u':cycliste_homme_peau_légèrement_mate:',
        'ja': u':自転車に乗る男_中間の肌色:',
        'ko': u':자전거_타는_남자_갈색_피부:',
        'pt': ':homem_ciclista_pele_morena:',
        'it': ':ciclista_uomo_carnagione_olivastra:',
        'fa': u':دوچرخه_سوار_مرد_پوست_طلایی:',
        'id': ':pria_bersepeda_warna_kulit_sedang:',
        'zh': u':男生骑自行车_中等肤色:'
    },
    u'\U0001F6B4\U0001F3FD\U0000200D\U00002642': { # 🚴🏽‍♂
        'en' : ':man_biking_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrer_mittlere_hautfarbe:',
        'es': ':hombre_en_bicicleta_tono_de_piel_medio:',
        'fr': u':cycliste_homme_peau_légèrement_mate:',
        'ja': u':自転車に乗る男_中間の肌色:',
        'ko': u':자전거_타는_남자_갈색_피부:',
        'pt': ':homem_ciclista_pele_morena:',
        'it': ':ciclista_uomo_carnagione_olivastra:',
        'fa': u':دوچرخه_سوار_مرد_پوست_طلایی:',
        'id': ':pria_bersepeda_warna_kulit_sedang:',
        'zh': u':男生骑自行车_中等肤色:'
    },
    u'\U0001F471\U0000200D\U00002642\U0000FE0F': { # 👱‍♂️
        'en' : ':man_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':blond_haired_man:'],
        'de': ':mann_blond:',
        'es': ':hombre_rubio:',
        'fr': ':homme_blond:',
        'ja': u':金髪の男性:',
        'ko': u':금발_남자:',
        'pt': ':homem_cabelo_loiro:',
        'it': ':uomo_biondo:',
        'fa': u':مرد_مو_بور:',
        'id': ':pria_berambut_pirang:',
        'zh': u':金发男:'
    },
    u'\U0001F471\U0000200D\U00002642': { # 👱‍♂
        'en' : ':man_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':blond_haired_man:'],
        'de': ':mann_blond:',
        'es': ':hombre_rubio:',
        'fr': ':homme_blond:',
        'ja': u':金髪の男性:',
        'ko': u':금발_남자:',
        'pt': ':homem_cabelo_loiro:',
        'it': ':uomo_biondo:',
        'fa': u':مرد_مو_بور:',
        'id': ':pria_berambut_pirang:',
        'zh': u':金发男:'
    },
    u'\U000026F9\U0000FE0F\U0000200D\U00002642\U0000FE0F': { # ⛹️‍♂️
        'en' : ':man_bouncing_ball:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':basketball_man:', ':bouncing_ball_man:'],
        'de': ':mann_mit_ball:',
        'es': u':hombre_botando_un_balón:',
        'fr': ':homme_avec_ballon:',
        'ja': u':バスケットボールをする男:',
        'ko': u':공_가진_남자:',
        'pt': ':homem_jogando_basquete:',
        'it': ':uomo_che_fa_rimbalzare_una_palla:',
        'fa': u':مرد_و_توپ:',
        'id': ':pria_memantulkan_bola:',
        'zh': u':男生玩球:'
    },
    u'\U000026F9\U0000200D\U00002642\U0000FE0F': { # ⛹‍♂️
        'en' : ':man_bouncing_ball:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':basketball_man:', ':bouncing_ball_man:'],
        'de': ':mann_mit_ball:',
        'es': u':hombre_botando_un_balón:',
        'fr': ':homme_avec_ballon:',
        'ja': u':バスケットボールをする男:',
        'ko': u':공_가진_남자:',
        'pt': ':homem_jogando_basquete:',
        'it': ':uomo_che_fa_rimbalzare_una_palla:',
        'fa': u':مرد_و_توپ:',
        'id': ':pria_memantulkan_bola:',
        'zh': u':男生玩球:'
    },
    u'\U000026F9\U0000FE0F\U0000200D\U00002642': { # ⛹️‍♂
        'en' : ':man_bouncing_ball:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':basketball_man:', ':bouncing_ball_man:'],
        'de': ':mann_mit_ball:',
        'es': u':hombre_botando_un_balón:',
        'fr': ':homme_avec_ballon:',
        'ja': u':バスケットボールをする男:',
        'ko': u':공_가진_남자:',
        'pt': ':homem_jogando_basquete:',
        'it': ':uomo_che_fa_rimbalzare_una_palla:',
        'fa': u':مرد_و_توپ:',
        'id': ':pria_memantulkan_bola:',
        'zh': u':男生玩球:'
    },
    u'\U000026F9\U0000200D\U00002642': { # ⛹‍♂
        'en' : ':man_bouncing_ball:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':basketball_man:', ':bouncing_ball_man:'],
        'de': ':mann_mit_ball:',
        'es': u':hombre_botando_un_balón:',
        'fr': ':homme_avec_ballon:',
        'ja': u':バスケットボールをする男:',
        'ko': u':공_가진_남자:',
        'pt': ':homem_jogando_basquete:',
        'it': ':uomo_che_fa_rimbalzare_una_palla:',
        'fa': u':مرد_و_توپ:',
        'id': ':pria_memantulkan_bola:',
        'zh': u':男生玩球:'
    },
    u'\U000026F9\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # ⛹🏿‍♂️
        'en' : ':man_bouncing_ball_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_dunkle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_oscuro:',
        'fr': u':homme_avec_ballon_peau_foncée:',
        'ja': u':バスケットボールをする男_濃い肌色:',
        'ko': u':공_가진_남자_검은색_피부:',
        'pt': ':homem_jogando_basquete_pele_escura:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_scura:',
        'fa': u':مرد_و_توپ_پوست_آبنوسی:',
        'id': ':pria_memantulkan_bola_warna_kulit_gelap:',
        'zh': u':男生玩球_较深肤色:'
    },
    u'\U000026F9\U0001F3FF\U0000200D\U00002642': { # ⛹🏿‍♂
        'en' : ':man_bouncing_ball_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_dunkle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_oscuro:',
        'fr': u':homme_avec_ballon_peau_foncée:',
        'ja': u':バスケットボールをする男_濃い肌色:',
        'ko': u':공_가진_남자_검은색_피부:',
        'pt': ':homem_jogando_basquete_pele_escura:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_scura:',
        'fa': u':مرد_و_توپ_پوست_آبنوسی:',
        'id': ':pria_memantulkan_bola_warna_kulit_gelap:',
        'zh': u':男生玩球_较深肤色:'
    },
    u'\U000026F9\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # ⛹🏻‍♂️
        'en' : ':man_bouncing_ball_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_helle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_claro:',
        'fr': ':homme_avec_ballon_peau_claire:',
        'ja': u':バスケットボールをする男_薄い肌色:',
        'ko': u':공_가진_남자_하얀_피부:',
        'pt': ':homem_jogando_basquete_pele_clara:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_chiara:',
        'fa': u':مرد_و_توپ_پوست_سفید:',
        'id': ':pria_memantulkan_bola_warna_kulit_cerah:',
        'zh': u':男生玩球_较浅肤色:'
    },
    u'\U000026F9\U0001F3FB\U0000200D\U00002642': { # ⛹🏻‍♂
        'en' : ':man_bouncing_ball_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_helle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_claro:',
        'fr': ':homme_avec_ballon_peau_claire:',
        'ja': u':バスケットボールをする男_薄い肌色:',
        'ko': u':공_가진_남자_하얀_피부:',
        'pt': ':homem_jogando_basquete_pele_clara:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_chiara:',
        'fa': u':مرد_و_توپ_پوست_سفید:',
        'id': ':pria_memantulkan_bola_warna_kulit_cerah:',
        'zh': u':男生玩球_较浅肤色:'
    },
    u'\U000026F9\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # ⛹🏾‍♂️
        'en' : ':man_bouncing_ball_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_mitteldunkle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_ballon_peau_mate:',
        'ja': u':バスケットボールをする男_やや濃い肌色:',
        'ko': u':공_가진_남자_진한_갈색_피부:',
        'pt': ':homem_jogando_basquete_pele_morena_escura:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_abbastanza_scura:',
        'fa': u':مرد_و_توپ_پوست_گندمی:',
        'id': ':pria_memantulkan_bola_warna_kulit_gelap-sedang:',
        'zh': u':男生玩球_中等深肤色:'
    },
    u'\U000026F9\U0001F3FE\U0000200D\U00002642': { # ⛹🏾‍♂
        'en' : ':man_bouncing_ball_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_mitteldunkle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_ballon_peau_mate:',
        'ja': u':バスケットボールをする男_やや濃い肌色:',
        'ko': u':공_가진_남자_진한_갈색_피부:',
        'pt': ':homem_jogando_basquete_pele_morena_escura:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_abbastanza_scura:',
        'fa': u':مرد_و_توپ_پوست_گندمی:',
        'id': ':pria_memantulkan_bola_warna_kulit_gelap-sedang:',
        'zh': u':男生玩球_中等深肤色:'
    },
    u'\U000026F9\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # ⛹🏼‍♂️
        'en' : ':man_bouncing_ball_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_mittelhelle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_ballon_peau_moyennement_claire:',
        'ja': u':バスケットボールをする男_やや薄い肌色:',
        'ko': u':공_가진_남자_연한_갈색_피부:',
        'pt': ':homem_jogando_basquete_pele_morena_clara:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_abbastanza_chiara:',
        'fa': u':مرد_و_توپ_پوست_روشن:',
        'id': ':pria_memantulkan_bola_warna_kulit_cerah-sedang:',
        'zh': u':男生玩球_中等浅肤色:'
    },
    u'\U000026F9\U0001F3FC\U0000200D\U00002642': { # ⛹🏼‍♂
        'en' : ':man_bouncing_ball_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_mittelhelle_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_ballon_peau_moyennement_claire:',
        'ja': u':バスケットボールをする男_やや薄い肌色:',
        'ko': u':공_가진_남자_연한_갈색_피부:',
        'pt': ':homem_jogando_basquete_pele_morena_clara:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_abbastanza_chiara:',
        'fa': u':مرد_و_توپ_پوست_روشن:',
        'id': ':pria_memantulkan_bola_warna_kulit_cerah-sedang:',
        'zh': u':男生玩球_中等浅肤色:'
    },
    u'\U000026F9\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # ⛹🏽‍♂️
        'en' : ':man_bouncing_ball_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_mittlere_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_medio:',
        'fr': u':homme_avec_ballon_peau_légèrement_mate:',
        'ja': u':バスケットボールをする男_中間の肌色:',
        'ko': u':공_가진_남자_갈색_피부:',
        'pt': ':homem_jogando_basquete_pele_morena:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_olivastra:',
        'fa': u':مرد_و_توپ_پوست_طلایی:',
        'id': ':pria_memantulkan_bola_warna_kulit_sedang:',
        'zh': u':男生玩球_中等肤色:'
    },
    u'\U000026F9\U0001F3FD\U0000200D\U00002642': { # ⛹🏽‍♂
        'en' : ':man_bouncing_ball_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_ball_mittlere_hautfarbe:',
        'es': u':hombre_botando_un_balón_tono_de_piel_medio:',
        'fr': u':homme_avec_ballon_peau_légèrement_mate:',
        'ja': u':バスケットボールをする男_中間の肌色:',
        'ko': u':공_가진_남자_갈색_피부:',
        'pt': ':homem_jogando_basquete_pele_morena:',
        'it': ':uomo_che_fa_rimbalzare_una_palla_carnagione_olivastra:',
        'fa': u':مرد_و_توپ_پوست_طلایی:',
        'id': ':pria_memantulkan_bola_warna_kulit_sedang:',
        'zh': u':男生玩球_中等肤色:'
    },
    u'\U0001F647\U0000200D\U00002642\U0000FE0F': { # 🙇‍♂️
        'en' : ':man_bowing:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':bowing_man:'],
        'de': ':sich_verbeugender_mann:',
        'es': ':hombre_haciendo_una_reverencia:',
        'fr': u':homme_qui_s’incline:',
        'ja': u':おじぎする男:',
        'ko': u':절하는_남자:',
        'pt': u':homem_fazendo_reverência:',
        'it': ':uomo_che_fa_inchino_profondo:',
        'fa': u':مرد_تعظیم_می_کند:',
        'id': ':pria_membungkuk:',
        'zh': u':男生鞠躬:'
    },
    u'\U0001F647\U0000200D\U00002642': { # 🙇‍♂
        'en' : ':man_bowing:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':bowing_man:'],
        'de': ':sich_verbeugender_mann:',
        'es': ':hombre_haciendo_una_reverencia:',
        'fr': u':homme_qui_s’incline:',
        'ja': u':おじぎする男:',
        'ko': u':절하는_남자:',
        'pt': u':homem_fazendo_reverência:',
        'it': ':uomo_che_fa_inchino_profondo:',
        'fa': u':مرد_تعظیم_می_کند:',
        'id': ':pria_membungkuk:',
        'zh': u':男生鞠躬:'
    },
    u'\U0001F647\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🙇🏿‍♂️
        'en' : ':man_bowing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_oscuro:',
        'fr': u':homme_qui_s’incline_peau_foncée:',
        'ja': u':おじぎする男_濃い肌色:',
        'ko': u':절하는_남자_검은색_피부:',
        'pt': u':homem_fazendo_reverência_pele_escura:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_scura:',
        'fa': u':مرد_تعظیم_می_کند_پوست_آبنوسی:',
        'id': ':pria_membungkuk_warna_kulit_gelap:',
        'zh': u':男生鞠躬_较深肤色:'
    },
    u'\U0001F647\U0001F3FF\U0000200D\U00002642': { # 🙇🏿‍♂
        'en' : ':man_bowing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_oscuro:',
        'fr': u':homme_qui_s’incline_peau_foncée:',
        'ja': u':おじぎする男_濃い肌色:',
        'ko': u':절하는_남자_검은색_피부:',
        'pt': u':homem_fazendo_reverência_pele_escura:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_scura:',
        'fa': u':مرد_تعظیم_می_کند_پوست_آبنوسی:',
        'id': ':pria_membungkuk_warna_kulit_gelap:',
        'zh': u':男生鞠躬_较深肤色:'
    },
    u'\U0001F647\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🙇🏻‍♂️
        'en' : ':man_bowing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_helle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_claro:',
        'fr': u':homme_qui_s’incline_peau_claire:',
        'ja': u':おじぎする男_薄い肌色:',
        'ko': u':절하는_남자_하얀_피부:',
        'pt': u':homem_fazendo_reverência_pele_clara:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_chiara:',
        'fa': u':مرد_تعظیم_می_کند_پوست_سفید:',
        'id': ':pria_membungkuk_warna_kulit_cerah:',
        'zh': u':男生鞠躬_较浅肤色:'
    },
    u'\U0001F647\U0001F3FB\U0000200D\U00002642': { # 🙇🏻‍♂
        'en' : ':man_bowing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_helle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_claro:',
        'fr': u':homme_qui_s’incline_peau_claire:',
        'ja': u':おじぎする男_薄い肌色:',
        'ko': u':절하는_남자_하얀_피부:',
        'pt': u':homem_fazendo_reverência_pele_clara:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_chiara:',
        'fa': u':مرد_تعظیم_می_کند_پوست_سفید:',
        'id': ':pria_membungkuk_warna_kulit_cerah:',
        'zh': u':男生鞠躬_较浅肤色:'
    },
    u'\U0001F647\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🙇🏾‍♂️
        'en' : ':man_bowing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_oscuro_medio:',
        'fr': u':homme_qui_s’incline_peau_mate:',
        'ja': u':おじぎする男_やや濃い肌色:',
        'ko': u':절하는_남자_진한_갈색_피부:',
        'pt': u':homem_fazendo_reverência_pele_morena_escura:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_abbastanza_scura:',
        'fa': u':مرد_تعظیم_می_کند_پوست_گندمی:',
        'id': ':pria_membungkuk_warna_kulit_gelap-sedang:',
        'zh': u':男生鞠躬_中等深肤色:'
    },
    u'\U0001F647\U0001F3FE\U0000200D\U00002642': { # 🙇🏾‍♂
        'en' : ':man_bowing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_oscuro_medio:',
        'fr': u':homme_qui_s’incline_peau_mate:',
        'ja': u':おじぎする男_やや濃い肌色:',
        'ko': u':절하는_남자_진한_갈색_피부:',
        'pt': u':homem_fazendo_reverência_pele_morena_escura:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_abbastanza_scura:',
        'fa': u':مرد_تعظیم_می_کند_پوست_گندمی:',
        'id': ':pria_membungkuk_warna_kulit_gelap-sedang:',
        'zh': u':男生鞠躬_中等深肤色:'
    },
    u'\U0001F647\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🙇🏼‍♂️
        'en' : ':man_bowing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_claro_medio:',
        'fr': u':homme_qui_s’incline_peau_moyennement_claire:',
        'ja': u':おじぎする男_やや薄い肌色:',
        'ko': u':절하는_남자_연한_갈색_피부:',
        'pt': u':homem_fazendo_reverência_pele_morena_clara:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_تعظیم_می_کند_پوست_روشن:',
        'id': ':pria_membungkuk_warna_kulit_cerah-sedang:',
        'zh': u':男生鞠躬_中等浅肤色:'
    },
    u'\U0001F647\U0001F3FC\U0000200D\U00002642': { # 🙇🏼‍♂
        'en' : ':man_bowing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_claro_medio:',
        'fr': u':homme_qui_s’incline_peau_moyennement_claire:',
        'ja': u':おじぎする男_やや薄い肌色:',
        'ko': u':절하는_남자_연한_갈색_피부:',
        'pt': u':homem_fazendo_reverência_pele_morena_clara:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_تعظیم_می_کند_پوست_روشن:',
        'id': ':pria_membungkuk_warna_kulit_cerah-sedang:',
        'zh': u':男生鞠躬_中等浅肤色:'
    },
    u'\U0001F647\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🙇🏽‍♂️
        'en' : ':man_bowing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_medio:',
        'fr': u':homme_qui_s’incline_peau_légèrement_mate:',
        'ja': u':おじぎする男_中間の肌色:',
        'ko': u':절하는_남자_갈색_피부:',
        'pt': u':homem_fazendo_reverência_pele_morena:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_olivastra:',
        'fa': u':مرد_تعظیم_می_کند_پوست_طلایی:',
        'id': ':pria_membungkuk_warna_kulit_sedang:',
        'zh': u':男生鞠躬_中等肤色:'
    },
    u'\U0001F647\U0001F3FD\U0000200D\U00002642': { # 🙇🏽‍♂
        'en' : ':man_bowing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugender_mann_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_una_reverencia_tono_de_piel_medio:',
        'fr': u':homme_qui_s’incline_peau_légèrement_mate:',
        'ja': u':おじぎする男_中間の肌色:',
        'ko': u':절하는_남자_갈색_피부:',
        'pt': u':homem_fazendo_reverência_pele_morena:',
        'it': ':uomo_che_fa_inchino_profondo_carnagione_olivastra:',
        'fa': u':مرد_تعظیم_می_کند_پوست_طلایی:',
        'id': ':pria_membungkuk_warna_kulit_sedang:',
        'zh': u':男生鞠躬_中等肤色:'
    },
    u'\U0001F938\U0000200D\U00002642\U0000FE0F': { # 🤸‍♂️
        'en' : ':man_cartwheeling:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann:',
        'es': ':hombre_haciendo_una_voltereta_lateral:',
        'fr': ':homme_faisant_la_roue:',
        'ja': u':側転する男:',
        'ko': u':옆돌기하는_남자:',
        'pt': ':homem_fazendo_estrela:',
        'it': ':uomo_che_fa_la_ruota:',
        'fa': u':مردِ_چرخ_وفلک_زن:',
        'id': ':pria_melakukan_gerakan_meroda:',
        'zh': u':男生侧手翻:'
    },
    u'\U0001F938\U0000200D\U00002642': { # 🤸‍♂
        'en' : ':man_cartwheeling:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann:',
        'es': ':hombre_dando_una_voltereta_lateral:',
        'fr': ':homme_faisant_la_roue:',
        'ja': u':側転する男:',
        'ko': u':옆돌기하는_남자:',
        'pt': ':homem_fazendo_estrela:',
        'it': ':uomo_che_fa_la_ruota:',
        'fa': u':مردِ_چرخ_وفلک_زن:',
        'id': ':pria_melakukan_gerakan_meroda:',
        'zh': u':男生侧手翻:'
    },
    u'\U0001F938\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🤸🏿‍♂️
        'en' : ':man_cartwheeling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_oscuro:',
        'fr': u':homme_faisant_la_roue_peau_foncée:',
        'ja': u':側転する男_濃い肌色:',
        'ko': u':옆돌기하는_남자_검은색_피부:',
        'pt': ':homem_fazendo_estrela_pele_escura:',
        'it': ':uomo_che_fa_la_ruota_carnagione_scura:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_آبنوسی:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_gelap:',
        'zh': u':男生侧手翻_较深肤色:'
    },
    u'\U0001F938\U0001F3FF\U0000200D\U00002642': { # 🤸🏿‍♂
        'en' : ':man_cartwheeling_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_oscuro:',
        'fr': u':homme_faisant_la_roue_peau_foncée:',
        'ja': u':側転する男_濃い肌色:',
        'ko': u':옆돌기하는_남자_검은색_피부:',
        'pt': ':homem_fazendo_estrela_pele_escura:',
        'it': ':uomo_che_fa_la_ruota_carnagione_scura:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_آبنوسی:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_gelap:',
        'zh': u':男生侧手翻_较深肤色:'
    },
    u'\U0001F938\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🤸🏻‍♂️
        'en' : ':man_cartwheeling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_helle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_claro:',
        'fr': ':homme_faisant_la_roue_peau_claire:',
        'ja': u':側転する男_薄い肌色:',
        'ko': u':옆돌기하는_남자_하얀_피부:',
        'pt': ':homem_fazendo_estrela_pele_clara:',
        'it': ':uomo_che_fa_la_ruota_carnagione_chiara:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_سفید:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_cerah:',
        'zh': u':男生侧手翻_较浅肤色:'
    },
    u'\U0001F938\U0001F3FB\U0000200D\U00002642': { # 🤸🏻‍♂
        'en' : ':man_cartwheeling_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_helle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_claro:',
        'fr': ':homme_faisant_la_roue_peau_claire:',
        'ja': u':側転する男_薄い肌色:',
        'ko': u':옆돌기하는_남자_하얀_피부:',
        'pt': ':homem_fazendo_estrela_pele_clara:',
        'it': ':uomo_che_fa_la_ruota_carnagione_chiara:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_سفید:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_cerah:',
        'zh': u':男生侧手翻_较浅肤色:'
    },
    u'\U0001F938\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🤸🏾‍♂️
        'en' : ':man_cartwheeling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_oscuro_medio:',
        'fr': ':homme_faisant_la_roue_peau_mate:',
        'ja': u':側転する男_やや濃い肌色:',
        'ko': u':옆돌기하는_남자_진한_갈색_피부:',
        'pt': ':homem_fazendo_estrela_pele_morena_escura:',
        'it': ':uomo_che_fa_la_ruota_carnagione_abbastanza_scura:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_گندمی:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_gelap-sedang:',
        'zh': u':男生侧手翻_中等深肤色:'
    },
    u'\U0001F938\U0001F3FE\U0000200D\U00002642': { # 🤸🏾‍♂
        'en' : ':man_cartwheeling_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_oscuro_medio:',
        'fr': ':homme_faisant_la_roue_peau_mate:',
        'ja': u':側転する男_やや濃い肌色:',
        'ko': u':옆돌기하는_남자_진한_갈색_피부:',
        'pt': ':homem_fazendo_estrela_pele_morena_escura:',
        'it': ':uomo_che_fa_la_ruota_carnagione_abbastanza_scura:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_گندمی:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_gelap-sedang:',
        'zh': u':男生侧手翻_中等深肤色:'
    },
    u'\U0001F938\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🤸🏼‍♂️
        'en' : ':man_cartwheeling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_claro_medio:',
        'fr': ':homme_faisant_la_roue_peau_moyennement_claire:',
        'ja': u':側転する男_やや薄い肌色:',
        'ko': u':옆돌기하는_남자_연한_갈색_피부:',
        'pt': ':homem_fazendo_estrela_pele_morena_clara:',
        'it': ':uomo_che_fa_la_ruota_carnagione_abbastanza_chiara:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_روشن:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_cerah-sedang:',
        'zh': u':男生侧手翻_中等浅肤色:'
    },
    u'\U0001F938\U0001F3FC\U0000200D\U00002642': { # 🤸🏼‍♂
        'en' : ':man_cartwheeling_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_claro_medio:',
        'fr': ':homme_faisant_la_roue_peau_moyennement_claire:',
        'ja': u':側転する男_やや薄い肌色:',
        'ko': u':옆돌기하는_남자_연한_갈색_피부:',
        'pt': ':homem_fazendo_estrela_pele_morena_clara:',
        'it': ':uomo_che_fa_la_ruota_carnagione_abbastanza_chiara:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_روشن:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_cerah-sedang:',
        'zh': u':男生侧手翻_中等浅肤色:'
    },
    u'\U0001F938\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🤸🏽‍♂️
        'en' : ':man_cartwheeling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_medio:',
        'fr': u':homme_faisant_la_roue_peau_légèrement_mate:',
        'ja': u':側転する男_中間の肌色:',
        'ko': u':옆돌기하는_남자_갈색_피부:',
        'pt': ':homem_fazendo_estrela_pele_morena:',
        'it': ':uomo_che_fa_la_ruota_carnagione_olivastra:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_طلایی:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_sedang:',
        'zh': u':男生侧手翻_中等肤色:'
    },
    u'\U0001F938\U0001F3FD\U0000200D\U00002642': { # 🤸🏽‍♂
        'en' : ':man_cartwheeling_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagender_mann_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_una_voltereta_lateral_tono_de_piel_medio:',
        'fr': u':homme_faisant_la_roue_peau_légèrement_mate:',
        'ja': u':側転する男_中間の肌色:',
        'ko': u':옆돌기하는_남자_갈색_피부:',
        'pt': ':homem_fazendo_estrela_pele_morena:',
        'it': ':uomo_che_fa_la_ruota_carnagione_olivastra:',
        'fa': u':مردِ_چرخ_وفلک_زن_پوست_طلایی:',
        'id': ':pria_melakukan_gerakan_meroda_warna_kulit_sedang:',
        'zh': u':男生侧手翻_中等肤色:'
    },
    u'\U0001F9D7\U0000200D\U00002642\U0000FE0F': { # 🧗‍♂️
        'en' : ':man_climbing:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':climbing_man:'],
        'de': ':bergsteiger:',
        'es': ':hombre_escalando:',
        'fr': ':homme_qui_grimpe:',
        'ja': u':山を登る男:',
        'ko': u':클라이밍하는_남자:',
        'pt': ':homem_escalando:',
        'it': ':scalatore:',
        'fa': u':مرد_کوه_نوردی_می_کند:',
        'id': ':pria_memanjat:',
        'zh': u':攀爬的男人:'
    },
    u'\U0001F9D7\U0000200D\U00002642': { # 🧗‍♂
        'en' : ':man_climbing:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':climbing_man:'],
        'de': ':bergsteiger:',
        'es': ':hombre_escalando:',
        'fr': ':homme_qui_grimpe:',
        'ja': u':山を登る男:',
        'ko': u':클라이밍하는_남자:',
        'pt': ':homem_escalando:',
        'it': ':scalatore:',
        'fa': u':مرد_کوه_نوردی_می_کند:',
        'id': ':pria_memanjat:',
        'zh': u':攀爬的男人:'
    },
    u'\U0001F9D7\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧗🏿‍♂️
        'en' : ':man_climbing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger_dunkle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_oscuro:',
        'fr': u':homme_qui_grimpe_peau_foncée:',
        'ja': u':山を登る男_濃い肌色:',
        'ko': u':클라이밍하는_남자_검은색_피부:',
        'pt': ':homem_escalando_pele_escura:',
        'it': ':scalatore_carnagione_scura:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_آبنوسی:',
        'id': ':pria_memanjat_warna_kulit_gelap:',
        'zh': u':攀爬的男人_较深肤色:'
    },
    u'\U0001F9D7\U0001F3FF\U0000200D\U00002642': { # 🧗🏿‍♂
        'en' : ':man_climbing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteiger_dunkle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_oscuro:',
        'fr': u':homme_qui_grimpe_peau_foncée:',
        'ja': u':山を登る男_濃い肌色:',
        'ko': u':클라이밍하는_남자_검은색_피부:',
        'pt': ':homem_escalando_pele_escura:',
        'it': ':scalatore_carnagione_scura:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_آبنوسی:',
        'id': ':pria_memanjat_warna_kulit_gelap:',
        'zh': u':攀爬的男人_较深肤色:'
    },
    u'\U0001F9D7\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧗🏻‍♂️
        'en' : ':man_climbing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger_helle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_claro:',
        'fr': ':homme_qui_grimpe_peau_claire:',
        'ja': u':山を登る男_薄い肌色:',
        'ko': u':클라이밍하는_남자_하얀_피부:',
        'pt': ':homem_escalando_pele_clara:',
        'it': ':scalatore_carnagione_chiara:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_سفید:',
        'id': ':pria_memanjat_warna_kulit_cerah:',
        'zh': u':攀爬的男人_较浅肤色:'
    },
    u'\U0001F9D7\U0001F3FB\U0000200D\U00002642': { # 🧗🏻‍♂
        'en' : ':man_climbing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteiger_helle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_claro:',
        'fr': ':homme_qui_grimpe_peau_claire:',
        'ja': u':山を登る男_薄い肌色:',
        'ko': u':클라이밍하는_남자_하얀_피부:',
        'pt': ':homem_escalando_pele_clara:',
        'it': ':scalatore_carnagione_chiara:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_سفید:',
        'id': ':pria_memanjat_warna_kulit_cerah:',
        'zh': u':攀爬的男人_较浅肤色:'
    },
    u'\U0001F9D7\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧗🏾‍♂️
        'en' : ':man_climbing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger_mitteldunkle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_grimpe_peau_mate:',
        'ja': u':山を登る男_やや濃い肌色:',
        'ko': u':클라이밍하는_남자_진한_갈색_피부:',
        'pt': ':homem_escalando_pele_morena_escura:',
        'it': ':scalatore_carnagione_abbastanza_scura:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_گندمی:',
        'id': ':pria_memanjat_warna_kulit_gelap-sedang:',
        'zh': u':攀爬的男人_中等深肤色:'
    },
    u'\U0001F9D7\U0001F3FE\U0000200D\U00002642': { # 🧗🏾‍♂
        'en' : ':man_climbing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteiger_mitteldunkle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_grimpe_peau_mate:',
        'ja': u':山を登る男_やや濃い肌色:',
        'ko': u':클라이밍하는_남자_진한_갈색_피부:',
        'pt': ':homem_escalando_pele_morena_escura:',
        'it': ':scalatore_carnagione_abbastanza_scura:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_گندمی:',
        'id': ':pria_memanjat_warna_kulit_gelap-sedang:',
        'zh': u':攀爬的男人_中等深肤色:'
    },
    u'\U0001F9D7\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧗🏼‍♂️
        'en' : ':man_climbing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger_mittelhelle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_grimpe_peau_moyennement_claire:',
        'ja': u':山を登る男_やや薄い肌色:',
        'ko': u':클라이밍하는_남자_연한_갈색_피부:',
        'pt': ':homem_escalando_pele_morena_clara:',
        'it': ':scalatore_carnagione_abbastanza_chiara:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_روشن:',
        'id': ':pria_memanjat_warna_kulit_cerah-sedang:',
        'zh': u':攀爬的男人_中等浅肤色:'
    },
    u'\U0001F9D7\U0001F3FC\U0000200D\U00002642': { # 🧗🏼‍♂
        'en' : ':man_climbing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteiger_mittelhelle_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_grimpe_peau_moyennement_claire:',
        'ja': u':山を登る男_やや薄い肌色:',
        'ko': u':클라이밍하는_남자_연한_갈색_피부:',
        'pt': ':homem_escalando_pele_morena_clara:',
        'it': ':scalatore_carnagione_abbastanza_chiara:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_روشن:',
        'id': ':pria_memanjat_warna_kulit_cerah-sedang:',
        'zh': u':攀爬的男人_中等浅肤色:'
    },
    u'\U0001F9D7\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧗🏽‍♂️
        'en' : ':man_climbing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger_mittlere_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_medio:',
        'fr': u':homme_qui_grimpe_peau_légèrement_mate:',
        'ja': u':山を登る男_中間の肌色:',
        'ko': u':클라이밍하는_남자_갈색_피부:',
        'pt': ':homem_escalando_pele_morena:',
        'it': ':scalatore_carnagione_olivastra:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_طلایی:',
        'id': ':pria_memanjat_warna_kulit_sedang:',
        'zh': u':攀爬的男人_中等肤色:'
    },
    u'\U0001F9D7\U0001F3FD\U0000200D\U00002642': { # 🧗🏽‍♂
        'en' : ':man_climbing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteiger_mittlere_hautfarbe:',
        'es': ':hombre_escalando_tono_de_piel_medio:',
        'fr': u':homme_qui_grimpe_peau_légèrement_mate:',
        'ja': u':山を登る男_中間の肌色:',
        'ko': u':클라이밍하는_남자_갈색_피부:',
        'pt': ':homem_escalando_pele_morena:',
        'it': ':scalatore_carnagione_olivastra:',
        'fa': u':مرد_کوه_نوردی_می_کند_پوست_طلایی:',
        'id': ':pria_memanjat_warna_kulit_sedang:',
        'zh': u':攀爬的男人_中等肤色:'
    },
    u'\U0001F477\U0000200D\U00002642\U0000FE0F': { # 👷‍♂️
        'en' : ':man_construction_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':construction_worker_man:'],
        'de': ':bauarbeiter:',
        'es': u':profesional_de_la_construcción_hombre:',
        'fr': u':ouvrier_du_bâtiment:',
        'ja': u':男性の建設作業員:',
        'ko': u':건설_현장_남자_노동자:',
        'pt': ':pedreiro:',
        'it': ':operaio_edile_uomo:',
        'fa': u':کارگر_ساختمانی_مرد:',
        'id': ':pekerja_konstruksi_pria:',
        'zh': u':男建筑工人:'
    },
    u'\U0001F477\U0000200D\U00002642': { # 👷‍♂
        'en' : ':man_construction_worker:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':construction_worker_man:'],
        'de': ':bauarbeiter:',
        'es': u':profesional_de_la_construcción_hombre:',
        'fr': u':ouvrier_du_bâtiment:',
        'ja': u':男性の建設作業員:',
        'ko': u':건설_현장_남자_노동자:',
        'pt': ':pedreiro:',
        'it': ':operaio_edile_uomo:',
        'fa': u':کارگر_ساختمانی_مرد:',
        'id': ':pekerja_konstruksi_pria:',
        'zh': u':男建筑工人:'
    },
    u'\U0001F477\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 👷🏿‍♂️
        'en' : ':man_construction_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiter_dunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_oscuro:',
        'fr': u':ouvrier_du_bâtiment_peau_foncée:',
        'ja': u':男性の建設作業員_濃い肌色:',
        'ko': u':건설_현장_남자_노동자_검은색_피부:',
        'pt': ':pedreiro_pele_escura:',
        'it': ':operaio_edile_uomo_carnagione_scura:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_آبنوسی:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_gelap:',
        'zh': u':男建筑工人_较深肤色:'
    },
    u'\U0001F477\U0001F3FF\U0000200D\U00002642': { # 👷🏿‍♂
        'en' : ':man_construction_worker_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiter_dunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_oscuro:',
        'fr': u':ouvrier_du_bâtiment_peau_foncée:',
        'ja': u':男性の建設作業員_濃い肌色:',
        'ko': u':건설_현장_남자_노동자_검은색_피부:',
        'pt': ':pedreiro_pele_escura:',
        'it': ':operaio_edile_uomo_carnagione_scura:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_آبنوسی:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_gelap:',
        'zh': u':男建筑工人_较深肤色:'
    },
    u'\U0001F477\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 👷🏻‍♂️
        'en' : ':man_construction_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiter_helle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_claro:',
        'fr': u':ouvrier_du_bâtiment_peau_claire:',
        'ja': u':男性の建設作業員_薄い肌色:',
        'ko': u':건설_현장_남자_노동자_하얀_피부:',
        'pt': ':pedreiro_pele_clara:',
        'it': ':operaio_edile_uomo_carnagione_chiara:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_سفید:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_cerah:',
        'zh': u':男建筑工人_较浅肤色:'
    },
    u'\U0001F477\U0001F3FB\U0000200D\U00002642': { # 👷🏻‍♂
        'en' : ':man_construction_worker_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiter_helle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_claro:',
        'fr': u':ouvrier_du_bâtiment_peau_claire:',
        'ja': u':男性の建設作業員_薄い肌色:',
        'ko': u':건설_현장_남자_노동자_하얀_피부:',
        'pt': ':pedreiro_pele_clara:',
        'it': ':operaio_edile_uomo_carnagione_chiara:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_سفید:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_cerah:',
        'zh': u':男建筑工人_较浅肤色:'
    },
    u'\U0001F477\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 👷🏾‍♂️
        'en' : ':man_construction_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiter_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':ouvrier_du_bâtiment_peau_mate:',
        'ja': u':男性の建設作業員_やや濃い肌色:',
        'ko': u':건설_현장_남자_노동자_진한_갈색_피부:',
        'pt': ':pedreiro_pele_morena_escura:',
        'it': ':operaio_edile_uomo_carnagione_abbastanza_scura:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_گندمی:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男建筑工人_中等深肤色:'
    },
    u'\U0001F477\U0001F3FE\U0000200D\U00002642': { # 👷🏾‍♂
        'en' : ':man_construction_worker_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiter_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':ouvrier_du_bâtiment_peau_mate:',
        'ja': u':男性の建設作業員_やや濃い肌色:',
        'ko': u':건설_현장_남자_노동자_진한_갈색_피부:',
        'pt': ':pedreiro_pele_morena_escura:',
        'it': ':operaio_edile_uomo_carnagione_abbastanza_scura:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_گندمی:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男建筑工人_中等深肤色:'
    },
    u'\U0001F477\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 👷🏼‍♂️
        'en' : ':man_construction_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiter_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_claro_medio:',
        'fr': u':ouvrier_du_bâtiment_peau_moyennement_claire:',
        'ja': u':男性の建設作業員_やや薄い肌色:',
        'ko': u':건설_현장_남자_노동자_연한_갈색_피부:',
        'pt': ':pedreiro_pele_morena_clara:',
        'it': ':operaio_edile_uomo_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_روشن:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男建筑工人_中等浅肤色:'
    },
    u'\U0001F477\U0001F3FC\U0000200D\U00002642': { # 👷🏼‍♂
        'en' : ':man_construction_worker_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiter_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_claro_medio:',
        'fr': u':ouvrier_du_bâtiment_peau_moyennement_claire:',
        'ja': u':男性の建設作業員_やや薄い肌色:',
        'ko': u':건설_현장_남자_노동자_연한_갈색_피부:',
        'pt': ':pedreiro_pele_morena_clara:',
        'it': ':operaio_edile_uomo_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_روشن:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男建筑工人_中等浅肤色:'
    },
    u'\U0001F477\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 👷🏽‍♂️
        'en' : ':man_construction_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiter_mittlere_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_medio:',
        'fr': u':ouvrier_du_bâtiment_peau_légèrement_mate:',
        'ja': u':男性の建設作業員_中間の肌色:',
        'ko': u':건설_현장_남자_노동자_갈색_피부:',
        'pt': ':pedreiro_pele_morena:',
        'it': ':operaio_edile_uomo_carnagione_olivastra:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_طلایی:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_sedang:',
        'zh': u':男建筑工人_中等肤色:'
    },
    u'\U0001F477\U0001F3FD\U0000200D\U00002642': { # 👷🏽‍♂
        'en' : ':man_construction_worker_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiter_mittlere_hautfarbe:',
        'es': u':profesional_de_la_construcción_hombre_tono_de_piel_medio:',
        'fr': u':ouvrier_du_bâtiment_peau_légèrement_mate:',
        'ja': u':男性の建設作業員_中間の肌色:',
        'ko': u':건설_현장_남자_노동자_갈색_피부:',
        'pt': ':pedreiro_pele_morena:',
        'it': ':operaio_edile_uomo_carnagione_olivastra:',
        'fa': u':کارگر_ساختمانی_مرد_پوست_طلایی:',
        'id': ':pekerja_konstruksi_pria_warna_kulit_sedang:',
        'zh': u':男建筑工人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F373': { # 👨‍🍳
        'en' : ':man_cook:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':koch:',
        'es': ':chef_hombre:',
        'fr': ':cuisinier:',
        'ja': u':男性のコック:',
        'ko': u':남자_요리사:',
        'pt': ':cozinheiro:',
        'it': ':cuoco:',
        'fa': u':آشپز_مرد:',
        'id': ':koki_pria:',
        'zh': u':男厨师:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F373': { # 👨🏿‍🍳
        'en' : ':man_cook_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':koch_dunkle_hautfarbe:',
        'es': ':chef_hombre_tono_de_piel_oscuro:',
        'fr': u':cuisinier_peau_foncée:',
        'ja': u':男性のコック_濃い肌色:',
        'ko': u':남자_요리사_검은색_피부:',
        'pt': ':cozinheiro_pele_escura:',
        'it': ':cuoco_carnagione_scura:',
        'fa': u':آشپز_مرد_پوست_آبنوسی:',
        'id': ':koki_pria_warna_kulit_gelap:',
        'zh': u':男厨师_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F373': { # 👨🏻‍🍳
        'en' : ':man_cook_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':koch_helle_hautfarbe:',
        'es': ':chef_hombre_tono_de_piel_claro:',
        'fr': ':cuisinier_peau_claire:',
        'ja': u':男性のコック_薄い肌色:',
        'ko': u':남자_요리사_하얀_피부:',
        'pt': ':cozinheiro_pele_clara:',
        'it': ':cuoco_carnagione_chiara:',
        'fa': u':آشپز_مرد_پوست_سفید:',
        'id': ':koki_pria_warna_kulit_cerah:',
        'zh': u':男厨师_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F373': { # 👨🏾‍🍳
        'en' : ':man_cook_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':koch_mitteldunkle_hautfarbe:',
        'es': ':chef_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':cuisinier_peau_mate:',
        'ja': u':男性のコック_やや濃い肌色:',
        'ko': u':남자_요리사_진한_갈색_피부:',
        'pt': ':cozinheiro_pele_morena_escura:',
        'it': ':cuoco_carnagione_abbastanza_scura:',
        'fa': u':آشپز_مرد_پوست_گندمی:',
        'id': ':koki_pria_warna_kulit_gelap-sedang:',
        'zh': u':男厨师_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F373': { # 👨🏼‍🍳
        'en' : ':man_cook_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':koch_mittelhelle_hautfarbe:',
        'es': ':chef_hombre_tono_de_piel_claro_medio:',
        'fr': ':cuisinier_peau_moyennement_claire:',
        'ja': u':男性のコック_やや薄い肌色:',
        'ko': u':남자_요리사_연한_갈색_피부:',
        'pt': ':cozinheiro_pele_morena_clara:',
        'it': ':cuoco_carnagione_abbastanza_chiara:',
        'fa': u':آشپز_مرد_پوست_روشن:',
        'id': ':koki_pria_warna_kulit_cerah-sedang:',
        'zh': u':男厨师_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F373': { # 👨🏽‍🍳
        'en' : ':man_cook_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':koch_mittlere_hautfarbe:',
        'es': ':chef_hombre_tono_de_piel_medio:',
        'fr': u':cuisinier_peau_légèrement_mate:',
        'ja': u':男性のコック_中間の肌色:',
        'ko': u':남자_요리사_갈색_피부:',
        'pt': ':cozinheiro_pele_morena:',
        'it': ':cuoco_carnagione_olivastra:',
        'fa': u':آشپز_مرد_پوست_طلایی:',
        'id': ':koki_pria_warna_kulit_sedang:',
        'zh': u':男厨师_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F9B1': { # 👨‍🦱
        'en' : ':man_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':curly_haired_man:'],
        'de': ':mann_lockiges_haar:',
        'es': ':hombre_pelo_rizado:',
        'fr': u':homme_cheveux_bouclés:',
        'ja': u':男性_巻き毛:',
        'ko': u':남자_곱슬머리:',
        'pt': ':homem_cabelo_cacheado:',
        'it': ':uomo_capelli_ricci:',
        'fa': u':مرد_موفرفری:',
        'id': ':pria_rambut_keriting:',
        'zh': u':男人_卷发:'
    },
    u'\U0001F57A': { # 🕺
        'en' : ':man_dancing:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tanzender_mann:',
        'es': ':hombre_bailando:',
        'fr': ':danseur:',
        'ja': u':踊る男:',
        'ko': u':남자_댄서:',
        'pt': u':homem_dançando:',
        'it': ':uomo_che_balla:',
        'fa': u':مرد_درحال_رقص:',
        'id': ':pria_menari:',
        'zh': u':跳舞的男人:'
    },
    u'\U0001F57A\U0001F3FF': { # 🕺🏿
        'en' : ':man_dancing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tanzender_mann_dunkle_hautfarbe:',
        'es': ':hombre_bailando_tono_de_piel_oscuro:',
        'fr': u':danseur_peau_foncée:',
        'ja': u':踊る男_濃い肌色:',
        'ko': u':남자_댄서_검은색_피부:',
        'pt': u':homem_dançando_pele_escura:',
        'it': ':uomo_che_balla_carnagione_scura:',
        'fa': u':مرد_درحال_رقص_پوست_آبنوسی:',
        'id': ':pria_menari_warna_kulit_gelap:',
        'zh': u':跳舞的男人_较深肤色:'
    },
    u'\U0001F57A\U0001F3FB': { # 🕺🏻
        'en' : ':man_dancing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tanzender_mann_helle_hautfarbe:',
        'es': ':hombre_bailando_tono_de_piel_claro:',
        'fr': ':danseur_peau_claire:',
        'ja': u':踊る男_薄い肌色:',
        'ko': u':남자_댄서_하얀_피부:',
        'pt': u':homem_dançando_pele_clara:',
        'it': ':uomo_che_balla_carnagione_chiara:',
        'fa': u':مرد_درحال_رقص_پوست_سفید:',
        'id': ':pria_menari_warna_kulit_cerah:',
        'zh': u':跳舞的男人_较浅肤色:'
    },
    u'\U0001F57A\U0001F3FE': { # 🕺🏾
        'en' : ':man_dancing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tanzender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_bailando_tono_de_piel_oscuro_medio:',
        'fr': ':danseur_peau_mate:',
        'ja': u':踊る男_やや濃い肌色:',
        'ko': u':남자_댄서_진한_갈색_피부:',
        'pt': u':homem_dançando_pele_morena_escura:',
        'it': ':uomo_che_balla_carnagione_abbastanza_scura:',
        'fa': u':مرد_درحال_رقص_پوست_گندمی:',
        'id': ':pria_menari_warna_kulit_gelap-sedang:',
        'zh': u':跳舞的男人_中等深肤色:'
    },
    u'\U0001F57A\U0001F3FC': { # 🕺🏼
        'en' : ':man_dancing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tanzender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_bailando_tono_de_piel_claro_medio:',
        'fr': ':danseur_peau_moyennement_claire:',
        'ja': u':踊る男_やや薄い肌色:',
        'ko': u':남자_댄서_연한_갈색_피부:',
        'pt': u':homem_dançando_pele_morena_clara:',
        'it': ':uomo_che_balla_carnagione_abbastanza_chiara:',
        'fa': u':مرد_درحال_رقص_پوست_روشن:',
        'id': ':pria_menari_warna_kulit_cerah-sedang:',
        'zh': u':跳舞的男人_中等浅肤色:'
    },
    u'\U0001F57A\U0001F3FD': { # 🕺🏽
        'en' : ':man_dancing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tanzender_mann_mittlere_hautfarbe:',
        'es': ':hombre_bailando_tono_de_piel_medio:',
        'fr': u':danseur_peau_légèrement_mate:',
        'ja': u':踊る男_中間の肌色:',
        'ko': u':남자_댄서_갈색_피부:',
        'pt': u':homem_dançando_pele_morena:',
        'it': ':uomo_che_balla_carnagione_olivastra:',
        'fa': u':مرد_درحال_رقص_پوست_طلایی:',
        'id': ':pria_menari_warna_kulit_sedang:',
        'zh': u':跳舞的男人_中等肤色:'
    },
    u'\U0001F468\U0001F3FF': { # 👨🏿
        'en' : ':man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_dunkle_hautfarbe:',
        'es': ':hombre_tono_de_piel_oscuro:',
        'fr': u':homme_peau_foncée:',
        'ja': u':男性_濃い肌色:',
        'ko': u':남자_검은색_피부:',
        'pt': ':homem_pele_escura:',
        'it': ':uomo_carnagione_scura:',
        'fa': u':مرد_پوست_آبنوسی:',
        'id': ':pria_warna_kulit_gelap:',
        'zh': u':男人_较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F9B2': { # 👨🏿‍🦲
        'en' : ':man_dark_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_dunkle_hautfarbe,_glatze:',
        'es': ':hombre_tono_de_piel_oscuro_y_sin_pelo:',
        'fr': u':homme_peau_foncée_et_chauve:',
        'ja': u':男性_濃い肌色_はげ頭:',
        'ko': u':남자_검은색_피부_대머리:',
        'pt': ':homem_pele_escura_e_careca:',
        'it': ':uomo_carnagione_scura_e_calvo:',
        'fa': u':مرد_پوست_آبنوسی_تاس:',
        'id': ':pria_warna_kulit_gelap_gundul:',
        'zh': u':男人_较深肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧔🏿‍♂️
        'en' : ':man_dark_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':mann_dunkle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_oscuro_y_barba:',
        'fr': u':homme_barbu__peau_foncée:',
        'ja': u':あごひげの男性_濃い肌色:',
        'ko': u':수염_난_남자_검은색_피부:',
        'pt': ':homem_pele_escura_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_scura:',
        'fa': u':مرد_پوست_آبنوسی_ریش:',
        'id': ':pria_warna_kulit_gelap_janggut:',
        'zh': u':有络腮胡子的男人_较深肤色:'
    },
    u'\U0001F9D4\U0001F3FF\U0000200D\U00002642': { # 🧔🏿‍♂
        'en' : ':man_dark_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':mann_dunkle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_oscuro_y_barba:',
        'fr': u':homme_barbu__peau_foncée:',
        'ja': u':あごひげの男性_濃い肌色:',
        'ko': u':수염_난_남자_검은색_피부:',
        'pt': ':homem_pele_escura_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_scura:',
        'fa': u':مرد_پوست_آبنوسی_ریش:',
        'id': ':pria_warna_kulit_gelap_janggut:',
        'zh': u':有络腮胡子的男人_较深肤色:'
    },
    u'\U0001F471\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 👱🏿‍♂️
        'en' : ':man_dark_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_dunkle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_oscuro:',
        'fr': u':homme_blond_peau_foncée:',
        'ja': u':金髪の男性_濃い肌色:',
        'ko': u':금발_남자_검은색_피부:',
        'pt': ':homem_pele_escura_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_scura:',
        'fa': u':مرد_پوست_آبنوسی_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_gelap:',
        'zh': u':金发男_较深肤色:'
    },
    u'\U0001F471\U0001F3FF\U0000200D\U00002642': { # 👱🏿‍♂
        'en' : ':man_dark_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_dunkle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_oscuro:',
        'fr': u':homme_blond_peau_foncée:',
        'ja': u':金髪の男性_濃い肌色:',
        'ko': u':금발_남자_검은색_피부:',
        'pt': ':homem_pele_escura_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_scura:',
        'fa': u':مرد_پوست_آبنوسی_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_gelap:',
        'zh': u':金发男_较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F9B1': { # 👨🏿‍🦱
        'en' : ':man_dark_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_dunkle_hautfarbe,_lockiges_haar:',
        'es': ':hombre_tono_de_piel_oscuro_y_pelo_rizado:',
        'fr': u':homme_peau_foncée_et_cheveux_bouclés:',
        'ja': u':男性_濃い肌色_巻き毛:',
        'ko': u':남자_검은색_피부_곱슬머리:',
        'pt': ':homem_pele_escura_e_cabelo_cacheado:',
        'it': ':uomo_carnagione_scura_e_capelli_ricci:',
        'fa': u':مرد_پوست_آبنوسی_موفرفری:',
        'id': ':pria_warna_kulit_gelap_rambut_keriting:',
        'zh': u':男人_较深肤色卷发:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F9B0': { # 👨🏿‍🦰
        'en' : ':man_dark_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_dunkle_hautfarbe,_rotes_haar:',
        'es': ':hombre_tono_de_piel_oscuro_y_pelo_pelirrojo:',
        'fr': u':homme_peau_foncée_et_cheveux_roux:',
        'ja': u':男性_濃い肌色_赤毛:',
        'ko': u':남자_검은색_피부_빨간_머리:',
        'pt': ':homem_pele_escura_e_cabelo_vermelho:',
        'it': ':uomo_carnagione_scura_e_capelli_rossi:',
        'fa': u':مرد_پوست_آبنوسی_موقرمز:',
        'id': ':pria_warna_kulit_gelap_rambut_merah:',
        'zh': u':男人_较深肤色红发:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F9B3': { # 👨🏿‍🦳
        'en' : ':man_dark_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':mann_dunkle_hautfarbe,_weißes_haar:',
        'es': ':hombre_tono_de_piel_oscuro_y_pelo_blanco:',
        'fr': u':homme_peau_foncée_et_cheveux_blancs:',
        'ja': u':男性_濃い肌色_白髪:',
        'ko': u':남자_검은색_피부_백발:',
        'pt': ':homem_pele_escura_e_cabelo_branco:',
        'it': ':uomo_carnagione_scura_e_capelli_bianchi:',
        'fa': u':مرد_پوست_آبنوسی_موسفید:',
        'id': ':pria_warna_kulit_gelap_rambut_putih:',
        'zh': u':男人_较深肤色白发:'
    },
    u'\U0001F575\U0000FE0F\U0000200D\U00002642\U0000FE0F': { # 🕵️‍♂️
        'en' : ':man_detective:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':male_detective:'],
        'de': ':detektiv:',
        'es': ':detective_hombre:',
        'fr': u':détective_homme:',
        'ja': u':男性の探偵:',
        'ko': u':남자_탐정:',
        'pt': ':detetive_homem:',
        'it': ':investigatore:',
        'fa': u':کارآگاه_مرد:',
        'id': ':detektif_pria:',
        'zh': u':男侦探:'
    },
    u'\U0001F575\U0000200D\U00002642\U0000FE0F': { # 🕵‍♂️
        'en' : ':man_detective:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':male_detective:'],
        'de': ':detektiv:',
        'es': ':detective_hombre:',
        'fr': u':détective_homme:',
        'ja': u':男性の探偵:',
        'ko': u':남자_탐정:',
        'pt': ':detetive_homem:',
        'it': ':investigatore:',
        'fa': u':کارآگاه_مرد:',
        'id': ':detektif_pria:',
        'zh': u':男侦探:'
    },
    u'\U0001F575\U0000FE0F\U0000200D\U00002642': { # 🕵️‍♂
        'en' : ':man_detective:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':male_detective:'],
        'de': ':detektiv:',
        'es': ':detective_hombre:',
        'fr': u':détective_homme:',
        'ja': u':男性の探偵:',
        'ko': u':남자_탐정:',
        'pt': ':detetive_homem:',
        'it': ':investigatore:',
        'fa': u':کارآگاه_مرد:',
        'id': ':detektif_pria:',
        'zh': u':男侦探:'
    },
    u'\U0001F575\U0000200D\U00002642': { # 🕵‍♂
        'en' : ':man_detective:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':male_detective:'],
        'de': ':detektiv:',
        'es': ':detective_hombre:',
        'fr': u':détective_homme:',
        'ja': u':男性の探偵:',
        'ko': u':남자_탐정:',
        'pt': ':detetive_homem:',
        'it': ':investigatore:',
        'fa': u':کارآگاه_مرد:',
        'id': ':detektif_pria:',
        'zh': u':男侦探:'
    },
    u'\U0001F575\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🕵🏿‍♂️
        'en' : ':man_detective_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektiv_dunkle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_oscuro:',
        'fr': u':détective_homme_peau_foncée:',
        'ja': u':男性の探偵_濃い肌色:',
        'ko': u':남자_탐정_검은색_피부:',
        'pt': ':detetive_homem_pele_escura:',
        'it': ':investigatore_carnagione_scura:',
        'fa': u':کارآگاه_مرد_پوست_آبنوسی:',
        'id': ':detektif_pria_warna_kulit_gelap:',
        'zh': u':男侦探_较深肤色:'
    },
    u'\U0001F575\U0001F3FF\U0000200D\U00002642': { # 🕵🏿‍♂
        'en' : ':man_detective_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektiv_dunkle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_oscuro:',
        'fr': u':détective_homme_peau_foncée:',
        'ja': u':男性の探偵_濃い肌色:',
        'ko': u':남자_탐정_검은색_피부:',
        'pt': ':detetive_homem_pele_escura:',
        'it': ':investigatore_carnagione_scura:',
        'fa': u':کارآگاه_مرد_پوست_آبنوسی:',
        'id': ':detektif_pria_warna_kulit_gelap:',
        'zh': u':男侦探_较深肤色:'
    },
    u'\U0001F575\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🕵🏻‍♂️
        'en' : ':man_detective_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektiv_helle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_claro:',
        'fr': u':détective_homme_peau_claire:',
        'ja': u':男性の探偵_薄い肌色:',
        'ko': u':남자_탐정_하얀_피부:',
        'pt': ':detetive_homem_pele_clara:',
        'it': ':investigatore_carnagione_chiara:',
        'fa': u':کارآگاه_مرد_پوست_سفید:',
        'id': ':detektif_pria_warna_kulit_cerah:',
        'zh': u':男侦探_较浅肤色:'
    },
    u'\U0001F575\U0001F3FB\U0000200D\U00002642': { # 🕵🏻‍♂
        'en' : ':man_detective_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektiv_helle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_claro:',
        'fr': u':détective_homme_peau_claire:',
        'ja': u':男性の探偵_薄い肌色:',
        'ko': u':남자_탐정_하얀_피부:',
        'pt': ':detetive_homem_pele_clara:',
        'it': ':investigatore_carnagione_chiara:',
        'fa': u':کارآگاه_مرد_پوست_سفید:',
        'id': ':detektif_pria_warna_kulit_cerah:',
        'zh': u':男侦探_较浅肤色:'
    },
    u'\U0001F575\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🕵🏾‍♂️
        'en' : ':man_detective_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektiv_mitteldunkle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':détective_homme_peau_mate:',
        'ja': u':男性の探偵_やや濃い肌色:',
        'ko': u':남자_탐정_진한_갈색_피부:',
        'pt': ':detetive_homem_pele_morena_escura:',
        'it': ':investigatore_carnagione_abbastanza_scura:',
        'fa': u':کارآگاه_مرد_پوست_گندمی:',
        'id': ':detektif_pria_warna_kulit_gelap-sedang:',
        'zh': u':男侦探_中等深肤色:'
    },
    u'\U0001F575\U0001F3FE\U0000200D\U00002642': { # 🕵🏾‍♂
        'en' : ':man_detective_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektiv_mitteldunkle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':détective_homme_peau_mate:',
        'ja': u':男性の探偵_やや濃い肌色:',
        'ko': u':남자_탐정_진한_갈색_피부:',
        'pt': ':detetive_homem_pele_morena_escura:',
        'it': ':investigatore_carnagione_abbastanza_scura:',
        'fa': u':کارآگاه_مرد_پوست_گندمی:',
        'id': ':detektif_pria_warna_kulit_gelap-sedang:',
        'zh': u':男侦探_中等深肤色:'
    },
    u'\U0001F575\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🕵🏼‍♂️
        'en' : ':man_detective_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektiv_mittelhelle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_claro_medio:',
        'fr': u':détective_homme_peau_moyennement_claire:',
        'ja': u':男性の探偵_やや薄い肌色:',
        'ko': u':남자_탐정_연한_갈색_피부:',
        'pt': ':detetive_homem_pele_morena_clara:',
        'it': ':investigatore_carnagione_abbastanza_chiara:',
        'fa': u':کارآگاه_مرد_پوست_روشن:',
        'id': ':detektif_pria_warna_kulit_cerah-sedang:',
        'zh': u':男侦探_中等浅肤色:'
    },
    u'\U0001F575\U0001F3FC\U0000200D\U00002642': { # 🕵🏼‍♂
        'en' : ':man_detective_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektiv_mittelhelle_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_claro_medio:',
        'fr': u':détective_homme_peau_moyennement_claire:',
        'ja': u':男性の探偵_やや薄い肌色:',
        'ko': u':남자_탐정_연한_갈색_피부:',
        'pt': ':detetive_homem_pele_morena_clara:',
        'it': ':investigatore_carnagione_abbastanza_chiara:',
        'fa': u':کارآگاه_مرد_پوست_روشن:',
        'id': ':detektif_pria_warna_kulit_cerah-sedang:',
        'zh': u':男侦探_中等浅肤色:'
    },
    u'\U0001F575\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🕵🏽‍♂️
        'en' : ':man_detective_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektiv_mittlere_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_medio:',
        'fr': u':détective_homme_peau_légèrement_mate:',
        'ja': u':男性の探偵_中間の肌色:',
        'ko': u':남자_탐정_갈색_피부:',
        'pt': ':detetive_homem_pele_morena:',
        'it': ':investigatore_carnagione_olivastra:',
        'fa': u':کارآگاه_مرد_پوست_طلایی:',
        'id': ':detektif_pria_warna_kulit_sedang:',
        'zh': u':男侦探_中等肤色:'
    },
    u'\U0001F575\U0001F3FD\U0000200D\U00002642': { # 🕵🏽‍♂
        'en' : ':man_detective_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektiv_mittlere_hautfarbe:',
        'es': ':detective_hombre_tono_de_piel_medio:',
        'fr': u':détective_homme_peau_légèrement_mate:',
        'ja': u':男性の探偵_中間の肌色:',
        'ko': u':남자_탐정_갈색_피부:',
        'pt': ':detetive_homem_pele_morena:',
        'it': ':investigatore_carnagione_olivastra:',
        'fa': u':کارآگاه_مرد_پوست_طلایی:',
        'id': ':detektif_pria_warna_kulit_sedang:',
        'zh': u':男侦探_中等肤色:'
    },
    u'\U0001F9DD\U0000200D\U00002642\U0000FE0F': { # 🧝‍♂️
        'en' : ':man_elf:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':elf_man:'],
        'de': ':elf:',
        'es': ':elfo_hombre:',
        'fr': ':elfe_homme:',
        'ja': u':男のエルフ:',
        'ko': u':남자_엘프:',
        'pt': ':elfo_homem:',
        'it': ':elfo_uomo:',
        'fa': u':اِلف_مرد:',
        'id': ':kurcaci_pria:',
        'zh': u':男小精灵:'
    },
    u'\U0001F9DD\U0000200D\U00002642': { # 🧝‍♂
        'en' : ':man_elf:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':elf_man:'],
        'de': ':elf:',
        'es': ':elfo_hombre:',
        'fr': ':elfe_homme:',
        'ja': u':男のエルフ:',
        'ko': u':남자_엘프:',
        'pt': ':elfo_homem:',
        'it': ':elfo_uomo:',
        'fa': u':اِلف_مرد:',
        'id': ':kurcaci_pria:',
        'zh': u':男小精灵:'
    },
    u'\U0001F9DD\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧝🏿‍♂️
        'en' : ':man_elf_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf_dunkle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_oscuro:',
        'fr': u':elfe_homme_peau_foncée:',
        'ja': u':男のエルフ_濃い肌色:',
        'ko': u':남자_엘프_검은색_피부:',
        'pt': ':elfo_homem_pele_escura:',
        'it': ':elfo_uomo_carnagione_scura:',
        'fa': u':اِلف_مرد_پوست_آبنوسی:',
        'id': ':kurcaci_pria_warna_kulit_gelap:',
        'zh': u':男小精灵_较深肤色:'
    },
    u'\U0001F9DD\U0001F3FF\U0000200D\U00002642': { # 🧝🏿‍♂
        'en' : ':man_elf_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elf_dunkle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_oscuro:',
        'fr': u':elfe_homme_peau_foncée:',
        'ja': u':男のエルフ_濃い肌色:',
        'ko': u':남자_엘프_검은색_피부:',
        'pt': ':elfo_homem_pele_escura:',
        'it': ':elfo_uomo_carnagione_scura:',
        'fa': u':اِلف_مرد_پوست_آبنوسی:',
        'id': ':kurcaci_pria_warna_kulit_gelap:',
        'zh': u':男小精灵_较深肤色:'
    },
    u'\U0001F9DD\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧝🏻‍♂️
        'en' : ':man_elf_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf_helle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_claro:',
        'fr': ':elfe_homme_peau_claire:',
        'ja': u':男のエルフ_薄い肌色:',
        'ko': u':남자_엘프_하얀_피부:',
        'pt': ':elfo_homem_pele_clara:',
        'it': ':elfo_uomo_carnagione_chiara:',
        'fa': u':اِلف_مرد_پوست_سفید:',
        'id': ':kurcaci_pria_warna_kulit_cerah:',
        'zh': u':男小精灵_较浅肤色:'
    },
    u'\U0001F9DD\U0001F3FB\U0000200D\U00002642': { # 🧝🏻‍♂
        'en' : ':man_elf_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elf_helle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_claro:',
        'fr': ':elfe_homme_peau_claire:',
        'ja': u':男のエルフ_薄い肌色:',
        'ko': u':남자_엘프_하얀_피부:',
        'pt': ':elfo_homem_pele_clara:',
        'it': ':elfo_uomo_carnagione_chiara:',
        'fa': u':اِلف_مرد_پوست_سفید:',
        'id': ':kurcaci_pria_warna_kulit_cerah:',
        'zh': u':男小精灵_较浅肤色:'
    },
    u'\U0001F9DD\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧝🏾‍♂️
        'en' : ':man_elf_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf_mitteldunkle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':elfe_homme_peau_mate:',
        'ja': u':男のエルフ_やや濃い肌色:',
        'ko': u':남자_엘프_진한_갈색_피부:',
        'pt': ':elfo_homem_pele_morena_escura:',
        'it': ':elfo_uomo_carnagione_abbastanza_scura:',
        'fa': u':اِلف_مرد_پوست_گندمی:',
        'id': ':kurcaci_pria_warna_kulit_gelap-sedang:',
        'zh': u':男小精灵_中等深肤色:'
    },
    u'\U0001F9DD\U0001F3FE\U0000200D\U00002642': { # 🧝🏾‍♂
        'en' : ':man_elf_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elf_mitteldunkle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':elfe_homme_peau_mate:',
        'ja': u':男のエルフ_やや濃い肌色:',
        'ko': u':남자_엘프_진한_갈색_피부:',
        'pt': ':elfo_homem_pele_morena_escura:',
        'it': ':elfo_uomo_carnagione_abbastanza_scura:',
        'fa': u':اِلف_مرد_پوست_گندمی:',
        'id': ':kurcaci_pria_warna_kulit_gelap-sedang:',
        'zh': u':男小精灵_中等深肤色:'
    },
    u'\U0001F9DD\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧝🏼‍♂️
        'en' : ':man_elf_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf_mittelhelle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_claro_medio:',
        'fr': ':elfe_homme_peau_moyennement_claire:',
        'ja': u':男のエルフ_やや薄い肌色:',
        'ko': u':남자_엘프_연한_갈색_피부:',
        'pt': ':elfo_homem_pele_morena_clara:',
        'it': ':elfo_uomo_carnagione_abbastanza_chiara:',
        'fa': u':اِلف_مرد_پوست_روشن:',
        'id': ':kurcaci_pria_warna_kulit_cerah-sedang:',
        'zh': u':男小精灵_中等浅肤色:'
    },
    u'\U0001F9DD\U0001F3FC\U0000200D\U00002642': { # 🧝🏼‍♂
        'en' : ':man_elf_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elf_mittelhelle_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_claro_medio:',
        'fr': ':elfe_homme_peau_moyennement_claire:',
        'ja': u':男のエルフ_やや薄い肌色:',
        'ko': u':남자_엘프_연한_갈색_피부:',
        'pt': ':elfo_homem_pele_morena_clara:',
        'it': ':elfo_uomo_carnagione_abbastanza_chiara:',
        'fa': u':اِلف_مرد_پوست_روشن:',
        'id': ':kurcaci_pria_warna_kulit_cerah-sedang:',
        'zh': u':男小精灵_中等浅肤色:'
    },
    u'\U0001F9DD\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧝🏽‍♂️
        'en' : ':man_elf_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elf_mittlere_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_medio:',
        'fr': u':elfe_homme_peau_légèrement_mate:',
        'ja': u':男のエルフ_中間の肌色:',
        'ko': u':남자_엘프_갈색_피부:',
        'pt': ':elfo_homem_pele_morena:',
        'it': ':elfo_uomo_carnagione_olivastra:',
        'fa': u':اِلف_مرد_پوست_طلایی:',
        'id': ':kurcaci_pria_warna_kulit_sedang:',
        'zh': u':男小精灵_中等肤色:'
    },
    u'\U0001F9DD\U0001F3FD\U0000200D\U00002642': { # 🧝🏽‍♂
        'en' : ':man_elf_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elf_mittlere_hautfarbe:',
        'es': ':elfo_hombre_tono_de_piel_medio:',
        'fr': u':elfe_homme_peau_légèrement_mate:',
        'ja': u':男のエルフ_中間の肌色:',
        'ko': u':남자_엘프_갈색_피부:',
        'pt': ':elfo_homem_pele_morena:',
        'it': ':elfo_uomo_carnagione_olivastra:',
        'fa': u':اِلف_مرد_پوست_طلایی:',
        'id': ':kurcaci_pria_warna_kulit_sedang:',
        'zh': u':男小精灵_中等肤色:'
    },
    u'\U0001F926\U0000200D\U00002642\U0000FE0F': { # 🤦‍♂️
        'en' : ':man_facepalming:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann:',
        'es': ':hombre_con_la_mano_en_la_frente:',
        'fr': ':homme_avec_la_paume_sur_le_visage:',
        'ja': u':ひたいに手をあてる男:',
        'ko': u':골치_아파하는_남자:',
        'pt': ':homem_decepcionado:',
        'it': ':uomo_esasperato:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند:',
        'id': ':pria_tepuk_jidat:',
        'zh': u':男生捂脸:'
    },
    u'\U0001F926\U0000200D\U00002642': { # 🤦‍♂
        'en' : ':man_facepalming:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann:',
        'es': ':hombre_con_la_mano_en_la_frente:',
        'fr': ':homme_avec_la_paume_sur_le_visage:',
        'ja': u':ひたいに手をあてる男:',
        'ko': u':골치_아파하는_남자:',
        'pt': ':homem_decepcionado:',
        'it': ':uomo_esasperato:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند:',
        'id': ':pria_tepuk_jidat:',
        'zh': u':男生捂脸:'
    },
    u'\U0001F926\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🤦🏿‍♂️
        'en' : ':man_facepalming_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_dunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_oscuro:',
        'fr': u':homme_avec_la_paume_sur_le_visage_peau_foncée:',
        'ja': u':ひたいに手をあてる男_濃い肌色:',
        'ko': u':골치_아파하는_남자_검은색_피부:',
        'pt': ':homem_decepcionado_pele_escura:',
        'it': ':uomo_esasperato_carnagione_scura:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_آبنوسی:',
        'id': ':pria_tepuk_jidat_warna_kulit_gelap:',
        'zh': u':男生捂脸_较深肤色:'
    },
    u'\U0001F926\U0001F3FF\U0000200D\U00002642': { # 🤦🏿‍♂
        'en' : ':man_facepalming_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_dunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_oscuro:',
        'fr': u':homme_avec_la_paume_sur_le_visage_peau_foncée:',
        'ja': u':ひたいに手をあてる男_濃い肌色:',
        'ko': u':골치_아파하는_남자_검은색_피부:',
        'pt': ':homem_decepcionado_pele_escura:',
        'it': ':uomo_esasperato_carnagione_scura:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_آبنوسی:',
        'id': ':pria_tepuk_jidat_warna_kulit_gelap:',
        'zh': u':男生捂脸_较深肤色:'
    },
    u'\U0001F926\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🤦🏻‍♂️
        'en' : ':man_facepalming_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_helle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_claro:',
        'fr': ':homme_avec_la_paume_sur_le_visage_peau_claire:',
        'ja': u':ひたいに手をあてる男_薄い肌色:',
        'ko': u':골치_아파하는_남자_하얀_피부:',
        'pt': ':homem_decepcionado_pele_clara:',
        'it': ':uomo_esasperato_carnagione_chiara:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_سفید:',
        'id': ':pria_tepuk_jidat_warna_kulit_cerah:',
        'zh': u':男生捂脸_较浅肤色:'
    },
    u'\U0001F926\U0001F3FB\U0000200D\U00002642': { # 🤦🏻‍♂
        'en' : ':man_facepalming_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_helle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_claro:',
        'fr': ':homme_avec_la_paume_sur_le_visage_peau_claire:',
        'ja': u':ひたいに手をあてる男_薄い肌色:',
        'ko': u':골치_아파하는_남자_하얀_피부:',
        'pt': ':homem_decepcionado_pele_clara:',
        'it': ':uomo_esasperato_carnagione_chiara:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_سفید:',
        'id': ':pria_tepuk_jidat_warna_kulit_cerah:',
        'zh': u':男生捂脸_较浅肤色:'
    },
    u'\U0001F926\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🤦🏾‍♂️
        'en' : ':man_facepalming_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_la_paume_sur_le_visage_peau_mate:',
        'ja': u':ひたいに手をあてる男_やや濃い肌色:',
        'ko': u':골치_아파하는_남자_진한_갈색_피부:',
        'pt': ':homem_decepcionado_pele_morena_escura:',
        'it': ':uomo_esasperato_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_گندمی:',
        'id': ':pria_tepuk_jidat_warna_kulit_gelap-sedang:',
        'zh': u':男生捂脸_中等深肤色:'
    },
    u'\U0001F926\U0001F3FE\U0000200D\U00002642': { # 🤦🏾‍♂
        'en' : ':man_facepalming_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_la_paume_sur_le_visage_peau_mate:',
        'ja': u':ひたいに手をあてる男_やや濃い肌色:',
        'ko': u':골치_아파하는_남자_진한_갈색_피부:',
        'pt': ':homem_decepcionado_pele_morena_escura:',
        'it': ':uomo_esasperato_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_گندمی:',
        'id': ':pria_tepuk_jidat_warna_kulit_gelap-sedang:',
        'zh': u':男生捂脸_中等深肤色:'
    },
    u'\U0001F926\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🤦🏼‍♂️
        'en' : ':man_facepalming_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_la_paume_sur_le_visage_peau_moyennement_claire:',
        'ja': u':ひたいに手をあてる男_やや薄い肌色:',
        'ko': u':골치_아파하는_남자_연한_갈색_피부:',
        'pt': ':homem_decepcionado_pele_morena_clara:',
        'it': ':uomo_esasperato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_روشن:',
        'id': ':pria_tepuk_jidat_warna_kulit_cerah-sedang:',
        'zh': u':男生捂脸_中等浅肤色:'
    },
    u'\U0001F926\U0001F3FC\U0000200D\U00002642': { # 🤦🏼‍♂
        'en' : ':man_facepalming_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_la_paume_sur_le_visage_peau_moyennement_claire:',
        'ja': u':ひたいに手をあてる男_やや薄い肌色:',
        'ko': u':골치_아파하는_남자_연한_갈색_피부:',
        'pt': ':homem_decepcionado_pele_morena_clara:',
        'it': ':uomo_esasperato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_روشن:',
        'id': ':pria_tepuk_jidat_warna_kulit_cerah-sedang:',
        'zh': u':男生捂脸_中等浅肤色:'
    },
    u'\U0001F926\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🤦🏽‍♂️
        'en' : ':man_facepalming_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_mittlere_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_medio:',
        'fr': u':homme_avec_la_paume_sur_le_visage_peau_légèrement_mate:',
        'ja': u':ひたいに手をあてる男_中間の肌色:',
        'ko': u':골치_아파하는_남자_갈색_피부:',
        'pt': ':homem_decepcionado_pele_morena:',
        'it': ':uomo_esasperato_carnagione_olivastra:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_طلایی:',
        'id': ':pria_tepuk_jidat_warna_kulit_sedang:',
        'zh': u':男生捂脸_中等肤色:'
    },
    u'\U0001F926\U0001F3FD\U0000200D\U00002642': { # 🤦🏽‍♂
        'en' : ':man_facepalming_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassender_mann_mittlere_hautfarbe:',
        'es': ':hombre_con_la_mano_en_la_frente_tono_de_piel_medio:',
        'fr': u':homme_avec_la_paume_sur_le_visage_peau_légèrement_mate:',
        'ja': u':ひたいに手をあてる男_中間の肌色:',
        'ko': u':골치_아파하는_남자_갈색_피부:',
        'pt': ':homem_decepcionado_pele_morena:',
        'it': ':uomo_esasperato_carnagione_olivastra:',
        'fa': u':مرد_با_کف_دست_به_پیشانی_می_زند_پوست_طلایی:',
        'id': ':pria_tepuk_jidat_warna_kulit_sedang:',
        'zh': u':男生捂脸_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F3ED': { # 👨‍🏭
        'en' : ':man_factory_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiter:',
        'es': ':profesional_industrial_hombre:',
        'fr': ':ouvrier:',
        'ja': u':男性の溶接工:',
        'ko': u':공장_남자_직원:',
        'pt': u':operário:',
        'it': ':operaio:',
        'fa': u':کارگر_کارخانه_مرد:',
        'id': ':pekerja_pabrik_pria:',
        'zh': u':男工人:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F3ED': { # 👨🏿‍🏭
        'en' : ':man_factory_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiter_dunkle_hautfarbe:',
        'es': ':profesional_industrial_hombre_tono_de_piel_oscuro:',
        'fr': u':ouvrier_peau_foncée:',
        'ja': u':男性の溶接工_濃い肌色:',
        'ko': u':공장_남자_직원_검은색_피부:',
        'pt': u':operário_pele_escura:',
        'it': ':operaio_carnagione_scura:',
        'fa': u':کارگر_کارخانه_مرد_پوست_آبنوسی:',
        'id': ':pekerja_pabrik_pria_warna_kulit_gelap:',
        'zh': u':男工人_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F3ED': { # 👨🏻‍🏭
        'en' : ':man_factory_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiter_helle_hautfarbe:',
        'es': ':profesional_industrial_hombre_tono_de_piel_claro:',
        'fr': ':ouvrier_peau_claire:',
        'ja': u':男性の溶接工_薄い肌色:',
        'ko': u':공장_남자_직원_하얀_피부:',
        'pt': u':operário_pele_clara:',
        'it': ':operaio_carnagione_chiara:',
        'fa': u':کارگر_کارخانه_مرد_پوست_سفید:',
        'id': ':pekerja_pabrik_pria_warna_kulit_cerah:',
        'zh': u':男工人_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F3ED': { # 👨🏾‍🏭
        'en' : ':man_factory_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiter_mitteldunkle_hautfarbe:',
        'es': ':profesional_industrial_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':ouvrier_peau_mate:',
        'ja': u':男性の溶接工_やや濃い肌色:',
        'ko': u':공장_남자_직원_진한_갈색_피부:',
        'pt': u':operário_pele_morena_escura:',
        'it': ':operaio_carnagione_abbastanza_scura:',
        'fa': u':کارگر_کارخانه_مرد_پوست_گندمی:',
        'id': ':pekerja_pabrik_pria_warna_kulit_gelap-sedang:',
        'zh': u':男工人_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F3ED': { # 👨🏼‍🏭
        'en' : ':man_factory_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiter_mittelhelle_hautfarbe:',
        'es': ':profesional_industrial_hombre_tono_de_piel_claro_medio:',
        'fr': ':ouvrier_peau_moyennement_claire:',
        'ja': u':男性の溶接工_やや薄い肌色:',
        'ko': u':공장_남자_직원_연한_갈색_피부:',
        'pt': u':operário_pele_morena_clara:',
        'it': ':operaio_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_کارخانه_مرد_پوست_روشن:',
        'id': ':pekerja_pabrik_pria_warna_kulit_cerah-sedang:',
        'zh': u':男工人_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F3ED': { # 👨🏽‍🏭
        'en' : ':man_factory_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiter_mittlere_hautfarbe:',
        'es': ':profesional_industrial_hombre_tono_de_piel_medio:',
        'fr': u':ouvrier_peau_légèrement_mate:',
        'ja': u':男性の溶接工_中間の肌色:',
        'ko': u':공장_남자_직원_갈색_피부:',
        'pt': u':operário_pele_morena:',
        'it': ':operaio_carnagione_olivastra:',
        'fa': u':کارگر_کارخانه_مرد_پوست_طلایی:',
        'id': ':pekerja_pabrik_pria_warna_kulit_sedang:',
        'zh': u':男工人_中等肤色:'
    },
    u'\U0001F9DA\U0000200D\U00002642\U0000FE0F': { # 🧚‍♂️
        'en' : ':man_fairy:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':fairy_man:'],
        'de': u':männliche_fee:',
        'es': ':hada_hombre:',
        'fr': u':féetaud:',
        'ja': u':男の妖精:',
        'ko': u':남자_요정:',
        'pt': ':homem_fada:',
        'it': ':folletto_alato:',
        'fa': u':پری_مرد:',
        'id': ':peri_pria:',
        'zh': u':仙人:'
    },
    u'\U0001F9DA\U0000200D\U00002642': { # 🧚‍♂
        'en' : ':man_fairy:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':fairy_man:'],
        'de': u':männliche_fee:',
        'es': ':hada_hombre:',
        'fr': u':féetaud:',
        'ja': u':男の妖精:',
        'ko': u':남자_요정:',
        'pt': ':homem_fada:',
        'it': ':folletto_alato:',
        'fa': u':پری_مرد:',
        'id': ':peri_pria:',
        'zh': u':仙人:'
    },
    u'\U0001F9DA\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧚🏿‍♂️
        'en' : ':man_fairy_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männliche_fee_dunkle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_oscuro:',
        'fr': u':féetaud_peau_foncée:',
        'ja': u':男の妖精_濃い肌色:',
        'ko': u':남자_요정_검은색_피부:',
        'pt': ':homem_fada_pele_escura:',
        'it': ':folletto_alato_carnagione_scura:',
        'fa': u':پری_مرد_پوست_آبنوسی:',
        'id': ':peri_pria_warna_kulit_gelap:',
        'zh': u':仙人_较深肤色:'
    },
    u'\U0001F9DA\U0001F3FF\U0000200D\U00002642': { # 🧚🏿‍♂
        'en' : ':man_fairy_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männliche_fee_dunkle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_oscuro:',
        'fr': u':féetaud_peau_foncée:',
        'ja': u':男の妖精_濃い肌色:',
        'ko': u':남자_요정_검은색_피부:',
        'pt': ':homem_fada_pele_escura:',
        'it': ':folletto_alato_carnagione_scura:',
        'fa': u':پری_مرد_پوست_آبنوسی:',
        'id': ':peri_pria_warna_kulit_gelap:',
        'zh': u':仙人_较深肤色:'
    },
    u'\U0001F9DA\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧚🏻‍♂️
        'en' : ':man_fairy_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männliche_fee_helle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_claro:',
        'fr': u':féetaud_peau_claire:',
        'ja': u':男の妖精_薄い肌色:',
        'ko': u':남자_요정_하얀_피부:',
        'pt': ':homem_fada_pele_clara:',
        'it': ':folletto_alato_carnagione_chiara:',
        'fa': u':پری_مرد_پوست_سفید:',
        'id': ':peri_pria_warna_kulit_cerah:',
        'zh': u':仙人_较浅肤色:'
    },
    u'\U0001F9DA\U0001F3FB\U0000200D\U00002642': { # 🧚🏻‍♂
        'en' : ':man_fairy_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männliche_fee_helle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_claro:',
        'fr': u':féetaud_peau_claire:',
        'ja': u':男の妖精_薄い肌色:',
        'ko': u':남자_요정_하얀_피부:',
        'pt': ':homem_fada_pele_clara:',
        'it': ':folletto_alato_carnagione_chiara:',
        'fa': u':پری_مرد_پوست_سفید:',
        'id': ':peri_pria_warna_kulit_cerah:',
        'zh': u':仙人_较浅肤色:'
    },
    u'\U0001F9DA\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧚🏾‍♂️
        'en' : ':man_fairy_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männliche_fee_mitteldunkle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':féetaud_peau_mate:',
        'ja': u':男の妖精_やや濃い肌色:',
        'ko': u':남자_요정_진한_갈색_피부:',
        'pt': ':homem_fada_pele_morena_escura:',
        'it': ':folletto_alato_carnagione_abbastanza_scura:',
        'fa': u':پری_مرد_پوست_گندمی:',
        'id': ':peri_pria_warna_kulit_gelap-sedang:',
        'zh': u':仙人_中等深肤色:'
    },
    u'\U0001F9DA\U0001F3FE\U0000200D\U00002642': { # 🧚🏾‍♂
        'en' : ':man_fairy_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männliche_fee_mitteldunkle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':féetaud_peau_mate:',
        'ja': u':男の妖精_やや濃い肌色:',
        'ko': u':남자_요정_진한_갈색_피부:',
        'pt': ':homem_fada_pele_morena_escura:',
        'it': ':folletto_alato_carnagione_abbastanza_scura:',
        'fa': u':پری_مرد_پوست_گندمی:',
        'id': ':peri_pria_warna_kulit_gelap-sedang:',
        'zh': u':仙人_中等深肤色:'
    },
    u'\U0001F9DA\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧚🏼‍♂️
        'en' : ':man_fairy_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männliche_fee_mittelhelle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_claro_medio:',
        'fr': u':féetaud_peau_moyennement_claire:',
        'ja': u':男の妖精_やや薄い肌色:',
        'ko': u':남자_요정_연한_갈색_피부:',
        'pt': ':homem_fada_pele_morena_clara:',
        'it': ':folletto_alato_carnagione_abbastanza_chiara:',
        'fa': u':پری_مرد_پوست_روشن:',
        'id': ':peri_pria_warna_kulit_cerah-sedang:',
        'zh': u':仙人_中等浅肤色:'
    },
    u'\U0001F9DA\U0001F3FC\U0000200D\U00002642': { # 🧚🏼‍♂
        'en' : ':man_fairy_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männliche_fee_mittelhelle_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_claro_medio:',
        'fr': u':féetaud_peau_moyennement_claire:',
        'ja': u':男の妖精_やや薄い肌色:',
        'ko': u':남자_요정_연한_갈색_피부:',
        'pt': ':homem_fada_pele_morena_clara:',
        'it': ':folletto_alato_carnagione_abbastanza_chiara:',
        'fa': u':پری_مرد_پوست_روشن:',
        'id': ':peri_pria_warna_kulit_cerah-sedang:',
        'zh': u':仙人_中等浅肤色:'
    },
    u'\U0001F9DA\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧚🏽‍♂️
        'en' : ':man_fairy_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männliche_fee_mittlere_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_medio:',
        'fr': u':féetaud_peau_légèrement_mate:',
        'ja': u':男の妖精_中間の肌色:',
        'ko': u':남자_요정_갈색_피부:',
        'pt': ':homem_fada_pele_morena:',
        'it': ':folletto_alato_carnagione_olivastra:',
        'fa': u':پری_مرد_پوست_طلایی:',
        'id': ':peri_pria_warna_kulit_sedang:',
        'zh': u':仙人_中等肤色:'
    },
    u'\U0001F9DA\U0001F3FD\U0000200D\U00002642': { # 🧚🏽‍♂
        'en' : ':man_fairy_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männliche_fee_mittlere_hautfarbe:',
        'es': ':hada_hombre_tono_de_piel_medio:',
        'fr': u':féetaud_peau_légèrement_mate:',
        'ja': u':男の妖精_中間の肌色:',
        'ko': u':남자_요정_갈색_피부:',
        'pt': ':homem_fada_pele_morena:',
        'it': ':folletto_alato_carnagione_olivastra:',
        'fa': u':پری_مرد_پوست_طلایی:',
        'id': ':peri_pria_warna_kulit_sedang:',
        'zh': u':仙人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F33E': { # 👨‍🌾
        'en' : ':man_farmer:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauer:',
        'es': ':profesional_de_la_agricultura_hombre:',
        'fr': ':fermier:',
        'ja': u':農家の男性:',
        'ko': u':남자_농부:',
        'pt': ':fazendeiro:',
        'it': ':contadino:',
        'fa': u':کشاورز_مرد:',
        'id': ':petani_pria:',
        'zh': u':农夫:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F33E': { # 👨🏿‍🌾
        'en' : ':man_farmer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauer_dunkle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_hombre_tono_de_piel_oscuro:',
        'fr': u':fermier_peau_foncée:',
        'ja': u':農家の男性_濃い肌色:',
        'ko': u':남자_농부_검은색_피부:',
        'pt': ':fazendeiro_pele_escura:',
        'it': ':contadino_carnagione_scura:',
        'fa': u':کشاورز_مرد_پوست_آبنوسی:',
        'id': ':petani_pria_warna_kulit_gelap:',
        'zh': u':农夫_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F33E': { # 👨🏻‍🌾
        'en' : ':man_farmer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauer_helle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_hombre_tono_de_piel_claro:',
        'fr': ':fermier_peau_claire:',
        'ja': u':農家の男性_薄い肌色:',
        'ko': u':남자_농부_하얀_피부:',
        'pt': ':fazendeiro_pele_clara:',
        'it': ':contadino_carnagione_chiara:',
        'fa': u':کشاورز_مرد_پوست_سفید:',
        'id': ':petani_pria_warna_kulit_cerah:',
        'zh': u':农夫_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F33E': { # 👨🏾‍🌾
        'en' : ':man_farmer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauer_mitteldunkle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':fermier_peau_mate:',
        'ja': u':農家の男性_やや濃い肌色:',
        'ko': u':남자_농부_진한_갈색_피부:',
        'pt': ':fazendeiro_pele_morena_escura:',
        'it': ':contadino_carnagione_abbastanza_scura:',
        'fa': u':کشاورز_مرد_پوست_گندمی:',
        'id': ':petani_pria_warna_kulit_gelap-sedang:',
        'zh': u':农夫_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F33E': { # 👨🏼‍🌾
        'en' : ':man_farmer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauer_mittelhelle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_hombre_tono_de_piel_claro_medio:',
        'fr': ':fermier_peau_moyennement_claire:',
        'ja': u':農家の男性_やや薄い肌色:',
        'ko': u':남자_농부_연한_갈색_피부:',
        'pt': ':fazendeiro_pele_morena_clara:',
        'it': ':contadino_carnagione_abbastanza_chiara:',
        'fa': u':کشاورز_مرد_پوست_روشن:',
        'id': ':petani_pria_warna_kulit_cerah-sedang:',
        'zh': u':农夫_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F33E': { # 👨🏽‍🌾
        'en' : ':man_farmer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauer_mittlere_hautfarbe:',
        'es': ':profesional_de_la_agricultura_hombre_tono_de_piel_medio:',
        'fr': u':fermier_peau_légèrement_mate:',
        'ja': u':農家の男性_中間の肌色:',
        'ko': u':남자_농부_갈색_피부:',
        'pt': ':fazendeiro_pele_morena:',
        'it': ':contadino_carnagione_olivastra:',
        'fa': u':کشاورز_مرد_پوست_طلایی:',
        'id': ':petani_pria_warna_kulit_sedang:',
        'zh': u':农夫_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F37C': { # 👨‍🍼
        'en' : ':man_feeding_baby:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillender_mann:',
        'es': u':hombre_alimentando_a_bebé:',
        'fr': u':homme_allaitant_un_bébé:',
        'ja': u':授乳する男性:',
        'ko': u':수유_중인_남자:',
        'pt': u':homem_alimentando_bebê:',
        'it': ':uomo_che_allatta:',
        'fa': u':مردی_که_به_بچه_شیر_می_دهد:',
        'id': ':pria_menyusui_bayi:',
        'zh': u':哺乳的男人:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F37C': { # 👨🏿‍🍼
        'en' : ':man_feeding_baby_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillender_mann_dunkle_hautfarbe:',
        'es': u':hombre_alimentando_a_bebé_tono_de_piel_oscuro:',
        'fr': u':homme_allaitant_un_bébé_peau_foncée:',
        'ja': u':授乳する男性_濃い肌色:',
        'ko': u':수유_중인_남자_검은색_피부:',
        'pt': u':homem_alimentando_bebê_pele_escura:',
        'it': ':uomo_che_allatta_carnagione_scura:',
        'fa': u':مردی_که_به_بچه_شیر_می_دهد_پوست_آبنوسی:',
        'id': ':pria_menyusui_bayi_warna_kulit_gelap:',
        'zh': u':哺乳的男人_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F37C': { # 👨🏻‍🍼
        'en' : ':man_feeding_baby_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillender_mann_helle_hautfarbe:',
        'es': u':hombre_alimentando_a_bebé_tono_de_piel_claro:',
        'fr': u':homme_allaitant_un_bébé_peau_claire:',
        'ja': u':授乳する男性_薄い肌色:',
        'ko': u':수유_중인_남자_하얀_피부:',
        'pt': u':homem_alimentando_bebê_pele_clara:',
        'it': ':uomo_che_allatta_carnagione_chiara:',
        'fa': u':مردی_که_به_بچه_شیر_می_دهد_پوست_سفید:',
        'id': ':pria_menyusui_bayi_warna_kulit_cerah:',
        'zh': u':哺乳的男人_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F37C': { # 👨🏾‍🍼
        'en' : ':man_feeding_baby_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillender_mann_mitteldunkle_hautfarbe:',
        'es': u':hombre_alimentando_a_bebé_tono_de_piel_oscuro_medio:',
        'fr': u':homme_allaitant_un_bébé_peau_mate:',
        'ja': u':授乳する男性_やや濃い肌色:',
        'ko': u':수유_중인_남자_진한_갈색_피부:',
        'pt': u':homem_alimentando_bebê_pele_morena_escura:',
        'it': ':uomo_che_allatta_carnagione_abbastanza_scura:',
        'fa': u':مردی_که_به_بچه_شیر_می_دهد_پوست_گندمی:',
        'id': ':pria_menyusui_bayi_warna_kulit_gelap-sedang:',
        'zh': u':哺乳的男人_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F37C': { # 👨🏼‍🍼
        'en' : ':man_feeding_baby_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillender_mann_mittelhelle_hautfarbe:',
        'es': u':hombre_alimentando_a_bebé_tono_de_piel_claro_medio:',
        'fr': u':homme_allaitant_un_bébé_peau_moyennement_claire:',
        'ja': u':授乳する男性_やや薄い肌色:',
        'ko': u':수유_중인_남자_연한_갈색_피부:',
        'pt': u':homem_alimentando_bebê_pele_morena_clara:',
        'it': ':uomo_che_allatta_carnagione_abbastanza_chiara:',
        'fa': u':مردی_که_به_بچه_شیر_می_دهد_پوست_روشن:',
        'id': ':pria_menyusui_bayi_warna_kulit_cerah-sedang:',
        'zh': u':哺乳的男人_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F37C': { # 👨🏽‍🍼
        'en' : ':man_feeding_baby_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillender_mann_mittlere_hautfarbe:',
        'es': u':hombre_alimentando_a_bebé_tono_de_piel_medio:',
        'fr': u':homme_allaitant_un_bébé_peau_légèrement_mate:',
        'ja': u':授乳する男性_中間の肌色:',
        'ko': u':수유_중인_남자_갈색_피부:',
        'pt': u':homem_alimentando_bebê_pele_morena:',
        'it': ':uomo_che_allatta_carnagione_olivastra:',
        'fa': u':مردی_که_به_بچه_شیر_می_دهد_پوست_طلایی:',
        'id': ':pria_menyusui_bayi_warna_kulit_sedang:',
        'zh': u':哺乳的男人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F692': { # 👨‍🚒
        'en' : ':man_firefighter:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrmann:',
        'es': ':bombero_hombre:',
        'fr': ':pompier_homme:',
        'ja': u':男性消防士:',
        'ko': u':남자_소방관:',
        'pt': ':bombeiro_homem:',
        'it': ':pompiere_uomo:',
        'fa': u':آتش_نشان_مرد:',
        'id': ':pemadam_kebakaran_pria:',
        'zh': u':男消防员:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F692': { # 👨🏿‍🚒
        'en' : ':man_firefighter_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrmann_dunkle_hautfarbe:',
        'es': ':bombero_hombre_tono_de_piel_oscuro:',
        'fr': u':pompier_homme_peau_foncée:',
        'ja': u':男性消防士_濃い肌色:',
        'ko': u':남자_소방관_검은색_피부:',
        'pt': ':bombeiro_homem_pele_escura:',
        'it': ':pompiere_uomo_carnagione_scura:',
        'fa': u':آتش_نشان_مرد_پوست_آبنوسی:',
        'id': ':pemadam_kebakaran_pria_warna_kulit_gelap:',
        'zh': u':男消防员_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F692': { # 👨🏻‍🚒
        'en' : ':man_firefighter_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrmann_helle_hautfarbe:',
        'es': ':bombero_hombre_tono_de_piel_claro:',
        'fr': ':pompier_homme_peau_claire:',
        'ja': u':男性消防士_薄い肌色:',
        'ko': u':남자_소방관_하얀_피부:',
        'pt': ':bombeiro_homem_pele_clara:',
        'it': ':pompiere_uomo_carnagione_chiara:',
        'fa': u':آتش_نشان_مرد_پوست_سفید:',
        'id': ':pemadam_kebakaran_pria_warna_kulit_cerah:',
        'zh': u':男消防员_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F692': { # 👨🏾‍🚒
        'en' : ':man_firefighter_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrmann_mitteldunkle_hautfarbe:',
        'es': ':bombero_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':pompier_homme_peau_mate:',
        'ja': u':男性消防士_やや濃い肌色:',
        'ko': u':남자_소방관_진한_갈색_피부:',
        'pt': ':bombeiro_homem_pele_morena_escura:',
        'it': ':pompiere_uomo_carnagione_abbastanza_scura:',
        'fa': u':آتش_نشان_مرد_پوست_گندمی:',
        'id': ':pemadam_kebakaran_pria_warna_kulit_gelap-sedang:',
        'zh': u':男消防员_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F692': { # 👨🏼‍🚒
        'en' : ':man_firefighter_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrmann_mittelhelle_hautfarbe:',
        'es': ':bombero_hombre_tono_de_piel_claro_medio:',
        'fr': ':pompier_homme_peau_moyennement_claire:',
        'ja': u':男性消防士_やや薄い肌色:',
        'ko': u':남자_소방관_연한_갈색_피부:',
        'pt': ':bombeiro_homem_pele_morena_clara:',
        'it': ':pompiere_uomo_carnagione_abbastanza_chiara:',
        'fa': u':آتش_نشان_مرد_پوست_روشن:',
        'id': ':pemadam_kebakaran_pria_warna_kulit_cerah-sedang:',
        'zh': u':男消防员_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F692': { # 👨🏽‍🚒
        'en' : ':man_firefighter_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrmann_mittlere_hautfarbe:',
        'es': ':bombero_hombre_tono_de_piel_medio:',
        'fr': u':pompier_homme_peau_légèrement_mate:',
        'ja': u':男性消防士_中間の肌色:',
        'ko': u':남자_소방관_갈색_피부:',
        'pt': ':bombeiro_homem_pele_morena:',
        'it': ':pompiere_uomo_carnagione_olivastra:',
        'fa': u':آتش_نشان_مرد_پوست_طلایی:',
        'id': ':pemadam_kebakaran_pria_warna_kulit_sedang:',
        'zh': u':男消防员_中等肤色:'
    },
    u'\U0001F64D\U0000200D\U00002642\U0000FE0F': { # 🙍‍♂️
        'en' : ':man_frowning:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':frowning_man:'],
        'de': ':missmutiger_mann:',
        'es': u':hombre_frunciendo_el_ceño:',
        'fr': u':homme_fronçant_les_sourcils:',
        'ja': u':しかめ面の男:',
        'ko': u':찌푸린_남자:',
        'pt': ':homem_franzindo_a_sobrancelha:',
        'it': ':uomo_corrucciato:',
        'fa': u':مرد_اخم_می_کند:',
        'id': ':pria_muka_tidak_senang:',
        'zh': u':皱眉男:'
    },
    u'\U0001F64D\U0000200D\U00002642': { # 🙍‍♂
        'en' : ':man_frowning:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':frowning_man:'],
        'de': ':missmutiger_mann:',
        'es': u':hombre_frunciendo_el_ceño:',
        'fr': u':homme_fronçant_les_sourcils:',
        'ja': u':しかめ面の男:',
        'ko': u':찌푸린_남자:',
        'pt': ':homem_franzindo_a_sobrancelha:',
        'it': ':uomo_corrucciato:',
        'fa': u':مرد_اخم_می_کند:',
        'id': ':pria_muka_tidak_senang:',
        'zh': u':皱眉男:'
    },
    u'\U0001F64D\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🙍🏿‍♂️
        'en' : ':man_frowning_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_dunkle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_oscuro:',
        'fr': u':homme_fronçant_les_sourcils_peau_foncée:',
        'ja': u':しかめ面の男_濃い肌色:',
        'ko': u':찌푸린_남자_검은색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_escura:',
        'it': ':uomo_corrucciato_carnagione_scura:',
        'fa': u':مرد_اخم_می_کند_پوست_آبنوسی:',
        'id': ':pria_muka_tidak_senang_warna_kulit_gelap:',
        'zh': u':皱眉男_较深肤色:'
    },
    u'\U0001F64D\U0001F3FF\U0000200D\U00002642': { # 🙍🏿‍♂
        'en' : ':man_frowning_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_dunkle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_oscuro:',
        'fr': u':homme_fronçant_les_sourcils_peau_foncée:',
        'ja': u':しかめ面の男_濃い肌色:',
        'ko': u':찌푸린_남자_검은색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_escura:',
        'it': ':uomo_corrucciato_carnagione_scura:',
        'fa': u':مرد_اخم_می_کند_پوست_آبنوسی:',
        'id': ':pria_muka_tidak_senang_warna_kulit_gelap:',
        'zh': u':皱眉男_较深肤色:'
    },
    u'\U0001F64D\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🙍🏻‍♂️
        'en' : ':man_frowning_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_helle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_claro:',
        'fr': u':homme_fronçant_les_sourcils_peau_claire:',
        'ja': u':しかめ面の男_薄い肌色:',
        'ko': u':찌푸린_남자_하얀_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_clara:',
        'it': ':uomo_corrucciato_carnagione_chiara:',
        'fa': u':مرد_اخم_می_کند_پوست_سفید:',
        'id': ':pria_muka_tidak_senang_warna_kulit_cerah:',
        'zh': u':皱眉男_较浅肤色:'
    },
    u'\U0001F64D\U0001F3FB\U0000200D\U00002642': { # 🙍🏻‍♂
        'en' : ':man_frowning_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_helle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_claro:',
        'fr': u':homme_fronçant_les_sourcils_peau_claire:',
        'ja': u':しかめ面の男_薄い肌色:',
        'ko': u':찌푸린_남자_하얀_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_clara:',
        'it': ':uomo_corrucciato_carnagione_chiara:',
        'fa': u':مرد_اخم_می_کند_پوست_سفید:',
        'id': ':pria_muka_tidak_senang_warna_kulit_cerah:',
        'zh': u':皱眉男_较浅肤色:'
    },
    u'\U0001F64D\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🙍🏾‍♂️
        'en' : ':man_frowning_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_mitteldunkle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_oscuro_medio:',
        'fr': u':homme_fronçant_les_sourcils_peau_mate:',
        'ja': u':しかめ面の男_やや濃い肌色:',
        'ko': u':찌푸린_남자_진한_갈색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_morena_escura:',
        'it': ':uomo_corrucciato_carnagione_abbastanza_scura:',
        'fa': u':مرد_اخم_می_کند_پوست_گندمی:',
        'id': ':pria_muka_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':皱眉男_中等深肤色:'
    },
    u'\U0001F64D\U0001F3FE\U0000200D\U00002642': { # 🙍🏾‍♂
        'en' : ':man_frowning_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_mitteldunkle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_oscuro_medio:',
        'fr': u':homme_fronçant_les_sourcils_peau_mate:',
        'ja': u':しかめ面の男_やや濃い肌色:',
        'ko': u':찌푸린_남자_진한_갈색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_morena_escura:',
        'it': ':uomo_corrucciato_carnagione_abbastanza_scura:',
        'fa': u':مرد_اخم_می_کند_پوست_گندمی:',
        'id': ':pria_muka_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':皱眉男_中等深肤色:'
    },
    u'\U0001F64D\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🙍🏼‍♂️
        'en' : ':man_frowning_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_mittelhelle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_claro_medio:',
        'fr': u':homme_fronçant_les_sourcils_peau_moyennement_claire:',
        'ja': u':しかめ面の男_やや薄い肌色:',
        'ko': u':찌푸린_남자_연한_갈색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_morena_clara:',
        'it': ':uomo_corrucciato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_اخم_می_کند_پوست_روشن:',
        'id': ':pria_muka_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':皱眉男_中等浅肤色:'
    },
    u'\U0001F64D\U0001F3FC\U0000200D\U00002642': { # 🙍🏼‍♂
        'en' : ':man_frowning_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_mittelhelle_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_claro_medio:',
        'fr': u':homme_fronçant_les_sourcils_peau_moyennement_claire:',
        'ja': u':しかめ面の男_やや薄い肌色:',
        'ko': u':찌푸린_남자_연한_갈색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_morena_clara:',
        'it': ':uomo_corrucciato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_اخم_می_کند_پوست_روشن:',
        'id': ':pria_muka_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':皱眉男_中等浅肤色:'
    },
    u'\U0001F64D\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🙍🏽‍♂️
        'en' : ':man_frowning_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_mittlere_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_medio:',
        'fr': u':homme_fronçant_les_sourcils_peau_légèrement_mate:',
        'ja': u':しかめ面の男_中間の肌色:',
        'ko': u':찌푸린_남자_갈색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_morena:',
        'it': ':uomo_corrucciato_carnagione_olivastra:',
        'fa': u':مرد_اخم_می_کند_پوست_طلایی:',
        'id': ':pria_muka_tidak_senang_warna_kulit_sedang:',
        'zh': u':皱眉男_中等肤色:'
    },
    u'\U0001F64D\U0001F3FD\U0000200D\U00002642': { # 🙍🏽‍♂
        'en' : ':man_frowning_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutiger_mann_mittlere_hautfarbe:',
        'es': u':hombre_frunciendo_el_ceño_tono_de_piel_medio:',
        'fr': u':homme_fronçant_les_sourcils_peau_légèrement_mate:',
        'ja': u':しかめ面の男_中間の肌色:',
        'ko': u':찌푸린_남자_갈색_피부:',
        'pt': ':homem_franzindo_a_sobrancelha_pele_morena:',
        'it': ':uomo_corrucciato_carnagione_olivastra:',
        'fa': u':مرد_اخم_می_کند_پوست_طلایی:',
        'id': ':pria_muka_tidak_senang_warna_kulit_sedang:',
        'zh': u':皱眉男_中等肤色:'
    },
    u'\U0001F9DE\U0000200D\U00002642\U0000FE0F': { # 🧞‍♂️
        'en' : ':man_genie:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':genie_man:'],
        'de': u':männlicher_flaschengeist:',
        'es': ':genio_hombre:',
        'fr': u':génie_homme:',
        'ja': u':男の精霊:',
        'ko': u':남자_지니:',
        'pt': u':homem_gênio:',
        'it': ':genio_uomo:',
        'fa': u':مرد_جن:',
        'id': ':jin_pria:',
        'zh': u':男妖怪:'
    },
    u'\U0001F9DE\U0000200D\U00002642': { # 🧞‍♂
        'en' : ':man_genie:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':genie_man:'],
        'de': u':männlicher_flaschengeist:',
        'es': ':genio_hombre:',
        'fr': u':génie_homme:',
        'ja': u':男の精霊:',
        'ko': u':남자_지니:',
        'pt': u':homem_gênio:',
        'it': ':genio_uomo:',
        'fa': u':مرد_جن:',
        'id': ':jin_pria:',
        'zh': u':男妖怪:'
    },
    u'\U0001F645\U0000200D\U00002642\U0000FE0F': { # 🙅‍♂️
        'en' : ':man_gesturing_NO:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':no_good_man:', ':ng_man:'],
        'de': u':mann_mit_überkreuzten_armen:',
        'es': ':hombre_haciendo_el_gesto_de_no:',
        'fr': u':homme_faisant_un_geste_d’interdiction:',
        'ja': u':ダメのポーズをする男:',
        'ko': u':안_된다는_제스처를_하는_남자:',
        'pt': u':homem_fazendo_gesto_de_“não”:',
        'it': ':uomo_con_gesto_di_rifiuto:',
        'fa': u':مرد_نمی_پذیرد:',
        'id': ':pria_mengisyaratkan_tidak:',
        'zh': u':禁止手势男:'
    },
    u'\U0001F645\U0000200D\U00002642': { # 🙅‍♂
        'en' : ':man_gesturing_NO:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':no_good_man:', ':ng_man:'],
        'de': u':mann_mit_überkreuzten_armen:',
        'es': ':hombre_haciendo_el_gesto_de_no:',
        'fr': u':homme_faisant_un_geste_d’interdiction:',
        'ja': u':ダメのポーズをする男:',
        'ko': u':안_된다는_제스처를_하는_남자:',
        'pt': u':homem_fazendo_gesto_de_“não”:',
        'it': ':uomo_con_gesto_di_rifiuto:',
        'fa': u':مرد_نمی_پذیرد:',
        'id': ':pria_mengisyaratkan_tidak:',
        'zh': u':禁止手势男:'
    },
    u'\U0001F645\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🙅🏿‍♂️
        'en' : ':man_gesturing_NO_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_oscuro:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_foncée:',
        'ja': u':ダメのポーズをする男_濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_검은색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_escura:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_scura:',
        'fa': u':مرد_نمی_پذیرد_پوست_آبنوسی:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_gelap:',
        'zh': u':禁止手势男_较深肤色:'
    },
    u'\U0001F645\U0001F3FF\U0000200D\U00002642': { # 🙅🏿‍♂
        'en' : ':man_gesturing_NO_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_oscuro:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_foncée:',
        'ja': u':ダメのポーズをする男_濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_검은색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_escura:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_scura:',
        'fa': u':مرد_نمی_پذیرد_پوست_آبنوسی:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_gelap:',
        'zh': u':禁止手势男_较深肤色:'
    },
    u'\U0001F645\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🙅🏻‍♂️
        'en' : ':man_gesturing_NO_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_helle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_claro:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_claire:',
        'ja': u':ダメのポーズをする男_薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_하얀_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_clara:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_chiara:',
        'fa': u':مرد_نمی_پذیرد_پوست_سفید:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_cerah:',
        'zh': u':禁止手势男_较浅肤色:'
    },
    u'\U0001F645\U0001F3FB\U0000200D\U00002642': { # 🙅🏻‍♂
        'en' : ':man_gesturing_NO_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_helle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_claro:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_claire:',
        'ja': u':ダメのポーズをする男_薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_하얀_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_clara:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_chiara:',
        'fa': u':مرد_نمی_پذیرد_پوست_سفید:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_cerah:',
        'zh': u':禁止手势男_较浅肤色:'
    },
    u'\U0001F645\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🙅🏾‍♂️
        'en' : ':man_gesturing_NO_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_oscuro_medio:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_mate:',
        'ja': u':ダメのポーズをする男_やや濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_진한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_morena_escura:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_abbastanza_scura:',
        'fa': u':مرد_نمی_پذیرد_پوست_گندمی:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_gelap-sedang:',
        'zh': u':禁止手势男_中等深肤色:'
    },
    u'\U0001F645\U0001F3FE\U0000200D\U00002642': { # 🙅🏾‍♂
        'en' : ':man_gesturing_NO_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_oscuro_medio:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_mate:',
        'ja': u':ダメのポーズをする男_やや濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_진한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_morena_escura:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_abbastanza_scura:',
        'fa': u':مرد_نمی_پذیرد_پوست_گندمی:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_gelap-sedang:',
        'zh': u':禁止手势男_中等深肤色:'
    },
    u'\U0001F645\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🙅🏼‍♂️
        'en' : ':man_gesturing_NO_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_claro_medio:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_moyennement_claire:',
        'ja': u':ダメのポーズをする男_やや薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_연한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_morena_clara:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_abbastanza_chiara:',
        'fa': u':مرد_نمی_پذیرد_پوست_روشن:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_cerah-sedang:',
        'zh': u':禁止手势男_中等浅肤色:'
    },
    u'\U0001F645\U0001F3FC\U0000200D\U00002642': { # 🙅🏼‍♂
        'en' : ':man_gesturing_NO_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_claro_medio:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_moyennement_claire:',
        'ja': u':ダメのポーズをする男_やや薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_연한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_morena_clara:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_abbastanza_chiara:',
        'fa': u':مرد_نمی_پذیرد_پوست_روشن:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_cerah-sedang:',
        'zh': u':禁止手势男_中等浅肤色:'
    },
    u'\U0001F645\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🙅🏽‍♂️
        'en' : ':man_gesturing_NO_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_medio:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_légèrement_mate:',
        'ja': u':ダメのポーズをする男_中間の肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_morena:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_olivastra:',
        'fa': u':مرد_نمی_پذیرد_پوست_طلایی:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_sedang:',
        'zh': u':禁止手势男_中等肤色:'
    },
    u'\U0001F645\U0001F3FD\U0000200D\U00002642': { # 🙅🏽‍♂
        'en' : ':man_gesturing_NO_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_überkreuzten_armen_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_no_tono_de_piel_medio:',
        'fr': u':homme_faisant_un_geste_d’interdiction_peau_légèrement_mate:',
        'ja': u':ダメのポーズをする男_中間の肌色:',
        'ko': u':안_된다는_제스처를_하는_남자_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“não”_pele_morena:',
        'it': ':uomo_con_gesto_di_rifiuto_carnagione_olivastra:',
        'fa': u':مرد_نمی_پذیرد_پوست_طلایی:',
        'id': ':pria_mengisyaratkan_tidak_warna_kulit_sedang:',
        'zh': u':禁止手势男_中等肤色:'
    },
    u'\U0001F646\U0000200D\U00002642\U0000FE0F': { # 🙆‍♂️
        'en' : ':man_gesturing_OK:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':ok_man:'],
        'de': u':mann_mit_händen_auf_dem_kopf:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo:',
        'fr': u':homme_faisant_un_geste_d’acceptation:',
        'ja': u':okのポーズをする男:',
        'ko': u':오케이라는_제스처를_하는_남자:',
        'pt': u':homem_fazendo_gesto_de_“ok”:',
        'it': ':uomo_con_gesto_ok:',
        'fa': u':مرد_می_پذیرد:',
        'id': ':pria_mengisyaratkan_oke:',
        'zh': u':OK手势男:'
    },
    u'\U0001F646\U0000200D\U00002642': { # 🙆‍♂
        'en' : ':man_gesturing_OK:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':ok_man:'],
        'de': u':mann_mit_händen_auf_dem_kopf:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo:',
        'fr': u':homme_faisant_un_geste_d’acceptation:',
        'ja': u':okのポーズをする男:',
        'ko': u':오케이라는_제스처를_하는_남자:',
        'pt': u':homem_fazendo_gesto_de_“ok”:',
        'it': ':uomo_con_gesto_ok:',
        'fa': u':مرد_می_پذیرد:',
        'id': ':pria_mengisyaratkan_oke:',
        'zh': u':OK手势男:'
    },
    u'\U0001F646\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🙆🏿‍♂️
        'en' : ':man_gesturing_OK_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_foncée:',
        'ja': u':okのポーズをする男_濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_검은색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_escura:',
        'it': ':uomo_con_gesto_ok_carnagione_scura:',
        'fa': u':مرد_می_پذیرد_پوست_آبنوسی:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_gelap:',
        'zh': u':OK手势男_较深肤色:'
    },
    u'\U0001F646\U0001F3FF\U0000200D\U00002642': { # 🙆🏿‍♂
        'en' : ':man_gesturing_OK_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_foncée:',
        'ja': u':okのポーズをする男_濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_검은색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_escura:',
        'it': ':uomo_con_gesto_ok_carnagione_scura:',
        'fa': u':مرد_می_پذیرد_پوست_آبنوسی:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_gelap:',
        'zh': u':OK手势男_较深肤色:'
    },
    u'\U0001F646\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🙆🏻‍♂️
        'en' : ':man_gesturing_OK_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_helle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_claire:',
        'ja': u':okのポーズをする男_薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_하얀_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_clara:',
        'it': ':uomo_con_gesto_ok_carnagione_chiara:',
        'fa': u':مرد_می_پذیرد_پوست_سفید:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_cerah:',
        'zh': u':OK手势男_较浅肤色:'
    },
    u'\U0001F646\U0001F3FB\U0000200D\U00002642': { # 🙆🏻‍♂
        'en' : ':man_gesturing_OK_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_helle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_claire:',
        'ja': u':okのポーズをする男_薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_하얀_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_clara:',
        'it': ':uomo_con_gesto_ok_carnagione_chiara:',
        'fa': u':مرد_می_پذیرد_پوست_سفید:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_cerah:',
        'zh': u':OK手势男_较浅肤色:'
    },
    u'\U0001F646\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🙆🏾‍♂️
        'en' : ':man_gesturing_OK_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro_medio:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_mate:',
        'ja': u':okのポーズをする男_やや濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_진한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_morena_escura:',
        'it': ':uomo_con_gesto_ok_carnagione_abbastanza_scura:',
        'fa': u':مرد_می_پذیرد_پوست_گندمی:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_gelap-sedang:',
        'zh': u':OK手势男_中等深肤色:'
    },
    u'\U0001F646\U0001F3FE\U0000200D\U00002642': { # 🙆🏾‍♂
        'en' : ':man_gesturing_OK_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro_medio:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_mate:',
        'ja': u':okのポーズをする男_やや濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_진한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_morena_escura:',
        'it': ':uomo_con_gesto_ok_carnagione_abbastanza_scura:',
        'fa': u':مرد_می_پذیرد_پوست_گندمی:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_gelap-sedang:',
        'zh': u':OK手势男_中等深肤色:'
    },
    u'\U0001F646\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🙆🏼‍♂️
        'en' : ':man_gesturing_OK_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro_medio:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_moyennement_claire:',
        'ja': u':okのポーズをする男_やや薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_연한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_morena_clara:',
        'it': ':uomo_con_gesto_ok_carnagione_abbastanza_chiara:',
        'fa': u':مرد_می_پذیرد_پوست_روشن:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_cerah-sedang:',
        'zh': u':OK手势男_中等浅肤色:'
    },
    u'\U0001F646\U0001F3FC\U0000200D\U00002642': { # 🙆🏼‍♂
        'en' : ':man_gesturing_OK_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro_medio:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_moyennement_claire:',
        'ja': u':okのポーズをする男_やや薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_연한_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_morena_clara:',
        'it': ':uomo_con_gesto_ok_carnagione_abbastanza_chiara:',
        'fa': u':مرد_می_پذیرد_پوست_روشن:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_cerah-sedang:',
        'zh': u':OK手势男_中等浅肤色:'
    },
    u'\U0001F646\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🙆🏽‍♂️
        'en' : ':man_gesturing_OK_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_medio:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_légèrement_mate:',
        'ja': u':okのポーズをする男_中間の肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_morena:',
        'it': ':uomo_con_gesto_ok_carnagione_olivastra:',
        'fa': u':مرد_می_پذیرد_پوست_طلایی:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_sedang:',
        'zh': u':OK手势男_中等肤色:'
    },
    u'\U0001F646\U0001F3FD\U0000200D\U00002642': { # 🙆🏽‍♂
        'en' : ':man_gesturing_OK_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':mann_mit_händen_auf_dem_kopf_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_medio:',
        'fr': u':homme_faisant_un_geste_d’acceptation_peau_légèrement_mate:',
        'ja': u':okのポーズをする男_中間の肌色:',
        'ko': u':오케이라는_제스처를_하는_남자_갈색_피부:',
        'pt': u':homem_fazendo_gesto_de_“ok”_pele_morena:',
        'it': ':uomo_con_gesto_ok_carnagione_olivastra:',
        'fa': u':مرد_می_پذیرد_پوست_طلایی:',
        'id': ':pria_mengisyaratkan_oke_warna_kulit_sedang:',
        'zh': u':OK手势男_中等肤色:'
    },
    u'\U0001F487\U0000200D\U00002642\U0000FE0F': { # 💇‍♂️
        'en' : ':man_getting_haircut:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':haircut_man:'],
        'de': ':mann_beim_haareschneiden:',
        'es': u':hombre_cortándose_el_pelo:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux:',
        'ja': u':散髪される男:',
        'ko': u':남자_헤어컷:',
        'pt': ':homem_cortando_o_cabelo:',
        'it': ':taglio_di_capelli_per_uomo:',
        'fa': u':مرد_مو_کوتاه_می_کند:',
        'id': ':pria_potong_rambut:',
        'zh': u':男生理发:'
    },
    u'\U0001F487\U0000200D\U00002642': { # 💇‍♂
        'en' : ':man_getting_haircut:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':haircut_man:'],
        'de': ':mann_beim_haareschneiden:',
        'es': u':hombre_cortándose_el_pelo:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux:',
        'ja': u':散髪される男:',
        'ko': u':남자_헤어컷:',
        'pt': ':homem_cortando_o_cabelo:',
        'it': ':taglio_di_capelli_per_uomo:',
        'fa': u':مرد_مو_کوتاه_می_کند:',
        'id': ':pria_potong_rambut:',
        'zh': u':男生理发:'
    },
    u'\U0001F487\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 💇🏿‍♂️
        'en' : ':man_getting_haircut_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_dunkle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_oscuro:',
        'fr': u':homme_qui_se_fait_couper_les_cheveux_peau_foncée:',
        'ja': u':散髪される男_濃い肌色:',
        'ko': u':남자_헤어컷_검은색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_escura:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_scura:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_آبنوسی:',
        'id': ':pria_potong_rambut_warna_kulit_gelap:',
        'zh': u':男生理发_较深肤色:'
    },
    u'\U0001F487\U0001F3FF\U0000200D\U00002642': { # 💇🏿‍♂
        'en' : ':man_getting_haircut_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_dunkle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_oscuro:',
        'fr': u':homme_qui_se_fait_couper_les_cheveux_peau_foncée:',
        'ja': u':散髪される男_濃い肌色:',
        'ko': u':남자_헤어컷_검은색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_escura:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_scura:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_آبنوسی:',
        'id': ':pria_potong_rambut_warna_kulit_gelap:',
        'zh': u':男生理发_较深肤色:'
    },
    u'\U0001F487\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 💇🏻‍♂️
        'en' : ':man_getting_haircut_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_helle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_claro:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux_peau_claire:',
        'ja': u':散髪される男_薄い肌色:',
        'ko': u':남자_헤어컷_하얀_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_clara:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_chiara:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_سفید:',
        'id': ':pria_potong_rambut_warna_kulit_cerah:',
        'zh': u':男生理发_较浅肤色:'
    },
    u'\U0001F487\U0001F3FB\U0000200D\U00002642': { # 💇🏻‍♂
        'en' : ':man_getting_haircut_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_helle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_claro:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux_peau_claire:',
        'ja': u':散髪される男_薄い肌色:',
        'ko': u':남자_헤어컷_하얀_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_clara:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_chiara:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_سفید:',
        'id': ':pria_potong_rambut_warna_kulit_cerah:',
        'zh': u':男生理发_较浅肤色:'
    },
    u'\U0001F487\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 💇🏾‍♂️
        'en' : ':man_getting_haircut_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_mitteldunkle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux_peau_mate:',
        'ja': u':散髪される男_やや濃い肌色:',
        'ko': u':남자_헤어컷_진한_갈색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_morena_escura:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_abbastanza_scura:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_گندمی:',
        'id': ':pria_potong_rambut_warna_kulit_gelap-sedang:',
        'zh': u':男生理发_中等深肤色:'
    },
    u'\U0001F487\U0001F3FE\U0000200D\U00002642': { # 💇🏾‍♂
        'en' : ':man_getting_haircut_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_mitteldunkle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux_peau_mate:',
        'ja': u':散髪される男_やや濃い肌色:',
        'ko': u':남자_헤어컷_진한_갈색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_morena_escura:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_abbastanza_scura:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_گندمی:',
        'id': ':pria_potong_rambut_warna_kulit_gelap-sedang:',
        'zh': u':男生理发_中等深肤色:'
    },
    u'\U0001F487\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 💇🏼‍♂️
        'en' : ':man_getting_haircut_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_mittelhelle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux_peau_moyennement_claire:',
        'ja': u':散髪される男_やや薄い肌色:',
        'ko': u':남자_헤어컷_연한_갈색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_morena_clara:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_روشن:',
        'id': ':pria_potong_rambut_warna_kulit_cerah-sedang:',
        'zh': u':男生理发_中等浅肤色:'
    },
    u'\U0001F487\U0001F3FC\U0000200D\U00002642': { # 💇🏼‍♂
        'en' : ':man_getting_haircut_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_mittelhelle_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_se_fait_couper_les_cheveux_peau_moyennement_claire:',
        'ja': u':散髪される男_やや薄い肌色:',
        'ko': u':남자_헤어컷_연한_갈색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_morena_clara:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_روشن:',
        'id': ':pria_potong_rambut_warna_kulit_cerah-sedang:',
        'zh': u':男生理发_中等浅肤色:'
    },
    u'\U0001F487\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 💇🏽‍♂️
        'en' : ':man_getting_haircut_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_mittlere_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_medio:',
        'fr': u':homme_qui_se_fait_couper_les_cheveux_peau_légèrement_mate:',
        'ja': u':散髪される男_中間の肌色:',
        'ko': u':남자_헤어컷_갈색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_morena:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_olivastra:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_طلایی:',
        'id': ':pria_potong_rambut_warna_kulit_sedang:',
        'zh': u':男生理发_中等肤色:'
    },
    u'\U0001F487\U0001F3FD\U0000200D\U00002642': { # 💇🏽‍♂
        'en' : ':man_getting_haircut_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_beim_haareschneiden_mittlere_hautfarbe:',
        'es': u':hombre_cortándose_el_pelo_tono_de_piel_medio:',
        'fr': u':homme_qui_se_fait_couper_les_cheveux_peau_légèrement_mate:',
        'ja': u':散髪される男_中間の肌色:',
        'ko': u':남자_헤어컷_갈색_피부:',
        'pt': ':homem_cortando_o_cabelo_pele_morena:',
        'it': ':taglio_di_capelli_per_uomo_carnagione_olivastra:',
        'fa': u':مرد_مو_کوتاه_می_کند_پوست_طلایی:',
        'id': ':pria_potong_rambut_warna_kulit_sedang:',
        'zh': u':男生理发_中等肤色:'
    },
    u'\U0001F486\U0000200D\U00002642\U0000FE0F': { # 💆‍♂️
        'en' : ':man_getting_massage:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':massage_man:'],
        'de': ':mann,_der_eine_kopfmassage_bekommt:',
        'es': ':hombre_recibiendo_masaje:',
        'fr': ':homme_qui_se_fait_masser:',
        'ja': u':フェイスマッサージ中の男:',
        'ko': u':마사지_받는_남자:',
        'pt': ':homem_recebendo_massagem_facial:',
        'it': ':uomo_che_riceve_un_massaggio:',
        'fa': u':ماساژ_صورت_مرد:',
        'id': ':pria_dipijat_kepalanya:',
        'zh': u':男生按摩:'
    },
    u'\U0001F486\U0000200D\U00002642': { # 💆‍♂
        'en' : ':man_getting_massage:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':massage_man:'],
        'de': ':mann_der_eine_kopfmassage_bekommt:',
        'es': ':hombre_recibiendo_masaje:',
        'fr': ':homme_qui_se_fait_masser:',
        'ja': u':フェイスマッサージ中の男:',
        'ko': u':마사지_받는_남자:',
        'pt': ':homem_recebendo_massagem_facial:',
        'it': ':uomo_che_riceve_un_massaggio:',
        'fa': u':ماساژ_صورت_مرد:',
        'id': ':pria_dipijat_kepalanya:',
        'zh': u':男生按摩:'
    },
    u'\U0001F486\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 💆🏿‍♂️
        'en' : ':man_getting_massage_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_dunkle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_oscuro:',
        'fr': u':homme_qui_se_fait_masser_peau_foncée:',
        'ja': u':フェイスマッサージ中の男_濃い肌色:',
        'ko': u':마사지_받는_남자_검은색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_escura:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_scura:',
        'fa': u':ماساژ_صورت_مرد_پوست_آبنوسی:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_gelap:',
        'zh': u':男生按摩_较深肤色:'
    },
    u'\U0001F486\U0001F3FF\U0000200D\U00002642': { # 💆🏿‍♂
        'en' : ':man_getting_massage_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_dunkle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_oscuro:',
        'fr': u':homme_qui_se_fait_masser_peau_foncée:',
        'ja': u':フェイスマッサージ中の男_濃い肌色:',
        'ko': u':마사지_받는_남자_검은색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_escura:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_scura:',
        'fa': u':ماساژ_صورت_مرد_پوست_آبنوسی:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_gelap:',
        'zh': u':男生按摩_较深肤色:'
    },
    u'\U0001F486\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 💆🏻‍♂️
        'en' : ':man_getting_massage_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_helle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_claro:',
        'fr': ':homme_qui_se_fait_masser_peau_claire:',
        'ja': u':フェイスマッサージ中の男_薄い肌色:',
        'ko': u':마사지_받는_남자_하얀_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_clara:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_chiara:',
        'fa': u':ماساژ_صورت_مرد_پوست_سفید:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_cerah:',
        'zh': u':男生按摩_较浅肤色:'
    },
    u'\U0001F486\U0001F3FB\U0000200D\U00002642': { # 💆🏻‍♂
        'en' : ':man_getting_massage_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_helle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_claro:',
        'fr': ':homme_qui_se_fait_masser_peau_claire:',
        'ja': u':フェイスマッサージ中の男_薄い肌色:',
        'ko': u':마사지_받는_남자_하얀_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_clara:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_chiara:',
        'fa': u':ماساژ_صورت_مرد_پوست_سفید:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_cerah:',
        'zh': u':男生按摩_较浅肤色:'
    },
    u'\U0001F486\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 💆🏾‍♂️
        'en' : ':man_getting_massage_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_mitteldunkle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_se_fait_masser_peau_mate:',
        'ja': u':フェイスマッサージ中の男_やや濃い肌色:',
        'ko': u':마사지_받는_남자_진한_갈색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_morena_escura:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_abbastanza_scura:',
        'fa': u':ماساژ_صورت_مرد_پوست_گندمی:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_gelap-sedang:',
        'zh': u':男生按摩_中等深肤色:'
    },
    u'\U0001F486\U0001F3FE\U0000200D\U00002642': { # 💆🏾‍♂
        'en' : ':man_getting_massage_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_mitteldunkle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_se_fait_masser_peau_mate:',
        'ja': u':フェイスマッサージ中の男_やや濃い肌色:',
        'ko': u':마사지_받는_남자_진한_갈색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_morena_escura:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_abbastanza_scura:',
        'fa': u':ماساژ_صورت_مرد_پوست_گندمی:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_gelap-sedang:',
        'zh': u':男生按摩_中等深肤色:'
    },
    u'\U0001F486\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 💆🏼‍♂️
        'en' : ':man_getting_massage_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_mittelhelle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_se_fait_masser_peau_moyennement_claire:',
        'ja': u':フェイスマッサージ中の男_やや薄い肌色:',
        'ko': u':마사지_받는_남자_연한_갈색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_morena_clara:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_abbastanza_chiara:',
        'fa': u':ماساژ_صورت_مرد_پوست_روشن:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_cerah-sedang:',
        'zh': u':男生按摩_中等浅肤色:'
    },
    u'\U0001F486\U0001F3FC\U0000200D\U00002642': { # 💆🏼‍♂
        'en' : ':man_getting_massage_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_mittelhelle_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_se_fait_masser_peau_moyennement_claire:',
        'ja': u':フェイスマッサージ中の男_やや薄い肌色:',
        'ko': u':마사지_받는_남자_연한_갈색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_morena_clara:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_abbastanza_chiara:',
        'fa': u':ماساژ_صورت_مرد_پوست_روشن:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_cerah-sedang:',
        'zh': u':男生按摩_中等浅肤色:'
    },
    u'\U0001F486\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 💆🏽‍♂️
        'en' : ':man_getting_massage_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_mittlere_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_medio:',
        'fr': u':homme_qui_se_fait_masser_peau_légèrement_mate:',
        'ja': u':フェイスマッサージ中の男_中間の肌色:',
        'ko': u':마사지_받는_남자_갈색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_morena:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_olivastra:',
        'fa': u':ماساژ_صورت_مرد_پوست_طلایی:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_sedang:',
        'zh': u':男生按摩_中等肤色:'
    },
    u'\U0001F486\U0001F3FD\U0000200D\U00002642': { # 💆🏽‍♂
        'en' : ':man_getting_massage_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann,_der_eine_kopfmassage_bekommt_mittlere_hautfarbe:',
        'es': ':hombre_recibiendo_masaje_tono_de_piel_medio:',
        'fr': u':homme_qui_se_fait_masser_peau_légèrement_mate:',
        'ja': u':フェイスマッサージ中の男_中間の肌色:',
        'ko': u':마사지_받는_남자_갈색_피부:',
        'pt': ':homem_recebendo_massagem_facial_pele_morena:',
        'it': ':uomo_che_riceve_un_massaggio_carnagione_olivastra:',
        'fa': u':ماساژ_صورت_مرد_پوست_طلایی:',
        'id': ':pria_dipijat_kepalanya_warna_kulit_sedang:',
        'zh': u':男生按摩_中等肤色:'
    },
    u'\U0001F3CC\U0000FE0F\U0000200D\U00002642\U0000FE0F': { # 🏌️‍♂️
        'en' : ':man_golfing:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':golfing_man:'],
        'de': ':golfer:',
        'es': ':hombre_jugando_al_golf:',
        'fr': ':golfeur:',
        'ja': u':ゴルフをする男:',
        'ko': u':골프치는_남자:',
        'pt': ':homem_golfista:',
        'it': ':golfista_uomo:',
        'fa': u':گلف_باز_مرد:',
        'id': ':pria_bermain_golf:',
        'zh': u':男生打高尔夫:'
    },
    u'\U0001F3CC\U0000200D\U00002642\U0000FE0F': { # 🏌‍♂️
        'en' : ':man_golfing:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':golfing_man:'],
        'de': ':golfer:',
        'es': ':hombre_jugando_al_golf:',
        'fr': ':golfeur:',
        'ja': u':ゴルフをする男:',
        'ko': u':골프치는_남자:',
        'pt': ':homem_golfista:',
        'it': ':golfista_uomo:',
        'fa': u':گلف_باز_مرد:',
        'id': ':pria_bermain_golf:',
        'zh': u':男生打高尔夫:'
    },
    u'\U0001F3CC\U0000FE0F\U0000200D\U00002642': { # 🏌️‍♂
        'en' : ':man_golfing:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':golfing_man:'],
        'de': ':golfer:',
        'es': ':hombre_jugando_al_golf:',
        'fr': ':golfeur:',
        'ja': u':ゴルフをする男:',
        'ko': u':골프치는_남자:',
        'pt': ':homem_golfista:',
        'it': ':golfista_uomo:',
        'fa': u':گلف_باز_مرد:',
        'id': ':pria_bermain_golf:',
        'zh': u':男生打高尔夫:'
    },
    u'\U0001F3CC\U0000200D\U00002642': { # 🏌‍♂
        'en' : ':man_golfing:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':golfing_man:'],
        'de': ':golfer:',
        'es': ':hombre_jugando_al_golf:',
        'fr': ':golfeur:',
        'ja': u':ゴルフをする男:',
        'ko': u':골프치는_남자:',
        'pt': ':homem_golfista:',
        'it': ':golfista_uomo:',
        'fa': u':گلف_باز_مرد:',
        'id': ':pria_bermain_golf:',
        'zh': u':男生打高尔夫:'
    },
    u'\U0001F3CC\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🏌🏿‍♂️
        'en' : ':man_golfing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer_dunkle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_oscuro:',
        'fr': u':golfeur_peau_foncée:',
        'ja': u':ゴルフをする男_濃い肌色:',
        'ko': u':골프치는_남자_검은색_피부:',
        'pt': ':homem_golfista_pele_escura:',
        'it': ':golfista_uomo_carnagione_scura:',
        'fa': u':گلف_باز_مرد_پوست_آبنوسی:',
        'id': ':pria_bermain_golf_warna_kulit_gelap:',
        'zh': u':男生打高尔夫_较深肤色:'
    },
    u'\U0001F3CC\U0001F3FF\U0000200D\U00002642': { # 🏌🏿‍♂
        'en' : ':man_golfing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golfer_dunkle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_oscuro:',
        'fr': u':golfeur_peau_foncée:',
        'ja': u':ゴルフをする男_濃い肌色:',
        'ko': u':골프치는_남자_검은색_피부:',
        'pt': ':homem_golfista_pele_escura:',
        'it': ':golfista_uomo_carnagione_scura:',
        'fa': u':گلف_باز_مرد_پوست_آبنوسی:',
        'id': ':pria_bermain_golf_warna_kulit_gelap:',
        'zh': u':男生打高尔夫_较深肤色:'
    },
    u'\U0001F3CC\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🏌🏻‍♂️
        'en' : ':man_golfing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer_helle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_claro:',
        'fr': ':golfeur_peau_claire:',
        'ja': u':ゴルフをする男_薄い肌色:',
        'ko': u':골프치는_남자_하얀_피부:',
        'pt': ':homem_golfista_pele_clara:',
        'it': ':golfista_uomo_carnagione_chiara:',
        'fa': u':گلف_باز_مرد_پوست_سفید:',
        'id': ':pria_bermain_golf_warna_kulit_cerah:',
        'zh': u':男生打高尔夫_较浅肤色:'
    },
    u'\U0001F3CC\U0001F3FB\U0000200D\U00002642': { # 🏌🏻‍♂
        'en' : ':man_golfing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golfer_helle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_claro:',
        'fr': ':golfeur_peau_claire:',
        'ja': u':ゴルフをする男_薄い肌色:',
        'ko': u':골프치는_남자_하얀_피부:',
        'pt': ':homem_golfista_pele_clara:',
        'it': ':golfista_uomo_carnagione_chiara:',
        'fa': u':گلف_باز_مرد_پوست_سفید:',
        'id': ':pria_bermain_golf_warna_kulit_cerah:',
        'zh': u':男生打高尔夫_较浅肤色:'
    },
    u'\U0001F3CC\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🏌🏾‍♂️
        'en' : ':man_golfing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer_mitteldunkle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_oscuro_medio:',
        'fr': ':golfeur_peau_mate:',
        'ja': u':ゴルフをする男_やや濃い肌色:',
        'ko': u':골프치는_남자_진한_갈색_피부:',
        'pt': ':homem_golfista_pele_morena_escura:',
        'it': ':golfista_uomo_carnagione_abbastanza_scura:',
        'fa': u':گلف_باز_مرد_پوست_گندمی:',
        'id': ':pria_bermain_golf_warna_kulit_gelap-sedang:',
        'zh': u':男生打高尔夫_中等深肤色:'
    },
    u'\U0001F3CC\U0001F3FE\U0000200D\U00002642': { # 🏌🏾‍♂
        'en' : ':man_golfing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golfer_mitteldunkle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_oscuro_medio:',
        'fr': ':golfeur_peau_mate:',
        'ja': u':ゴルフをする男_やや濃い肌色:',
        'ko': u':골프치는_남자_진한_갈색_피부:',
        'pt': ':homem_golfista_pele_morena_escura:',
        'it': ':golfista_uomo_carnagione_abbastanza_scura:',
        'fa': u':گلف_باز_مرد_پوست_گندمی:',
        'id': ':pria_bermain_golf_warna_kulit_gelap-sedang:',
        'zh': u':男生打高尔夫_中等深肤色:'
    },
    u'\U0001F3CC\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🏌🏼‍♂️
        'en' : ':man_golfing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer_mittelhelle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_claro_medio:',
        'fr': ':golfeur_peau_moyennement_claire:',
        'ja': u':ゴルフをする男_やや薄い肌色:',
        'ko': u':골프치는_남자_연한_갈색_피부:',
        'pt': ':homem_golfista_pele_morena_clara:',
        'it': ':golfista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':گلف_باز_مرد_پوست_روشن:',
        'id': ':pria_bermain_golf_warna_kulit_cerah-sedang:',
        'zh': u':男生打高尔夫_中等浅肤色:'
    },
    u'\U0001F3CC\U0001F3FC\U0000200D\U00002642': { # 🏌🏼‍♂
        'en' : ':man_golfing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golfer_mittelhelle_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_claro_medio:',
        'fr': ':golfeur_peau_moyennement_claire:',
        'ja': u':ゴルフをする男_やや薄い肌色:',
        'ko': u':골프치는_남자_연한_갈색_피부:',
        'pt': ':homem_golfista_pele_morena_clara:',
        'it': ':golfista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':گلف_باز_مرد_پوست_روشن:',
        'id': ':pria_bermain_golf_warna_kulit_cerah-sedang:',
        'zh': u':男生打高尔夫_中等浅肤色:'
    },
    u'\U0001F3CC\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🏌🏽‍♂️
        'en' : ':man_golfing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer_mittlere_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_medio:',
        'fr': u':golfeur_peau_légèrement_mate:',
        'ja': u':ゴルフをする男_中間の肌色:',
        'ko': u':골프치는_남자_갈색_피부:',
        'pt': ':homem_golfista_pele_morena:',
        'it': ':golfista_uomo_carnagione_olivastra:',
        'fa': u':گلف_باز_مرد_پوست_طلایی:',
        'id': ':pria_bermain_golf_warna_kulit_sedang:',
        'zh': u':男生打高尔夫_中等肤色:'
    },
    u'\U0001F3CC\U0001F3FD\U0000200D\U00002642': { # 🏌🏽‍♂
        'en' : ':man_golfing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golfer_mittlere_hautfarbe:',
        'es': ':hombre_jugando_al_golf_tono_de_piel_medio:',
        'fr': u':golfeur_peau_légèrement_mate:',
        'ja': u':ゴルフをする男_中間の肌色:',
        'ko': u':골프치는_남자_갈색_피부:',
        'pt': ':homem_golfista_pele_morena:',
        'it': ':golfista_uomo_carnagione_olivastra:',
        'fa': u':گلف_باز_مرد_پوست_طلایی:',
        'id': ':pria_bermain_golf_warna_kulit_sedang:',
        'zh': u':男生打高尔夫_中等肤色:'
    },
    u'\U0001F482\U0000200D\U00002642\U0000FE0F': { # 💂‍♂️
        'en' : ':man_guard:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':guardsman:'],
        'de': ':wachmann:',
        'es': ':guardia_hombre:',
        'fr': ':garde_homme:',
        'ja': u':男性の衛兵:',
        'ko': u':남자_근위병:',
        'pt': ':guarda_homem:',
        'it': ':guardia_uomo:',
        'fa': u':گارد_مرد:',
        'id': ':penjaga_pria:',
        'zh': u':男卫兵:'
    },
    u'\U0001F482\U0000200D\U00002642': { # 💂‍♂
        'en' : ':man_guard:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':guardsman:'],
        'de': ':wachsoldat:',
        'es': ':guardia_hombre:',
        'fr': ':garde_homme:',
        'ja': u':男性の衛兵:',
        'ko': u':남자_근위병:',
        'pt': ':guarda_homem:',
        'it': ':guardia_uomo:',
        'fa': u':گارد_مرد:',
        'id': ':penjaga_pria:',
        'zh': u':男卫兵:'
    },
    u'\U0001F482\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 💂🏿‍♂️
        'en' : ':man_guard_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachmann_dunkle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_oscuro:',
        'fr': u':garde_homme_peau_foncée:',
        'ja': u':男性の衛兵_濃い肌色:',
        'ko': u':남자_근위병_검은색_피부:',
        'pt': ':guarda_homem_pele_escura:',
        'it': ':guardia_uomo_carnagione_scura:',
        'fa': u':گارد_مرد_پوست_آبنوسی:',
        'id': ':penjaga_pria_warna_kulit_gelap:',
        'zh': u':男卫兵_较深肤色:'
    },
    u'\U0001F482\U0001F3FF\U0000200D\U00002642': { # 💂🏿‍♂
        'en' : ':man_guard_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachmann_dunkle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_oscuro:',
        'fr': u':garde_homme_peau_foncée:',
        'ja': u':男性の衛兵_濃い肌色:',
        'ko': u':남자_근위병_검은색_피부:',
        'pt': ':guarda_homem_pele_escura:',
        'it': ':guardia_uomo_carnagione_scura:',
        'fa': u':گارد_مرد_پوست_آبنوسی:',
        'id': ':penjaga_pria_warna_kulit_gelap:',
        'zh': u':男卫兵_较深肤色:'
    },
    u'\U0001F482\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 💂🏻‍♂️
        'en' : ':man_guard_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachmann_helle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_claro:',
        'fr': ':garde_homme_peau_claire:',
        'ja': u':男性の衛兵_薄い肌色:',
        'ko': u':남자_근위병_하얀_피부:',
        'pt': ':guarda_homem_pele_clara:',
        'it': ':guardia_uomo_carnagione_chiara:',
        'fa': u':گارد_مرد_پوست_سفید:',
        'id': ':penjaga_pria_warna_kulit_cerah:',
        'zh': u':男卫兵_较浅肤色:'
    },
    u'\U0001F482\U0001F3FB\U0000200D\U00002642': { # 💂🏻‍♂
        'en' : ':man_guard_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachmann_helle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_claro:',
        'fr': ':garde_homme_peau_claire:',
        'ja': u':男性の衛兵_薄い肌色:',
        'ko': u':남자_근위병_하얀_피부:',
        'pt': ':guarda_homem_pele_clara:',
        'it': ':guardia_uomo_carnagione_chiara:',
        'fa': u':گارد_مرد_پوست_سفید:',
        'id': ':penjaga_pria_warna_kulit_cerah:',
        'zh': u':男卫兵_较浅肤色:'
    },
    u'\U0001F482\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 💂🏾‍♂️
        'en' : ':man_guard_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachmann_mitteldunkle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':garde_homme_peau_mate:',
        'ja': u':男性の衛兵_やや濃い肌色:',
        'ko': u':남자_근위병_진한_갈색_피부:',
        'pt': ':guarda_homem_pele_morena_escura:',
        'it': ':guardia_uomo_carnagione_abbastanza_scura:',
        'fa': u':گارد_مرد_پوست_گندمی:',
        'id': ':penjaga_pria_warna_kulit_gelap-sedang:',
        'zh': u':男卫兵_中等深肤色:'
    },
    u'\U0001F482\U0001F3FE\U0000200D\U00002642': { # 💂🏾‍♂
        'en' : ':man_guard_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachmann_mitteldunkle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':garde_homme_peau_mate:',
        'ja': u':男性の衛兵_やや濃い肌色:',
        'ko': u':남자_근위병_진한_갈색_피부:',
        'pt': ':guarda_homem_pele_morena_escura:',
        'it': ':guardia_uomo_carnagione_abbastanza_scura:',
        'fa': u':گارد_مرد_پوست_گندمی:',
        'id': ':penjaga_pria_warna_kulit_gelap-sedang:',
        'zh': u':男卫兵_中等深肤色:'
    },
    u'\U0001F482\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 💂🏼‍♂️
        'en' : ':man_guard_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachmann_mittelhelle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_claro_medio:',
        'fr': ':garde_homme_peau_moyennement_claire:',
        'ja': u':男性の衛兵_やや薄い肌色:',
        'ko': u':남자_근위병_연한_갈색_피부:',
        'pt': ':guarda_homem_pele_morena_clara:',
        'it': ':guardia_uomo_carnagione_abbastanza_chiara:',
        'fa': u':گارد_مرد_پوست_روشن:',
        'id': ':penjaga_pria_warna_kulit_cerah-sedang:',
        'zh': u':男卫兵_中等浅肤色:'
    },
    u'\U0001F482\U0001F3FC\U0000200D\U00002642': { # 💂🏼‍♂
        'en' : ':man_guard_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachmann_mittelhelle_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_claro_medio:',
        'fr': ':garde_homme_peau_moyennement_claire:',
        'ja': u':男性の衛兵_やや薄い肌色:',
        'ko': u':남자_근위병_연한_갈색_피부:',
        'pt': ':guarda_homem_pele_morena_clara:',
        'it': ':guardia_uomo_carnagione_abbastanza_chiara:',
        'fa': u':گارد_مرد_پوست_روشن:',
        'id': ':penjaga_pria_warna_kulit_cerah-sedang:',
        'zh': u':男卫兵_中等浅肤色:'
    },
    u'\U0001F482\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 💂🏽‍♂️
        'en' : ':man_guard_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachmann_mittlere_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_medio:',
        'fr': u':garde_homme_peau_légèrement_mate:',
        'ja': u':男性の衛兵_中間の肌色:',
        'ko': u':남자_근위병_갈색_피부:',
        'pt': ':guarda_homem_pele_morena:',
        'it': ':guardia_uomo_carnagione_olivastra:',
        'fa': u':گارد_مرد_پوست_طلایی:',
        'id': ':penjaga_pria_warna_kulit_sedang:',
        'zh': u':男卫兵_中等肤色:'
    },
    u'\U0001F482\U0001F3FD\U0000200D\U00002642': { # 💂🏽‍♂
        'en' : ':man_guard_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachmann_mittlere_hautfarbe:',
        'es': ':guardia_hombre_tono_de_piel_medio:',
        'fr': u':garde_homme_peau_légèrement_mate:',
        'ja': u':男性の衛兵_中間の肌色:',
        'ko': u':남자_근위병_갈색_피부:',
        'pt': ':guarda_homem_pele_morena:',
        'it': ':guardia_uomo_carnagione_olivastra:',
        'fa': u':گارد_مرد_پوست_طلایی:',
        'id': ':penjaga_pria_warna_kulit_sedang:',
        'zh': u':男卫兵_中等肤色:'
    },
    u'\U0001F468\U0000200D\U00002695\U0000FE0F': { # 👨‍⚕️
        'en' : ':man_health_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':arzt:',
        'es': ':profesional_sanitario_hombre:',
        'fr': u':professionnel_de_la_santé:',
        'ja': u':男性の医者:',
        'ko': u':남자_의료인:',
        'pt': u':homem_profissional_da_saúde:',
        'it': ':operatore_sanitario:',
        'fa': u':مددکار_بهداشت_مرد:',
        'id': ':pekerja_kesehatan_pria:',
        'zh': u':男医生:'
    },
    u'\U0001F468\U0000200D\U00002695': { # 👨‍⚕
        'en' : ':man_health_worker:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':arzt:',
        'es': ':profesional_sanitario_hombre:',
        'fr': u':professionnel_de_la_santé:',
        'ja': u':男性の医者:',
        'ko': u':남자_의료인:',
        'pt': u':homem_profissional_da_saúde:',
        'it': ':operatore_sanitario:',
        'fa': u':مددکار_بهداشت_مرد:',
        'id': ':pekerja_kesehatan_pria:',
        'zh': u':男医生:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002695\U0000FE0F': { # 👨🏿‍⚕️
        'en' : ':man_health_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':arzt_dunkle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_oscuro:',
        'fr': u':professionnel_de_la_santé_peau_foncée:',
        'ja': u':男性の医者_濃い肌色:',
        'ko': u':남자_의료인_검은색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_escura:',
        'it': ':operatore_sanitario_carnagione_scura:',
        'fa': u':مددکار_بهداشت_مرد_پوست_آبنوسی:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_gelap:',
        'zh': u':男医生_较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002695': { # 👨🏿‍⚕
        'en' : ':man_health_worker_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':arzt_dunkle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_oscuro:',
        'fr': u':professionnel_de_la_santé_peau_foncée:',
        'ja': u':男性の医者_濃い肌色:',
        'ko': u':남자_의료인_검은색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_escura:',
        'it': ':operatore_sanitario_carnagione_scura:',
        'fa': u':مددکار_بهداشت_مرد_پوست_آبنوسی:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_gelap:',
        'zh': u':男医生_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002695\U0000FE0F': { # 👨🏻‍⚕️
        'en' : ':man_health_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':arzt_helle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_claro:',
        'fr': u':professionnel_de_la_santé_peau_claire:',
        'ja': u':男性の医者_薄い肌色:',
        'ko': u':남자_의료인_하얀_피부:',
        'pt': u':homem_profissional_da_saúde_pele_clara:',
        'it': ':operatore_sanitario_carnagione_chiara:',
        'fa': u':مددکار_بهداشت_مرد_پوست_سفید:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_cerah:',
        'zh': u':男医生_较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002695': { # 👨🏻‍⚕
        'en' : ':man_health_worker_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':arzt_helle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_claro:',
        'fr': u':professionnel_de_la_santé_peau_claire:',
        'ja': u':男性の医者_薄い肌色:',
        'ko': u':남자_의료인_하얀_피부:',
        'pt': u':homem_profissional_da_saúde_pele_clara:',
        'it': ':operatore_sanitario_carnagione_chiara:',
        'fa': u':مددکار_بهداشت_مرد_پوست_سفید:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_cerah:',
        'zh': u':男医生_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002695\U0000FE0F': { # 👨🏾‍⚕️
        'en' : ':man_health_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':arzt_mitteldunkle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':professionnel_de_la_santé_peau_mate:',
        'ja': u':男性の医者_やや濃い肌色:',
        'ko': u':남자_의료인_진한_갈색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_morena_escura:',
        'it': ':operatore_sanitario_carnagione_abbastanza_scura:',
        'fa': u':مددکار_بهداشت_مرد_پوست_گندمی:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_gelap-sedang:',
        'zh': u':男医生_中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002695': { # 👨🏾‍⚕
        'en' : ':man_health_worker_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':arzt_mitteldunkle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':professionnel_de_la_santé_peau_mate:',
        'ja': u':男性の医者_やや濃い肌色:',
        'ko': u':남자_의료인_진한_갈색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_morena_escura:',
        'it': ':operatore_sanitario_carnagione_abbastanza_scura:',
        'fa': u':مددکار_بهداشت_مرد_پوست_گندمی:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_gelap-sedang:',
        'zh': u':男医生_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002695\U0000FE0F': { # 👨🏼‍⚕️
        'en' : ':man_health_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':arzt_mittelhelle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_claro_medio:',
        'fr': u':professionnel_de_la_santé_peau_moyennement_claire:',
        'ja': u':男性の医者_やや薄い肌色:',
        'ko': u':남자_의료인_연한_갈색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_morena_clara:',
        'it': ':operatore_sanitario_carnagione_abbastanza_chiara:',
        'fa': u':مددکار_بهداشت_مرد_پوست_روشن:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_cerah-sedang:',
        'zh': u':男医生_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002695': { # 👨🏼‍⚕
        'en' : ':man_health_worker_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':arzt_mittelhelle_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_claro_medio:',
        'fr': u':professionnel_de_la_santé_peau_moyennement_claire:',
        'ja': u':男性の医者_やや薄い肌色:',
        'ko': u':남자_의료인_연한_갈색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_morena_clara:',
        'it': ':operatore_sanitario_carnagione_abbastanza_chiara:',
        'fa': u':مددکار_بهداشت_مرد_پوست_روشن:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_cerah-sedang:',
        'zh': u':男医生_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002695\U0000FE0F': { # 👨🏽‍⚕️
        'en' : ':man_health_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':arzt_mittlere_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_medio:',
        'fr': u':professionnel_de_la_santé_peau_légèrement_mate:',
        'ja': u':男性の医者_中間の肌色:',
        'ko': u':남자_의료인_갈색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_morena:',
        'it': ':operatore_sanitario_carnagione_olivastra:',
        'fa': u':مددکار_بهداشت_مرد_پوست_طلایی:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_sedang:',
        'zh': u':男医生_中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002695': { # 👨🏽‍⚕
        'en' : ':man_health_worker_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':arzt_mittlere_hautfarbe:',
        'es': ':profesional_sanitario_hombre_tono_de_piel_medio:',
        'fr': u':professionnel_de_la_santé_peau_légèrement_mate:',
        'ja': u':男性の医者_中間の肌色:',
        'ko': u':남자_의료인_갈색_피부:',
        'pt': u':homem_profissional_da_saúde_pele_morena:',
        'it': ':operatore_sanitario_carnagione_olivastra:',
        'fa': u':مددکار_بهداشت_مرد_پوست_طلایی:',
        'id': ':pekerja_kesehatan_pria_warna_kulit_sedang:',
        'zh': u':男医生_中等肤色:'
    },
    u'\U0001F9D8\U0000200D\U00002642\U0000FE0F': { # 🧘‍♂️
        'en' : ':man_in_lotus_position:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':lotus_position_man:'],
        'de': ':mann_im_lotossitz:',
        'es': u':hombre_en_posición_de_loto:',
        'fr': ':homme_dans_la_posture_du_lotus:',
        'ja': u':ヨガのポーズをする男:',
        'ko': u':가부좌한_남자:',
        'pt': u':homem_na_posição_de_lótus:',
        'it': ':uomo_in_posizione_del_loto:',
        'fa': u':مرد_در_حالت_خلسه:',
        'id': ':pria_dalam_posisi_teratai:',
        'zh': u':盘腿的男人:'
    },
    u'\U0001F9D8\U0000200D\U00002642': { # 🧘‍♂
        'en' : ':man_in_lotus_position:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':lotus_position_man:'],
        'de': ':mann_im_lotossitz:',
        'es': u':hombre_en_posición_de_loto:',
        'fr': ':homme_dans_la_posture_du_lotus:',
        'ja': u':ヨガのポーズをする男:',
        'ko': u':가부좌한_남자:',
        'pt': u':homem_na_posição_de_lótus:',
        'it': ':uomo_in_posizione_del_loto:',
        'fa': u':مرد_در_حالت_خلسه:',
        'id': ':pria_dalam_posisi_teratai:',
        'zh': u':盘腿的男人:'
    },
    u'\U0001F9D8\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧘🏿‍♂️
        'en' : ':man_in_lotus_position_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_dunkle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_oscuro:',
        'fr': u':homme_dans_la_posture_du_lotus_peau_foncée:',
        'ja': u':ヨガのポーズをする男_濃い肌色:',
        'ko': u':가부좌한_남자_검은색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_escura:',
        'it': ':uomo_in_posizione_del_loto_carnagione_scura:',
        'fa': u':مرد_در_حالت_خلسه_پوست_آبنوسی:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_gelap:',
        'zh': u':盘腿的男人_较深肤色:'
    },
    u'\U0001F9D8\U0001F3FF\U0000200D\U00002642': { # 🧘🏿‍♂
        'en' : ':man_in_lotus_position_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_dunkle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_oscuro:',
        'fr': u':homme_dans_la_posture_du_lotus_peau_foncée:',
        'ja': u':ヨガのポーズをする男_濃い肌色:',
        'ko': u':가부좌한_남자_검은색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_escura:',
        'it': ':uomo_in_posizione_del_loto_carnagione_scura:',
        'fa': u':مرد_در_حالت_خلسه_پوست_آبنوسی:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_gelap:',
        'zh': u':盘腿的男人_较深肤色:'
    },
    u'\U0001F9D8\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧘🏻‍♂️
        'en' : ':man_in_lotus_position_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_helle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_claro:',
        'fr': ':homme_dans_la_posture_du_lotus_peau_claire:',
        'ja': u':ヨガのポーズをする男_薄い肌色:',
        'ko': u':가부좌한_남자_하얀_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_clara:',
        'it': ':uomo_in_posizione_del_loto_carnagione_chiara:',
        'fa': u':مرد_در_حالت_خلسه_پوست_سفید:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_cerah:',
        'zh': u':盘腿的男人_较浅肤色:'
    },
    u'\U0001F9D8\U0001F3FB\U0000200D\U00002642': { # 🧘🏻‍♂
        'en' : ':man_in_lotus_position_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_helle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_claro:',
        'fr': ':homme_dans_la_posture_du_lotus_peau_claire:',
        'ja': u':ヨガのポーズをする男_薄い肌色:',
        'ko': u':가부좌한_남자_하얀_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_clara:',
        'it': ':uomo_in_posizione_del_loto_carnagione_chiara:',
        'fa': u':مرد_در_حالت_خلسه_پوست_سفید:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_cerah:',
        'zh': u':盘腿的男人_较浅肤色:'
    },
    u'\U0001F9D8\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧘🏾‍♂️
        'en' : ':man_in_lotus_position_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_mitteldunkle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_oscuro_medio:',
        'fr': ':homme_dans_la_posture_du_lotus_peau_mate:',
        'ja': u':ヨガのポーズをする男_やや濃い肌色:',
        'ko': u':가부좌한_남자_진한_갈색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_morena_escura:',
        'it': ':uomo_in_posizione_del_loto_carnagione_abbastanza_scura:',
        'fa': u':مرد_در_حالت_خلسه_پوست_گندمی:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_gelap-sedang:',
        'zh': u':盘腿的男人_中等深肤色:'
    },
    u'\U0001F9D8\U0001F3FE\U0000200D\U00002642': { # 🧘🏾‍♂
        'en' : ':man_in_lotus_position_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_mitteldunkle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_oscuro_medio:',
        'fr': ':homme_dans_la_posture_du_lotus_peau_mate:',
        'ja': u':ヨガのポーズをする男_やや濃い肌色:',
        'ko': u':가부좌한_남자_진한_갈색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_morena_escura:',
        'it': ':uomo_in_posizione_del_loto_carnagione_abbastanza_scura:',
        'fa': u':مرد_در_حالت_خلسه_پوست_گندمی:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_gelap-sedang:',
        'zh': u':盘腿的男人_中等深肤色:'
    },
    u'\U0001F9D8\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧘🏼‍♂️
        'en' : ':man_in_lotus_position_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_mittelhelle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_claro_medio:',
        'fr': ':homme_dans_la_posture_du_lotus_peau_moyennement_claire:',
        'ja': u':ヨガのポーズをする男_やや薄い肌色:',
        'ko': u':가부좌한_남자_연한_갈색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_morena_clara:',
        'it': ':uomo_in_posizione_del_loto_carnagione_abbastanza_chiara:',
        'fa': u':مرد_در_حالت_خلسه_پوست_روشن:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_cerah-sedang:',
        'zh': u':盘腿的男人_中等浅肤色:'
    },
    u'\U0001F9D8\U0001F3FC\U0000200D\U00002642': { # 🧘🏼‍♂
        'en' : ':man_in_lotus_position_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_mittelhelle_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_claro_medio:',
        'fr': ':homme_dans_la_posture_du_lotus_peau_moyennement_claire:',
        'ja': u':ヨガのポーズをする男_やや薄い肌色:',
        'ko': u':가부좌한_남자_연한_갈색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_morena_clara:',
        'it': ':uomo_in_posizione_del_loto_carnagione_abbastanza_chiara:',
        'fa': u':مرد_در_حالت_خلسه_پوست_روشن:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_cerah-sedang:',
        'zh': u':盘腿的男人_中等浅肤色:'
    },
    u'\U0001F9D8\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧘🏽‍♂️
        'en' : ':man_in_lotus_position_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_mittlere_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_medio:',
        'fr': u':homme_dans_la_posture_du_lotus_peau_légèrement_mate:',
        'ja': u':ヨガのポーズをする男_中間の肌色:',
        'ko': u':가부좌한_남자_갈색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_morena:',
        'it': ':uomo_in_posizione_del_loto_carnagione_olivastra:',
        'fa': u':مرد_در_حالت_خلسه_پوست_طلایی:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_sedang:',
        'zh': u':盘腿的男人_中等肤色:'
    },
    u'\U0001F9D8\U0001F3FD\U0000200D\U00002642': { # 🧘🏽‍♂
        'en' : ':man_in_lotus_position_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_im_lotossitz_mittlere_hautfarbe:',
        'es': u':hombre_en_posición_de_loto_tono_de_piel_medio:',
        'fr': u':homme_dans_la_posture_du_lotus_peau_légèrement_mate:',
        'ja': u':ヨガのポーズをする男_中間の肌色:',
        'ko': u':가부좌한_남자_갈색_피부:',
        'pt': u':homem_na_posição_de_lótus_pele_morena:',
        'it': ':uomo_in_posizione_del_loto_carnagione_olivastra:',
        'fa': u':مرد_در_حالت_خلسه_پوست_طلایی:',
        'id': ':pria_dalam_posisi_teratai_warna_kulit_sedang:',
        'zh': u':盘腿的男人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F9BD': { # 👨‍🦽
        'en' : ':man_in_manual_wheelchair:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_manuellem_rollstuhl:',
        'es': ':hombre_en_silla_de_ruedas_manual:',
        'fr': ':homme_en_fauteuil_roulant_manuel:',
        'ja': u':手動式車椅子の男性:',
        'ko': u':수동_휠체어를_탄_남자:',
        'pt': ':homem_em_cadeira_de_rodas_manual:',
        'it': ':uomo_su_sedia_a_rotelle_manuale:',
        'fa': u':مرد_در_صندلی_چرخ_دار_دستی:',
        'id': ':pria_dengan_kursi_roda_manual:',
        'zh': u':坐手动轮椅的男人:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F9BD': { # 👨🏿‍🦽
        'en' : ':man_in_manual_wheelchair_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_manuellem_rollstuhl_dunkle_hautfarbe:',
        'es': ':hombre_en_silla_de_ruedas_manual_tono_de_piel_oscuro:',
        'fr': u':homme_en_fauteuil_roulant_manuel_peau_foncée:',
        'ja': u':手動式車椅子の男性_濃い肌色:',
        'ko': u':수동_휠체어를_탄_남자_검은색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_manual_pele_escura:',
        'it': ':uomo_su_sedia_a_rotelle_manuale_carnagione_scura:',
        'fa': u':مرد_در_صندلی_چرخ_دار_دستی_پوست_آبنوسی:',
        'id': ':pria_dengan_kursi_roda_manual_warna_kulit_gelap:',
        'zh': u':坐手动轮椅的男人_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F9BD': { # 👨🏻‍🦽
        'en' : ':man_in_manual_wheelchair_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_manuellem_rollstuhl_helle_hautfarbe:',
        'es': ':hombre_en_silla_de_ruedas_manual_tono_de_piel_claro:',
        'fr': ':homme_en_fauteuil_roulant_manuel_peau_claire:',
        'ja': u':手動式車椅子の男性_薄い肌色:',
        'ko': u':수동_휠체어를_탄_남자_하얀_피부:',
        'pt': ':homem_em_cadeira_de_rodas_manual_pele_clara:',
        'it': ':uomo_su_sedia_a_rotelle_manuale_carnagione_chiara:',
        'fa': u':مرد_در_صندلی_چرخ_دار_دستی_پوست_سفید:',
        'id': ':pria_dengan_kursi_roda_manual_warna_kulit_cerah:',
        'zh': u':坐手动轮椅的男人_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F9BD': { # 👨🏾‍🦽
        'en' : ':man_in_manual_wheelchair_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_manuellem_rollstuhl_mitteldunkle_hautfarbe:',
        'es': ':hombre_en_silla_de_ruedas_manual_tono_de_piel_oscuro_medio:',
        'fr': ':homme_en_fauteuil_roulant_manuel_peau_mate:',
        'ja': u':手動式車椅子の男性_やや濃い肌色:',
        'ko': u':수동_휠체어를_탄_남자_진한_갈색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_manual_pele_morena_escura:',
        'it': ':uomo_su_sedia_a_rotelle_manuale_carnagione_abbastanza_scura:',
        'fa': u':مرد_در_صندلی_چرخ_دار_دستی_پوست_گندمی:',
        'id': ':pria_dengan_kursi_roda_manual_warna_kulit_gelap-sedang:',
        'zh': u':坐手动轮椅的男人_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F9BD': { # 👨🏼‍🦽
        'en' : ':man_in_manual_wheelchair_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_manuellem_rollstuhl_mittelhelle_hautfarbe:',
        'es': ':hombre_en_silla_de_ruedas_manual_tono_de_piel_claro_medio:',
        'fr': ':homme_en_fauteuil_roulant_manuel_peau_moyennement_claire:',
        'ja': u':手動式車椅子の男性_やや薄い肌色:',
        'ko': u':수동_휠체어를_탄_남자_연한_갈색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_manual_pele_morena_clara:',
        'it': ':uomo_su_sedia_a_rotelle_manuale_carnagione_abbastanza_chiara:',
        'fa': u':مرد_در_صندلی_چرخ_دار_دستی_پوست_روشن:',
        'id': ':pria_dengan_kursi_roda_manual_warna_kulit_cerah-sedang:',
        'zh': u':坐手动轮椅的男人_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F9BD': { # 👨🏽‍🦽
        'en' : ':man_in_manual_wheelchair_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_manuellem_rollstuhl_mittlere_hautfarbe:',
        'es': ':hombre_en_silla_de_ruedas_manual_tono_de_piel_medio:',
        'fr': u':homme_en_fauteuil_roulant_manuel_peau_légèrement_mate:',
        'ja': u':手動式車椅子の男性_中間の肌色:',
        'ko': u':수동_휠체어를_탄_남자_갈색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_manual_pele_morena:',
        'it': ':uomo_su_sedia_a_rotelle_manuale_carnagione_olivastra:',
        'fa': u':مرد_در_صندلی_چرخ_دار_دستی_پوست_طلایی:',
        'id': ':pria_dengan_kursi_roda_manual_warna_kulit_sedang:',
        'zh': u':坐手动轮椅的男人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F9BC': { # 👨‍🦼
        'en' : ':man_in_motorized_wheelchair:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_elektrischem_rollstuhl:',
        'es': u':hombre_en_silla_de_ruedas_eléctrica:',
        'fr': u':homme_en_fauteuil_motorisé:',
        'ja': u':電動車椅子の男性:',
        'ko': u':전동_휠체어를_탄_남자:',
        'pt': ':homem_em_cadeira_de_rodas_motorizada:',
        'it': ':uomo_su_sedia_a_rotelle_motorizzata:',
        'fa': u':مرد_در_صندلی_چرخ_دار_برقی:',
        'id': ':pria_dengan_kursi_roda_bermotor:',
        'zh': u':坐电动轮椅的男人:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F9BC': { # 👨🏿‍🦼
        'en' : ':man_in_motorized_wheelchair_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_elektrischem_rollstuhl_dunkle_hautfarbe:',
        'es': u':hombre_en_silla_de_ruedas_eléctrica_tono_de_piel_oscuro:',
        'fr': u':homme_en_fauteuil_motorisé_peau_foncée:',
        'ja': u':電動車椅子の男性_濃い肌色:',
        'ko': u':전동_휠체어를_탄_남자_검은색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_motorizada_pele_escura:',
        'it': ':uomo_su_sedia_a_rotelle_motorizzata_carnagione_scura:',
        'fa': u':مرد_در_صندلی_چرخ_دار_برقی_پوست_آبنوسی:',
        'id': ':pria_dengan_kursi_roda_bermotor_warna_kulit_gelap:',
        'zh': u':坐电动轮椅的男人_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F9BC': { # 👨🏻‍🦼
        'en' : ':man_in_motorized_wheelchair_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_elektrischem_rollstuhl_helle_hautfarbe:',
        'es': u':hombre_en_silla_de_ruedas_eléctrica_tono_de_piel_claro:',
        'fr': u':homme_en_fauteuil_motorisé_peau_claire:',
        'ja': u':電動車椅子の男性_薄い肌色:',
        'ko': u':전동_휠체어를_탄_남자_하얀_피부:',
        'pt': ':homem_em_cadeira_de_rodas_motorizada_pele_clara:',
        'it': ':uomo_su_sedia_a_rotelle_motorizzata_carnagione_chiara:',
        'fa': u':مرد_در_صندلی_چرخ_دار_برقی_پوست_سفید:',
        'id': ':pria_dengan_kursi_roda_bermotor_warna_kulit_cerah:',
        'zh': u':坐电动轮椅的男人_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F9BC': { # 👨🏾‍🦼
        'en' : ':man_in_motorized_wheelchair_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_elektrischem_rollstuhl_mitteldunkle_hautfarbe:',
        'es': u':hombre_en_silla_de_ruedas_eléctrica_tono_de_piel_oscuro_medio:',
        'fr': u':homme_en_fauteuil_motorisé_peau_mate:',
        'ja': u':電動車椅子の男性_やや濃い肌色:',
        'ko': u':전동_휠체어를_탄_남자_진한_갈색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_motorizada_pele_morena_escura:',
        'it': ':uomo_su_sedia_a_rotelle_motorizzata_carnagione_abbastanza_scura:',
        'fa': u':مرد_در_صندلی_چرخ_دار_برقی_پوست_گندمی:',
        'id': ':pria_dengan_kursi_roda_bermotor_warna_kulit_gelap-sedang:',
        'zh': u':坐电动轮椅的男人_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F9BC': { # 👨🏼‍🦼
        'en' : ':man_in_motorized_wheelchair_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_elektrischem_rollstuhl_mittelhelle_hautfarbe:',
        'es': u':hombre_en_silla_de_ruedas_eléctrica_tono_de_piel_claro_medio:',
        'fr': u':homme_en_fauteuil_motorisé_peau_moyennement_claire:',
        'ja': u':電動車椅子の男性_やや薄い肌色:',
        'ko': u':전동_휠체어를_탄_남자_연한_갈색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_motorizada_pele_morena_clara:',
        'it': ':uomo_su_sedia_a_rotelle_motorizzata_carnagione_abbastanza_chiara:',
        'fa': u':مرد_در_صندلی_چرخ_دار_برقی_پوست_روشن:',
        'id': ':pria_dengan_kursi_roda_bermotor_warna_kulit_cerah-sedang:',
        'zh': u':坐电动轮椅的男人_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F9BC': { # 👨🏽‍🦼
        'en' : ':man_in_motorized_wheelchair_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_in_elektrischem_rollstuhl_mittlere_hautfarbe:',
        'es': u':hombre_en_silla_de_ruedas_eléctrica_tono_de_piel_medio:',
        'fr': u':homme_en_fauteuil_motorisé_peau_légèrement_mate:',
        'ja': u':電動車椅子の男性_中間の肌色:',
        'ko': u':전동_휠체어를_탄_남자_갈색_피부:',
        'pt': ':homem_em_cadeira_de_rodas_motorizada_pele_morena:',
        'it': ':uomo_su_sedia_a_rotelle_motorizzata_carnagione_olivastra:',
        'fa': u':مرد_در_صندلی_چرخ_دار_برقی_پوست_طلایی:',
        'id': ':pria_dengan_kursi_roda_bermotor_warna_kulit_sedang:',
        'zh': u':坐电动轮椅的男人_中等肤色:'
    },
    u'\U0001F9D6\U0000200D\U00002642\U0000FE0F': { # 🧖‍♂️
        'en' : ':man_in_steamy_room:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':sauna_man:'],
        'de': ':mann_in_dampfsauna:',
        'es': ':hombre_en_una_sauna:',
        'fr': ':homme_au_hammam:',
        'ja': u':サウナに入る男:',
        'ko': u':사우나_하는_남자:',
        'pt': ':homem_na_sauna:',
        'it': ':uomo_in_sauna:',
        'fa': u':مرد_در_حمام_بخار:',
        'id': ':pria_di_ruangan_beruap:',
        'zh': u':蒸房里的男人:'
    },
    u'\U0001F9D6\U0000200D\U00002642': { # 🧖‍♂
        'en' : ':man_in_steamy_room:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':sauna_man:'],
        'de': ':mann_in_dampfsauna:',
        'es': ':hombre_en_una_sauna:',
        'fr': ':homme_au_hammam:',
        'ja': u':サウナに入る男:',
        'ko': u':사우나_하는_남자:',
        'pt': ':homem_na_sauna:',
        'it': ':uomo_in_sauna:',
        'fa': u':مرد_در_حمام_بخار:',
        'id': ':pria_di_ruangan_beruap:',
        'zh': u':蒸房里的男人:'
    },
    u'\U0001F9D6\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧖🏿‍♂️
        'en' : ':man_in_steamy_room_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_dunkle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_oscuro:',
        'fr': u':homme_au_hammam_peau_foncée:',
        'ja': u':サウナに入る男_濃い肌色:',
        'ko': u':사우나_하는_남자_검은색_피부:',
        'pt': ':homem_na_sauna_pele_escura:',
        'it': ':uomo_in_sauna_carnagione_scura:',
        'fa': u':مرد_در_حمام_بخار_پوست_آبنوسی:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_gelap:',
        'zh': u':蒸房里的男人_较深肤色:'
    },
    u'\U0001F9D6\U0001F3FF\U0000200D\U00002642': { # 🧖🏿‍♂
        'en' : ':man_in_steamy_room_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_dunkle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_oscuro:',
        'fr': u':homme_au_hammam_peau_foncée:',
        'ja': u':サウナに入る男_濃い肌色:',
        'ko': u':사우나_하는_남자_검은색_피부:',
        'pt': ':homem_na_sauna_pele_escura:',
        'it': ':uomo_in_sauna_carnagione_scura:',
        'fa': u':مرد_در_حمام_بخار_پوست_آبنوسی:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_gelap:',
        'zh': u':蒸房里的男人_较深肤色:'
    },
    u'\U0001F9D6\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧖🏻‍♂️
        'en' : ':man_in_steamy_room_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_helle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_claro:',
        'fr': ':homme_au_hammam_peau_claire:',
        'ja': u':サウナに入る男_薄い肌色:',
        'ko': u':사우나_하는_남자_하얀_피부:',
        'pt': ':homem_na_sauna_pele_clara:',
        'it': ':uomo_in_sauna_carnagione_chiara:',
        'fa': u':مرد_در_حمام_بخار_پوست_سفید:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_cerah:',
        'zh': u':蒸房里的男人_较浅肤色:'
    },
    u'\U0001F9D6\U0001F3FB\U0000200D\U00002642': { # 🧖🏻‍♂
        'en' : ':man_in_steamy_room_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_helle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_claro:',
        'fr': ':homme_au_hammam_peau_claire:',
        'ja': u':サウナに入る男_薄い肌色:',
        'ko': u':사우나_하는_남자_하얀_피부:',
        'pt': ':homem_na_sauna_pele_clara:',
        'it': ':uomo_in_sauna_carnagione_chiara:',
        'fa': u':مرد_در_حمام_بخار_پوست_سفید:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_cerah:',
        'zh': u':蒸房里的男人_较浅肤色:'
    },
    u'\U0001F9D6\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧖🏾‍♂️
        'en' : ':man_in_steamy_room_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_mitteldunkle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_oscuro_medio:',
        'fr': ':homme_au_hammam_peau_mate:',
        'ja': u':サウナに入る男_やや濃い肌色:',
        'ko': u':사우나_하는_남자_진한_갈색_피부:',
        'pt': ':homem_na_sauna_pele_morena_escura:',
        'it': ':uomo_in_sauna_carnagione_abbastanza_scura:',
        'fa': u':مرد_در_حمام_بخار_پوست_گندمی:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_gelap-sedang:',
        'zh': u':蒸房里的男人_中等深肤色:'
    },
    u'\U0001F9D6\U0001F3FE\U0000200D\U00002642': { # 🧖🏾‍♂
        'en' : ':man_in_steamy_room_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_mitteldunkle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_oscuro_medio:',
        'fr': ':homme_au_hammam_peau_mate:',
        'ja': u':サウナに入る男_やや濃い肌色:',
        'ko': u':사우나_하는_남자_진한_갈색_피부:',
        'pt': ':homem_na_sauna_pele_morena_escura:',
        'it': ':uomo_in_sauna_carnagione_abbastanza_scura:',
        'fa': u':مرد_در_حمام_بخار_پوست_گندمی:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_gelap-sedang:',
        'zh': u':蒸房里的男人_中等深肤色:'
    },
    u'\U0001F9D6\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧖🏼‍♂️
        'en' : ':man_in_steamy_room_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_mittelhelle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_claro_medio:',
        'fr': ':homme_au_hammam_peau_moyennement_claire:',
        'ja': u':サウナに入る男_やや薄い肌色:',
        'ko': u':사우나_하는_남자_연한_갈색_피부:',
        'pt': ':homem_na_sauna_pele_morena_clara:',
        'it': ':uomo_in_sauna_carnagione_abbastanza_chiara:',
        'fa': u':مرد_در_حمام_بخار_پوست_روشن:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_cerah-sedang:',
        'zh': u':蒸房里的男人_中等浅肤色:'
    },
    u'\U0001F9D6\U0001F3FC\U0000200D\U00002642': { # 🧖🏼‍♂
        'en' : ':man_in_steamy_room_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_mittelhelle_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_claro_medio:',
        'fr': ':homme_au_hammam_peau_moyennement_claire:',
        'ja': u':サウナに入る男_やや薄い肌色:',
        'ko': u':사우나_하는_남자_연한_갈색_피부:',
        'pt': ':homem_na_sauna_pele_morena_clara:',
        'it': ':uomo_in_sauna_carnagione_abbastanza_chiara:',
        'fa': u':مرد_در_حمام_بخار_پوست_روشن:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_cerah-sedang:',
        'zh': u':蒸房里的男人_中等浅肤色:'
    },
    u'\U0001F9D6\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧖🏽‍♂️
        'en' : ':man_in_steamy_room_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_mittlere_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_medio:',
        'fr': u':homme_au_hammam_peau_légèrement_mate:',
        'ja': u':サウナに入る男_中間の肌色:',
        'ko': u':사우나_하는_남자_갈색_피부:',
        'pt': ':homem_na_sauna_pele_morena:',
        'it': ':uomo_in_sauna_carnagione_olivastra:',
        'fa': u':مرد_در_حمام_بخار_پوست_طلایی:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_sedang:',
        'zh': u':蒸房里的男人_中等肤色:'
    },
    u'\U0001F9D6\U0001F3FD\U0000200D\U00002642': { # 🧖🏽‍♂
        'en' : ':man_in_steamy_room_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':mann_in_dampfsauna_mittlere_hautfarbe:',
        'es': ':hombre_en_una_sauna_tono_de_piel_medio:',
        'fr': u':homme_au_hammam_peau_légèrement_mate:',
        'ja': u':サウナに入る男_中間の肌色:',
        'ko': u':사우나_하는_남자_갈색_피부:',
        'pt': ':homem_na_sauna_pele_morena:',
        'it': ':uomo_in_sauna_carnagione_olivastra:',
        'fa': u':مرد_در_حمام_بخار_پوست_طلایی:',
        'id': ':pria_di_ruangan_beruap_warna_kulit_sedang:',
        'zh': u':蒸房里的男人_中等肤色:'
    },
    u'\U0001F935\U0000200D\U00002642\U0000FE0F': { # 🤵‍♂️
        'en' : ':man_in_tuxedo:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_im_smoking:',
        'es': ':hombre_con_esmoquin:',
        'fr': ':homme_en_smoking:',
        'ja': u':タキシードの男性:',
        'ko': u':턱시도를_입은_남자:',
        'pt': ':homem_de_smoking:',
        'it': ':uomo_in_smoking:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون:',
        'id': ':pria_dewasa_bertuksedo:',
        'zh': u':穿礼服的男人:'
    },
    u'\U0001F935\U0000200D\U00002642': { # 🤵‍♂
        'en' : ':man_in_tuxedo:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_im_smoking:',
        'es': ':hombre_con_esmoquin:',
        'fr': ':homme_en_smoking:',
        'ja': u':タキシードの男性:',
        'ko': u':턱시도를_입은_남자:',
        'pt': ':homem_de_smoking:',
        'it': ':uomo_in_smoking:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون:',
        'id': ':pria_dewasa_bertuksedo:',
        'zh': u':穿礼服的男人:'
    },
    u'\U0001F935\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🤵🏿‍♂️
        'en' : ':man_in_tuxedo_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_dunkle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_oscuro:',
        'fr': u':homme_en_smoking_peau_foncée:',
        'ja': u':タキシードの男性_濃い肌色:',
        'ko': u':턱시도를_입은_남자_검은색_피부:',
        'pt': ':homem_de_smoking_pele_escura:',
        'it': ':uomo_in_smoking_carnagione_scura:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_آبنوسی:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_gelap:',
        'zh': u':穿礼服的男人_较深肤色:'
    },
    u'\U0001F935\U0001F3FF\U0000200D\U00002642': { # 🤵🏿‍♂
        'en' : ':man_in_tuxedo_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_dunkle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_oscuro:',
        'fr': u':homme_en_smoking_peau_foncée:',
        'ja': u':タキシードの男性_濃い肌色:',
        'ko': u':턱시도를_입은_남자_검은색_피부:',
        'pt': ':homem_de_smoking_pele_escura:',
        'it': ':uomo_in_smoking_carnagione_scura:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_آبنوسی:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_gelap:',
        'zh': u':穿礼服的男人_较深肤色:'
    },
    u'\U0001F935\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🤵🏻‍♂️
        'en' : ':man_in_tuxedo_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_helle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_claro:',
        'fr': ':homme_en_smoking_peau_claire:',
        'ja': u':タキシードの男性_薄い肌色:',
        'ko': u':턱시도를_입은_남자_하얀_피부:',
        'pt': ':homem_de_smoking_pele_clara:',
        'it': ':uomo_in_smoking_carnagione_chiara:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_سفید:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_cerah:',
        'zh': u':穿礼服的男人_较浅肤色:'
    },
    u'\U0001F935\U0001F3FB\U0000200D\U00002642': { # 🤵🏻‍♂
        'en' : ':man_in_tuxedo_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_helle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_claro:',
        'fr': ':homme_en_smoking_peau_claire:',
        'ja': u':タキシードの男性_薄い肌色:',
        'ko': u':턱시도를_입은_남자_하얀_피부:',
        'pt': ':homem_de_smoking_pele_clara:',
        'it': ':uomo_in_smoking_carnagione_chiara:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_سفید:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_cerah:',
        'zh': u':穿礼服的男人_较浅肤色:'
    },
    u'\U0001F935\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🤵🏾‍♂️
        'en' : ':man_in_tuxedo_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_oscuro_medio:',
        'fr': ':homme_en_smoking_peau_mate:',
        'ja': u':タキシードの男性_やや濃い肌色:',
        'ko': u':턱시도를_입은_남자_진한_갈색_피부:',
        'pt': ':homem_de_smoking_pele_morena_escura:',
        'it': ':uomo_in_smoking_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_گندمی:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_gelap-sedang:',
        'zh': u':穿礼服的男人_中等深肤色:'
    },
    u'\U0001F935\U0001F3FE\U0000200D\U00002642': { # 🤵🏾‍♂
        'en' : ':man_in_tuxedo_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_oscuro_medio:',
        'fr': ':homme_en_smoking_peau_mate:',
        'ja': u':タキシードの男性_やや濃い肌色:',
        'ko': u':턱시도를_입은_남자_진한_갈색_피부:',
        'pt': ':homem_de_smoking_pele_morena_escura:',
        'it': ':uomo_in_smoking_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_گندمی:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_gelap-sedang:',
        'zh': u':穿礼服的男人_中等深肤色:'
    },
    u'\U0001F935\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🤵🏼‍♂️
        'en' : ':man_in_tuxedo_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_mittelhelle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_claro_medio:',
        'fr': ':homme_en_smoking_peau_moyennement_claire:',
        'ja': u':タキシードの男性_やや薄い肌色:',
        'ko': u':턱시도를_입은_남자_연한_갈색_피부:',
        'pt': ':homem_de_smoking_pele_morena_clara:',
        'it': ':uomo_in_smoking_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_روشن:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_cerah-sedang:',
        'zh': u':穿礼服的男人_中等浅肤色:'
    },
    u'\U0001F935\U0001F3FC\U0000200D\U00002642': { # 🤵🏼‍♂
        'en' : ':man_in_tuxedo_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_mittelhelle_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_claro_medio:',
        'fr': ':homme_en_smoking_peau_moyennement_claire:',
        'ja': u':タキシードの男性_やや薄い肌色:',
        'ko': u':턱시도를_입은_남자_연한_갈색_피부:',
        'pt': ':homem_de_smoking_pele_morena_clara:',
        'it': ':uomo_in_smoking_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_روشن:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_cerah-sedang:',
        'zh': u':穿礼服的男人_中等浅肤色:'
    },
    u'\U0001F935\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🤵🏽‍♂️
        'en' : ':man_in_tuxedo_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_mittlere_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_medio:',
        'fr': u':homme_en_smoking_peau_légèrement_mate:',
        'ja': u':タキシードの男性_中間の肌色:',
        'ko': u':턱시도를_입은_남자_갈색_피부:',
        'pt': ':homem_de_smoking_pele_morena:',
        'it': ':uomo_in_smoking_carnagione_olivastra:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_طلایی:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_sedang:',
        'zh': u':穿礼服的男人_中等肤色:'
    },
    u'\U0001F935\U0001F3FD\U0000200D\U00002642': { # 🤵🏽‍♂
        'en' : ':man_in_tuxedo_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_im_smoking_mittlere_hautfarbe:',
        'es': ':hombre_con_esmoquin_tono_de_piel_medio:',
        'fr': u':homme_en_smoking_peau_légèrement_mate:',
        'ja': u':タキシードの男性_中間の肌色:',
        'ko': u':턱시도를_입은_남자_갈색_피부:',
        'pt': ':homem_de_smoking_pele_morena:',
        'it': ':uomo_in_smoking_carnagione_olivastra:',
        'fa': u':مرد_با_کت_و_شلوار_و_پاپیون_پوست_طلایی:',
        'id': ':pria_dewasa_bertuksedo_warna_kulit_sedang:',
        'zh': u':穿礼服的男人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U00002696\U0000FE0F': { # 👨‍⚖️
        'en' : ':man_judge:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richter:',
        'es': ':fiscal_hombre:',
        'fr': ':juge_homme:',
        'ja': u':男性の裁判官:',
        'ko': u':남자_판사:',
        'pt': ':juiz:',
        'it': ':giudice_uomo:',
        'fa': u':قاضی_مرد:',
        'id': ':hakim_pria:',
        'zh': u':男法官:'
    },
    u'\U0001F468\U0000200D\U00002696': { # 👨‍⚖
        'en' : ':man_judge:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richter:',
        'es': ':fiscal_hombre:',
        'fr': ':juge_homme:',
        'ja': u':男性の裁判官:',
        'ko': u':남자_판사:',
        'pt': ':juiz:',
        'it': ':giudice_uomo:',
        'fa': u':قاضی_مرد:',
        'id': ':hakim_pria:',
        'zh': u':男法官:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002696\U0000FE0F': { # 👨🏿‍⚖️
        'en' : ':man_judge_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richter_dunkle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_oscuro:',
        'fr': u':juge_homme_peau_foncée:',
        'ja': u':男性の裁判官_濃い肌色:',
        'ko': u':남자_판사_검은색_피부:',
        'pt': ':juiz_pele_escura:',
        'it': ':giudice_uomo_carnagione_scura:',
        'fa': u':قاضی_مرد_پوست_آبنوسی:',
        'id': ':hakim_pria_warna_kulit_gelap:',
        'zh': u':男法官_较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002696': { # 👨🏿‍⚖
        'en' : ':man_judge_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richter_dunkle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_oscuro:',
        'fr': u':juge_homme_peau_foncée:',
        'ja': u':男性の裁判官_濃い肌色:',
        'ko': u':남자_판사_검은색_피부:',
        'pt': ':juiz_pele_escura:',
        'it': ':giudice_uomo_carnagione_scura:',
        'fa': u':قاضی_مرد_پوست_آبنوسی:',
        'id': ':hakim_pria_warna_kulit_gelap:',
        'zh': u':男法官_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002696\U0000FE0F': { # 👨🏻‍⚖️
        'en' : ':man_judge_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richter_helle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_claro:',
        'fr': ':juge_homme_peau_claire:',
        'ja': u':男性の裁判官_薄い肌色:',
        'ko': u':남자_판사_하얀_피부:',
        'pt': ':juiz_pele_clara:',
        'it': ':giudice_uomo_carnagione_chiara:',
        'fa': u':قاضی_مرد_پوست_سفید:',
        'id': ':hakim_pria_warna_kulit_cerah:',
        'zh': u':男法官_较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002696': { # 👨🏻‍⚖
        'en' : ':man_judge_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richter_helle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_claro:',
        'fr': ':juge_homme_peau_claire:',
        'ja': u':男性の裁判官_薄い肌色:',
        'ko': u':남자_판사_하얀_피부:',
        'pt': ':juiz_pele_clara:',
        'it': ':giudice_uomo_carnagione_chiara:',
        'fa': u':قاضی_مرد_پوست_سفید:',
        'id': ':hakim_pria_warna_kulit_cerah:',
        'zh': u':男法官_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002696\U0000FE0F': { # 👨🏾‍⚖️
        'en' : ':man_judge_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richter_mitteldunkle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':juge_homme_peau_mate:',
        'ja': u':男性の裁判官_やや濃い肌色:',
        'ko': u':남자_판사_진한_갈색_피부:',
        'pt': ':juiz_pele_morena_escura:',
        'it': ':giudice_uomo_carnagione_abbastanza_scura:',
        'fa': u':قاضی_مرد_پوست_گندمی:',
        'id': ':hakim_pria_warna_kulit_gelap-sedang:',
        'zh': u':男法官_中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002696': { # 👨🏾‍⚖
        'en' : ':man_judge_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richter_mitteldunkle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':juge_homme_peau_mate:',
        'ja': u':男性の裁判官_やや濃い肌色:',
        'ko': u':남자_판사_진한_갈색_피부:',
        'pt': ':juiz_pele_morena_escura:',
        'it': ':giudice_uomo_carnagione_abbastanza_scura:',
        'fa': u':قاضی_مرد_پوست_گندمی:',
        'id': ':hakim_pria_warna_kulit_gelap-sedang:',
        'zh': u':男法官_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002696\U0000FE0F': { # 👨🏼‍⚖️
        'en' : ':man_judge_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richter_mittelhelle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_claro_medio:',
        'fr': ':juge_homme_peau_moyennement_claire:',
        'ja': u':男性の裁判官_やや薄い肌色:',
        'ko': u':남자_판사_연한_갈색_피부:',
        'pt': ':juiz_pele_morena_clara:',
        'it': ':giudice_uomo_carnagione_abbastanza_chiara:',
        'fa': u':قاضی_مرد_پوست_روشن:',
        'id': ':hakim_pria_warna_kulit_cerah-sedang:',
        'zh': u':男法官_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002696': { # 👨🏼‍⚖
        'en' : ':man_judge_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richter_mittelhelle_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_claro_medio:',
        'fr': ':juge_homme_peau_moyennement_claire:',
        'ja': u':男性の裁判官_やや薄い肌色:',
        'ko': u':남자_판사_연한_갈색_피부:',
        'pt': ':juiz_pele_morena_clara:',
        'it': ':giudice_uomo_carnagione_abbastanza_chiara:',
        'fa': u':قاضی_مرد_پوست_روشن:',
        'id': ':hakim_pria_warna_kulit_cerah-sedang:',
        'zh': u':男法官_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002696\U0000FE0F': { # 👨🏽‍⚖️
        'en' : ':man_judge_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richter_mittlere_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_medio:',
        'fr': u':juge_homme_peau_légèrement_mate:',
        'ja': u':男性の裁判官_中間の肌色:',
        'ko': u':남자_판사_갈색_피부:',
        'pt': ':juiz_pele_morena:',
        'it': ':giudice_uomo_carnagione_olivastra:',
        'fa': u':قاضی_مرد_پوست_طلایی:',
        'id': ':hakim_pria_warna_kulit_sedang:',
        'zh': u':男法官_中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002696': { # 👨🏽‍⚖
        'en' : ':man_judge_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richter_mittlere_hautfarbe:',
        'es': ':fiscal_hombre_tono_de_piel_medio:',
        'fr': u':juge_homme_peau_légèrement_mate:',
        'ja': u':男性の裁判官_中間の肌色:',
        'ko': u':남자_판사_갈색_피부:',
        'pt': ':juiz_pele_morena:',
        'it': ':giudice_uomo_carnagione_olivastra:',
        'fa': u':قاضی_مرد_پوست_طلایی:',
        'id': ':hakim_pria_warna_kulit_sedang:',
        'zh': u':男法官_中等肤色:'
    },
    u'\U0001F939\U0000200D\U00002642\U0000FE0F': { # 🤹‍♂️
        'en' : ':man_juggling:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleur:',
        'es': ':hombre_haciendo_malabares:',
        'fr': ':jongleur:',
        'ja': u':ジャグリングをする男:',
        'ko': u':저글링하는_남자:',
        'pt': ':homem_malabarista:',
        'it': ':giocoliere_uomo:',
        'fa': u':مرد_ژانگولربازی_می_کند:',
        'id': ':pria_melempar:',
        'zh': u':男生抛接杂耍:'
    },
    u'\U0001F939\U0000200D\U00002642': { # 🤹‍♂
        'en' : ':man_juggling:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleur:',
        'es': ':hombre_haciendo_malabares:',
        'fr': ':jongleur:',
        'ja': u':ジャグリングをする男:',
        'ko': u':저글링하는_남자:',
        'pt': ':homem_malabarista:',
        'it': ':giocoliere_uomo:',
        'fa': u':مرد_ژانگولربازی_می_کند:',
        'id': ':pria_melempar:',
        'zh': u':男生抛接杂耍:'
    },
    u'\U0001F939\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🤹🏿‍♂️
        'en' : ':man_juggling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleur_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_oscuro:',
        'fr': u':jongleur_peau_foncée:',
        'ja': u':ジャグリングをする男_濃い肌色:',
        'ko': u':저글링하는_남자_검은색_피부:',
        'pt': ':homem_malabarista_pele_escura:',
        'it': ':giocoliere_uomo_carnagione_scura:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_آبنوسی:',
        'id': ':pria_melempar_warna_kulit_gelap:',
        'zh': u':男生抛接杂耍_较深肤色:'
    },
    u'\U0001F939\U0001F3FF\U0000200D\U00002642': { # 🤹🏿‍♂
        'en' : ':man_juggling_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleur_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_oscuro:',
        'fr': u':jongleur_peau_foncée:',
        'ja': u':ジャグリングをする男_濃い肌色:',
        'ko': u':저글링하는_남자_검은색_피부:',
        'pt': ':homem_malabarista_pele_escura:',
        'it': ':giocoliere_uomo_carnagione_scura:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_آبنوسی:',
        'id': ':pria_melempar_warna_kulit_gelap:',
        'zh': u':男生抛接杂耍_较深肤色:'
    },
    u'\U0001F939\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🤹🏻‍♂️
        'en' : ':man_juggling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleur_helle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_claro:',
        'fr': ':jongleur_peau_claire:',
        'ja': u':ジャグリングをする男_薄い肌色:',
        'ko': u':저글링하는_남자_하얀_피부:',
        'pt': ':homem_malabarista_pele_clara:',
        'it': ':giocoliere_uomo_carnagione_chiara:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_سفید:',
        'id': ':pria_melempar_warna_kulit_cerah:',
        'zh': u':男生抛接杂耍_较浅肤色:'
    },
    u'\U0001F939\U0001F3FB\U0000200D\U00002642': { # 🤹🏻‍♂
        'en' : ':man_juggling_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleur_helle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_claro:',
        'fr': ':jongleur_peau_claire:',
        'ja': u':ジャグリングをする男_薄い肌色:',
        'ko': u':저글링하는_남자_하얀_피부:',
        'pt': ':homem_malabarista_pele_clara:',
        'it': ':giocoliere_uomo_carnagione_chiara:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_سفید:',
        'id': ':pria_melempar_warna_kulit_cerah:',
        'zh': u':男生抛接杂耍_较浅肤色:'
    },
    u'\U0001F939\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🤹🏾‍♂️
        'en' : ':man_juggling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleur_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_oscuro_medio:',
        'fr': ':jongleur_peau_mate:',
        'ja': u':ジャグリングをする男_やや濃い肌色:',
        'ko': u':저글링하는_남자_진한_갈색_피부:',
        'pt': ':homem_malabarista_pele_morena_escura:',
        'it': ':giocoliere_uomo_carnagione_abbastanza_scura:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_گندمی:',
        'id': ':pria_melempar_warna_kulit_gelap-sedang:',
        'zh': u':男生抛接杂耍_中等深肤色:'
    },
    u'\U0001F939\U0001F3FE\U0000200D\U00002642': { # 🤹🏾‍♂
        'en' : ':man_juggling_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleur_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_oscuro_medio:',
        'fr': ':jongleur_peau_mate:',
        'ja': u':ジャグリングをする男_やや濃い肌色:',
        'ko': u':저글링하는_남자_진한_갈색_피부:',
        'pt': ':homem_malabarista_pele_morena_escura:',
        'it': ':giocoliere_uomo_carnagione_abbastanza_scura:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_گندمی:',
        'id': ':pria_melempar_warna_kulit_gelap-sedang:',
        'zh': u':男生抛接杂耍_中等深肤色:'
    },
    u'\U0001F939\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🤹🏼‍♂️
        'en' : ':man_juggling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleur_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_claro_medio:',
        'fr': ':jongleur_peau_moyennement_claire:',
        'ja': u':ジャグリングをする男_やや薄い肌色:',
        'ko': u':저글링하는_남자_연한_갈색_피부:',
        'pt': ':homem_malabarista_pele_morena_clara:',
        'it': ':giocoliere_uomo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_روشن:',
        'id': ':pria_melempar_warna_kulit_cerah-sedang:',
        'zh': u':男生抛接杂耍_中等浅肤色:'
    },
    u'\U0001F939\U0001F3FC\U0000200D\U00002642': { # 🤹🏼‍♂
        'en' : ':man_juggling_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleur_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_claro_medio:',
        'fr': ':jongleur_peau_moyennement_claire:',
        'ja': u':ジャグリングをする男_やや薄い肌色:',
        'ko': u':저글링하는_남자_연한_갈색_피부:',
        'pt': ':homem_malabarista_pele_morena_clara:',
        'it': ':giocoliere_uomo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_روشن:',
        'id': ':pria_melempar_warna_kulit_cerah-sedang:',
        'zh': u':男生抛接杂耍_中等浅肤色:'
    },
    u'\U0001F939\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🤹🏽‍♂️
        'en' : ':man_juggling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleur_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_medio:',
        'fr': u':jongleur_peau_légèrement_mate:',
        'ja': u':ジャグリングをする男_中間の肌色:',
        'ko': u':저글링하는_남자_갈색_피부:',
        'pt': ':homem_malabarista_pele_morena:',
        'it': ':giocoliere_uomo_carnagione_olivastra:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_طلایی:',
        'id': ':pria_melempar_warna_kulit_sedang:',
        'zh': u':男生抛接杂耍_中等肤色:'
    },
    u'\U0001F939\U0001F3FD\U0000200D\U00002642': { # 🤹🏽‍♂
        'en' : ':man_juggling_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleur_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_malabares_tono_de_piel_medio:',
        'fr': u':jongleur_peau_légèrement_mate:',
        'ja': u':ジャグリングをする男_中間の肌色:',
        'ko': u':저글링하는_남자_갈색_피부:',
        'pt': ':homem_malabarista_pele_morena:',
        'it': ':giocoliere_uomo_carnagione_olivastra:',
        'fa': u':مرد_ژانگولربازی_می_کند_پوست_طلایی:',
        'id': ':pria_melempar_warna_kulit_sedang:',
        'zh': u':男生抛接杂耍_中等肤色:'
    },
    u'\U0001F9CE\U0000200D\U00002642\U0000FE0F': { # 🧎‍♂️
        'en' : ':man_kneeling:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':kneeling_man:'],
        'de': ':kniender_mann:',
        'es': ':hombre_de_rodillas:',
        'fr': u':homme_à_genoux:',
        'ja': u':正座する男性:',
        'ko': u':무릎을_꿇은_남자:',
        'pt': ':homem_ajoelhando:',
        'it': ':uomo_inginocchiato:',
        'fa': u':مرد_زانوزده:',
        'id': ':pria_berlutut:',
        'zh': u':跪下的男人:'
    },
    u'\U0001F9CE\U0000200D\U00002642': { # 🧎‍♂
        'en' : ':man_kneeling:',
        'status' : minimally_qualified,
        'E' : 12,
        'alias' : [':kneeling_man:'],
        'de': ':kniender_mann:',
        'es': ':hombre_de_rodillas:',
        'fr': u':homme_à_genoux:',
        'ja': u':正座する男性:',
        'ko': u':무릎을_꿇은_남자:',
        'pt': ':homem_ajoelhando:',
        'it': ':uomo_inginocchiato:',
        'fa': u':مرد_زانوزده:',
        'id': ':pria_berlutut:',
        'zh': u':跪下的男人:'
    },
    u'\U0001F9CE\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧎🏿‍♂️
        'en' : ':man_kneeling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniender_mann_dunkle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_oscuro:',
        'fr': u':homme_à_genoux_peau_foncée:',
        'ja': u':正座する男性_濃い肌色:',
        'ko': u':무릎을_꿇은_남자_검은색_피부:',
        'pt': ':homem_ajoelhando_pele_escura:',
        'it': ':uomo_inginocchiato_carnagione_scura:',
        'fa': u':مرد_زانوزده_پوست_آبنوسی:',
        'id': ':pria_berlutut_warna_kulit_gelap:',
        'zh': u':跪下的男人_较深肤色:'
    },
    u'\U0001F9CE\U0001F3FF\U0000200D\U00002642': { # 🧎🏿‍♂
        'en' : ':man_kneeling_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniender_mann_dunkle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_oscuro:',
        'fr': u':homme_à_genoux_peau_foncée:',
        'ja': u':正座する男性_濃い肌色:',
        'ko': u':무릎을_꿇은_남자_검은색_피부:',
        'pt': ':homem_ajoelhando_pele_escura:',
        'it': ':uomo_inginocchiato_carnagione_scura:',
        'fa': u':مرد_زانوزده_پوست_آبنوسی:',
        'id': ':pria_berlutut_warna_kulit_gelap:',
        'zh': u':跪下的男人_较深肤色:'
    },
    u'\U0001F9CE\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧎🏻‍♂️
        'en' : ':man_kneeling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniender_mann_helle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_claro:',
        'fr': u':homme_à_genoux_peau_claire:',
        'ja': u':正座する男性_薄い肌色:',
        'ko': u':무릎을_꿇은_남자_하얀_피부:',
        'pt': ':homem_ajoelhando_pele_clara:',
        'it': ':uomo_inginocchiato_carnagione_chiara:',
        'fa': u':مرد_زانوزده_پوست_سفید:',
        'id': ':pria_berlutut_warna_kulit_cerah:',
        'zh': u':跪下的男人_较浅肤色:'
    },
    u'\U0001F9CE\U0001F3FB\U0000200D\U00002642': { # 🧎🏻‍♂
        'en' : ':man_kneeling_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniender_mann_helle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_claro:',
        'fr': u':homme_à_genoux_peau_claire:',
        'ja': u':正座する男性_薄い肌色:',
        'ko': u':무릎을_꿇은_남자_하얀_피부:',
        'pt': ':homem_ajoelhando_pele_clara:',
        'it': ':uomo_inginocchiato_carnagione_chiara:',
        'fa': u':مرد_زانوزده_پوست_سفید:',
        'id': ':pria_berlutut_warna_kulit_cerah:',
        'zh': u':跪下的男人_较浅肤色:'
    },
    u'\U0001F9CE\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧎🏾‍♂️
        'en' : ':man_kneeling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_oscuro_medio:',
        'fr': u':homme_à_genoux_peau_mate:',
        'ja': u':正座する男性_やや濃い肌色:',
        'ko': u':무릎을_꿇은_남자_진한_갈색_피부:',
        'pt': ':homem_ajoelhando_pele_morena_escura:',
        'it': ':uomo_inginocchiato_carnagione_abbastanza_scura:',
        'fa': u':مرد_زانوزده_پوست_گندمی:',
        'id': ':pria_berlutut_warna_kulit_gelap-sedang:',
        'zh': u':跪下的男人_中等深肤色:'
    },
    u'\U0001F9CE\U0001F3FE\U0000200D\U00002642': { # 🧎🏾‍♂
        'en' : ':man_kneeling_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_oscuro_medio:',
        'fr': u':homme_à_genoux_peau_mate:',
        'ja': u':正座する男性_やや濃い肌色:',
        'ko': u':무릎을_꿇은_남자_진한_갈색_피부:',
        'pt': ':homem_ajoelhando_pele_morena_escura:',
        'it': ':uomo_inginocchiato_carnagione_abbastanza_scura:',
        'fa': u':مرد_زانوزده_پوست_گندمی:',
        'id': ':pria_berlutut_warna_kulit_gelap-sedang:',
        'zh': u':跪下的男人_中等深肤色:'
    },
    u'\U0001F9CE\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧎🏼‍♂️
        'en' : ':man_kneeling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_claro_medio:',
        'fr': u':homme_à_genoux_peau_moyennement_claire:',
        'ja': u':正座する男性_やや薄い肌色:',
        'ko': u':무릎을_꿇은_남자_연한_갈색_피부:',
        'pt': ':homem_ajoelhando_pele_morena_clara:',
        'it': ':uomo_inginocchiato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_زانوزده_پوست_روشن:',
        'id': ':pria_berlutut_warna_kulit_cerah-sedang:',
        'zh': u':跪下的男人_中等浅肤色:'
    },
    u'\U0001F9CE\U0001F3FC\U0000200D\U00002642': { # 🧎🏼‍♂
        'en' : ':man_kneeling_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_claro_medio:',
        'fr': u':homme_à_genoux_peau_moyennement_claire:',
        'ja': u':正座する男性_やや薄い肌色:',
        'ko': u':무릎을_꿇은_남자_연한_갈색_피부:',
        'pt': ':homem_ajoelhando_pele_morena_clara:',
        'it': ':uomo_inginocchiato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_زانوزده_پوست_روشن:',
        'id': ':pria_berlutut_warna_kulit_cerah-sedang:',
        'zh': u':跪下的男人_中等浅肤色:'
    },
    u'\U0001F9CE\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧎🏽‍♂️
        'en' : ':man_kneeling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniender_mann_mittlere_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_medio:',
        'fr': u':homme_à_genoux_peau_légèrement_mate:',
        'ja': u':正座する男性_中間の肌色:',
        'ko': u':무릎을_꿇은_남자_갈색_피부:',
        'pt': ':homem_ajoelhando_pele_morena:',
        'it': ':uomo_inginocchiato_carnagione_olivastra:',
        'fa': u':مرد_زانوزده_پوست_طلایی:',
        'id': ':pria_berlutut_warna_kulit_sedang:',
        'zh': u':跪下的男人_中等肤色:'
    },
    u'\U0001F9CE\U0001F3FD\U0000200D\U00002642': { # 🧎🏽‍♂
        'en' : ':man_kneeling_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniender_mann_mittlere_hautfarbe:',
        'es': ':hombre_de_rodillas_tono_de_piel_medio:',
        'fr': u':homme_à_genoux_peau_légèrement_mate:',
        'ja': u':正座する男性_中間の肌色:',
        'ko': u':무릎을_꿇은_남자_갈색_피부:',
        'pt': ':homem_ajoelhando_pele_morena:',
        'it': ':uomo_inginocchiato_carnagione_olivastra:',
        'fa': u':مرد_زانوزده_پوست_طلایی:',
        'id': ':pria_berlutut_warna_kulit_sedang:',
        'zh': u':跪下的男人_中等肤色:'
    },
    u'\U0001F3CB\U0000FE0F\U0000200D\U00002642\U0000FE0F': { # 🏋️‍♂️
        'en' : ':man_lifting_weights:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':weight_lifting_man:'],
        'de': ':gewichtheber:',
        'es': ':hombre_levantando_pesas:',
        'fr': u':homme_haltérophile:',
        'ja': u':重量挙げをする男:',
        'ko': u':남자_역도_선수:',
        'pt': ':homem_levantando_peso:',
        'it': ':uomo_che_solleva_pesi:',
        'fa': u':وزنه_بردار_مرد:',
        'id': ':pria_mengangkat_beban:',
        'zh': u':男生举重:'
    },
    u'\U0001F3CB\U0000200D\U00002642\U0000FE0F': { # 🏋‍♂️
        'en' : ':man_lifting_weights:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':weight_lifting_man:'],
        'de': ':gewichtheber:',
        'es': ':hombre_levantando_pesas:',
        'fr': u':homme_haltérophile:',
        'ja': u':重量挙げをする男:',
        'ko': u':남자_역도_선수:',
        'pt': ':homem_levantando_peso:',
        'it': ':uomo_che_solleva_pesi:',
        'fa': u':وزنه_بردار_مرد:',
        'id': ':pria_mengangkat_beban:',
        'zh': u':男生举重:'
    },
    u'\U0001F3CB\U0000FE0F\U0000200D\U00002642': { # 🏋️‍♂
        'en' : ':man_lifting_weights:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':weight_lifting_man:'],
        'de': ':gewichtheber:',
        'es': ':hombre_levantando_pesas:',
        'fr': u':homme_haltérophile:',
        'ja': u':重量挙げをする男:',
        'ko': u':남자_역도_선수:',
        'pt': ':homem_levantando_peso:',
        'it': ':uomo_che_solleva_pesi:',
        'fa': u':وزنه_بردار_مرد:',
        'id': ':pria_mengangkat_beban:',
        'zh': u':男生举重:'
    },
    u'\U0001F3CB\U0000200D\U00002642': { # 🏋‍♂
        'en' : ':man_lifting_weights:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':weight_lifting_man:'],
        'de': ':gewichtheber:',
        'es': ':hombre_levantando_pesas:',
        'fr': u':homme_haltérophile:',
        'ja': u':重量挙げをする男:',
        'ko': u':남자_역도_선수:',
        'pt': ':homem_levantando_peso:',
        'it': ':uomo_che_solleva_pesi:',
        'fa': u':وزنه_بردار_مرد:',
        'id': ':pria_mengangkat_beban:',
        'zh': u':男生举重:'
    },
    u'\U0001F3CB\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🏋🏿‍♂️
        'en' : ':man_lifting_weights_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheber_dunkle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_oscuro:',
        'fr': u':homme_haltérophile_peau_foncée:',
        'ja': u':重量挙げをする男_濃い肌色:',
        'ko': u':남자_역도_선수_검은색_피부:',
        'pt': ':homem_levantando_peso_pele_escura:',
        'it': ':uomo_che_solleva_pesi_carnagione_scura:',
        'fa': u':وزنه_بردار_مرد_پوست_آبنوسی:',
        'id': ':pria_mengangkat_beban_warna_kulit_gelap:',
        'zh': u':男生举重_较深肤色:'
    },
    u'\U0001F3CB\U0001F3FF\U0000200D\U00002642': { # 🏋🏿‍♂
        'en' : ':man_lifting_weights_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheber_dunkle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_oscuro:',
        'fr': u':homme_haltérophile_peau_foncée:',
        'ja': u':重量挙げをする男_濃い肌色:',
        'ko': u':남자_역도_선수_검은색_피부:',
        'pt': ':homem_levantando_peso_pele_escura:',
        'it': ':uomo_che_solleva_pesi_carnagione_scura:',
        'fa': u':وزنه_بردار_مرد_پوست_آبنوسی:',
        'id': ':pria_mengangkat_beban_warna_kulit_gelap:',
        'zh': u':男生举重_较深肤色:'
    },
    u'\U0001F3CB\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🏋🏻‍♂️
        'en' : ':man_lifting_weights_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheber_helle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_claro:',
        'fr': u':homme_haltérophile_peau_claire:',
        'ja': u':重量挙げをする男_薄い肌色:',
        'ko': u':남자_역도_선수_하얀_피부:',
        'pt': ':homem_levantando_peso_pele_clara:',
        'it': ':uomo_che_solleva_pesi_carnagione_chiara:',
        'fa': u':وزنه_بردار_مرد_پوست_سفید:',
        'id': ':pria_mengangkat_beban_warna_kulit_cerah:',
        'zh': u':男生举重_较浅肤色:'
    },
    u'\U0001F3CB\U0001F3FB\U0000200D\U00002642': { # 🏋🏻‍♂
        'en' : ':man_lifting_weights_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheber_helle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_claro:',
        'fr': u':homme_haltérophile_peau_claire:',
        'ja': u':重量挙げをする男_薄い肌色:',
        'ko': u':남자_역도_선수_하얀_피부:',
        'pt': ':homem_levantando_peso_pele_clara:',
        'it': ':uomo_che_solleva_pesi_carnagione_chiara:',
        'fa': u':وزنه_بردار_مرد_پوست_سفید:',
        'id': ':pria_mengangkat_beban_warna_kulit_cerah:',
        'zh': u':男生举重_较浅肤色:'
    },
    u'\U0001F3CB\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🏋🏾‍♂️
        'en' : ':man_lifting_weights_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheber_mitteldunkle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_oscuro_medio:',
        'fr': u':homme_haltérophile_peau_mate:',
        'ja': u':重量挙げをする男_やや濃い肌色:',
        'ko': u':남자_역도_선수_진한_갈색_피부:',
        'pt': ':homem_levantando_peso_pele_morena_escura:',
        'it': ':uomo_che_solleva_pesi_carnagione_abbastanza_scura:',
        'fa': u':وزنه_بردار_مرد_پوست_گندمی:',
        'id': ':pria_mengangkat_beban_warna_kulit_gelap-sedang:',
        'zh': u':男生举重_中等深肤色:'
    },
    u'\U0001F3CB\U0001F3FE\U0000200D\U00002642': { # 🏋🏾‍♂
        'en' : ':man_lifting_weights_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheber_mitteldunkle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_oscuro_medio:',
        'fr': u':homme_haltérophile_peau_mate:',
        'ja': u':重量挙げをする男_やや濃い肌色:',
        'ko': u':남자_역도_선수_진한_갈색_피부:',
        'pt': ':homem_levantando_peso_pele_morena_escura:',
        'it': ':uomo_che_solleva_pesi_carnagione_abbastanza_scura:',
        'fa': u':وزنه_بردار_مرد_پوست_گندمی:',
        'id': ':pria_mengangkat_beban_warna_kulit_gelap-sedang:',
        'zh': u':男生举重_中等深肤色:'
    },
    u'\U0001F3CB\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🏋🏼‍♂️
        'en' : ':man_lifting_weights_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheber_mittelhelle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_claro_medio:',
        'fr': u':homme_haltérophile_peau_moyennement_claire:',
        'ja': u':重量挙げをする男_やや薄い肌色:',
        'ko': u':남자_역도_선수_연한_갈색_피부:',
        'pt': ':homem_levantando_peso_pele_morena_clara:',
        'it': ':uomo_che_solleva_pesi_carnagione_abbastanza_chiara:',
        'fa': u':وزنه_بردار_مرد_پوست_روشن:',
        'id': ':pria_mengangkat_beban_warna_kulit_cerah-sedang:',
        'zh': u':男生举重_中等浅肤色:'
    },
    u'\U0001F3CB\U0001F3FC\U0000200D\U00002642': { # 🏋🏼‍♂
        'en' : ':man_lifting_weights_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheber_mittelhelle_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_claro_medio:',
        'fr': u':homme_haltérophile_peau_moyennement_claire:',
        'ja': u':重量挙げをする男_やや薄い肌色:',
        'ko': u':남자_역도_선수_연한_갈색_피부:',
        'pt': ':homem_levantando_peso_pele_morena_clara:',
        'it': ':uomo_che_solleva_pesi_carnagione_abbastanza_chiara:',
        'fa': u':وزنه_بردار_مرد_پوست_روشن:',
        'id': ':pria_mengangkat_beban_warna_kulit_cerah-sedang:',
        'zh': u':男生举重_中等浅肤色:'
    },
    u'\U0001F3CB\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🏋🏽‍♂️
        'en' : ':man_lifting_weights_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheber_mittlere_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_medio:',
        'fr': u':homme_haltérophile_peau_légèrement_mate:',
        'ja': u':重量挙げをする男_中間の肌色:',
        'ko': u':남자_역도_선수_갈색_피부:',
        'pt': ':homem_levantando_peso_pele_morena:',
        'it': ':uomo_che_solleva_pesi_carnagione_olivastra:',
        'fa': u':وزنه_بردار_مرد_پوست_طلایی:',
        'id': ':pria_mengangkat_beban_warna_kulit_sedang:',
        'zh': u':男生举重_中等肤色:'
    },
    u'\U0001F3CB\U0001F3FD\U0000200D\U00002642': { # 🏋🏽‍♂
        'en' : ':man_lifting_weights_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheber_mittlere_hautfarbe:',
        'es': ':hombre_levantando_pesas_tono_de_piel_medio:',
        'fr': u':homme_haltérophile_peau_légèrement_mate:',
        'ja': u':重量挙げをする男_中間の肌色:',
        'ko': u':남자_역도_선수_갈색_피부:',
        'pt': ':homem_levantando_peso_pele_morena:',
        'it': ':uomo_che_solleva_pesi_carnagione_olivastra:',
        'fa': u':وزنه_بردار_مرد_پوست_طلایی:',
        'id': ':pria_mengangkat_beban_warna_kulit_sedang:',
        'zh': u':男生举重_中等肤色:'
    },
    u'\U0001F468\U0001F3FB': { # 👨🏻
        'en' : ':man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_helle_hautfarbe:',
        'es': ':hombre_tono_de_piel_claro:',
        'fr': ':homme_peau_claire:',
        'ja': u':男性_薄い肌色:',
        'ko': u':남자_하얀_피부:',
        'pt': ':homem_pele_clara:',
        'it': ':uomo_carnagione_chiara:',
        'fa': u':مرد_پوست_سفید:',
        'id': ':pria_warna_kulit_cerah:',
        'zh': u':男人_较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F9B2': { # 👨🏻‍🦲
        'en' : ':man_light_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_helle_hautfarbe,_glatze:',
        'es': ':hombre_tono_de_piel_claro_y_sin_pelo:',
        'fr': ':homme_peau_claire_et_chauve:',
        'ja': u':男性_薄い肌色_はげ頭:',
        'ko': u':남자_하얀_피부_대머리:',
        'pt': ':homem_pele_clara_e_careca:',
        'it': ':uomo_carnagione_chiara_e_calvo:',
        'fa': u':مرد_پوست_سفید_تاس:',
        'id': ':pria_warna_kulit_cerah_gundul:',
        'zh': u':男人_较浅肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧔🏻‍♂️
        'en' : ':man_light_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':mann_helle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_claro_y_barba:',
        'fr': ':homme_barbu__peau_claire:',
        'ja': u':あごひげの男性_薄い肌色:',
        'ko': u':수염_난_남자_하얀_피부:',
        'pt': ':homem_pele_clara_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_chiara:',
        'fa': u':مرد_پوست_سفید_ریش:',
        'id': ':pria_warna_kulit_cerah_janggut:',
        'zh': u':有络腮胡子的男人_较浅肤色:'
    },
    u'\U0001F9D4\U0001F3FB\U0000200D\U00002642': { # 🧔🏻‍♂
        'en' : ':man_light_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':mann_helle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_claro_y_barba:',
        'fr': ':homme_barbu__peau_claire:',
        'ja': u':あごひげの男性_薄い肌色:',
        'ko': u':수염_난_남자_하얀_피부:',
        'pt': ':homem_pele_clara_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_chiara:',
        'fa': u':مرد_پوست_سفید_ریش:',
        'id': ':pria_warna_kulit_cerah_janggut:',
        'zh': u':有络腮胡子的男人_较浅肤色:'
    },
    u'\U0001F471\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 👱🏻‍♂️
        'en' : ':man_light_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_helle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_claro:',
        'fr': ':homme_blond_peau_claire:',
        'ja': u':金髪の男性_薄い肌色:',
        'ko': u':금발_남자_하얀_피부:',
        'pt': ':homem_pele_clara_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_chiara:',
        'fa': u':مرد_پوست_سفید_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_cerah:',
        'zh': u':金发男_较浅肤色:'
    },
    u'\U0001F471\U0001F3FB\U0000200D\U00002642': { # 👱🏻‍♂
        'en' : ':man_light_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_helle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_claro:',
        'fr': ':homme_blond_peau_claire:',
        'ja': u':金髪の男性_薄い肌色:',
        'ko': u':금발_남자_하얀_피부:',
        'pt': ':homem_pele_clara_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_chiara:',
        'fa': u':مرد_پوست_سفید_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_cerah:',
        'zh': u':金发男_较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F9B1': { # 👨🏻‍🦱
        'en' : ':man_light_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_helle_hautfarbe,_lockiges_haar:',
        'es': ':hombre_tono_de_piel_claro_y_pelo_rizado:',
        'fr': u':homme_peau_claire_et_cheveux_bouclés:',
        'ja': u':男性_薄い肌色_巻き毛:',
        'ko': u':남자_하얀_피부_곱슬머리:',
        'pt': ':homem_pele_clara_e_cabelo_cacheado:',
        'it': ':uomo_carnagione_chiara_e_capelli_ricci:',
        'fa': u':مرد_پوست_سفید_موفرفری:',
        'id': ':pria_warna_kulit_cerah_rambut_keriting:',
        'zh': u':男人_较浅肤色卷发:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F9B0': { # 👨🏻‍🦰
        'en' : ':man_light_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_helle_hautfarbe,_rotes_haar:',
        'es': ':hombre_tono_de_piel_claro_y_pelo_pelirrojo:',
        'fr': ':homme_peau_claire_et_cheveux_roux:',
        'ja': u':男性_薄い肌色_赤毛:',
        'ko': u':남자_하얀_피부_빨간_머리:',
        'pt': ':homem_pele_clara_e_cabelo_vermelho:',
        'it': ':uomo_carnagione_chiara_e_capelli_rossi:',
        'fa': u':مرد_پوست_سفید_موقرمز:',
        'id': ':pria_warna_kulit_cerah_rambut_merah:',
        'zh': u':男人_较浅肤色红发:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F9B3': { # 👨🏻‍🦳
        'en' : ':man_light_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':mann_helle_hautfarbe,_weißes_haar:',
        'es': ':hombre_tono_de_piel_claro_y_pelo_blanco:',
        'fr': ':homme_peau_claire_et_cheveux_blancs:',
        'ja': u':男性_薄い肌色_白髪:',
        'ko': u':남자_하얀_피부_백발:',
        'pt': ':homem_pele_clara_e_cabelo_branco:',
        'it': ':uomo_carnagione_chiara_e_capelli_bianchi:',
        'fa': u':مرد_پوست_سفید_موسفید:',
        'id': ':pria_warna_kulit_cerah_rambut_putih:',
        'zh': u':男人_较浅肤色白发:'
    },
    u'\U0001F9D9\U0000200D\U00002642\U0000FE0F': { # 🧙‍♂️
        'en' : ':man_mage:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':mage_man:'],
        'de': ':magier:',
        'es': ':mago:',
        'fr': ':mage_homme:',
        'ja': u':男の魔法使い:',
        'ko': u':남자_마법사:',
        'pt': ':homem_mago:',
        'it': ':mago_uomo:',
        'fa': u':ساحر_مرد:',
        'id': ':magi_pria:',
        'zh': u':男法师:'
    },
    u'\U0001F9D9\U0000200D\U00002642': { # 🧙‍♂
        'en' : ':man_mage:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':mage_man:'],
        'de': ':magier:',
        'es': ':mago:',
        'fr': ':mage_homme:',
        'ja': u':男の魔法使い:',
        'ko': u':남자_마법사:',
        'pt': ':homem_mago:',
        'it': ':mago_uomo:',
        'fa': u':ساحر_مرد:',
        'id': ':magi_pria:',
        'zh': u':男法师:'
    },
    u'\U0001F9D9\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧙🏿‍♂️
        'en' : ':man_mage_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier_dunkle_hautfarbe:',
        'es': ':mago_tono_de_piel_oscuro:',
        'fr': u':mage_homme_peau_foncée:',
        'ja': u':男の魔法使い_濃い肌色:',
        'ko': u':남자_마법사_검은색_피부:',
        'pt': ':homem_mago_pele_escura:',
        'it': ':mago_uomo_carnagione_scura:',
        'fa': u':ساحر_مرد_پوست_آبنوسی:',
        'id': ':magi_pria_warna_kulit_gelap:',
        'zh': u':男法师_较深肤色:'
    },
    u'\U0001F9D9\U0001F3FF\U0000200D\U00002642': { # 🧙🏿‍♂
        'en' : ':man_mage_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magier_dunkle_hautfarbe:',
        'es': ':mago_tono_de_piel_oscuro:',
        'fr': u':mage_homme_peau_foncée:',
        'ja': u':男の魔法使い_濃い肌色:',
        'ko': u':남자_마법사_검은색_피부:',
        'pt': ':homem_mago_pele_escura:',
        'it': ':mago_uomo_carnagione_scura:',
        'fa': u':ساحر_مرد_پوست_آبنوسی:',
        'id': ':magi_pria_warna_kulit_gelap:',
        'zh': u':男法师_较深肤色:'
    },
    u'\U0001F9D9\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧙🏻‍♂️
        'en' : ':man_mage_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier_helle_hautfarbe:',
        'es': ':mago_tono_de_piel_claro:',
        'fr': ':mage_homme_peau_claire:',
        'ja': u':男の魔法使い_薄い肌色:',
        'ko': u':남자_마법사_하얀_피부:',
        'pt': ':homem_mago_pele_clara:',
        'it': ':mago_uomo_carnagione_chiara:',
        'fa': u':ساحر_مرد_پوست_سفید:',
        'id': ':magi_pria_warna_kulit_cerah:',
        'zh': u':男法师_较浅肤色:'
    },
    u'\U0001F9D9\U0001F3FB\U0000200D\U00002642': { # 🧙🏻‍♂
        'en' : ':man_mage_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magier_helle_hautfarbe:',
        'es': ':mago_tono_de_piel_claro:',
        'fr': ':mage_homme_peau_claire:',
        'ja': u':男の魔法使い_薄い肌色:',
        'ko': u':남자_마법사_하얀_피부:',
        'pt': ':homem_mago_pele_clara:',
        'it': ':mago_uomo_carnagione_chiara:',
        'fa': u':ساحر_مرد_پوست_سفید:',
        'id': ':magi_pria_warna_kulit_cerah:',
        'zh': u':男法师_较浅肤色:'
    },
    u'\U0001F9D9\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧙🏾‍♂️
        'en' : ':man_mage_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier_mitteldunkle_hautfarbe:',
        'es': ':mago_tono_de_piel_oscuro_medio:',
        'fr': ':mage_homme_peau_mate:',
        'ja': u':男の魔法使い_やや濃い肌色:',
        'ko': u':남자_마법사_진한_갈색_피부:',
        'pt': ':homem_mago_pele_morena_escura:',
        'it': ':mago_uomo_carnagione_abbastanza_scura:',
        'fa': u':ساحر_مرد_پوست_گندمی:',
        'id': ':magi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男法师_中等深肤色:'
    },
    u'\U0001F9D9\U0001F3FE\U0000200D\U00002642': { # 🧙🏾‍♂
        'en' : ':man_mage_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magier_mitteldunkle_hautfarbe:',
        'es': ':mago_tono_de_piel_oscuro_medio:',
        'fr': ':mage_homme_peau_mate:',
        'ja': u':男の魔法使い_やや濃い肌色:',
        'ko': u':남자_마법사_진한_갈색_피부:',
        'pt': ':homem_mago_pele_morena_escura:',
        'it': ':mago_uomo_carnagione_abbastanza_scura:',
        'fa': u':ساحر_مرد_پوست_گندمی:',
        'id': ':magi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男法师_中等深肤色:'
    },
    u'\U0001F9D9\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧙🏼‍♂️
        'en' : ':man_mage_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier_mittelhelle_hautfarbe:',
        'es': ':mago_tono_de_piel_claro_medio:',
        'fr': ':mage_homme_peau_moyennement_claire:',
        'ja': u':男の魔法使い_やや薄い肌色:',
        'ko': u':남자_마법사_연한_갈색_피부:',
        'pt': ':homem_mago_pele_morena_clara:',
        'it': ':mago_uomo_carnagione_abbastanza_chiara:',
        'fa': u':ساحر_مرد_پوست_روشن:',
        'id': ':magi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男法师_中等浅肤色:'
    },
    u'\U0001F9D9\U0001F3FC\U0000200D\U00002642': { # 🧙🏼‍♂
        'en' : ':man_mage_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magier_mittelhelle_hautfarbe:',
        'es': ':mago_tono_de_piel_claro_medio:',
        'fr': ':mage_homme_peau_moyennement_claire:',
        'ja': u':男の魔法使い_やや薄い肌色:',
        'ko': u':남자_마법사_연한_갈색_피부:',
        'pt': ':homem_mago_pele_morena_clara:',
        'it': ':mago_uomo_carnagione_abbastanza_chiara:',
        'fa': u':ساحر_مرد_پوست_روشن:',
        'id': ':magi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男法师_中等浅肤色:'
    },
    u'\U0001F9D9\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧙🏽‍♂️
        'en' : ':man_mage_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magier_mittlere_hautfarbe:',
        'es': ':mago_tono_de_piel_medio:',
        'fr': u':mage_homme_peau_légèrement_mate:',
        'ja': u':男の魔法使い_中間の肌色:',
        'ko': u':남자_마법사_갈색_피부:',
        'pt': ':homem_mago_pele_morena:',
        'it': ':mago_uomo_carnagione_olivastra:',
        'fa': u':ساحر_مرد_پوست_طلایی:',
        'id': ':magi_pria_warna_kulit_sedang:',
        'zh': u':男法师_中等肤色:'
    },
    u'\U0001F9D9\U0001F3FD\U0000200D\U00002642': { # 🧙🏽‍♂
        'en' : ':man_mage_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magier_mittlere_hautfarbe:',
        'es': ':mago_tono_de_piel_medio:',
        'fr': u':mage_homme_peau_légèrement_mate:',
        'ja': u':男の魔法使い_中間の肌色:',
        'ko': u':남자_마법사_갈색_피부:',
        'pt': ':homem_mago_pele_morena:',
        'it': ':mago_uomo_carnagione_olivastra:',
        'fa': u':ساحر_مرد_پوست_طلایی:',
        'id': ':magi_pria_warna_kulit_sedang:',
        'zh': u':男法师_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F527': { # 👨‍🔧
        'en' : ':man_mechanic:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechaniker:',
        'es': u':profesional_de_la_mecánica_hombre:',
        'fr': u':mécanicien:',
        'ja': u':男性の整備士:',
        'ko': u':남자_정비공:',
        'pt': u':mecânico:',
        'it': ':meccanico_uomo:',
        'fa': u':تعمیرکار_مرد:',
        'id': ':montir_pria:',
        'zh': u':男技工:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F527': { # 👨🏿‍🔧
        'en' : ':man_mechanic_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechaniker_dunkle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_hombre_tono_de_piel_oscuro:',
        'fr': u':mécanicien_peau_foncée:',
        'ja': u':男性の整備士_濃い肌色:',
        'ko': u':남자_정비공_검은색_피부:',
        'pt': u':mecânico_pele_escura:',
        'it': ':meccanico_uomo_carnagione_scura:',
        'fa': u':تعمیرکار_مرد_پوست_آبنوسی:',
        'id': ':montir_pria_warna_kulit_gelap:',
        'zh': u':男技工_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F527': { # 👨🏻‍🔧
        'en' : ':man_mechanic_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechaniker_helle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_hombre_tono_de_piel_claro:',
        'fr': u':mécanicien_peau_claire:',
        'ja': u':男性の整備士_薄い肌色:',
        'ko': u':남자_정비공_하얀_피부:',
        'pt': u':mecânico_pele_clara:',
        'it': ':meccanico_uomo_carnagione_chiara:',
        'fa': u':تعمیرکار_مرد_پوست_سفید:',
        'id': ':montir_pria_warna_kulit_cerah:',
        'zh': u':男技工_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F527': { # 👨🏾‍🔧
        'en' : ':man_mechanic_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechaniker_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':mécanicien_peau_mate:',
        'ja': u':男性の整備士_やや濃い肌色:',
        'ko': u':남자_정비공_진한_갈색_피부:',
        'pt': u':mecânico_pele_morena_escura:',
        'it': ':meccanico_uomo_carnagione_abbastanza_scura:',
        'fa': u':تعمیرکار_مرد_پوست_گندمی:',
        'id': ':montir_pria_warna_kulit_gelap-sedang:',
        'zh': u':男技工_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F527': { # 👨🏼‍🔧
        'en' : ':man_mechanic_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechaniker_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_hombre_tono_de_piel_claro_medio:',
        'fr': u':mécanicien_peau_moyennement_claire:',
        'ja': u':男性の整備士_やや薄い肌色:',
        'ko': u':남자_정비공_연한_갈색_피부:',
        'pt': u':mecânico_pele_morena_clara:',
        'it': ':meccanico_uomo_carnagione_abbastanza_chiara:',
        'fa': u':تعمیرکار_مرد_پوست_روشن:',
        'id': ':montir_pria_warna_kulit_cerah-sedang:',
        'zh': u':男技工_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F527': { # 👨🏽‍🔧
        'en' : ':man_mechanic_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechaniker_mittlere_hautfarbe:',
        'es': u':profesional_de_la_mecánica_hombre_tono_de_piel_medio:',
        'fr': u':mécanicien_peau_légèrement_mate:',
        'ja': u':男性の整備士_中間の肌色:',
        'ko': u':남자_정비공_갈색_피부:',
        'pt': u':mecânico_pele_morena:',
        'it': ':meccanico_uomo_carnagione_olivastra:',
        'fa': u':تعمیرکار_مرد_پوست_طلایی:',
        'id': ':montir_pria_warna_kulit_sedang:',
        'zh': u':男技工_中等肤色:'
    },
    u'\U0001F468\U0001F3FE': { # 👨🏾
        'en' : ':man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_tono_de_piel_oscuro_medio:',
        'fr': ':homme_peau_mate:',
        'ja': u':男性_やや濃い肌色:',
        'ko': u':남자_진한_갈색_피부:',
        'pt': ':homem_pele_morena_escura:',
        'it': ':uomo_carnagione_abbastanza_scura:',
        'fa': u':مرد_پوست_گندمی:',
        'id': ':pria_warna_kulit_gelap-sedang:',
        'zh': u':男人_中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F9B2': { # 👨🏾‍🦲
        'en' : ':man_medium-dark_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mitteldunkle_hautfarbe,_glatze:',
        'es': ':hombre_tono_de_piel_oscuro_medio_y_sin_pelo:',
        'fr': ':homme_peau_mate_et_chauve:',
        'ja': u':男性_やや濃い肌色_はげ頭:',
        'ko': u':남자_진한_갈색_피부_대머리:',
        'pt': ':homem_pele_morena_escura_e_careca:',
        'it': ':uomo_carnagione_abbastanza_scura_e_calvo:',
        'fa': u':مرد_پوست_گندمی_تاس:',
        'id': ':pria_warna_kulit_gelap-sedang_gundul:',
        'zh': u':男人_中等深肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧔🏾‍♂️
        'en' : ':man_medium-dark_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':mann_mitteldunkle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_oscuro_medio_y_barba:',
        'fr': ':homme_barbu__peau_mate:',
        'ja': u':あごひげの男性_やや濃い肌色:',
        'ko': u':수염_난_남자_진한_갈색_피부:',
        'pt': ':homem_pele_morena_escura_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_abbastanza_scura:',
        'fa': u':مرد_پوست_گندمی_ریش:',
        'id': ':pria_warna_kulit_gelap-sedang_janggut:',
        'zh': u':有络腮胡子的男人_中等深肤色:'
    },
    u'\U0001F9D4\U0001F3FE\U0000200D\U00002642': { # 🧔🏾‍♂
        'en' : ':man_medium-dark_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':mann_mitteldunkle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_oscuro_medio_y_barba:',
        'fr': ':homme_barbu__peau_mate:',
        'ja': u':あごひげの男性_やや濃い肌色:',
        'ko': u':수염_난_남자_진한_갈색_피부:',
        'pt': ':homem_pele_morena_escura_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_abbastanza_scura:',
        'fa': u':مرد_پوست_گندمی_ریش:',
        'id': ':pria_warna_kulit_gelap-sedang_janggut:',
        'zh': u':有络腮胡子的男人_中等深肤色:'
    },
    u'\U0001F471\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 👱🏾‍♂️
        'en' : ':man_medium-dark_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mitteldunkle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_oscuro_medio:',
        'fr': ':homme_blond_peau_mate:',
        'ja': u':金髪の男性_やや濃い肌色:',
        'ko': u':금발_남자_진한_갈색_피부:',
        'pt': ':homem_pele_morena_escura_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_abbastanza_scura:',
        'fa': u':مرد_پوست_گندمی_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_gelap-sedang:',
        'zh': u':金发男_中等深肤色:'
    },
    u'\U0001F471\U0001F3FE\U0000200D\U00002642': { # 👱🏾‍♂
        'en' : ':man_medium-dark_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mitteldunkle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_oscuro_medio:',
        'fr': ':homme_blond_peau_mate:',
        'ja': u':金髪の男性_やや濃い肌色:',
        'ko': u':금발_남자_진한_갈색_피부:',
        'pt': ':homem_pele_morena_escura_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_abbastanza_scura:',
        'fa': u':مرد_پوست_گندمی_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_gelap-sedang:',
        'zh': u':金发男_中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F9B1': { # 👨🏾‍🦱
        'en' : ':man_medium-dark_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mitteldunkle_hautfarbe,_lockiges_haar:',
        'es': ':hombre_tono_de_piel_oscuro_medio_y_pelo_rizado:',
        'fr': u':homme_peau_mate_et_cheveux_bouclés:',
        'ja': u':男性_やや濃い肌色_巻き毛:',
        'ko': u':남자_진한_갈색_피부_곱슬머리:',
        'pt': ':homem_pele_morena_escura_e_cabelo_cacheado:',
        'it': ':uomo_carnagione_abbastanza_scura_e_capelli_ricci:',
        'fa': u':مرد_پوست_گندمی_موفرفری:',
        'id': ':pria_warna_kulit_gelap-sedang_rambut_keriting:',
        'zh': u':男人_中等深肤色卷发:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F9B0': { # 👨🏾‍🦰
        'en' : ':man_medium-dark_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mitteldunkle_hautfarbe,_rotes_haar:',
        'es': ':hombre_tono_de_piel_oscuro_medio_y_pelo_pelirrojo:',
        'fr': ':homme_peau_mate_et_cheveux_roux:',
        'ja': u':男性_やや濃い肌色_赤毛:',
        'ko': u':남자_진한_갈색_피부_빨간_머리:',
        'pt': ':homem_pele_morena_escura_e_cabelo_vermelho:',
        'it': ':uomo_carnagione_abbastanza_scura_e_capelli_rossi:',
        'fa': u':مرد_پوست_گندمی_موقرمز:',
        'id': ':pria_warna_kulit_gelap-sedang_rambut_merah:',
        'zh': u':男人_中等深肤色红发:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F9B3': { # 👨🏾‍🦳
        'en' : ':man_medium-dark_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':mann_mitteldunkle_hautfarbe,_weißes_haar:',
        'es': ':hombre_tono_de_piel_oscuro_medio_y_pelo_blanco:',
        'fr': ':homme_peau_mate_et_cheveux_blancs:',
        'ja': u':男性_やや濃い肌色_白髪:',
        'ko': u':남자_진한_갈색_피부_백발:',
        'pt': ':homem_pele_morena_escura_e_cabelo_branco:',
        'it': ':uomo_carnagione_abbastanza_scura_e_capelli_bianchi:',
        'fa': u':مرد_پوست_گندمی_موسفید:',
        'id': ':pria_warna_kulit_gelap-sedang_rambut_putih:',
        'zh': u':男人_中等深肤色白发:'
    },
    u'\U0001F468\U0001F3FC': { # 👨🏼
        'en' : ':man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mittelhelle_hautfarbe:',
        'es': ':hombre_tono_de_piel_claro_medio:',
        'fr': ':homme_peau_moyennement_claire:',
        'ja': u':男性_やや薄い肌色:',
        'ko': u':남자_연한_갈색_피부:',
        'pt': ':homem_pele_morena_clara:',
        'it': ':uomo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پوست_روشن:',
        'id': ':pria_warna_kulit_cerah-sedang:',
        'zh': u':男人_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F9B2': { # 👨🏼‍🦲
        'en' : ':man_medium-light_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mittelhelle_hautfarbe,_glatze:',
        'es': ':hombre_tono_de_piel_claro_medio_y_sin_pelo:',
        'fr': ':homme_peau_moyennement_claire_et_chauve:',
        'ja': u':男性_やや薄い肌色_はげ頭:',
        'ko': u':남자_연한_갈색_피부_대머리:',
        'pt': ':homem_pele_morena_clara_e_careca:',
        'it': ':uomo_carnagione_abbastanza_chiara_e_calvo:',
        'fa': u':مرد_پوست_روشن_تاس:',
        'id': ':pria_warna_kulit_cerah-sedang_gundul:',
        'zh': u':男人_中等浅肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧔🏼‍♂️
        'en' : ':man_medium-light_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':mann_mittelhelle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_claro_medio_y_barba:',
        'fr': ':homme_barbu__peau_moyennement_claire:',
        'ja': u':あごひげの男性_やや薄い肌色:',
        'ko': u':수염_난_남자_연한_갈색_피부:',
        'pt': ':homem_pele_morena_clara_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پوست_روشن_ریش:',
        'id': ':pria_warna_kulit_cerah-sedang_janggut:',
        'zh': u':有络腮胡子的男人_中等浅肤色:'
    },
    u'\U0001F9D4\U0001F3FC\U0000200D\U00002642': { # 🧔🏼‍♂
        'en' : ':man_medium-light_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':mann_mittelhelle_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_claro_medio_y_barba:',
        'fr': ':homme_barbu__peau_moyennement_claire:',
        'ja': u':あごひげの男性_やや薄い肌色:',
        'ko': u':수염_난_남자_연한_갈색_피부:',
        'pt': ':homem_pele_morena_clara_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پوست_روشن_ریش:',
        'id': ':pria_warna_kulit_cerah-sedang_janggut:',
        'zh': u':有络腮胡子的男人_中等浅肤色:'
    },
    u'\U0001F471\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 👱🏼‍♂️
        'en' : ':man_medium-light_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mittelhelle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_claro_medio:',
        'fr': ':homme_blond_peau_moyennement_claire:',
        'ja': u':金髪の男性_やや薄い肌色:',
        'ko': u':금발_남자_연한_갈색_피부:',
        'pt': ':homem_pele_morena_clara_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پوست_روشن_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_cerah-sedang:',
        'zh': u':金发男_中等浅肤色:'
    },
    u'\U0001F471\U0001F3FC\U0000200D\U00002642': { # 👱🏼‍♂
        'en' : ':man_medium-light_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mittelhelle_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_claro_medio:',
        'fr': ':homme_blond_peau_moyennement_claire:',
        'ja': u':金髪の男性_やや薄い肌色:',
        'ko': u':금발_남자_연한_갈색_피부:',
        'pt': ':homem_pele_morena_clara_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پوست_روشن_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_cerah-sedang:',
        'zh': u':金发男_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F9B1': { # 👨🏼‍🦱
        'en' : ':man_medium-light_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mittelhelle_hautfarbe,_lockiges_haar:',
        'es': ':hombre_tono_de_piel_claro_medio_y_pelo_rizado:',
        'fr': u':homme_peau_moyennement_claire_et_cheveux_bouclés:',
        'ja': u':男性_やや薄い肌色_巻き毛:',
        'ko': u':남자_연한_갈색_피부_곱슬머리:',
        'pt': ':homem_pele_morena_clara_e_cabelo_cacheado:',
        'it': ':uomo_carnagione_abbastanza_chiara_e_capelli_ricci:',
        'fa': u':مرد_پوست_روشن_موفرفری:',
        'id': ':pria_warna_kulit_cerah-sedang_rambut_keriting:',
        'zh': u':男人_中等浅肤色卷发:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F9B0': { # 👨🏼‍🦰
        'en' : ':man_medium-light_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mittelhelle_hautfarbe,_rotes_haar:',
        'es': ':hombre_tono_de_piel_claro_medio_y_pelo_pelirrojo:',
        'fr': ':homme_peau_moyennement_claire_et_cheveux_roux:',
        'ja': u':男性_やや薄い肌色_赤毛:',
        'ko': u':남자_연한_갈색_피부_빨간_머리:',
        'pt': ':homem_pele_morena_clara_e_cabelo_vermelho:',
        'it': ':uomo_carnagione_abbastanza_chiara_e_capelli_rossi:',
        'fa': u':مرد_پوست_روشن_موقرمز:',
        'id': ':pria_warna_kulit_cerah-sedang_rambut_merah:',
        'zh': u':男人_中等浅肤色红发:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F9B3': { # 👨🏼‍🦳
        'en' : ':man_medium-light_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':mann_mittelhelle_hautfarbe,_weißes_haar:',
        'es': ':hombre_tono_de_piel_claro_medio_y_pelo_blanco:',
        'fr': ':homme_peau_moyennement_claire_et_cheveux_blancs:',
        'ja': u':男性_やや薄い肌色_白髪:',
        'ko': u':남자_연한_갈색_피부_백발:',
        'pt': ':homem_pele_morena_clara_e_cabelo_branco:',
        'it': ':uomo_carnagione_abbastanza_chiara_e_capelli_bianchi:',
        'fa': u':مرد_پوست_روشن_موسفید:',
        'id': ':pria_warna_kulit_cerah-sedang_rambut_putih:',
        'zh': u':男人_中等浅肤色白发:'
    },
    u'\U0001F468\U0001F3FD': { # 👨🏽
        'en' : ':man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mittlere_hautfarbe:',
        'es': ':hombre_tono_de_piel_medio:',
        'fr': u':homme_peau_légèrement_mate:',
        'ja': u':男性_中間の肌色:',
        'ko': u':남자_갈색_피부:',
        'pt': ':homem_pele_morena:',
        'it': ':uomo_carnagione_olivastra:',
        'fa': u':مرد_پوست_طلایی:',
        'id': ':pria_warna_kulit_sedang:',
        'zh': u':男人_中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F9B2': { # 👨🏽‍🦲
        'en' : ':man_medium_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mittlere_hautfarbe,_glatze:',
        'es': ':hombre_tono_de_piel_medio_y_sin_pelo:',
        'fr': u':homme_peau_légèrement_mate_et_chauve:',
        'ja': u':男性_中間の肌色_はげ頭:',
        'ko': u':남자_갈색_피부_대머리:',
        'pt': ':homem_pele_morena_e_careca:',
        'it': ':uomo_carnagione_olivastra_e_calvo:',
        'fa': u':مرد_پوست_طلایی_تاس:',
        'id': ':pria_warna_kulit_sedang_gundul:',
        'zh': u':男人_中等肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧔🏽‍♂️
        'en' : ':man_medium_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':mann_mittlere_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_medio_y_barba:',
        'fr': u':homme_barbu__peau_légèrement_mate:',
        'ja': u':あごひげの男性_中間の肌色:',
        'ko': u':수염_난_남자_갈색_피부:',
        'pt': ':homem_pele_morena_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_olivastra:',
        'fa': u':مرد_پوست_طلایی_ریش:',
        'id': ':pria_warna_kulit_sedang_janggut:',
        'zh': u':有络腮胡子的男人_中等肤色:'
    },
    u'\U0001F9D4\U0001F3FD\U0000200D\U00002642': { # 🧔🏽‍♂
        'en' : ':man_medium_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':mann_mittlere_hautfarbe_bart:',
        'es': ':hombre_tono_de_piel_medio_y_barba:',
        'fr': u':homme_barbu__peau_légèrement_mate:',
        'ja': u':あごひげの男性_中間の肌色:',
        'ko': u':수염_난_남자_갈색_피부:',
        'pt': ':homem_pele_morena_e_barbudo:',
        'it': ':uomo_con_la_barba_carnagione_olivastra:',
        'fa': u':مرد_پوست_طلایی_ریش:',
        'id': ':pria_warna_kulit_sedang_janggut:',
        'zh': u':有络腮胡子的男人_中等肤色:'
    },
    u'\U0001F471\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 👱🏽‍♂️
        'en' : ':man_medium_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mittlere_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_medio:',
        'fr': u':homme_blond_peau_légèrement_mate:',
        'ja': u':金髪の男性_中間の肌色:',
        'ko': u':금발_남자_갈색_피부:',
        'pt': ':homem_pele_morena_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_olivastra:',
        'fa': u':مرد_پوست_طلایی_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_sedang:',
        'zh': u':金发男_中等肤色:'
    },
    u'\U0001F471\U0001F3FD\U0000200D\U00002642': { # 👱🏽‍♂
        'en' : ':man_medium_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mittlere_hautfarbe,_blond:',
        'es': ':hombre_rubio_tono_de_piel_medio:',
        'fr': u':homme_blond_peau_légèrement_mate:',
        'ja': u':金髪の男性_中間の肌色:',
        'ko': u':금발_남자_갈색_피부:',
        'pt': ':homem_pele_morena_e_cabelo_loiro:',
        'it': ':uomo_biondo_carnagione_olivastra:',
        'fa': u':مرد_پوست_طلایی_مو_بور:',
        'id': ':pria_berambut_pirang_warna_kulit_sedang:',
        'zh': u':金发男_中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F9B1': { # 👨🏽‍🦱
        'en' : ':man_medium_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mittlere_hautfarbe,_lockiges_haar:',
        'es': ':hombre_tono_de_piel_medio_y_pelo_rizado:',
        'fr': u':homme_peau_légèrement_mate_et_cheveux_bouclés:',
        'ja': u':男性_中間の肌色_巻き毛:',
        'ko': u':남자_갈색_피부_곱슬머리:',
        'pt': ':homem_pele_morena_e_cabelo_cacheado:',
        'it': ':uomo_carnagione_olivastra_e_capelli_ricci:',
        'fa': u':مرد_پوست_طلایی_موفرفری:',
        'id': ':pria_warna_kulit_sedang_rambut_keriting:',
        'zh': u':男人_中等肤色卷发:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F9B0': { # 👨🏽‍🦰
        'en' : ':man_medium_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mann_mittlere_hautfarbe,_rotes_haar:',
        'es': ':hombre_tono_de_piel_medio_y_pelo_pelirrojo:',
        'fr': u':homme_peau_légèrement_mate_et_cheveux_roux:',
        'ja': u':男性_中間の肌色_赤毛:',
        'ko': u':남자_갈색_피부_빨간_머리:',
        'pt': ':homem_pele_morena_e_cabelo_vermelho:',
        'it': ':uomo_carnagione_olivastra_e_capelli_rossi:',
        'fa': u':مرد_پوست_طلایی_موقرمز:',
        'id': ':pria_warna_kulit_sedang_rambut_merah:',
        'zh': u':男人_中等肤色红发:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F9B3': { # 👨🏽‍🦳
        'en' : ':man_medium_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':mann_mittlere_hautfarbe,_weißes_haar:',
        'es': ':hombre_tono_de_piel_medio_y_pelo_blanco:',
        'fr': u':homme_peau_légèrement_mate_et_cheveux_blancs:',
        'ja': u':男性_中間の肌色_白髪:',
        'ko': u':남자_갈색_피부_백발:',
        'pt': ':homem_pele_morena_e_cabelo_branco:',
        'it': ':uomo_carnagione_olivastra_e_capelli_bianchi:',
        'fa': u':مرد_پوست_طلایی_موسفید:',
        'id': ':pria_warna_kulit_sedang_rambut_putih:',
        'zh': u':男人_中等肤色白发:'
    },
    u'\U0001F6B5\U0000200D\U00002642\U0000FE0F': { # 🚵‍♂️
        'en' : ':man_mountain_biking:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':mountain_biking_man:'],
        'de': ':mountainbiker:',
        'es': u':hombre_en_bicicleta_de_montaña:',
        'fr': ':homme_en_vtt:',
        'ja': u':マウンテンバイクに乗る男:',
        'ko': u':산악_자전거_타는_남자:',
        'pt': ':homem_fazendo_mountain_bike:',
        'it': ':ciclista_uomo_di_mountain_bike:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان:',
        'id': ':pria_bersepeda_gunung:',
        'zh': u':男生骑山地车:'
    },
    u'\U0001F6B5\U0000200D\U00002642': { # 🚵‍♂
        'en' : ':man_mountain_biking:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':mountain_biking_man:'],
        'de': ':mountainbiker:',
        'es': u':hombre_en_bicicleta_de_montaña:',
        'fr': ':homme_en_vtt:',
        'ja': u':マウンテンバイクに乗る男:',
        'ko': u':산악_자전거_타는_남자:',
        'pt': ':homem_fazendo_mountain_bike:',
        'it': ':ciclista_uomo_di_mountain_bike:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان:',
        'id': ':pria_bersepeda_gunung:',
        'zh': u':男生骑山地车:'
    },
    u'\U0001F6B5\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🚵🏿‍♂️
        'en' : ':man_mountain_biking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbiker_dunkle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_oscuro:',
        'fr': u':homme_en_vtt_peau_foncée:',
        'ja': u':マウンテンバイクに乗る男_濃い肌色:',
        'ko': u':산악_자전거_타는_남자_검은색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_escura:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_scura:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_آبنوسی:',
        'id': ':pria_bersepeda_gunung_warna_kulit_gelap:',
        'zh': u':男生骑山地车_较深肤色:'
    },
    u'\U0001F6B5\U0001F3FF\U0000200D\U00002642': { # 🚵🏿‍♂
        'en' : ':man_mountain_biking_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbiker_dunkle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_oscuro:',
        'fr': u':homme_en_vtt_peau_foncée:',
        'ja': u':マウンテンバイクに乗る男_濃い肌色:',
        'ko': u':산악_자전거_타는_남자_검은색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_escura:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_scura:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_آبنوسی:',
        'id': ':pria_bersepeda_gunung_warna_kulit_gelap:',
        'zh': u':男生骑山地车_较深肤色:'
    },
    u'\U0001F6B5\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🚵🏻‍♂️
        'en' : ':man_mountain_biking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbiker_helle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_claro:',
        'fr': ':homme_en_vtt_peau_claire:',
        'ja': u':マウンテンバイクに乗る男_薄い肌色:',
        'ko': u':산악_자전거_타는_남자_하얀_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_clara:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_chiara:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_سفید:',
        'id': ':pria_bersepeda_gunung_warna_kulit_cerah:',
        'zh': u':男生骑山地车_较浅肤色:'
    },
    u'\U0001F6B5\U0001F3FB\U0000200D\U00002642': { # 🚵🏻‍♂
        'en' : ':man_mountain_biking_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbiker_helle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_claro:',
        'fr': ':homme_en_vtt_peau_claire:',
        'ja': u':マウンテンバイクに乗る男_薄い肌色:',
        'ko': u':산악_자전거_타는_남자_하얀_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_clara:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_chiara:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_سفید:',
        'id': ':pria_bersepeda_gunung_warna_kulit_cerah:',
        'zh': u':男生骑山地车_较浅肤色:'
    },
    u'\U0001F6B5\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🚵🏾‍♂️
        'en' : ':man_mountain_biking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbiker_mitteldunkle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_oscuro_medio:',
        'fr': ':homme_en_vtt_peau_mate:',
        'ja': u':マウンテンバイクに乗る男_やや濃い肌色:',
        'ko': u':산악_자전거_타는_남자_진한_갈색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_morena_escura:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_abbastanza_scura:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_گندمی:',
        'id': ':pria_bersepeda_gunung_warna_kulit_gelap-sedang:',
        'zh': u':男生骑山地车_中等深肤色:'
    },
    u'\U0001F6B5\U0001F3FE\U0000200D\U00002642': { # 🚵🏾‍♂
        'en' : ':man_mountain_biking_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbiker_mitteldunkle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_oscuro_medio:',
        'fr': ':homme_en_vtt_peau_mate:',
        'ja': u':マウンテンバイクに乗る男_やや濃い肌色:',
        'ko': u':산악_자전거_타는_남자_진한_갈색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_morena_escura:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_abbastanza_scura:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_گندمی:',
        'id': ':pria_bersepeda_gunung_warna_kulit_gelap-sedang:',
        'zh': u':男生骑山地车_中等深肤色:'
    },
    u'\U0001F6B5\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🚵🏼‍♂️
        'en' : ':man_mountain_biking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbiker_mittelhelle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_claro_medio:',
        'fr': ':homme_en_vtt_peau_moyennement_claire:',
        'ja': u':マウンテンバイクに乗る男_やや薄い肌色:',
        'ko': u':산악_자전거_타는_남자_연한_갈색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_morena_clara:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_abbastanza_chiara:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_روشن:',
        'id': ':pria_bersepeda_gunung_warna_kulit_cerah-sedang:',
        'zh': u':男生骑山地车_中等浅肤色:'
    },
    u'\U0001F6B5\U0001F3FC\U0000200D\U00002642': { # 🚵🏼‍♂
        'en' : ':man_mountain_biking_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbiker_mittelhelle_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_claro_medio:',
        'fr': ':homme_en_vtt_peau_moyennement_claire:',
        'ja': u':マウンテンバイクに乗る男_やや薄い肌色:',
        'ko': u':산악_자전거_타는_남자_연한_갈색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_morena_clara:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_abbastanza_chiara:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_روشن:',
        'id': ':pria_bersepeda_gunung_warna_kulit_cerah-sedang:',
        'zh': u':男生骑山地车_中等浅肤色:'
    },
    u'\U0001F6B5\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🚵🏽‍♂️
        'en' : ':man_mountain_biking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbiker_mittlere_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_medio:',
        'fr': u':homme_en_vtt_peau_légèrement_mate:',
        'ja': u':マウンテンバイクに乗る男_中間の肌色:',
        'ko': u':산악_자전거_타는_남자_갈색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_morena:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_olivastra:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_طلایی:',
        'id': ':pria_bersepeda_gunung_warna_kulit_sedang:',
        'zh': u':男生骑山地车_中等肤色:'
    },
    u'\U0001F6B5\U0001F3FD\U0000200D\U00002642': { # 🚵🏽‍♂
        'en' : ':man_mountain_biking_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbiker_mittlere_hautfarbe:',
        'es': u':hombre_en_bicicleta_de_montaña_tono_de_piel_medio:',
        'fr': u':homme_en_vtt_peau_légèrement_mate:',
        'ja': u':マウンテンバイクに乗る男_中間の肌色:',
        'ko': u':산악_자전거_타는_남자_갈색_피부:',
        'pt': ':homem_fazendo_mountain_bike_pele_morena:',
        'it': ':ciclista_uomo_di_mountain_bike_carnagione_olivastra:',
        'fa': u':مرد_و_دوچرخه_سواری_کوهستان_پوست_طلایی:',
        'id': ':pria_bersepeda_gunung_warna_kulit_sedang:',
        'zh': u':男生骑山地车_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F4BC': { # 👨‍💼
        'en' : ':man_office_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellter:',
        'es': ':oficinista_hombre:',
        'fr': u':employé_de_bureau:',
        'ja': u':男性会社員:',
        'ko': u':남자_회사원:',
        'pt': u':funcionário_de_escritório:',
        'it': ':impiegato:',
        'fa': u':کارمند_مرد:',
        'id': ':pekerja_kantor_pria:',
        'zh': u':男白领:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F4BC': { # 👨🏿‍💼
        'en' : ':man_office_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellter_dunkle_hautfarbe:',
        'es': ':oficinista_hombre_tono_de_piel_oscuro:',
        'fr': u':employé_de_bureau_peau_foncée:',
        'ja': u':男性会社員_濃い肌色:',
        'ko': u':남자_회사원_검은색_피부:',
        'pt': u':funcionário_de_escritório_pele_escura:',
        'it': ':impiegato_carnagione_scura:',
        'fa': u':کارمند_مرد_پوست_آبنوسی:',
        'id': ':pekerja_kantor_pria_warna_kulit_gelap:',
        'zh': u':男白领_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F4BC': { # 👨🏻‍💼
        'en' : ':man_office_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellter_helle_hautfarbe:',
        'es': ':oficinista_hombre_tono_de_piel_claro:',
        'fr': u':employé_de_bureau_peau_claire:',
        'ja': u':男性会社員_薄い肌色:',
        'ko': u':남자_회사원_하얀_피부:',
        'pt': u':funcionário_de_escritório_pele_clara:',
        'it': ':impiegato_carnagione_chiara:',
        'fa': u':کارمند_مرد_پوست_سفید:',
        'id': ':pekerja_kantor_pria_warna_kulit_cerah:',
        'zh': u':男白领_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F4BC': { # 👨🏾‍💼
        'en' : ':man_office_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellter_mitteldunkle_hautfarbe:',
        'es': ':oficinista_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':employé_de_bureau_peau_mate:',
        'ja': u':男性会社員_やや濃い肌色:',
        'ko': u':남자_회사원_진한_갈색_피부:',
        'pt': u':funcionário_de_escritório_pele_morena_escura:',
        'it': ':impiegato_carnagione_abbastanza_scura:',
        'fa': u':کارمند_مرد_پوست_گندمی:',
        'id': ':pekerja_kantor_pria_warna_kulit_gelap-sedang:',
        'zh': u':男白领_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F4BC': { # 👨🏼‍💼
        'en' : ':man_office_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellter_mittelhelle_hautfarbe:',
        'es': ':oficinista_hombre_tono_de_piel_claro_medio:',
        'fr': u':employé_de_bureau_peau_moyennement_claire:',
        'ja': u':男性会社員_やや薄い肌色:',
        'ko': u':남자_회사원_연한_갈색_피부:',
        'pt': u':funcionário_de_escritório_pele_morena_clara:',
        'it': ':impiegato_carnagione_abbastanza_chiara:',
        'fa': u':کارمند_مرد_پوست_روشن:',
        'id': ':pekerja_kantor_pria_warna_kulit_cerah-sedang:',
        'zh': u':男白领_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F4BC': { # 👨🏽‍💼
        'en' : ':man_office_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellter_mittlere_hautfarbe:',
        'es': ':oficinista_hombre_tono_de_piel_medio:',
        'fr': u':employé_de_bureau_peau_légèrement_mate:',
        'ja': u':男性会社員_中間の肌色:',
        'ko': u':남자_회사원_갈색_피부:',
        'pt': u':funcionário_de_escritório_pele_morena:',
        'it': ':impiegato_carnagione_olivastra:',
        'fa': u':کارمند_مرد_پوست_طلایی:',
        'id': ':pekerja_kantor_pria_warna_kulit_sedang:',
        'zh': u':男白领_中等肤色:'
    },
    u'\U0001F468\U0000200D\U00002708\U0000FE0F': { # 👨‍✈️
        'en' : ':man_pilot:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilot:',
        'es': ':piloto_hombre:',
        'fr': ':pilote_homme:',
        'ja': u':男性パイロット:',
        'ko': u':남자_기장:',
        'pt': u':piloto_de_avião_homem:',
        'it': ':pilota_uomo:',
        'fa': u':خلبان_مرد:',
        'id': ':pilot_pria:',
        'zh': u':男飞行员:'
    },
    u'\U0001F468\U0000200D\U00002708': { # 👨‍✈
        'en' : ':man_pilot:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilot:',
        'es': ':piloto_hombre:',
        'fr': ':pilote_homme:',
        'ja': u':男性パイロット:',
        'ko': u':남자_기장:',
        'pt': u':piloto_de_avião_homem:',
        'it': ':pilota_uomo:',
        'fa': u':خلبان_مرد:',
        'id': ':pilot_pria:',
        'zh': u':男飞行员:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002708\U0000FE0F': { # 👨🏿‍✈️
        'en' : ':man_pilot_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilot_dunkle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_oscuro:',
        'fr': u':pilote_homme_peau_foncée:',
        'ja': u':男性パイロット_濃い肌色:',
        'ko': u':남자_기장_검은색_피부:',
        'pt': u':piloto_de_avião_homem_pele_escura:',
        'it': ':pilota_uomo_carnagione_scura:',
        'fa': u':خلبان_مرد_پوست_آبنوسی:',
        'id': ':pilot_pria_warna_kulit_gelap:',
        'zh': u':男飞行员_较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U00002708': { # 👨🏿‍✈
        'en' : ':man_pilot_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilot_dunkle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_oscuro:',
        'fr': u':pilote_homme_peau_foncée:',
        'ja': u':男性パイロット_濃い肌色:',
        'ko': u':남자_기장_검은색_피부:',
        'pt': u':piloto_de_avião_homem_pele_escura:',
        'it': ':pilota_uomo_carnagione_scura:',
        'fa': u':خلبان_مرد_پوست_آبنوسی:',
        'id': ':pilot_pria_warna_kulit_gelap:',
        'zh': u':男飞行员_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002708\U0000FE0F': { # 👨🏻‍✈️
        'en' : ':man_pilot_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilot_helle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_claro:',
        'fr': ':pilote_homme_peau_claire:',
        'ja': u':男性パイロット_薄い肌色:',
        'ko': u':남자_기장_하얀_피부:',
        'pt': u':piloto_de_avião_homem_pele_clara:',
        'it': ':pilota_uomo_carnagione_chiara:',
        'fa': u':خلبان_مرد_پوست_سفید:',
        'id': ':pilot_pria_warna_kulit_cerah:',
        'zh': u':男飞行员_较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U00002708': { # 👨🏻‍✈
        'en' : ':man_pilot_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilot_helle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_claro:',
        'fr': ':pilote_homme_peau_claire:',
        'ja': u':男性パイロット_薄い肌色:',
        'ko': u':남자_기장_하얀_피부:',
        'pt': u':piloto_de_avião_homem_pele_clara:',
        'it': ':pilota_uomo_carnagione_chiara:',
        'fa': u':خلبان_مرد_پوست_سفید:',
        'id': ':pilot_pria_warna_kulit_cerah:',
        'zh': u':男飞行员_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002708\U0000FE0F': { # 👨🏾‍✈️
        'en' : ':man_pilot_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilot_mitteldunkle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':pilote_homme_peau_mate:',
        'ja': u':男性パイロット_やや濃い肌色:',
        'ko': u':남자_기장_진한_갈색_피부:',
        'pt': u':piloto_de_avião_homem_pele_morena_escura:',
        'it': ':pilota_uomo_carnagione_abbastanza_scura:',
        'fa': u':خلبان_مرد_پوست_گندمی:',
        'id': ':pilot_pria_warna_kulit_gelap-sedang:',
        'zh': u':男飞行员_中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U00002708': { # 👨🏾‍✈
        'en' : ':man_pilot_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilot_mitteldunkle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':pilote_homme_peau_mate:',
        'ja': u':男性パイロット_やや濃い肌色:',
        'ko': u':남자_기장_진한_갈색_피부:',
        'pt': u':piloto_de_avião_homem_pele_morena_escura:',
        'it': ':pilota_uomo_carnagione_abbastanza_scura:',
        'fa': u':خلبان_مرد_پوست_گندمی:',
        'id': ':pilot_pria_warna_kulit_gelap-sedang:',
        'zh': u':男飞行员_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002708\U0000FE0F': { # 👨🏼‍✈️
        'en' : ':man_pilot_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilot_mittelhelle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_claro_medio:',
        'fr': ':pilote_homme_peau_moyennement_claire:',
        'ja': u':男性パイロット_やや薄い肌色:',
        'ko': u':남자_기장_연한_갈색_피부:',
        'pt': u':piloto_de_avião_homem_pele_morena_clara:',
        'it': ':pilota_uomo_carnagione_abbastanza_chiara:',
        'fa': u':خلبان_مرد_پوست_روشن:',
        'id': ':pilot_pria_warna_kulit_cerah-sedang:',
        'zh': u':男飞行员_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U00002708': { # 👨🏼‍✈
        'en' : ':man_pilot_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilot_mittelhelle_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_claro_medio:',
        'fr': ':pilote_homme_peau_moyennement_claire:',
        'ja': u':男性パイロット_やや薄い肌色:',
        'ko': u':남자_기장_연한_갈색_피부:',
        'pt': u':piloto_de_avião_homem_pele_morena_clara:',
        'it': ':pilota_uomo_carnagione_abbastanza_chiara:',
        'fa': u':خلبان_مرد_پوست_روشن:',
        'id': ':pilot_pria_warna_kulit_cerah-sedang:',
        'zh': u':男飞行员_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002708\U0000FE0F': { # 👨🏽‍✈️
        'en' : ':man_pilot_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilot_mittlere_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_medio:',
        'fr': u':pilote_homme_peau_légèrement_mate:',
        'ja': u':男性パイロット_中間の肌色:',
        'ko': u':남자_기장_갈색_피부:',
        'pt': u':piloto_de_avião_homem_pele_morena:',
        'it': ':pilota_uomo_carnagione_olivastra:',
        'fa': u':خلبان_مرد_پوست_طلایی:',
        'id': ':pilot_pria_warna_kulit_sedang:',
        'zh': u':男飞行员_中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U00002708': { # 👨🏽‍✈
        'en' : ':man_pilot_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilot_mittlere_hautfarbe:',
        'es': ':piloto_hombre_tono_de_piel_medio:',
        'fr': u':pilote_homme_peau_légèrement_mate:',
        'ja': u':男性パイロット_中間の肌色:',
        'ko': u':남자_기장_갈색_피부:',
        'pt': u':piloto_de_avião_homem_pele_morena:',
        'it': ':pilota_uomo_carnagione_olivastra:',
        'fa': u':خلبان_مرد_پوست_طلایی:',
        'id': ':pilot_pria_warna_kulit_sedang:',
        'zh': u':男飞行员_中等肤色:'
    },
    u'\U0001F93E\U0000200D\U00002642\U0000FE0F': { # 🤾‍♂️
        'en' : ':man_playing_handball:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspieler:',
        'es': ':hombre_jugando_al_balonmano:',
        'fr': ':handballeur:',
        'ja': u':ハンドボールをする男:',
        'ko': u':핸드볼하는_남자:',
        'pt': ':jogador_de_handebol:',
        'it': ':pallamanista_uomo:',
        'fa': u':هندبالیست_مرد:',
        'id': ':pria_bermain_bola_tangan:',
        'zh': u':男生玩手球:'
    },
    u'\U0001F93E\U0000200D\U00002642': { # 🤾‍♂
        'en' : ':man_playing_handball:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspieler:',
        'es': ':hombre_jugando_al_balonmano:',
        'fr': ':handballeur:',
        'ja': u':ハンドボールをする男:',
        'ko': u':핸드볼하는_남자:',
        'pt': ':jogador_de_handebol:',
        'it': ':pallamanista_uomo:',
        'fa': u':هندبالیست_مرد:',
        'id': ':pria_bermain_bola_tangan:',
        'zh': u':男生玩手球:'
    },
    u'\U0001F93E\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🤾🏿‍♂️
        'en' : ':man_playing_handball_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspieler_dunkle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_oscuro:',
        'fr': u':handballeur_peau_foncée:',
        'ja': u':ハンドボールをする男_濃い肌色:',
        'ko': u':핸드볼하는_남자_검은색_피부:',
        'pt': ':jogador_de_handebol_pele_escura:',
        'it': ':pallamanista_uomo_carnagione_scura:',
        'fa': u':هندبالیست_مرد_پوست_آبنوسی:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_gelap:',
        'zh': u':男生玩手球_较深肤色:'
    },
    u'\U0001F93E\U0001F3FF\U0000200D\U00002642': { # 🤾🏿‍♂
        'en' : ':man_playing_handball_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspieler_dunkle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_oscuro:',
        'fr': u':handballeur_peau_foncée:',
        'ja': u':ハンドボールをする男_濃い肌色:',
        'ko': u':핸드볼하는_남자_검은색_피부:',
        'pt': ':jogador_de_handebol_pele_escura:',
        'it': ':pallamanista_uomo_carnagione_scura:',
        'fa': u':هندبالیست_مرد_پوست_آبنوسی:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_gelap:',
        'zh': u':男生玩手球_较深肤色:'
    },
    u'\U0001F93E\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🤾🏻‍♂️
        'en' : ':man_playing_handball_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspieler_helle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_claro:',
        'fr': ':handballeur_peau_claire:',
        'ja': u':ハンドボールをする男_薄い肌色:',
        'ko': u':핸드볼하는_남자_하얀_피부:',
        'pt': ':jogador_de_handebol_pele_clara:',
        'it': ':pallamanista_uomo_carnagione_chiara:',
        'fa': u':هندبالیست_مرد_پوست_سفید:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_cerah:',
        'zh': u':男生玩手球_较浅肤色:'
    },
    u'\U0001F93E\U0001F3FB\U0000200D\U00002642': { # 🤾🏻‍♂
        'en' : ':man_playing_handball_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspieler_helle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_claro:',
        'fr': ':handballeur_peau_claire:',
        'ja': u':ハンドボールをする男_薄い肌色:',
        'ko': u':핸드볼하는_남자_하얀_피부:',
        'pt': ':jogador_de_handebol_pele_clara:',
        'it': ':pallamanista_uomo_carnagione_chiara:',
        'fa': u':هندبالیست_مرد_پوست_سفید:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_cerah:',
        'zh': u':男生玩手球_较浅肤色:'
    },
    u'\U0001F93E\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🤾🏾‍♂️
        'en' : ':man_playing_handball_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspieler_mitteldunkle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_oscuro_medio:',
        'fr': ':handballeur_peau_mate:',
        'ja': u':ハンドボールをする男_やや濃い肌色:',
        'ko': u':핸드볼하는_남자_진한_갈색_피부:',
        'pt': ':jogador_de_handebol_pele_morena_escura:',
        'it': ':pallamanista_uomo_carnagione_abbastanza_scura:',
        'fa': u':هندبالیست_مرد_پوست_گندمی:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_gelap-sedang:',
        'zh': u':男生玩手球_中等深肤色:'
    },
    u'\U0001F93E\U0001F3FE\U0000200D\U00002642': { # 🤾🏾‍♂
        'en' : ':man_playing_handball_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspieler_mitteldunkle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_oscuro_medio:',
        'fr': ':handballeur_peau_mate:',
        'ja': u':ハンドボールをする男_やや濃い肌色:',
        'ko': u':핸드볼하는_남자_진한_갈색_피부:',
        'pt': ':jogador_de_handebol_pele_morena_escura:',
        'it': ':pallamanista_uomo_carnagione_abbastanza_scura:',
        'fa': u':هندبالیست_مرد_پوست_گندمی:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_gelap-sedang:',
        'zh': u':男生玩手球_中等深肤色:'
    },
    u'\U0001F93E\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🤾🏼‍♂️
        'en' : ':man_playing_handball_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspieler_mittelhelle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_claro_medio:',
        'fr': ':handballeur_peau_moyennement_claire:',
        'ja': u':ハンドボールをする男_やや薄い肌色:',
        'ko': u':핸드볼하는_남자_연한_갈색_피부:',
        'pt': ':jogador_de_handebol_pele_morena_clara:',
        'it': ':pallamanista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':هندبالیست_مرد_پوست_روشن:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_cerah-sedang:',
        'zh': u':男生玩手球_中等浅肤色:'
    },
    u'\U0001F93E\U0001F3FC\U0000200D\U00002642': { # 🤾🏼‍♂
        'en' : ':man_playing_handball_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspieler_mittelhelle_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_claro_medio:',
        'fr': ':handballeur_peau_moyennement_claire:',
        'ja': u':ハンドボールをする男_やや薄い肌色:',
        'ko': u':핸드볼하는_남자_연한_갈색_피부:',
        'pt': ':jogador_de_handebol_pele_morena_clara:',
        'it': ':pallamanista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':هندبالیست_مرد_پوست_روشن:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_cerah-sedang:',
        'zh': u':男生玩手球_中等浅肤色:'
    },
    u'\U0001F93E\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🤾🏽‍♂️
        'en' : ':man_playing_handball_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspieler_mittlere_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_medio:',
        'fr': u':handballeur_peau_légèrement_mate:',
        'ja': u':ハンドボールをする男_中間の肌色:',
        'ko': u':핸드볼하는_남자_갈색_피부:',
        'pt': ':jogador_de_handebol_pele_morena:',
        'it': ':pallamanista_uomo_carnagione_olivastra:',
        'fa': u':هندبالیست_مرد_پوست_طلایی:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_sedang:',
        'zh': u':男生玩手球_中等肤色:'
    },
    u'\U0001F93E\U0001F3FD\U0000200D\U00002642': { # 🤾🏽‍♂
        'en' : ':man_playing_handball_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspieler_mittlere_hautfarbe:',
        'es': ':hombre_jugando_al_balonmano_tono_de_piel_medio:',
        'fr': u':handballeur_peau_légèrement_mate:',
        'ja': u':ハンドボールをする男_中間の肌色:',
        'ko': u':핸드볼하는_남자_갈색_피부:',
        'pt': ':jogador_de_handebol_pele_morena:',
        'it': ':pallamanista_uomo_carnagione_olivastra:',
        'fa': u':هندبالیست_مرد_پوست_طلایی:',
        'id': ':pria_bermain_bola_tangan_warna_kulit_sedang:',
        'zh': u':男生玩手球_中等肤色:'
    },
    u'\U0001F93D\U0000200D\U00002642\U0000FE0F': { # 🤽‍♂️
        'en' : ':man_playing_water_polo:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspieler:',
        'es': ':hombre_jugando_al_waterpolo:',
        'fr': ':joueur_de_water-polo:',
        'ja': u':水球をする男:',
        'ko': u':수구하는_남자:',
        'pt': u':homem_jogando_polo_aquático:',
        'it': ':pallanuotista_uomo:',
        'fa': u':واترپلو_مردان:',
        'id': ':pria_bermain_polo_air:',
        'zh': u':男生玩水球:'
    },
    u'\U0001F93D\U0000200D\U00002642': { # 🤽‍♂
        'en' : ':man_playing_water_polo:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspieler:',
        'es': ':hombre_jugando_al_waterpolo:',
        'fr': ':joueur_de_water-polo:',
        'ja': u':水球をする男:',
        'ko': u':수구하는_남자:',
        'pt': u':homem_jogando_polo_aquático:',
        'it': ':pallanuotista_uomo:',
        'fa': u':واترپلو_مردان:',
        'id': ':pria_bermain_polo_air:',
        'zh': u':男生玩水球:'
    },
    u'\U0001F93D\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🤽🏿‍♂️
        'en' : ':man_playing_water_polo_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspieler_dunkle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_oscuro:',
        'fr': u':joueur_de_water-polo_peau_foncée:',
        'ja': u':水球をする男_濃い肌色:',
        'ko': u':수구하는_남자_검은색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_escura:',
        'it': ':pallanuotista_uomo_carnagione_scura:',
        'fa': u':واترپلو_مردان_پوست_آبنوسی:',
        'id': ':pria_bermain_polo_air_warna_kulit_gelap:',
        'zh': u':男生玩水球_较深肤色:'
    },
    u'\U0001F93D\U0001F3FF\U0000200D\U00002642': { # 🤽🏿‍♂
        'en' : ':man_playing_water_polo_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspieler_dunkle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_oscuro:',
        'fr': u':joueur_de_water-polo_peau_foncée:',
        'ja': u':水球をする男_濃い肌色:',
        'ko': u':수구하는_남자_검은색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_escura:',
        'it': ':pallanuotista_uomo_carnagione_scura:',
        'fa': u':واترپلو_مردان_پوست_آبنوسی:',
        'id': ':pria_bermain_polo_air_warna_kulit_gelap:',
        'zh': u':男生玩水球_较深肤色:'
    },
    u'\U0001F93D\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🤽🏻‍♂️
        'en' : ':man_playing_water_polo_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspieler_helle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_claro:',
        'fr': ':joueur_de_water-polo_peau_claire:',
        'ja': u':水球をする男_薄い肌色:',
        'ko': u':수구하는_남자_하얀_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_clara:',
        'it': ':pallanuotista_uomo_carnagione_chiara:',
        'fa': u':واترپلو_مردان_پوست_سفید:',
        'id': ':pria_bermain_polo_air_warna_kulit_cerah:',
        'zh': u':男生玩水球_较浅肤色:'
    },
    u'\U0001F93D\U0001F3FB\U0000200D\U00002642': { # 🤽🏻‍♂
        'en' : ':man_playing_water_polo_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspieler_helle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_claro:',
        'fr': ':joueur_de_water-polo_peau_claire:',
        'ja': u':水球をする男_薄い肌色:',
        'ko': u':수구하는_남자_하얀_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_clara:',
        'it': ':pallanuotista_uomo_carnagione_chiara:',
        'fa': u':واترپلو_مردان_پوست_سفید:',
        'id': ':pria_bermain_polo_air_warna_kulit_cerah:',
        'zh': u':男生玩水球_较浅肤色:'
    },
    u'\U0001F93D\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🤽🏾‍♂️
        'en' : ':man_playing_water_polo_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspieler_mitteldunkle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_oscuro_medio:',
        'fr': ':joueur_de_water-polo_peau_mate:',
        'ja': u':水球をする男_やや濃い肌色:',
        'ko': u':수구하는_남자_진한_갈색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_morena_escura:',
        'it': ':pallanuotista_uomo_carnagione_abbastanza_scura:',
        'fa': u':واترپلو_مردان_پوست_گندمی:',
        'id': ':pria_bermain_polo_air_warna_kulit_gelap-sedang:',
        'zh': u':男生玩水球_中等深肤色:'
    },
    u'\U0001F93D\U0001F3FE\U0000200D\U00002642': { # 🤽🏾‍♂
        'en' : ':man_playing_water_polo_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspieler_mitteldunkle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_oscuro_medio:',
        'fr': ':joueur_de_water-polo_peau_mate:',
        'ja': u':水球をする男_やや濃い肌色:',
        'ko': u':수구하는_남자_진한_갈색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_morena_escura:',
        'it': ':pallanuotista_uomo_carnagione_abbastanza_scura:',
        'fa': u':واترپلو_مردان_پوست_گندمی:',
        'id': ':pria_bermain_polo_air_warna_kulit_gelap-sedang:',
        'zh': u':男生玩水球_中等深肤色:'
    },
    u'\U0001F93D\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🤽🏼‍♂️
        'en' : ':man_playing_water_polo_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspieler_mittelhelle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_claro_medio:',
        'fr': ':joueur_de_water-polo_peau_moyennement_claire:',
        'ja': u':水球をする男_やや薄い肌色:',
        'ko': u':수구하는_남자_연한_갈색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_morena_clara:',
        'it': ':pallanuotista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':واترپلو_مردان_پوست_روشن:',
        'id': ':pria_bermain_polo_air_warna_kulit_cerah-sedang:',
        'zh': u':男生玩水球_中等浅肤色:'
    },
    u'\U0001F93D\U0001F3FC\U0000200D\U00002642': { # 🤽🏼‍♂
        'en' : ':man_playing_water_polo_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspieler_mittelhelle_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_claro_medio:',
        'fr': ':joueur_de_water-polo_peau_moyennement_claire:',
        'ja': u':水球をする男_やや薄い肌色:',
        'ko': u':수구하는_남자_연한_갈색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_morena_clara:',
        'it': ':pallanuotista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':واترپلو_مردان_پوست_روشن:',
        'id': ':pria_bermain_polo_air_warna_kulit_cerah-sedang:',
        'zh': u':男生玩水球_中等浅肤色:'
    },
    u'\U0001F93D\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🤽🏽‍♂️
        'en' : ':man_playing_water_polo_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspieler_mittlere_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_medio:',
        'fr': u':joueur_de_water-polo_peau_légèrement_mate:',
        'ja': u':水球をする男_中間の肌色:',
        'ko': u':수구하는_남자_갈색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_morena:',
        'it': ':pallanuotista_uomo_carnagione_olivastra:',
        'fa': u':واترپلو_مردان_پوست_طلایی:',
        'id': ':pria_bermain_polo_air_warna_kulit_sedang:',
        'zh': u':男生玩水球_中等肤色:'
    },
    u'\U0001F93D\U0001F3FD\U0000200D\U00002642': { # 🤽🏽‍♂
        'en' : ':man_playing_water_polo_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspieler_mittlere_hautfarbe:',
        'es': ':hombre_jugando_al_waterpolo_tono_de_piel_medio:',
        'fr': u':joueur_de_water-polo_peau_légèrement_mate:',
        'ja': u':水球をする男_中間の肌色:',
        'ko': u':수구하는_남자_갈색_피부:',
        'pt': u':homem_jogando_polo_aquático_pele_morena:',
        'it': ':pallanuotista_uomo_carnagione_olivastra:',
        'fa': u':واترپلو_مردان_پوست_طلایی:',
        'id': ':pria_bermain_polo_air_warna_kulit_sedang:',
        'zh': u':男生玩水球_中等肤色:'
    },
    u'\U0001F46E\U0000200D\U00002642\U0000FE0F': { # 👮‍♂️
        'en' : ':man_police_officer:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':policeman:'],
        'de': ':polizist:',
        'es': u':agente_de_policía_hombre:',
        'fr': ':policier:',
        'ja': u':男性警察官:',
        'ko': u':남자_경찰관:',
        'pt': ':policial_homem:',
        'it': ':poliziotto_uomo:',
        'fa': u':پلیس_مرد:',
        'id': ':polisi_pria:',
        'zh': u':男警察:'
    },
    u'\U0001F46E\U0000200D\U00002642': { # 👮‍♂
        'en' : ':man_police_officer:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':policeman:'],
        'de': ':polizist:',
        'es': u':agente_de_policía_hombre:',
        'fr': ':policier:',
        'ja': u':男性警察官:',
        'ko': u':남자_경찰관:',
        'pt': ':policial_homem:',
        'it': ':poliziotto_uomo:',
        'fa': u':پلیس_مرد:',
        'id': ':polisi_pria:',
        'zh': u':男警察:'
    },
    u'\U0001F46E\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 👮🏿‍♂️
        'en' : ':man_police_officer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizist_dunkle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_oscuro:',
        'fr': u':policier_peau_foncée:',
        'ja': u':男性警察官_濃い肌色:',
        'ko': u':남자_경찰관_검은색_피부:',
        'pt': ':policial_homem_pele_escura:',
        'it': ':poliziotto_uomo_carnagione_scura:',
        'fa': u':پلیس_مرد_پوست_آبنوسی:',
        'id': ':polisi_pria_warna_kulit_gelap:',
        'zh': u':男警察_较深肤色:'
    },
    u'\U0001F46E\U0001F3FF\U0000200D\U00002642': { # 👮🏿‍♂
        'en' : ':man_police_officer_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizist_dunkle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_oscuro:',
        'fr': u':policier_peau_foncée:',
        'ja': u':男性警察官_濃い肌色:',
        'ko': u':남자_경찰관_검은색_피부:',
        'pt': ':policial_homem_pele_escura:',
        'it': ':poliziotto_uomo_carnagione_scura:',
        'fa': u':پلیس_مرد_پوست_آبنوسی:',
        'id': ':polisi_pria_warna_kulit_gelap:',
        'zh': u':男警察_较深肤色:'
    },
    u'\U0001F46E\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 👮🏻‍♂️
        'en' : ':man_police_officer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizist_helle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_claro:',
        'fr': ':policier_peau_claire:',
        'ja': u':男性警察官_薄い肌色:',
        'ko': u':남자_경찰관_하얀_피부:',
        'pt': ':policial_homem_pele_clara:',
        'it': ':poliziotto_uomo_carnagione_chiara:',
        'fa': u':پلیس_مرد_پوست_سفید:',
        'id': ':polisi_pria_warna_kulit_cerah:',
        'zh': u':男警察_较浅肤色:'
    },
    u'\U0001F46E\U0001F3FB\U0000200D\U00002642': { # 👮🏻‍♂
        'en' : ':man_police_officer_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizist_helle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_claro:',
        'fr': ':policier_peau_claire:',
        'ja': u':男性警察官_薄い肌色:',
        'ko': u':남자_경찰관_하얀_피부:',
        'pt': ':policial_homem_pele_clara:',
        'it': ':poliziotto_uomo_carnagione_chiara:',
        'fa': u':پلیس_مرد_پوست_سفید:',
        'id': ':polisi_pria_warna_kulit_cerah:',
        'zh': u':男警察_较浅肤色:'
    },
    u'\U0001F46E\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 👮🏾‍♂️
        'en' : ':man_police_officer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizist_mitteldunkle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':policier_peau_mate:',
        'ja': u':男性警察官_やや濃い肌色:',
        'ko': u':남자_경찰관_진한_갈색_피부:',
        'pt': ':policial_homem_pele_morena_escura:',
        'it': ':poliziotto_uomo_carnagione_abbastanza_scura:',
        'fa': u':پلیس_مرد_پوست_گندمی:',
        'id': ':polisi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男警察_中等深肤色:'
    },
    u'\U0001F46E\U0001F3FE\U0000200D\U00002642': { # 👮🏾‍♂
        'en' : ':man_police_officer_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizist_mitteldunkle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':policier_peau_mate:',
        'ja': u':男性警察官_やや濃い肌色:',
        'ko': u':남자_경찰관_진한_갈색_피부:',
        'pt': ':policial_homem_pele_morena_escura:',
        'it': ':poliziotto_uomo_carnagione_abbastanza_scura:',
        'fa': u':پلیس_مرد_پوست_گندمی:',
        'id': ':polisi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男警察_中等深肤色:'
    },
    u'\U0001F46E\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 👮🏼‍♂️
        'en' : ':man_police_officer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizist_mittelhelle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_claro_medio:',
        'fr': ':policier_peau_moyennement_claire:',
        'ja': u':男性警察官_やや薄い肌色:',
        'ko': u':남자_경찰관_연한_갈색_피부:',
        'pt': ':policial_homem_pele_morena_clara:',
        'it': ':poliziotto_uomo_carnagione_abbastanza_chiara:',
        'fa': u':پلیس_مرد_پوست_روشن:',
        'id': ':polisi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男警察_中等浅肤色:'
    },
    u'\U0001F46E\U0001F3FC\U0000200D\U00002642': { # 👮🏼‍♂
        'en' : ':man_police_officer_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizist_mittelhelle_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_claro_medio:',
        'fr': ':policier_peau_moyennement_claire:',
        'ja': u':男性警察官_やや薄い肌色:',
        'ko': u':남자_경찰관_연한_갈색_피부:',
        'pt': ':policial_homem_pele_morena_clara:',
        'it': ':poliziotto_uomo_carnagione_abbastanza_chiara:',
        'fa': u':پلیس_مرد_پوست_روشن:',
        'id': ':polisi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男警察_中等浅肤色:'
    },
    u'\U0001F46E\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 👮🏽‍♂️
        'en' : ':man_police_officer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizist_mittlere_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_medio:',
        'fr': u':policier_peau_légèrement_mate:',
        'ja': u':男性警察官_中間の肌色:',
        'ko': u':남자_경찰관_갈색_피부:',
        'pt': ':policial_homem_pele_morena:',
        'it': ':poliziotto_uomo_carnagione_olivastra:',
        'fa': u':پلیس_مرد_پوست_طلایی:',
        'id': ':polisi_pria_warna_kulit_sedang:',
        'zh': u':男警察_中等肤色:'
    },
    u'\U0001F46E\U0001F3FD\U0000200D\U00002642': { # 👮🏽‍♂
        'en' : ':man_police_officer_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizist_mittlere_hautfarbe:',
        'es': u':agente_de_policía_hombre_tono_de_piel_medio:',
        'fr': u':policier_peau_légèrement_mate:',
        'ja': u':男性警察官_中間の肌色:',
        'ko': u':남자_경찰관_갈색_피부:',
        'pt': ':policial_homem_pele_morena:',
        'it': ':poliziotto_uomo_carnagione_olivastra:',
        'fa': u':پلیس_مرد_پوست_طلایی:',
        'id': ':polisi_pria_warna_kulit_sedang:',
        'zh': u':男警察_中等肤色:'
    },
    u'\U0001F64E\U0000200D\U00002642\U0000FE0F': { # 🙎‍♂️
        'en' : ':man_pouting:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':pouting_man:'],
        'de': ':schmollender_mann:',
        'es': ':hombre_haciendo_pucheros:',
        'fr': ':homme_qui_boude:',
        'ja': u':不機嫌な男:',
        'ko': u':뾰로통한_남자:',
        'pt': ':homem_fazendo_bico:',
        'it': ':uomo_imbronciato:',
        'fa': u':مرد_اخم_وتخم_می_کند:',
        'id': ':pria_tidak_senang:',
        'zh': u':撅嘴男:'
    },
    u'\U0001F64E\U0000200D\U00002642': { # 🙎‍♂
        'en' : ':man_pouting:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':pouting_man:'],
        'de': ':schmollender_mann:',
        'es': ':hombre_haciendo_pucheros:',
        'fr': ':homme_qui_boude:',
        'ja': u':不機嫌な男:',
        'ko': u':뾰로통한_남자:',
        'pt': ':homem_fazendo_bico:',
        'it': ':uomo_imbronciato:',
        'fa': u':مرد_اخم_وتخم_می_کند:',
        'id': ':pria_tidak_senang:',
        'zh': u':撅嘴男:'
    },
    u'\U0001F64E\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🙎🏿‍♂️
        'en' : ':man_pouting_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollender_mann_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_oscuro:',
        'fr': u':homme_qui_boude_peau_foncée:',
        'ja': u':不機嫌な男_濃い肌色:',
        'ko': u':뾰로통한_남자_검은색_피부:',
        'pt': ':homem_fazendo_bico_pele_escura:',
        'it': ':uomo_imbronciato_carnagione_scura:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_آبنوسی:',
        'id': ':pria_tidak_senang_warna_kulit_gelap:',
        'zh': u':撅嘴男_较深肤色:'
    },
    u'\U0001F64E\U0001F3FF\U0000200D\U00002642': { # 🙎🏿‍♂
        'en' : ':man_pouting_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollender_mann_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_oscuro:',
        'fr': u':homme_qui_boude_peau_foncée:',
        'ja': u':不機嫌な男_濃い肌色:',
        'ko': u':뾰로통한_남자_검은색_피부:',
        'pt': ':homem_fazendo_bico_pele_escura:',
        'it': ':uomo_imbronciato_carnagione_scura:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_آبنوسی:',
        'id': ':pria_tidak_senang_warna_kulit_gelap:',
        'zh': u':撅嘴男_较深肤色:'
    },
    u'\U0001F64E\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🙎🏻‍♂️
        'en' : ':man_pouting_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollender_mann_helle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_claro:',
        'fr': ':homme_qui_boude_peau_claire:',
        'ja': u':不機嫌な男_薄い肌色:',
        'ko': u':뾰로통한_남자_하얀_피부:',
        'pt': ':homem_fazendo_bico_pele_clara:',
        'it': ':uomo_imbronciato_carnagione_chiara:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_سفید:',
        'id': ':pria_tidak_senang_warna_kulit_cerah:',
        'zh': u':撅嘴男_较浅肤色:'
    },
    u'\U0001F64E\U0001F3FB\U0000200D\U00002642': { # 🙎🏻‍♂
        'en' : ':man_pouting_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollender_mann_helle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_claro:',
        'fr': ':homme_qui_boude_peau_claire:',
        'ja': u':不機嫌な男_薄い肌色:',
        'ko': u':뾰로통한_남자_하얀_피부:',
        'pt': ':homem_fazendo_bico_pele_clara:',
        'it': ':uomo_imbronciato_carnagione_chiara:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_سفید:',
        'id': ':pria_tidak_senang_warna_kulit_cerah:',
        'zh': u':撅嘴男_较浅肤色:'
    },
    u'\U0001F64E\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🙎🏾‍♂️
        'en' : ':man_pouting_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_boude_peau_mate:',
        'ja': u':不機嫌な男_やや濃い肌色:',
        'ko': u':뾰로통한_남자_진한_갈색_피부:',
        'pt': ':homem_fazendo_bico_pele_morena_escura:',
        'it': ':uomo_imbronciato_carnagione_abbastanza_scura:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_گندمی:',
        'id': ':pria_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':撅嘴男_中等深肤色:'
    },
    u'\U0001F64E\U0001F3FE\U0000200D\U00002642': { # 🙎🏾‍♂
        'en' : ':man_pouting_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_boude_peau_mate:',
        'ja': u':不機嫌な男_やや濃い肌色:',
        'ko': u':뾰로통한_남자_진한_갈색_피부:',
        'pt': ':homem_fazendo_bico_pele_morena_escura:',
        'it': ':uomo_imbronciato_carnagione_abbastanza_scura:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_گندمی:',
        'id': ':pria_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':撅嘴男_中等深肤色:'
    },
    u'\U0001F64E\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🙎🏼‍♂️
        'en' : ':man_pouting_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_boude_peau_moyennement_claire:',
        'ja': u':不機嫌な男_やや薄い肌色:',
        'ko': u':뾰로통한_남자_연한_갈색_피부:',
        'pt': ':homem_fazendo_bico_pele_morena_clara:',
        'it': ':uomo_imbronciato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_روشن:',
        'id': ':pria_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':撅嘴男_中等浅肤色:'
    },
    u'\U0001F64E\U0001F3FC\U0000200D\U00002642': { # 🙎🏼‍♂
        'en' : ':man_pouting_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_boude_peau_moyennement_claire:',
        'ja': u':不機嫌な男_やや薄い肌色:',
        'ko': u':뾰로통한_남자_연한_갈색_피부:',
        'pt': ':homem_fazendo_bico_pele_morena_clara:',
        'it': ':uomo_imbronciato_carnagione_abbastanza_chiara:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_روشن:',
        'id': ':pria_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':撅嘴男_中等浅肤色:'
    },
    u'\U0001F64E\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🙎🏽‍♂️
        'en' : ':man_pouting_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollender_mann_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_medio:',
        'fr': u':homme_qui_boude_peau_légèrement_mate:',
        'ja': u':不機嫌な男_中間の肌色:',
        'ko': u':뾰로통한_남자_갈색_피부:',
        'pt': ':homem_fazendo_bico_pele_morena:',
        'it': ':uomo_imbronciato_carnagione_olivastra:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_طلایی:',
        'id': ':pria_tidak_senang_warna_kulit_sedang:',
        'zh': u':撅嘴男_中等肤色:'
    },
    u'\U0001F64E\U0001F3FD\U0000200D\U00002642': { # 🙎🏽‍♂
        'en' : ':man_pouting_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollender_mann_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_pucheros_tono_de_piel_medio:',
        'fr': u':homme_qui_boude_peau_légèrement_mate:',
        'ja': u':不機嫌な男_中間の肌色:',
        'ko': u':뾰로통한_남자_갈색_피부:',
        'pt': ':homem_fazendo_bico_pele_morena:',
        'it': ':uomo_imbronciato_carnagione_olivastra:',
        'fa': u':مرد_اخم_وتخم_می_کند_پوست_طلایی:',
        'id': ':pria_tidak_senang_warna_kulit_sedang:',
        'zh': u':撅嘴男_中等肤色:'
    },
    u'\U0001F64B\U0000200D\U00002642\U0000FE0F': { # 🙋‍♂️
        'en' : ':man_raising_hand:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':raising_hand_man:'],
        'de': ':mann_mit_erhobenem_arm:',
        'es': ':hombre_con_la_mano_levantada:',
        'fr': u':homme_qui_lève_la_main:',
        'ja': u':手を挙げる男:',
        'ko': u':한_손_든_남자:',
        'pt': u':homem_levantando_a_mão:',
        'it': ':uomo_con_mano_alzata:',
        'fa': u':مرد_دستش_را_بالا_می_برد:',
        'id': ':pria_mengangkat_tangan:',
        'zh': u':男生举手:'
    },
    u'\U0001F64B\U0000200D\U00002642': { # 🙋‍♂
        'en' : ':man_raising_hand:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':raising_hand_man:'],
        'de': ':mann_mit_erhobenem_arm:',
        'es': ':hombre_con_la_mano_levantada:',
        'fr': u':homme_qui_lève_la_main:',
        'ja': u':手を挙げる男:',
        'ko': u':한_손_든_남자:',
        'pt': u':homem_levantando_a_mão:',
        'it': ':uomo_con_mano_alzata:',
        'fa': u':مرد_دستش_را_بالا_می_برد:',
        'id': ':pria_mengangkat_tangan:',
        'zh': u':男生举手:'
    },
    u'\U0001F64B\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🙋🏿‍♂️
        'en' : ':man_raising_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_dunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_oscuro:',
        'fr': u':homme_qui_lève_la_main_peau_foncée:',
        'ja': u':手を挙げる男_濃い肌色:',
        'ko': u':한_손_든_남자_검은색_피부:',
        'pt': u':homem_levantando_a_mão_pele_escura:',
        'it': ':uomo_con_mano_alzata_carnagione_scura:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_آبنوسی:',
        'id': ':pria_mengangkat_tangan_warna_kulit_gelap:',
        'zh': u':男生举手_较深肤色:'
    },
    u'\U0001F64B\U0001F3FF\U0000200D\U00002642': { # 🙋🏿‍♂
        'en' : ':man_raising_hand_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_dunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_oscuro:',
        'fr': u':homme_qui_lève_la_main_peau_foncée:',
        'ja': u':手を挙げる男_濃い肌色:',
        'ko': u':한_손_든_남자_검은색_피부:',
        'pt': u':homem_levantando_a_mão_pele_escura:',
        'it': ':uomo_con_mano_alzata_carnagione_scura:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_آبنوسی:',
        'id': ':pria_mengangkat_tangan_warna_kulit_gelap:',
        'zh': u':男生举手_较深肤色:'
    },
    u'\U0001F64B\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🙋🏻‍♂️
        'en' : ':man_raising_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_helle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_claro:',
        'fr': u':homme_qui_lève_la_main_peau_claire:',
        'ja': u':手を挙げる男_薄い肌色:',
        'ko': u':한_손_든_남자_하얀_피부:',
        'pt': u':homem_levantando_a_mão_pele_clara:',
        'it': ':uomo_con_mano_alzata_carnagione_chiara:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_سفید:',
        'id': ':pria_mengangkat_tangan_warna_kulit_cerah:',
        'zh': u':男生举手_较浅肤色:'
    },
    u'\U0001F64B\U0001F3FB\U0000200D\U00002642': { # 🙋🏻‍♂
        'en' : ':man_raising_hand_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_helle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_claro:',
        'fr': u':homme_qui_lève_la_main_peau_claire:',
        'ja': u':手を挙げる男_薄い肌色:',
        'ko': u':한_손_든_남자_하얀_피부:',
        'pt': u':homem_levantando_a_mão_pele_clara:',
        'it': ':uomo_con_mano_alzata_carnagione_chiara:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_سفید:',
        'id': ':pria_mengangkat_tangan_warna_kulit_cerah:',
        'zh': u':男生举手_较浅肤色:'
    },
    u'\U0001F64B\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🙋🏾‍♂️
        'en' : ':man_raising_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_oscuro_medio:',
        'fr': u':homme_qui_lève_la_main_peau_mate:',
        'ja': u':手を挙げる男_やや濃い肌色:',
        'ko': u':한_손_든_남자_진한_갈색_피부:',
        'pt': u':homem_levantando_a_mão_pele_morena_escura:',
        'it': ':uomo_con_mano_alzata_carnagione_abbastanza_scura:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_گندمی:',
        'id': ':pria_mengangkat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':男生举手_中等深肤色:'
    },
    u'\U0001F64B\U0001F3FE\U0000200D\U00002642': { # 🙋🏾‍♂
        'en' : ':man_raising_hand_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_oscuro_medio:',
        'fr': u':homme_qui_lève_la_main_peau_mate:',
        'ja': u':手を挙げる男_やや濃い肌色:',
        'ko': u':한_손_든_남자_진한_갈색_피부:',
        'pt': u':homem_levantando_a_mão_pele_morena_escura:',
        'it': ':uomo_con_mano_alzata_carnagione_abbastanza_scura:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_گندمی:',
        'id': ':pria_mengangkat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':男生举手_中等深肤色:'
    },
    u'\U0001F64B\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🙋🏼‍♂️
        'en' : ':man_raising_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_mittelhelle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_claro_medio:',
        'fr': u':homme_qui_lève_la_main_peau_moyennement_claire:',
        'ja': u':手を挙げる男_やや薄い肌色:',
        'ko': u':한_손_든_남자_연한_갈색_피부:',
        'pt': u':homem_levantando_a_mão_pele_morena_clara:',
        'it': ':uomo_con_mano_alzata_carnagione_abbastanza_chiara:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_روشن:',
        'id': ':pria_mengangkat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':男生举手_中等浅肤色:'
    },
    u'\U0001F64B\U0001F3FC\U0000200D\U00002642': { # 🙋🏼‍♂
        'en' : ':man_raising_hand_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_mittelhelle_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_claro_medio:',
        'fr': u':homme_qui_lève_la_main_peau_moyennement_claire:',
        'ja': u':手を挙げる男_やや薄い肌色:',
        'ko': u':한_손_든_남자_연한_갈색_피부:',
        'pt': u':homem_levantando_a_mão_pele_morena_clara:',
        'it': ':uomo_con_mano_alzata_carnagione_abbastanza_chiara:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_روشن:',
        'id': ':pria_mengangkat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':男生举手_中等浅肤色:'
    },
    u'\U0001F64B\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🙋🏽‍♂️
        'en' : ':man_raising_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_mittlere_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_medio:',
        'fr': u':homme_qui_lève_la_main_peau_légèrement_mate:',
        'ja': u':手を挙げる男_中間の肌色:',
        'ko': u':한_손_든_남자_갈색_피부:',
        'pt': u':homem_levantando_a_mão_pele_morena:',
        'it': ':uomo_con_mano_alzata_carnagione_olivastra:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_طلایی:',
        'id': ':pria_mengangkat_tangan_warna_kulit_sedang:',
        'zh': u':男生举手_中等肤色:'
    },
    u'\U0001F64B\U0001F3FD\U0000200D\U00002642': { # 🙋🏽‍♂
        'en' : ':man_raising_hand_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_erhobenem_arm_mittlere_hautfarbe:',
        'es': ':hombre_con_la_mano_levantada_tono_de_piel_medio:',
        'fr': u':homme_qui_lève_la_main_peau_légèrement_mate:',
        'ja': u':手を挙げる男_中間の肌色:',
        'ko': u':한_손_든_남자_갈색_피부:',
        'pt': u':homem_levantando_a_mão_pele_morena:',
        'it': ':uomo_con_mano_alzata_carnagione_olivastra:',
        'fa': u':مرد_دستش_را_بالا_می_برد_پوست_طلایی:',
        'id': ':pria_mengangkat_tangan_warna_kulit_sedang:',
        'zh': u':男生举手_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F9B0': { # 👨‍🦰
        'en' : ':man_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':red_haired_man:'],
        'de': ':mann_rotes_haar:',
        'es': ':hombre_pelo_pelirrojo:',
        'fr': ':homme_cheveux_roux:',
        'ja': u':男性_赤毛:',
        'ko': u':남자_빨간_머리:',
        'pt': ':homem_cabelo_vermelho:',
        'it': ':uomo_capelli_rossi:',
        'fa': u':مرد_موقرمز:',
        'id': ':pria_rambut_merah:',
        'zh': u':男人_红发:'
    },
    u'\U0001F6A3\U0000200D\U00002642\U0000FE0F': { # 🚣‍♂️
        'en' : ':man_rowing_boat:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':rowing_man:'],
        'de': ':mann_im_ruderboot:',
        'es': ':hombre_remando_en_un_bote:',
        'fr': ':rameur_dans_une_barque:',
        'ja': u':ボートをこぐ男:',
        'ko': u':노젓는_남자:',
        'pt': ':homem_remando:',
        'it': ':uomo_in_barca_a_remi:',
        'fa': u':پاروزن_مرد:',
        'id': ':pria_mendayung_perahu:',
        'zh': u':男生划船:'
    },
    u'\U0001F6A3\U0000200D\U00002642': { # 🚣‍♂
        'en' : ':man_rowing_boat:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':rowing_man:'],
        'de': ':mann_im_ruderboot:',
        'es': ':hombre_remando_en_un_bote:',
        'fr': ':rameur_dans_une_barque:',
        'ja': u':ボートをこぐ男:',
        'ko': u':노젓는_남자:',
        'pt': ':homem_remando:',
        'it': ':uomo_in_barca_a_remi:',
        'fa': u':پاروزن_مرد:',
        'id': ':pria_mendayung_perahu:',
        'zh': u':男生划船:'
    },
    u'\U0001F6A3\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🚣🏿‍♂️
        'en' : ':man_rowing_boat_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_dunkle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_oscuro:',
        'fr': u':rameur_dans_une_barque_peau_foncée:',
        'ja': u':ボートをこぐ男_濃い肌色:',
        'ko': u':노젓는_남자_검은색_피부:',
        'pt': ':homem_remando_pele_escura:',
        'it': ':uomo_in_barca_a_remi_carnagione_scura:',
        'fa': u':پاروزن_مرد_پوست_آبنوسی:',
        'id': ':pria_mendayung_perahu_warna_kulit_gelap:',
        'zh': u':男生划船_较深肤色:'
    },
    u'\U0001F6A3\U0001F3FF\U0000200D\U00002642': { # 🚣🏿‍♂
        'en' : ':man_rowing_boat_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_dunkle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_oscuro:',
        'fr': u':rameur_dans_une_barque_peau_foncée:',
        'ja': u':ボートをこぐ男_濃い肌色:',
        'ko': u':노젓는_남자_검은색_피부:',
        'pt': ':homem_remando_pele_escura:',
        'it': ':uomo_in_barca_a_remi_carnagione_scura:',
        'fa': u':پاروزن_مرد_پوست_آبنوسی:',
        'id': ':pria_mendayung_perahu_warna_kulit_gelap:',
        'zh': u':男生划船_较深肤色:'
    },
    u'\U0001F6A3\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🚣🏻‍♂️
        'en' : ':man_rowing_boat_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_helle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_claro:',
        'fr': ':rameur_dans_une_barque_peau_claire:',
        'ja': u':ボートをこぐ男_薄い肌色:',
        'ko': u':노젓는_남자_하얀_피부:',
        'pt': ':homem_remando_pele_clara:',
        'it': ':uomo_in_barca_a_remi_carnagione_chiara:',
        'fa': u':پاروزن_مرد_پوست_سفید:',
        'id': ':pria_mendayung_perahu_warna_kulit_cerah:',
        'zh': u':男生划船_较浅肤色:'
    },
    u'\U0001F6A3\U0001F3FB\U0000200D\U00002642': { # 🚣🏻‍♂
        'en' : ':man_rowing_boat_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_helle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_claro:',
        'fr': ':rameur_dans_une_barque_peau_claire:',
        'ja': u':ボートをこぐ男_薄い肌色:',
        'ko': u':노젓는_남자_하얀_피부:',
        'pt': ':homem_remando_pele_clara:',
        'it': ':uomo_in_barca_a_remi_carnagione_chiara:',
        'fa': u':پاروزن_مرد_پوست_سفید:',
        'id': ':pria_mendayung_perahu_warna_kulit_cerah:',
        'zh': u':男生划船_较浅肤色:'
    },
    u'\U0001F6A3\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🚣🏾‍♂️
        'en' : ':man_rowing_boat_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_mitteldunkle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_oscuro_medio:',
        'fr': ':rameur_dans_une_barque_peau_mate:',
        'ja': u':ボートをこぐ男_やや濃い肌色:',
        'ko': u':노젓는_남자_진한_갈색_피부:',
        'pt': ':homem_remando_pele_morena_escura:',
        'it': ':uomo_in_barca_a_remi_carnagione_abbastanza_scura:',
        'fa': u':پاروزن_مرد_پوست_گندمی:',
        'id': ':pria_mendayung_perahu_warna_kulit_gelap-sedang:',
        'zh': u':男生划船_中等深肤色:'
    },
    u'\U0001F6A3\U0001F3FE\U0000200D\U00002642': { # 🚣🏾‍♂
        'en' : ':man_rowing_boat_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_mitteldunkle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_oscuro_medio:',
        'fr': ':rameur_dans_une_barque_peau_mate:',
        'ja': u':ボートをこぐ男_やや濃い肌色:',
        'ko': u':노젓는_남자_진한_갈색_피부:',
        'pt': ':homem_remando_pele_morena_escura:',
        'it': ':uomo_in_barca_a_remi_carnagione_abbastanza_scura:',
        'fa': u':پاروزن_مرد_پوست_گندمی:',
        'id': ':pria_mendayung_perahu_warna_kulit_gelap-sedang:',
        'zh': u':男生划船_中等深肤色:'
    },
    u'\U0001F6A3\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🚣🏼‍♂️
        'en' : ':man_rowing_boat_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_mittelhelle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_claro_medio:',
        'fr': ':rameur_dans_une_barque_peau_moyennement_claire:',
        'ja': u':ボートをこぐ男_やや薄い肌色:',
        'ko': u':노젓는_남자_연한_갈색_피부:',
        'pt': ':homem_remando_pele_morena_clara:',
        'it': ':uomo_in_barca_a_remi_carnagione_abbastanza_chiara:',
        'fa': u':پاروزن_مرد_پوست_روشن:',
        'id': ':pria_mendayung_perahu_warna_kulit_cerah-sedang:',
        'zh': u':男生划船_中等浅肤色:'
    },
    u'\U0001F6A3\U0001F3FC\U0000200D\U00002642': { # 🚣🏼‍♂
        'en' : ':man_rowing_boat_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_mittelhelle_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_claro_medio:',
        'fr': ':rameur_dans_une_barque_peau_moyennement_claire:',
        'ja': u':ボートをこぐ男_やや薄い肌色:',
        'ko': u':노젓는_남자_연한_갈색_피부:',
        'pt': ':homem_remando_pele_morena_clara:',
        'it': ':uomo_in_barca_a_remi_carnagione_abbastanza_chiara:',
        'fa': u':پاروزن_مرد_پوست_روشن:',
        'id': ':pria_mendayung_perahu_warna_kulit_cerah-sedang:',
        'zh': u':男生划船_中等浅肤色:'
    },
    u'\U0001F6A3\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🚣🏽‍♂️
        'en' : ':man_rowing_boat_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_mittlere_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_medio:',
        'fr': u':rameur_dans_une_barque_peau_légèrement_mate:',
        'ja': u':ボートをこぐ男_中間の肌色:',
        'ko': u':노젓는_남자_갈색_피부:',
        'pt': ':homem_remando_pele_morena:',
        'it': ':uomo_in_barca_a_remi_carnagione_olivastra:',
        'fa': u':پاروزن_مرد_پوست_طلایی:',
        'id': ':pria_mendayung_perahu_warna_kulit_sedang:',
        'zh': u':男生划船_中等肤色:'
    },
    u'\U0001F6A3\U0001F3FD\U0000200D\U00002642': { # 🚣🏽‍♂
        'en' : ':man_rowing_boat_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_im_ruderboot_mittlere_hautfarbe:',
        'es': ':hombre_remando_en_un_bote_tono_de_piel_medio:',
        'fr': u':rameur_dans_une_barque_peau_légèrement_mate:',
        'ja': u':ボートをこぐ男_中間の肌色:',
        'ko': u':노젓는_남자_갈색_피부:',
        'pt': ':homem_remando_pele_morena:',
        'it': ':uomo_in_barca_a_remi_carnagione_olivastra:',
        'fa': u':پاروزن_مرد_پوست_طلایی:',
        'id': ':pria_mendayung_perahu_warna_kulit_sedang:',
        'zh': u':男生划船_中等肤色:'
    },
    u'\U0001F3C3\U0000200D\U00002642\U0000FE0F': { # 🏃‍♂️
        'en' : ':man_running:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':running_man:'],
        'de': ':laufender_mann:',
        'es': ':hombre_corriendo:',
        'fr': ':homme_qui_court:',
        'ja': u':走る男:',
        'ko': u':뛰는_남자:',
        'pt': ':homem_correndo:',
        'it': ':uomo_che_corre:',
        'fa': u':مرد_دونده:',
        'id': ':pria_berlari:',
        'zh': u':男生跑步:'
    },
    u'\U0001F3C3\U0000200D\U00002642': { # 🏃‍♂
        'en' : ':man_running:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':running_man:'],
        'de': ':laufender_mann:',
        'es': ':hombre_corriendo:',
        'fr': ':homme_qui_court:',
        'ja': u':走る男:',
        'ko': u':뛰는_남자:',
        'pt': ':homem_correndo:',
        'it': ':uomo_che_corre:',
        'fa': u':مرد_دونده:',
        'id': ':pria_berlari:',
        'zh': u':男生跑步:'
    },
    u'\U0001F3C3\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🏃🏿‍♂️
        'en' : ':man_running_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufender_mann_dunkle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_oscuro:',
        'fr': u':homme_qui_court_peau_foncée:',
        'ja': u':走る男_濃い肌色:',
        'ko': u':뛰는_남자_검은색_피부:',
        'pt': ':homem_correndo_pele_escura:',
        'it': ':uomo_che_corre_carnagione_scura:',
        'fa': u':مرد_دونده_پوست_آبنوسی:',
        'id': ':pria_berlari_warna_kulit_gelap:',
        'zh': u':男生跑步_较深肤色:'
    },
    u'\U0001F3C3\U0001F3FF\U0000200D\U00002642': { # 🏃🏿‍♂
        'en' : ':man_running_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufender_mann_dunkle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_oscuro:',
        'fr': u':homme_qui_court_peau_foncée:',
        'ja': u':走る男_濃い肌色:',
        'ko': u':뛰는_남자_검은색_피부:',
        'pt': ':homem_correndo_pele_escura:',
        'it': ':uomo_che_corre_carnagione_scura:',
        'fa': u':مرد_دونده_پوست_آبنوسی:',
        'id': ':pria_berlari_warna_kulit_gelap:',
        'zh': u':男生跑步_较深肤色:'
    },
    u'\U0001F3C3\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🏃🏻‍♂️
        'en' : ':man_running_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufender_mann_helle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_claro:',
        'fr': ':homme_qui_court_peau_claire:',
        'ja': u':走る男_薄い肌色:',
        'ko': u':뛰는_남자_하얀_피부:',
        'pt': ':homem_correndo_pele_clara:',
        'it': ':uomo_che_corre_carnagione_chiara:',
        'fa': u':مرد_دونده_پوست_سفید:',
        'id': ':pria_berlari_warna_kulit_cerah:',
        'zh': u':男生跑步_较浅肤色:'
    },
    u'\U0001F3C3\U0001F3FB\U0000200D\U00002642': { # 🏃🏻‍♂
        'en' : ':man_running_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufender_mann_helle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_claro:',
        'fr': ':homme_qui_court_peau_claire:',
        'ja': u':走る男_薄い肌色:',
        'ko': u':뛰는_남자_하얀_피부:',
        'pt': ':homem_correndo_pele_clara:',
        'it': ':uomo_che_corre_carnagione_chiara:',
        'fa': u':مرد_دونده_پوست_سفید:',
        'id': ':pria_berlari_warna_kulit_cerah:',
        'zh': u':男生跑步_较浅肤色:'
    },
    u'\U0001F3C3\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🏃🏾‍♂️
        'en' : ':man_running_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_court_peau_mate:',
        'ja': u':走る男_やや濃い肌色:',
        'ko': u':뛰는_남자_진한_갈색_피부:',
        'pt': ':homem_correndo_pele_morena_escura:',
        'it': ':uomo_che_corre_carnagione_abbastanza_scura:',
        'fa': u':مرد_دونده_پوست_گندمی:',
        'id': ':pria_berlari_warna_kulit_gelap-sedang:',
        'zh': u':男生跑步_中等深肤色:'
    },
    u'\U0001F3C3\U0001F3FE\U0000200D\U00002642': { # 🏃🏾‍♂
        'en' : ':man_running_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_court_peau_mate:',
        'ja': u':走る男_やや濃い肌色:',
        'ko': u':뛰는_남자_진한_갈색_피부:',
        'pt': ':homem_correndo_pele_morena_escura:',
        'it': ':uomo_che_corre_carnagione_abbastanza_scura:',
        'fa': u':مرد_دونده_پوست_گندمی:',
        'id': ':pria_berlari_warna_kulit_gelap-sedang:',
        'zh': u':男生跑步_中等深肤色:'
    },
    u'\U0001F3C3\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🏃🏼‍♂️
        'en' : ':man_running_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_court_peau_moyennement_claire:',
        'ja': u':走る男_やや薄い肌色:',
        'ko': u':뛰는_남자_연한_갈색_피부:',
        'pt': ':homem_correndo_pele_morena_clara:',
        'it': ':uomo_che_corre_carnagione_abbastanza_chiara:',
        'fa': u':مرد_دونده_پوست_روشن:',
        'id': ':pria_berlari_warna_kulit_cerah-sedang:',
        'zh': u':男生跑步_中等浅肤色:'
    },
    u'\U0001F3C3\U0001F3FC\U0000200D\U00002642': { # 🏃🏼‍♂
        'en' : ':man_running_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_court_peau_moyennement_claire:',
        'ja': u':走る男_やや薄い肌色:',
        'ko': u':뛰는_남자_연한_갈색_피부:',
        'pt': ':homem_correndo_pele_morena_clara:',
        'it': ':uomo_che_corre_carnagione_abbastanza_chiara:',
        'fa': u':مرد_دونده_پوست_روشن:',
        'id': ':pria_berlari_warna_kulit_cerah-sedang:',
        'zh': u':男生跑步_中等浅肤色:'
    },
    u'\U0001F3C3\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🏃🏽‍♂️
        'en' : ':man_running_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufender_mann_mittlere_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_medio:',
        'fr': u':homme_qui_court_peau_légèrement_mate:',
        'ja': u':走る男_中間の肌色:',
        'ko': u':뛰는_남자_갈색_피부:',
        'pt': ':homem_correndo_pele_morena:',
        'it': ':uomo_che_corre_carnagione_olivastra:',
        'fa': u':مرد_دونده_پوست_طلایی:',
        'id': ':pria_berlari_warna_kulit_sedang:',
        'zh': u':男生跑步_中等肤色:'
    },
    u'\U0001F3C3\U0001F3FD\U0000200D\U00002642': { # 🏃🏽‍♂
        'en' : ':man_running_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufender_mann_mittlere_hautfarbe:',
        'es': ':hombre_corriendo_tono_de_piel_medio:',
        'fr': u':homme_qui_court_peau_légèrement_mate:',
        'ja': u':走る男_中間の肌色:',
        'ko': u':뛰는_남자_갈색_피부:',
        'pt': ':homem_correndo_pele_morena:',
        'it': ':uomo_che_corre_carnagione_olivastra:',
        'fa': u':مرد_دونده_پوست_طلایی:',
        'id': ':pria_berlari_warna_kulit_sedang:',
        'zh': u':男生跑步_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F52C': { # 👨‍🔬
        'en' : ':man_scientist:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftler:',
        'es': ':profesional_de_la_ciencia_hombre:',
        'fr': ':scientifique_homme:',
        'ja': u':男性科学者:',
        'ko': u':남자_과학자:',
        'pt': ':cientista_homem:',
        'it': ':scienziato:',
        'fa': u':دانشمند_مرد:',
        'id': ':ilmuwan_pria:',
        'zh': u':男科学家:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F52C': { # 👨🏿‍🔬
        'en' : ':man_scientist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftler_dunkle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_hombre_tono_de_piel_oscuro:',
        'fr': u':scientifique_homme_peau_foncée:',
        'ja': u':男性科学者_濃い肌色:',
        'ko': u':남자_과학자_검은색_피부:',
        'pt': ':cientista_homem_pele_escura:',
        'it': ':scienziato_carnagione_scura:',
        'fa': u':دانشمند_مرد_پوست_آبنوسی:',
        'id': ':ilmuwan_pria_warna_kulit_gelap:',
        'zh': u':男科学家_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F52C': { # 👨🏻‍🔬
        'en' : ':man_scientist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftler_helle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_hombre_tono_de_piel_claro:',
        'fr': ':scientifique_homme_peau_claire:',
        'ja': u':男性科学者_薄い肌色:',
        'ko': u':남자_과학자_하얀_피부:',
        'pt': ':cientista_homem_pele_clara:',
        'it': ':scienziato_carnagione_chiara:',
        'fa': u':دانشمند_مرد_پوست_سفید:',
        'id': ':ilmuwan_pria_warna_kulit_cerah:',
        'zh': u':男科学家_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F52C': { # 👨🏾‍🔬
        'en' : ':man_scientist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftler_mitteldunkle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':scientifique_homme_peau_mate:',
        'ja': u':男性科学者_やや濃い肌色:',
        'ko': u':남자_과학자_진한_갈색_피부:',
        'pt': ':cientista_homem_pele_morena_escura:',
        'it': ':scienziato_carnagione_abbastanza_scura:',
        'fa': u':دانشمند_مرد_پوست_گندمی:',
        'id': ':ilmuwan_pria_warna_kulit_gelap-sedang:',
        'zh': u':男科学家_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F52C': { # 👨🏼‍🔬
        'en' : ':man_scientist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftler_mittelhelle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_hombre_tono_de_piel_claro_medio:',
        'fr': ':scientifique_homme_peau_moyennement_claire:',
        'ja': u':男性科学者_やや薄い肌色:',
        'ko': u':남자_과학자_연한_갈색_피부:',
        'pt': ':cientista_homem_pele_morena_clara:',
        'it': ':scienziato_carnagione_abbastanza_chiara:',
        'fa': u':دانشمند_مرد_پوست_روشن:',
        'id': ':ilmuwan_pria_warna_kulit_cerah-sedang:',
        'zh': u':男科学家_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F52C': { # 👨🏽‍🔬
        'en' : ':man_scientist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftler_mittlere_hautfarbe:',
        'es': ':profesional_de_la_ciencia_hombre_tono_de_piel_medio:',
        'fr': u':scientifique_homme_peau_légèrement_mate:',
        'ja': u':男性科学者_中間の肌色:',
        'ko': u':남자_과학자_갈색_피부:',
        'pt': ':cientista_homem_pele_morena:',
        'it': ':scienziato_carnagione_olivastra:',
        'fa': u':دانشمند_مرد_پوست_طلایی:',
        'id': ':ilmuwan_pria_warna_kulit_sedang:',
        'zh': u':男科学家_中等肤色:'
    },
    u'\U0001F937\U0000200D\U00002642\U0000FE0F': { # 🤷‍♂️
        'en' : ':man_shrugging:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann:',
        'es': ':hombre_encogido_de_hombros:',
        'fr': u':homme_qui_hausse_les_épaules:',
        'ja': u':お手上げする男:',
        'ko': u':어깨를_으쓱하는_남자:',
        'pt': ':homem_dando_de_ombros:',
        'it': ':uomo_che_scrolla_le_spalle:',
        'fa': u':مرد_شانه_بالا_می_اندازد:',
        'id': ':pria_mengangkat_bahu:',
        'zh': u':男生耸肩:'
    },
    u'\U0001F937\U0000200D\U00002642': { # 🤷‍♂
        'en' : ':man_shrugging:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann:',
        'es': ':hombre_encogido_de_hombros:',
        'fr': u':homme_qui_hausse_les_épaules:',
        'ja': u':お手上げする男:',
        'ko': u':어깨를_으쓱하는_남자:',
        'pt': ':homem_dando_de_ombros:',
        'it': ':uomo_che_scrolla_le_spalle:',
        'fa': u':مرد_شانه_بالا_می_اندازد:',
        'id': ':pria_mengangkat_bahu:',
        'zh': u':男生耸肩:'
    },
    u'\U0001F937\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🤷🏿‍♂️
        'en' : ':man_shrugging_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_dunkle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_oscuro:',
        'fr': u':homme_qui_hausse_les_épaules_peau_foncée:',
        'ja': u':お手上げする男_濃い肌色:',
        'ko': u':어깨를_으쓱하는_남자_검은색_피부:',
        'pt': ':homem_dando_de_ombros_pele_escura:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_scura:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_آبنوسی:',
        'id': ':pria_mengangkat_bahu_warna_kulit_gelap:',
        'zh': u':男生耸肩_较深肤色:'
    },
    u'\U0001F937\U0001F3FF\U0000200D\U00002642': { # 🤷🏿‍♂
        'en' : ':man_shrugging_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_dunkle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_oscuro:',
        'fr': u':homme_qui_hausse_les_épaules_peau_foncée:',
        'ja': u':お手上げする男_濃い肌色:',
        'ko': u':어깨를_으쓱하는_남자_검은색_피부:',
        'pt': ':homem_dando_de_ombros_pele_escura:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_scura:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_آبنوسی:',
        'id': ':pria_mengangkat_bahu_warna_kulit_gelap:',
        'zh': u':男生耸肩_较深肤色:'
    },
    u'\U0001F937\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🤷🏻‍♂️
        'en' : ':man_shrugging_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_helle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_claro:',
        'fr': u':homme_qui_hausse_les_épaules_peau_claire:',
        'ja': u':お手上げする男_薄い肌色:',
        'ko': u':어깨를_으쓱하는_남자_하얀_피부:',
        'pt': ':homem_dando_de_ombros_pele_clara:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_chiara:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_سفید:',
        'id': ':pria_mengangkat_bahu_warna_kulit_cerah:',
        'zh': u':男生耸肩_较浅肤色:'
    },
    u'\U0001F937\U0001F3FB\U0000200D\U00002642': { # 🤷🏻‍♂
        'en' : ':man_shrugging_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_helle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_claro:',
        'fr': u':homme_qui_hausse_les_épaules_peau_claire:',
        'ja': u':お手上げする男_薄い肌色:',
        'ko': u':어깨를_으쓱하는_남자_하얀_피부:',
        'pt': ':homem_dando_de_ombros_pele_clara:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_chiara:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_سفید:',
        'id': ':pria_mengangkat_bahu_warna_kulit_cerah:',
        'zh': u':男生耸肩_较浅肤色:'
    },
    u'\U0001F937\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🤷🏾‍♂️
        'en' : ':man_shrugging_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_oscuro_medio:',
        'fr': u':homme_qui_hausse_les_épaules_peau_mate:',
        'ja': u':お手上げする男_やや濃い肌色:',
        'ko': u':어깨를_으쓱하는_남자_진한_갈색_피부:',
        'pt': ':homem_dando_de_ombros_pele_morena_escura:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_abbastanza_scura:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_گندمی:',
        'id': ':pria_mengangkat_bahu_warna_kulit_gelap-sedang:',
        'zh': u':男生耸肩_中等深肤色:'
    },
    u'\U0001F937\U0001F3FE\U0000200D\U00002642': { # 🤷🏾‍♂
        'en' : ':man_shrugging_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_oscuro_medio:',
        'fr': u':homme_qui_hausse_les_épaules_peau_mate:',
        'ja': u':お手上げする男_やや濃い肌色:',
        'ko': u':어깨를_으쓱하는_남자_진한_갈색_피부:',
        'pt': ':homem_dando_de_ombros_pele_morena_escura:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_abbastanza_scura:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_گندمی:',
        'id': ':pria_mengangkat_bahu_warna_kulit_gelap-sedang:',
        'zh': u':男生耸肩_中等深肤色:'
    },
    u'\U0001F937\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🤷🏼‍♂️
        'en' : ':man_shrugging_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_claro_medio:',
        'fr': u':homme_qui_hausse_les_épaules_peau_moyennement_claire:',
        'ja': u':お手上げする男_やや薄い肌色:',
        'ko': u':어깨를_으쓱하는_남자_연한_갈색_피부:',
        'pt': ':homem_dando_de_ombros_pele_morena_clara:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_abbastanza_chiara:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_روشن:',
        'id': ':pria_mengangkat_bahu_warna_kulit_cerah-sedang:',
        'zh': u':男生耸肩_中等浅肤色:'
    },
    u'\U0001F937\U0001F3FC\U0000200D\U00002642': { # 🤷🏼‍♂
        'en' : ':man_shrugging_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_claro_medio:',
        'fr': u':homme_qui_hausse_les_épaules_peau_moyennement_claire:',
        'ja': u':お手上げする男_やや薄い肌色:',
        'ko': u':어깨를_으쓱하는_남자_연한_갈색_피부:',
        'pt': ':homem_dando_de_ombros_pele_morena_clara:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_abbastanza_chiara:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_روشن:',
        'id': ':pria_mengangkat_bahu_warna_kulit_cerah-sedang:',
        'zh': u':男生耸肩_中等浅肤色:'
    },
    u'\U0001F937\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🤷🏽‍♂️
        'en' : ':man_shrugging_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_mittlere_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_medio:',
        'fr': u':homme_qui_hausse_les_épaules_peau_légèrement_mate:',
        'ja': u':お手上げする男_中間の肌色:',
        'ko': u':어깨를_으쓱하는_남자_갈색_피부:',
        'pt': ':homem_dando_de_ombros_pele_morena:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_olivastra:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_طلایی:',
        'id': ':pria_mengangkat_bahu_warna_kulit_sedang:',
        'zh': u':男生耸肩_中等肤色:'
    },
    u'\U0001F937\U0001F3FD\U0000200D\U00002642': { # 🤷🏽‍♂
        'en' : ':man_shrugging_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckender_mann_mittlere_hautfarbe:',
        'es': ':hombre_encogido_de_hombros_tono_de_piel_medio:',
        'fr': u':homme_qui_hausse_les_épaules_peau_légèrement_mate:',
        'ja': u':お手上げする男_中間の肌色:',
        'ko': u':어깨를_으쓱하는_남자_갈색_피부:',
        'pt': ':homem_dando_de_ombros_pele_morena:',
        'it': ':uomo_che_scrolla_le_spalle_carnagione_olivastra:',
        'fa': u':مرد_شانه_بالا_می_اندازد_پوست_طلایی:',
        'id': ':pria_mengangkat_bahu_warna_kulit_sedang:',
        'zh': u':男生耸肩_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F3A4': { # 👨‍🎤
        'en' : ':man_singer:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sänger:',
        'es': ':cantante_hombre:',
        'fr': ':chanteur:',
        'ja': u':男性歌手:',
        'ko': u':남자_가수:',
        'pt': ':cantor_homem:',
        'it': ':cantante_uomo:',
        'fa': u':خواننده_مرد:',
        'id': ':penyanyi_pria:',
        'zh': u':男歌手:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F3A4': { # 👨🏿‍🎤
        'en' : ':man_singer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sänger_dunkle_hautfarbe:',
        'es': ':cantante_hombre_tono_de_piel_oscuro:',
        'fr': u':chanteur_peau_foncée:',
        'ja': u':男性歌手_濃い肌色:',
        'ko': u':남자_가수_검은색_피부:',
        'pt': ':cantor_homem_pele_escura:',
        'it': ':cantante_uomo_carnagione_scura:',
        'fa': u':خواننده_مرد_پوست_آبنوسی:',
        'id': ':penyanyi_pria_warna_kulit_gelap:',
        'zh': u':男歌手_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F3A4': { # 👨🏻‍🎤
        'en' : ':man_singer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sänger_helle_hautfarbe:',
        'es': ':cantante_hombre_tono_de_piel_claro:',
        'fr': ':chanteur_peau_claire:',
        'ja': u':男性歌手_薄い肌色:',
        'ko': u':남자_가수_하얀_피부:',
        'pt': ':cantor_homem_pele_clara:',
        'it': ':cantante_uomo_carnagione_chiara:',
        'fa': u':خواننده_مرد_پوست_سفید:',
        'id': ':penyanyi_pria_warna_kulit_cerah:',
        'zh': u':男歌手_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F3A4': { # 👨🏾‍🎤
        'en' : ':man_singer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sänger_mitteldunkle_hautfarbe:',
        'es': ':cantante_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':chanteur_peau_mate:',
        'ja': u':男性歌手_やや濃い肌色:',
        'ko': u':남자_가수_진한_갈색_피부:',
        'pt': ':cantor_homem_pele_morena_escura:',
        'it': ':cantante_uomo_carnagione_abbastanza_scura:',
        'fa': u':خواننده_مرد_پوست_گندمی:',
        'id': ':penyanyi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男歌手_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F3A4': { # 👨🏼‍🎤
        'en' : ':man_singer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sänger_mittelhelle_hautfarbe:',
        'es': ':cantante_hombre_tono_de_piel_claro_medio:',
        'fr': ':chanteur_peau_moyennement_claire:',
        'ja': u':男性歌手_やや薄い肌色:',
        'ko': u':남자_가수_연한_갈색_피부:',
        'pt': ':cantor_homem_pele_morena_clara:',
        'it': ':cantante_uomo_carnagione_abbastanza_chiara:',
        'fa': u':خواننده_مرد_پوست_روشن:',
        'id': ':penyanyi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男歌手_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F3A4': { # 👨🏽‍🎤
        'en' : ':man_singer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sänger_mittlere_hautfarbe:',
        'es': ':cantante_hombre_tono_de_piel_medio:',
        'fr': u':chanteur_peau_légèrement_mate:',
        'ja': u':男性歌手_中間の肌色:',
        'ko': u':남자_가수_갈색_피부:',
        'pt': ':cantor_homem_pele_morena:',
        'it': ':cantante_uomo_carnagione_olivastra:',
        'fa': u':خواننده_مرد_پوست_طلایی:',
        'id': ':penyanyi_pria_warna_kulit_sedang:',
        'zh': u':男歌手_中等肤色:'
    },
    u'\U0001F9CD\U0000200D\U00002642\U0000FE0F': { # 🧍‍♂️
        'en' : ':man_standing:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':standing_man:'],
        'de': ':stehender_mann:',
        'es': ':hombre_de_pie:',
        'fr': ':homme_debout:',
        'ja': u':立つ男:',
        'ko': u':서_있는_남자:',
        'pt': u':homem_em_pé:',
        'it': ':uomo_in_piedi:',
        'fa': u':مرد_ایستاده:',
        'id': ':pria_berdiri:',
        'zh': u':站立的男人:'
    },
    u'\U0001F9CD\U0000200D\U00002642': { # 🧍‍♂
        'en' : ':man_standing:',
        'status' : minimally_qualified,
        'E' : 12,
        'alias' : [':standing_man:'],
        'de': ':stehender_mann:',
        'es': ':hombre_de_pie:',
        'fr': ':homme_debout:',
        'ja': u':立つ男:',
        'ko': u':서_있는_남자:',
        'pt': u':homem_em_pé:',
        'it': ':uomo_in_piedi:',
        'fa': u':مرد_ایستاده:',
        'id': ':pria_berdiri:',
        'zh': u':站立的男人:'
    },
    u'\U0001F9CD\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧍🏿‍♂️
        'en' : ':man_standing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehender_mann_dunkle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_oscuro:',
        'fr': u':homme_debout_peau_foncée:',
        'ja': u':立つ男_濃い肌色:',
        'ko': u':서_있는_남자_검은색_피부:',
        'pt': u':homem_em_pé_pele_escura:',
        'it': ':uomo_in_piedi_carnagione_scura:',
        'fa': u':مرد_ایستاده_پوست_آبنوسی:',
        'id': ':pria_berdiri_warna_kulit_gelap:',
        'zh': u':站立的男人_较深肤色:'
    },
    u'\U0001F9CD\U0001F3FF\U0000200D\U00002642': { # 🧍🏿‍♂
        'en' : ':man_standing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehender_mann_dunkle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_oscuro:',
        'fr': u':homme_debout_peau_foncée:',
        'ja': u':立つ男_濃い肌色:',
        'ko': u':서_있는_남자_검은색_피부:',
        'pt': u':homem_em_pé_pele_escura:',
        'it': ':uomo_in_piedi_carnagione_scura:',
        'fa': u':مرد_ایستاده_پوست_آبنوسی:',
        'id': ':pria_berdiri_warna_kulit_gelap:',
        'zh': u':站立的男人_较深肤色:'
    },
    u'\U0001F9CD\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧍🏻‍♂️
        'en' : ':man_standing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehender_mann_helle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_claro:',
        'fr': ':homme_debout_peau_claire:',
        'ja': u':立つ男_薄い肌色:',
        'ko': u':서_있는_남자_하얀_피부:',
        'pt': u':homem_em_pé_pele_clara:',
        'it': ':uomo_in_piedi_carnagione_chiara:',
        'fa': u':مرد_ایستاده_پوست_سفید:',
        'id': ':pria_berdiri_warna_kulit_cerah:',
        'zh': u':站立的男人_较浅肤色:'
    },
    u'\U0001F9CD\U0001F3FB\U0000200D\U00002642': { # 🧍🏻‍♂
        'en' : ':man_standing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehender_mann_helle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_claro:',
        'fr': ':homme_debout_peau_claire:',
        'ja': u':立つ男_薄い肌色:',
        'ko': u':서_있는_남자_하얀_피부:',
        'pt': u':homem_em_pé_pele_clara:',
        'it': ':uomo_in_piedi_carnagione_chiara:',
        'fa': u':مرد_ایستاده_پوست_سفید:',
        'id': ':pria_berdiri_warna_kulit_cerah:',
        'zh': u':站立的男人_较浅肤色:'
    },
    u'\U0001F9CD\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧍🏾‍♂️
        'en' : ':man_standing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_oscuro_medio:',
        'fr': ':homme_debout_peau_mate:',
        'ja': u':立つ男_やや濃い肌色:',
        'ko': u':서_있는_남자_진한_갈색_피부:',
        'pt': u':homem_em_pé_pele_morena_escura:',
        'it': ':uomo_in_piedi_carnagione_abbastanza_scura:',
        'fa': u':مرد_ایستاده_پوست_گندمی:',
        'id': ':pria_berdiri_warna_kulit_gelap-sedang:',
        'zh': u':站立的男人_中等深肤色:'
    },
    u'\U0001F9CD\U0001F3FE\U0000200D\U00002642': { # 🧍🏾‍♂
        'en' : ':man_standing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehender_mann_mitteldunkle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_oscuro_medio:',
        'fr': ':homme_debout_peau_mate:',
        'ja': u':立つ男_やや濃い肌色:',
        'ko': u':서_있는_남자_진한_갈색_피부:',
        'pt': u':homem_em_pé_pele_morena_escura:',
        'it': ':uomo_in_piedi_carnagione_abbastanza_scura:',
        'fa': u':مرد_ایستاده_پوست_گندمی:',
        'id': ':pria_berdiri_warna_kulit_gelap-sedang:',
        'zh': u':站立的男人_中等深肤色:'
    },
    u'\U0001F9CD\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧍🏼‍♂️
        'en' : ':man_standing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_claro_medio:',
        'fr': ':homme_debout_peau_moyennement_claire:',
        'ja': u':立つ男_やや薄い肌色:',
        'ko': u':서_있는_남자_연한_갈색_피부:',
        'pt': u':homem_em_pé_pele_morena_clara:',
        'it': ':uomo_in_piedi_carnagione_abbastanza_chiara:',
        'fa': u':مرد_ایستاده_پوست_روشن:',
        'id': ':pria_berdiri_warna_kulit_cerah-sedang:',
        'zh': u':站立的男人_中等浅肤色:'
    },
    u'\U0001F9CD\U0001F3FC\U0000200D\U00002642': { # 🧍🏼‍♂
        'en' : ':man_standing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehender_mann_mittelhelle_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_claro_medio:',
        'fr': ':homme_debout_peau_moyennement_claire:',
        'ja': u':立つ男_やや薄い肌色:',
        'ko': u':서_있는_남자_연한_갈색_피부:',
        'pt': u':homem_em_pé_pele_morena_clara:',
        'it': ':uomo_in_piedi_carnagione_abbastanza_chiara:',
        'fa': u':مرد_ایستاده_پوست_روشن:',
        'id': ':pria_berdiri_warna_kulit_cerah-sedang:',
        'zh': u':站立的男人_中等浅肤色:'
    },
    u'\U0001F9CD\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧍🏽‍♂️
        'en' : ':man_standing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehender_mann_mittlere_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_medio:',
        'fr': u':homme_debout_peau_légèrement_mate:',
        'ja': u':立つ男_中間の肌色:',
        'ko': u':서_있는_남자_갈색_피부:',
        'pt': u':homem_em_pé_pele_morena:',
        'it': ':uomo_in_piedi_carnagione_olivastra:',
        'fa': u':مرد_ایستاده_پوست_طلایی:',
        'id': ':pria_berdiri_warna_kulit_sedang:',
        'zh': u':站立的男人_中等肤色:'
    },
    u'\U0001F9CD\U0001F3FD\U0000200D\U00002642': { # 🧍🏽‍♂
        'en' : ':man_standing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehender_mann_mittlere_hautfarbe:',
        'es': ':hombre_de_pie_tono_de_piel_medio:',
        'fr': u':homme_debout_peau_légèrement_mate:',
        'ja': u':立つ男_中間の肌色:',
        'ko': u':서_있는_남자_갈색_피부:',
        'pt': u':homem_em_pé_pele_morena:',
        'it': ':uomo_in_piedi_carnagione_olivastra:',
        'fa': u':مرد_ایستاده_پوست_طلایی:',
        'id': ':pria_berdiri_warna_kulit_sedang:',
        'zh': u':站立的男人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F393': { # 👨‍🎓
        'en' : ':man_student:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':student:',
        'es': ':estudiante_hombre:',
        'fr': u':étudiant:',
        'ja': u':男子学生:',
        'ko': u':남학생:',
        'pt': ':estudante:',
        'it': ':studente_maschio:',
        'fa': u':دانشجوی_مرد:',
        'id': ':sarjana_pria:',
        'zh': u':男学生:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F393': { # 👨🏿‍🎓
        'en' : ':man_student_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':student_dunkle_hautfarbe:',
        'es': ':estudiante_hombre_tono_de_piel_oscuro:',
        'fr': u':étudiant_peau_foncée:',
        'ja': u':男子学生_濃い肌色:',
        'ko': u':남학생_검은색_피부:',
        'pt': ':estudante_pele_escura:',
        'it': ':studente_maschio_carnagione_scura:',
        'fa': u':دانشجوی_مرد_پوست_آبنوسی:',
        'id': ':sarjana_pria_warna_kulit_gelap:',
        'zh': u':男学生_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F393': { # 👨🏻‍🎓
        'en' : ':man_student_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':student_helle_hautfarbe:',
        'es': ':estudiante_hombre_tono_de_piel_claro:',
        'fr': u':étudiant_peau_claire:',
        'ja': u':男子学生_薄い肌色:',
        'ko': u':남학생_하얀_피부:',
        'pt': ':estudante_pele_clara:',
        'it': ':studente_maschio_carnagione_chiara:',
        'fa': u':دانشجوی_مرد_پوست_سفید:',
        'id': ':sarjana_pria_warna_kulit_cerah:',
        'zh': u':男学生_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F393': { # 👨🏾‍🎓
        'en' : ':man_student_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':student_mitteldunkle_hautfarbe:',
        'es': ':estudiante_hombre_tono_de_piel_oscuro_medio:',
        'fr': u':étudiant_peau_mate:',
        'ja': u':男子学生_やや濃い肌色:',
        'ko': u':남학생_진한_갈색_피부:',
        'pt': ':estudante_pele_morena_escura:',
        'it': ':studente_maschio_carnagione_abbastanza_scura:',
        'fa': u':دانشجوی_مرد_پوست_گندمی:',
        'id': ':sarjana_pria_warna_kulit_gelap-sedang:',
        'zh': u':男学生_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F393': { # 👨🏼‍🎓
        'en' : ':man_student_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':student_mittelhelle_hautfarbe:',
        'es': ':estudiante_hombre_tono_de_piel_claro_medio:',
        'fr': u':étudiant_peau_moyennement_claire:',
        'ja': u':男子学生_やや薄い肌色:',
        'ko': u':남학생_연한_갈색_피부:',
        'pt': ':estudante_pele_morena_clara:',
        'it': ':studente_maschio_carnagione_abbastanza_chiara:',
        'fa': u':دانشجوی_مرد_پوست_روشن:',
        'id': ':sarjana_pria_warna_kulit_cerah-sedang:',
        'zh': u':男学生_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F393': { # 👨🏽‍🎓
        'en' : ':man_student_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':student_mittlere_hautfarbe:',
        'es': ':estudiante_hombre_tono_de_piel_medio:',
        'fr': u':étudiant_peau_légèrement_mate:',
        'ja': u':男子学生_中間の肌色:',
        'ko': u':남학생_갈색_피부:',
        'pt': ':estudante_pele_morena:',
        'it': ':studente_maschio_carnagione_olivastra:',
        'fa': u':دانشجوی_مرد_پوست_طلایی:',
        'id': ':sarjana_pria_warna_kulit_sedang:',
        'zh': u':男学生_中等肤色:'
    },
    u'\U0001F9B8\U0000200D\U00002642\U0000FE0F': { # 🦸‍♂️
        'en' : ':man_superhero:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':superhero_man:'],
        'de': ':superheld:',
        'es': u':superhéroe:',
        'fr': u':super-héros_homme:',
        'ja': u':男性のスーパーヒーロー:',
        'ko': u':남자_히어로:',
        'pt': u':homem_super-herói:',
        'it': ':supereroe_uomo:',
        'fa': u':ابرقهرمان_مرد:',
        'id': ':pahlawan_super_pria:',
        'zh': u':男超级英雄:'
    },
    u'\U0001F9B8\U0000200D\U00002642': { # 🦸‍♂
        'en' : ':man_superhero:',
        'status' : minimally_qualified,
        'E' : 11,
        'alias' : [':superhero_man:'],
        'de': ':superheld:',
        'es': u':superhéroe:',
        'fr': u':super-héros_homme:',
        'ja': u':男性のスーパーヒーロー:',
        'ko': u':남자_히어로:',
        'pt': u':homem_super-herói:',
        'it': ':supereroe_uomo:',
        'fa': u':ابرقهرمان_مرد:',
        'id': ':pahlawan_super_pria:',
        'zh': u':男超级英雄:'
    },
    u'\U0001F9B8\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🦸🏿‍♂️
        'en' : ':man_superhero_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':superheld_dunkle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_oscuro:',
        'fr': u':super-héros_homme_peau_foncée:',
        'ja': u':男性のスーパーヒーロー_濃い肌色:',
        'ko': u':남자_히어로_검은색_피부:',
        'pt': u':homem_super-herói_pele_escura:',
        'it': ':supereroe_uomo_carnagione_scura:',
        'fa': u':ابرقهرمان_مرد_پوست_آبنوسی:',
        'id': ':pahlawan_super_pria_warna_kulit_gelap:',
        'zh': u':男超级英雄_较深肤色:'
    },
    u'\U0001F9B8\U0001F3FF\U0000200D\U00002642': { # 🦸🏿‍♂
        'en' : ':man_superhero_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':superheld_dunkle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_oscuro:',
        'fr': u':super-héros_homme_peau_foncée:',
        'ja': u':男性のスーパーヒーロー_濃い肌色:',
        'ko': u':남자_히어로_검은색_피부:',
        'pt': u':homem_super-herói_pele_escura:',
        'it': ':supereroe_uomo_carnagione_scura:',
        'fa': u':ابرقهرمان_مرد_پوست_آبنوسی:',
        'id': ':pahlawan_super_pria_warna_kulit_gelap:',
        'zh': u':男超级英雄_较深肤色:'
    },
    u'\U0001F9B8\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🦸🏻‍♂️
        'en' : ':man_superhero_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':superheld_helle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_claro:',
        'fr': u':super-héros_homme_peau_claire:',
        'ja': u':男性のスーパーヒーロー_薄い肌色:',
        'ko': u':남자_히어로_하얀_피부:',
        'pt': u':homem_super-herói_pele_clara:',
        'it': ':supereroe_uomo_carnagione_chiara:',
        'fa': u':ابرقهرمان_مرد_پوست_سفید:',
        'id': ':pahlawan_super_pria_warna_kulit_cerah:',
        'zh': u':男超级英雄_较浅肤色:'
    },
    u'\U0001F9B8\U0001F3FB\U0000200D\U00002642': { # 🦸🏻‍♂
        'en' : ':man_superhero_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':superheld_helle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_claro:',
        'fr': u':super-héros_homme_peau_claire:',
        'ja': u':男性のスーパーヒーロー_薄い肌色:',
        'ko': u':남자_히어로_하얀_피부:',
        'pt': u':homem_super-herói_pele_clara:',
        'it': ':supereroe_uomo_carnagione_chiara:',
        'fa': u':ابرقهرمان_مرد_پوست_سفید:',
        'id': ':pahlawan_super_pria_warna_kulit_cerah:',
        'zh': u':男超级英雄_较浅肤色:'
    },
    u'\U0001F9B8\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🦸🏾‍♂️
        'en' : ':man_superhero_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':superheld_mitteldunkle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_oscuro_medio:',
        'fr': u':super-héros_homme_peau_mate:',
        'ja': u':男性のスーパーヒーロー_やや濃い肌色:',
        'ko': u':남자_히어로_진한_갈색_피부:',
        'pt': u':homem_super-herói_pele_morena_escura:',
        'it': ':supereroe_uomo_carnagione_abbastanza_scura:',
        'fa': u':ابرقهرمان_مرد_پوست_گندمی:',
        'id': ':pahlawan_super_pria_warna_kulit_gelap-sedang:',
        'zh': u':男超级英雄_中等深肤色:'
    },
    u'\U0001F9B8\U0001F3FE\U0000200D\U00002642': { # 🦸🏾‍♂
        'en' : ':man_superhero_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':superheld_mitteldunkle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_oscuro_medio:',
        'fr': u':super-héros_homme_peau_mate:',
        'ja': u':男性のスーパーヒーロー_やや濃い肌色:',
        'ko': u':남자_히어로_진한_갈색_피부:',
        'pt': u':homem_super-herói_pele_morena_escura:',
        'it': ':supereroe_uomo_carnagione_abbastanza_scura:',
        'fa': u':ابرقهرمان_مرد_پوست_گندمی:',
        'id': ':pahlawan_super_pria_warna_kulit_gelap-sedang:',
        'zh': u':男超级英雄_中等深肤色:'
    },
    u'\U0001F9B8\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🦸🏼‍♂️
        'en' : ':man_superhero_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':superheld_mittelhelle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_claro_medio:',
        'fr': u':super-héros_homme_peau_moyennement_claire:',
        'ja': u':男性のスーパーヒーロー_やや薄い肌色:',
        'ko': u':남자_히어로_연한_갈색_피부:',
        'pt': u':homem_super-herói_pele_morena_clara:',
        'it': ':supereroe_uomo_carnagione_abbastanza_chiara:',
        'fa': u':ابرقهرمان_مرد_پوست_روشن:',
        'id': ':pahlawan_super_pria_warna_kulit_cerah-sedang:',
        'zh': u':男超级英雄_中等浅肤色:'
    },
    u'\U0001F9B8\U0001F3FC\U0000200D\U00002642': { # 🦸🏼‍♂
        'en' : ':man_superhero_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':superheld_mittelhelle_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_claro_medio:',
        'fr': u':super-héros_homme_peau_moyennement_claire:',
        'ja': u':男性のスーパーヒーロー_やや薄い肌色:',
        'ko': u':남자_히어로_연한_갈색_피부:',
        'pt': u':homem_super-herói_pele_morena_clara:',
        'it': ':supereroe_uomo_carnagione_abbastanza_chiara:',
        'fa': u':ابرقهرمان_مرد_پوست_روشن:',
        'id': ':pahlawan_super_pria_warna_kulit_cerah-sedang:',
        'zh': u':男超级英雄_中等浅肤色:'
    },
    u'\U0001F9B8\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🦸🏽‍♂️
        'en' : ':man_superhero_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':superheld_mittlere_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_medio:',
        'fr': u':super-héros_homme_peau_légèrement_mate:',
        'ja': u':男性のスーパーヒーロー_中間の肌色:',
        'ko': u':남자_히어로_갈색_피부:',
        'pt': u':homem_super-herói_pele_morena:',
        'it': ':supereroe_uomo_carnagione_olivastra:',
        'fa': u':ابرقهرمان_مرد_پوست_طلایی:',
        'id': ':pahlawan_super_pria_warna_kulit_sedang:',
        'zh': u':男超级英雄_中等肤色:'
    },
    u'\U0001F9B8\U0001F3FD\U0000200D\U00002642': { # 🦸🏽‍♂
        'en' : ':man_superhero_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':superheld_mittlere_hautfarbe:',
        'es': u':superhéroe_tono_de_piel_medio:',
        'fr': u':super-héros_homme_peau_légèrement_mate:',
        'ja': u':男性のスーパーヒーロー_中間の肌色:',
        'ko': u':남자_히어로_갈색_피부:',
        'pt': u':homem_super-herói_pele_morena:',
        'it': ':supereroe_uomo_carnagione_olivastra:',
        'fa': u':ابرقهرمان_مرد_پوست_طلایی:',
        'id': ':pahlawan_super_pria_warna_kulit_sedang:',
        'zh': u':男超级英雄_中等肤色:'
    },
    u'\U0001F9B9\U0000200D\U00002642\U0000FE0F': { # 🦹‍♂️
        'en' : ':man_supervillain:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':supervillain_man:'],
        'de': u':männlicher_bösewicht:',
        'es': ':supervillano:',
        'fr': ':super-vilain_homme:',
        'ja': u':男性の悪役:',
        'ko': u':남자_슈퍼_악당:',
        'pt': u':homem_supervilão:',
        'it': ':supercattivo_uomo:',
        'fa': u':ابرشرور_مرد:',
        'id': ':penjahat_super_pria:',
        'zh': u':男超级大坏蛋:'
    },
    u'\U0001F9B9\U0000200D\U00002642': { # 🦹‍♂
        'en' : ':man_supervillain:',
        'status' : minimally_qualified,
        'E' : 11,
        'alias' : [':supervillain_man:'],
        'de': u':männlicher_bösewicht:',
        'es': ':supervillano:',
        'fr': ':super-vilain_homme:',
        'ja': u':男性の悪役:',
        'ko': u':남자_슈퍼_악당:',
        'pt': u':homem_supervilão:',
        'it': ':supercattivo_uomo:',
        'fa': u':ابرشرور_مرد:',
        'id': ':penjahat_super_pria:',
        'zh': u':男超级大坏蛋:'
    },
    u'\U0001F9B9\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🦹🏿‍♂️
        'en' : ':man_supervillain_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_dunkle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_oscuro:',
        'fr': u':super-vilain_homme_peau_foncée:',
        'ja': u':男性の悪役_濃い肌色:',
        'ko': u':남자_슈퍼_악당_검은색_피부:',
        'pt': u':homem_supervilão_pele_escura:',
        'it': ':supercattivo_uomo_carnagione_scura:',
        'fa': u':ابرشرور_مرد_پوست_آبنوسی:',
        'id': ':penjahat_super_pria_warna_kulit_gelap:',
        'zh': u':男超级大坏蛋_较深肤色:'
    },
    u'\U0001F9B9\U0001F3FF\U0000200D\U00002642': { # 🦹🏿‍♂
        'en' : ':man_supervillain_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_dunkle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_oscuro:',
        'fr': u':super-vilain_homme_peau_foncée:',
        'ja': u':男性の悪役_濃い肌色:',
        'ko': u':남자_슈퍼_악당_검은색_피부:',
        'pt': u':homem_supervilão_pele_escura:',
        'it': ':supercattivo_uomo_carnagione_scura:',
        'fa': u':ابرشرور_مرد_پوست_آبنوسی:',
        'id': ':penjahat_super_pria_warna_kulit_gelap:',
        'zh': u':男超级大坏蛋_较深肤色:'
    },
    u'\U0001F9B9\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🦹🏻‍♂️
        'en' : ':man_supervillain_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_helle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_claro:',
        'fr': ':super-vilain_homme_peau_claire:',
        'ja': u':男性の悪役_薄い肌色:',
        'ko': u':남자_슈퍼_악당_하얀_피부:',
        'pt': u':homem_supervilão_pele_clara:',
        'it': ':supercattivo_uomo_carnagione_chiara:',
        'fa': u':ابرشرور_مرد_پوست_سفید:',
        'id': ':penjahat_super_pria_warna_kulit_cerah:',
        'zh': u':男超级大坏蛋_较浅肤色:'
    },
    u'\U0001F9B9\U0001F3FB\U0000200D\U00002642': { # 🦹🏻‍♂
        'en' : ':man_supervillain_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_helle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_claro:',
        'fr': ':super-vilain_homme_peau_claire:',
        'ja': u':男性の悪役_薄い肌色:',
        'ko': u':남자_슈퍼_악당_하얀_피부:',
        'pt': u':homem_supervilão_pele_clara:',
        'it': ':supercattivo_uomo_carnagione_chiara:',
        'fa': u':ابرشرور_مرد_پوست_سفید:',
        'id': ':penjahat_super_pria_warna_kulit_cerah:',
        'zh': u':男超级大坏蛋_较浅肤色:'
    },
    u'\U0001F9B9\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🦹🏾‍♂️
        'en' : ':man_supervillain_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_mitteldunkle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_oscuro_medio:',
        'fr': ':super-vilain_homme_peau_mate:',
        'ja': u':男性の悪役_やや濃い肌色:',
        'ko': u':남자_슈퍼_악당_진한_갈색_피부:',
        'pt': u':homem_supervilão_pele_morena_escura:',
        'it': ':supercattivo_uomo_carnagione_abbastanza_scura:',
        'fa': u':ابرشرور_مرد_پوست_گندمی:',
        'id': ':penjahat_super_pria_warna_kulit_gelap-sedang:',
        'zh': u':男超级大坏蛋_中等深肤色:'
    },
    u'\U0001F9B9\U0001F3FE\U0000200D\U00002642': { # 🦹🏾‍♂
        'en' : ':man_supervillain_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_mitteldunkle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_oscuro_medio:',
        'fr': ':super-vilain_homme_peau_mate:',
        'ja': u':男性の悪役_やや濃い肌色:',
        'ko': u':남자_슈퍼_악당_진한_갈색_피부:',
        'pt': u':homem_supervilão_pele_morena_escura:',
        'it': ':supercattivo_uomo_carnagione_abbastanza_scura:',
        'fa': u':ابرشرور_مرد_پوست_گندمی:',
        'id': ':penjahat_super_pria_warna_kulit_gelap-sedang:',
        'zh': u':男超级大坏蛋_中等深肤色:'
    },
    u'\U0001F9B9\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🦹🏼‍♂️
        'en' : ':man_supervillain_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_mittelhelle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_claro_medio:',
        'fr': ':super-vilain_homme_peau_moyennement_claire:',
        'ja': u':男性の悪役_やや薄い肌色:',
        'ko': u':남자_슈퍼_악당_연한_갈색_피부:',
        'pt': u':homem_supervilão_pele_morena_clara:',
        'it': ':supercattivo_uomo_carnagione_abbastanza_chiara:',
        'fa': u':ابرشرور_مرد_پوست_روشن:',
        'id': ':penjahat_super_pria_warna_kulit_cerah-sedang:',
        'zh': u':男超级大坏蛋_中等浅肤色:'
    },
    u'\U0001F9B9\U0001F3FC\U0000200D\U00002642': { # 🦹🏼‍♂
        'en' : ':man_supervillain_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_mittelhelle_hautfarbe:',
        'es': ':supervillano_tono_de_piel_claro_medio:',
        'fr': ':super-vilain_homme_peau_moyennement_claire:',
        'ja': u':男性の悪役_やや薄い肌色:',
        'ko': u':남자_슈퍼_악당_연한_갈색_피부:',
        'pt': u':homem_supervilão_pele_morena_clara:',
        'it': ':supercattivo_uomo_carnagione_abbastanza_chiara:',
        'fa': u':ابرشرور_مرد_پوست_روشن:',
        'id': ':penjahat_super_pria_warna_kulit_cerah-sedang:',
        'zh': u':男超级大坏蛋_中等浅肤色:'
    },
    u'\U0001F9B9\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🦹🏽‍♂️
        'en' : ':man_supervillain_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_mittlere_hautfarbe:',
        'es': ':supervillano_tono_de_piel_medio:',
        'fr': u':super-vilain_homme_peau_légèrement_mate:',
        'ja': u':男性の悪役_中間の肌色:',
        'ko': u':남자_슈퍼_악당_갈색_피부:',
        'pt': u':homem_supervilão_pele_morena:',
        'it': ':supercattivo_uomo_carnagione_olivastra:',
        'fa': u':ابرشرور_مرد_پوست_طلایی:',
        'id': ':penjahat_super_pria_warna_kulit_sedang:',
        'zh': u':男超级大坏蛋_中等肤色:'
    },
    u'\U0001F9B9\U0001F3FD\U0000200D\U00002642': { # 🦹🏽‍♂
        'en' : ':man_supervillain_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':männlicher_bösewicht_mittlere_hautfarbe:',
        'es': ':supervillano_tono_de_piel_medio:',
        'fr': u':super-vilain_homme_peau_légèrement_mate:',
        'ja': u':男性の悪役_中間の肌色:',
        'ko': u':남자_슈퍼_악당_갈색_피부:',
        'pt': u':homem_supervilão_pele_morena:',
        'it': ':supercattivo_uomo_carnagione_olivastra:',
        'fa': u':ابرشرور_مرد_پوست_طلایی:',
        'id': ':penjahat_super_pria_warna_kulit_sedang:',
        'zh': u':男超级大坏蛋_中等肤色:'
    },
    u'\U0001F3C4\U0000200D\U00002642\U0000FE0F': { # 🏄‍♂️
        'en' : ':man_surfing:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':surfing_man:'],
        'de': ':surfer:',
        'es': ':hombre_haciendo_surf:',
        'fr': ':surfeur:',
        'ja': u':サーフィンする男:',
        'ko': u':서핑하는_남자:',
        'pt': ':homem_surfista:',
        'it': ':surfista_uomo:',
        'fa': u':موج_سوار_مرد:',
        'id': ':pria_berselancar:',
        'zh': u':男生冲浪:'
    },
    u'\U0001F3C4\U0000200D\U00002642': { # 🏄‍♂
        'en' : ':man_surfing:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':surfing_man:'],
        'de': ':surfer:',
        'es': ':hombre_haciendo_surf:',
        'fr': ':surfeur:',
        'ja': u':サーフィンする男:',
        'ko': u':서핑하는_남자:',
        'pt': ':homem_surfista:',
        'it': ':surfista_uomo:',
        'fa': u':موج_سوار_مرد:',
        'id': ':pria_berselancar:',
        'zh': u':男生冲浪:'
    },
    u'\U0001F3C4\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🏄🏿‍♂️
        'en' : ':man_surfing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surfer_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_oscuro:',
        'fr': u':surfeur_peau_foncée:',
        'ja': u':サーフィンする男_濃い肌色:',
        'ko': u':서핑하는_남자_검은색_피부:',
        'pt': ':homem_surfista_pele_escura:',
        'it': ':surfista_uomo_carnagione_scura:',
        'fa': u':موج_سوار_مرد_پوست_آبنوسی:',
        'id': ':pria_berselancar_warna_kulit_gelap:',
        'zh': u':男生冲浪_较深肤色:'
    },
    u'\U0001F3C4\U0001F3FF\U0000200D\U00002642': { # 🏄🏿‍♂
        'en' : ':man_surfing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surfer_dunkle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_oscuro:',
        'fr': u':surfeur_peau_foncée:',
        'ja': u':サーフィンする男_濃い肌色:',
        'ko': u':서핑하는_남자_검은색_피부:',
        'pt': ':homem_surfista_pele_escura:',
        'it': ':surfista_uomo_carnagione_scura:',
        'fa': u':موج_سوار_مرد_پوست_آبنوسی:',
        'id': ':pria_berselancar_warna_kulit_gelap:',
        'zh': u':男生冲浪_较深肤色:'
    },
    u'\U0001F3C4\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🏄🏻‍♂️
        'en' : ':man_surfing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surfer_helle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_claro:',
        'fr': ':surfeur_peau_claire:',
        'ja': u':サーフィンする男_薄い肌色:',
        'ko': u':서핑하는_남자_하얀_피부:',
        'pt': ':homem_surfista_pele_clara:',
        'it': ':surfista_uomo_carnagione_chiara:',
        'fa': u':موج_سوار_مرد_پوست_سفید:',
        'id': ':pria_berselancar_warna_kulit_cerah:',
        'zh': u':男生冲浪_较浅肤色:'
    },
    u'\U0001F3C4\U0001F3FB\U0000200D\U00002642': { # 🏄🏻‍♂
        'en' : ':man_surfing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surfer_helle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_claro:',
        'fr': ':surfeur_peau_claire:',
        'ja': u':サーフィンする男_薄い肌色:',
        'ko': u':서핑하는_남자_하얀_피부:',
        'pt': ':homem_surfista_pele_clara:',
        'it': ':surfista_uomo_carnagione_chiara:',
        'fa': u':موج_سوار_مرد_پوست_سفید:',
        'id': ':pria_berselancar_warna_kulit_cerah:',
        'zh': u':男生冲浪_较浅肤色:'
    },
    u'\U0001F3C4\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🏄🏾‍♂️
        'en' : ':man_surfing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surfer_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_oscuro_medio:',
        'fr': ':surfeur_peau_mate:',
        'ja': u':サーフィンする男_やや濃い肌色:',
        'ko': u':서핑하는_남자_진한_갈색_피부:',
        'pt': ':homem_surfista_pele_morena_escura:',
        'it': ':surfista_uomo_carnagione_abbastanza_scura:',
        'fa': u':موج_سوار_مرد_پوست_گندمی:',
        'id': ':pria_berselancar_warna_kulit_gelap-sedang:',
        'zh': u':男生冲浪_中等深肤色:'
    },
    u'\U0001F3C4\U0001F3FE\U0000200D\U00002642': { # 🏄🏾‍♂
        'en' : ':man_surfing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surfer_mitteldunkle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_oscuro_medio:',
        'fr': ':surfeur_peau_mate:',
        'ja': u':サーフィンする男_やや濃い肌色:',
        'ko': u':서핑하는_남자_진한_갈색_피부:',
        'pt': ':homem_surfista_pele_morena_escura:',
        'it': ':surfista_uomo_carnagione_abbastanza_scura:',
        'fa': u':موج_سوار_مرد_پوست_گندمی:',
        'id': ':pria_berselancar_warna_kulit_gelap-sedang:',
        'zh': u':男生冲浪_中等深肤色:'
    },
    u'\U0001F3C4\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🏄🏼‍♂️
        'en' : ':man_surfing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surfer_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_claro_medio:',
        'fr': ':surfeur_peau_moyennement_claire:',
        'ja': u':サーフィンする男_やや薄い肌色:',
        'ko': u':서핑하는_남자_연한_갈색_피부:',
        'pt': ':homem_surfista_pele_morena_clara:',
        'it': ':surfista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':موج_سوار_مرد_پوست_روشن:',
        'id': ':pria_berselancar_warna_kulit_cerah-sedang:',
        'zh': u':男生冲浪_中等浅肤色:'
    },
    u'\U0001F3C4\U0001F3FC\U0000200D\U00002642': { # 🏄🏼‍♂
        'en' : ':man_surfing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surfer_mittelhelle_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_claro_medio:',
        'fr': ':surfeur_peau_moyennement_claire:',
        'ja': u':サーフィンする男_やや薄い肌色:',
        'ko': u':서핑하는_남자_연한_갈색_피부:',
        'pt': ':homem_surfista_pele_morena_clara:',
        'it': ':surfista_uomo_carnagione_abbastanza_chiara:',
        'fa': u':موج_سوار_مرد_پوست_روشن:',
        'id': ':pria_berselancar_warna_kulit_cerah-sedang:',
        'zh': u':男生冲浪_中等浅肤色:'
    },
    u'\U0001F3C4\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🏄🏽‍♂️
        'en' : ':man_surfing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surfer_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_medio:',
        'fr': u':surfeur_peau_légèrement_mate:',
        'ja': u':サーフィンする男_中間の肌色:',
        'ko': u':서핑하는_남자_갈색_피부:',
        'pt': ':homem_surfista_pele_morena:',
        'it': ':surfista_uomo_carnagione_olivastra:',
        'fa': u':موج_سوار_مرد_پوست_طلایی:',
        'id': ':pria_berselancar_warna_kulit_sedang:',
        'zh': u':男生冲浪_中等肤色:'
    },
    u'\U0001F3C4\U0001F3FD\U0000200D\U00002642': { # 🏄🏽‍♂
        'en' : ':man_surfing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surfer_mittlere_hautfarbe:',
        'es': ':hombre_haciendo_surf_tono_de_piel_medio:',
        'fr': u':surfeur_peau_légèrement_mate:',
        'ja': u':サーフィンする男_中間の肌色:',
        'ko': u':서핑하는_남자_갈색_피부:',
        'pt': ':homem_surfista_pele_morena:',
        'it': ':surfista_uomo_carnagione_olivastra:',
        'fa': u':موج_سوار_مرد_پوست_طلایی:',
        'id': ':pria_berselancar_warna_kulit_sedang:',
        'zh': u':男生冲浪_中等肤色:'
    },
    u'\U0001F3CA\U0000200D\U00002642\U0000FE0F': { # 🏊‍♂️
        'en' : ':man_swimming:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':swimming_man:'],
        'de': ':schwimmer:',
        'es': ':hombre_nadando:',
        'fr': ':nageur:',
        'ja': u':泳ぐ男:',
        'ko': u':수영하는_남자:',
        'pt': ':homem_nadando:',
        'it': ':nuotatore:',
        'fa': u':شناگر_مرد:',
        'id': ':pria_berenang:',
        'zh': u':男生游泳:'
    },
    u'\U0001F3CA\U0000200D\U00002642': { # 🏊‍♂
        'en' : ':man_swimming:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':swimming_man:'],
        'de': ':schwimmer:',
        'es': ':hombre_nadando:',
        'fr': ':nageur:',
        'ja': u':泳ぐ男:',
        'ko': u':수영하는_남자:',
        'pt': ':homem_nadando:',
        'it': ':nuotatore:',
        'fa': u':شناگر_مرد:',
        'id': ':pria_berenang:',
        'zh': u':男生游泳:'
    },
    u'\U0001F3CA\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🏊🏿‍♂️
        'en' : ':man_swimming_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmer_dunkle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_oscuro:',
        'fr': u':nageur_peau_foncée:',
        'ja': u':泳ぐ男_濃い肌色:',
        'ko': u':수영하는_남자_검은색_피부:',
        'pt': ':homem_nadando_pele_escura:',
        'it': ':nuotatore_carnagione_scura:',
        'fa': u':شناگر_مرد_پوست_آبنوسی:',
        'id': ':pria_berenang_warna_kulit_gelap:',
        'zh': u':男生游泳_较深肤色:'
    },
    u'\U0001F3CA\U0001F3FF\U0000200D\U00002642': { # 🏊🏿‍♂
        'en' : ':man_swimming_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmer_dunkle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_oscuro:',
        'fr': u':nageur_peau_foncée:',
        'ja': u':泳ぐ男_濃い肌色:',
        'ko': u':수영하는_남자_검은색_피부:',
        'pt': ':homem_nadando_pele_escura:',
        'it': ':nuotatore_carnagione_scura:',
        'fa': u':شناگر_مرد_پوست_آبنوسی:',
        'id': ':pria_berenang_warna_kulit_gelap:',
        'zh': u':男生游泳_较深肤色:'
    },
    u'\U0001F3CA\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🏊🏻‍♂️
        'en' : ':man_swimming_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmer_helle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_claro:',
        'fr': ':nageur_peau_claire:',
        'ja': u':泳ぐ男_薄い肌色:',
        'ko': u':수영하는_남자_하얀_피부:',
        'pt': ':homem_nadando_pele_clara:',
        'it': ':nuotatore_carnagione_chiara:',
        'fa': u':شناگر_مرد_پوست_سفید:',
        'id': ':pria_berenang_warna_kulit_cerah:',
        'zh': u':男生游泳_较浅肤色:'
    },
    u'\U0001F3CA\U0001F3FB\U0000200D\U00002642': { # 🏊🏻‍♂
        'en' : ':man_swimming_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmer_helle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_claro:',
        'fr': ':nageur_peau_claire:',
        'ja': u':泳ぐ男_薄い肌色:',
        'ko': u':수영하는_남자_하얀_피부:',
        'pt': ':homem_nadando_pele_clara:',
        'it': ':nuotatore_carnagione_chiara:',
        'fa': u':شناگر_مرد_پوست_سفید:',
        'id': ':pria_berenang_warna_kulit_cerah:',
        'zh': u':男生游泳_较浅肤色:'
    },
    u'\U0001F3CA\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🏊🏾‍♂️
        'en' : ':man_swimming_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmer_mitteldunkle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_oscuro_medio:',
        'fr': ':nageur_peau_mate:',
        'ja': u':泳ぐ男_やや濃い肌色:',
        'ko': u':수영하는_남자_진한_갈색_피부:',
        'pt': ':homem_nadando_pele_morena_escura:',
        'it': ':nuotatore_carnagione_abbastanza_scura:',
        'fa': u':شناگر_مرد_پوست_گندمی:',
        'id': ':pria_berenang_warna_kulit_gelap-sedang:',
        'zh': u':男生游泳_中等深肤色:'
    },
    u'\U0001F3CA\U0001F3FE\U0000200D\U00002642': { # 🏊🏾‍♂
        'en' : ':man_swimming_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmer_mitteldunkle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_oscuro_medio:',
        'fr': ':nageur_peau_mate:',
        'ja': u':泳ぐ男_やや濃い肌色:',
        'ko': u':수영하는_남자_진한_갈색_피부:',
        'pt': ':homem_nadando_pele_morena_escura:',
        'it': ':nuotatore_carnagione_abbastanza_scura:',
        'fa': u':شناگر_مرد_پوست_گندمی:',
        'id': ':pria_berenang_warna_kulit_gelap-sedang:',
        'zh': u':男生游泳_中等深肤色:'
    },
    u'\U0001F3CA\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🏊🏼‍♂️
        'en' : ':man_swimming_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmer_mittelhelle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_claro_medio:',
        'fr': ':nageur_peau_moyennement_claire:',
        'ja': u':泳ぐ男_やや薄い肌色:',
        'ko': u':수영하는_남자_연한_갈색_피부:',
        'pt': ':homem_nadando_pele_morena_clara:',
        'it': ':nuotatore_carnagione_abbastanza_chiara:',
        'fa': u':شناگر_مرد_پوست_روشن:',
        'id': ':pria_berenang_warna_kulit_cerah-sedang:',
        'zh': u':男生游泳_中等浅肤色:'
    },
    u'\U0001F3CA\U0001F3FC\U0000200D\U00002642': { # 🏊🏼‍♂
        'en' : ':man_swimming_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmer_mittelhelle_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_claro_medio:',
        'fr': ':nageur_peau_moyennement_claire:',
        'ja': u':泳ぐ男_やや薄い肌色:',
        'ko': u':수영하는_남자_연한_갈색_피부:',
        'pt': ':homem_nadando_pele_morena_clara:',
        'it': ':nuotatore_carnagione_abbastanza_chiara:',
        'fa': u':شناگر_مرد_پوست_روشن:',
        'id': ':pria_berenang_warna_kulit_cerah-sedang:',
        'zh': u':男生游泳_中等浅肤色:'
    },
    u'\U0001F3CA\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🏊🏽‍♂️
        'en' : ':man_swimming_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmer_mittlere_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_medio:',
        'fr': u':nageur_peau_légèrement_mate:',
        'ja': u':泳ぐ男_中間の肌色:',
        'ko': u':수영하는_남자_갈색_피부:',
        'pt': ':homem_nadando_pele_morena:',
        'it': ':nuotatore_carnagione_olivastra:',
        'fa': u':شناگر_مرد_پوست_طلایی:',
        'id': ':pria_berenang_warna_kulit_sedang:',
        'zh': u':男生游泳_中等肤色:'
    },
    u'\U0001F3CA\U0001F3FD\U0000200D\U00002642': { # 🏊🏽‍♂
        'en' : ':man_swimming_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmer_mittlere_hautfarbe:',
        'es': ':hombre_nadando_tono_de_piel_medio:',
        'fr': u':nageur_peau_légèrement_mate:',
        'ja': u':泳ぐ男_中間の肌色:',
        'ko': u':수영하는_남자_갈색_피부:',
        'pt': ':homem_nadando_pele_morena:',
        'it': ':nuotatore_carnagione_olivastra:',
        'fa': u':شناگر_مرد_پوست_طلایی:',
        'id': ':pria_berenang_warna_kulit_sedang:',
        'zh': u':男生游泳_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F3EB': { # 👨‍🏫
        'en' : ':man_teacher:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrer:',
        'es': ':docente_hombre:',
        'fr': ':enseignant:',
        'ja': u':男性の教師:',
        'ko': u':남교사:',
        'pt': ':professor:',
        'it': ':professore:',
        'fa': u':آموزگار_مرد:',
        'id': ':pengajar_pria:',
        'zh': u':男老师:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F3EB': { # 👨🏿‍🏫
        'en' : ':man_teacher_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrer_dunkle_hautfarbe:',
        'es': ':docente_hombre_tono_de_piel_oscuro:',
        'fr': u':enseignant_peau_foncée:',
        'ja': u':男性の教師_濃い肌色:',
        'ko': u':남교사_검은색_피부:',
        'pt': ':professor_pele_escura:',
        'it': ':professore_carnagione_scura:',
        'fa': u':آموزگار_مرد_پوست_آبنوسی:',
        'id': ':pengajar_pria_warna_kulit_gelap:',
        'zh': u':男老师_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F3EB': { # 👨🏻‍🏫
        'en' : ':man_teacher_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrer_helle_hautfarbe:',
        'es': ':docente_hombre_tono_de_piel_claro:',
        'fr': ':enseignant_peau_claire:',
        'ja': u':男性の教師_薄い肌色:',
        'ko': u':남교사_하얀_피부:',
        'pt': ':professor_pele_clara:',
        'it': ':professore_carnagione_chiara:',
        'fa': u':آموزگار_مرد_پوست_سفید:',
        'id': ':pengajar_pria_warna_kulit_cerah:',
        'zh': u':男老师_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F3EB': { # 👨🏾‍🏫
        'en' : ':man_teacher_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrer_mitteldunkle_hautfarbe:',
        'es': ':docente_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':enseignant_peau_mate:',
        'ja': u':男性の教師_やや濃い肌色:',
        'ko': u':남교사_진한_갈색_피부:',
        'pt': ':professor_pele_morena_escura:',
        'it': ':professore_carnagione_abbastanza_scura:',
        'fa': u':آموزگار_مرد_پوست_گندمی:',
        'id': ':pengajar_pria_warna_kulit_gelap-sedang:',
        'zh': u':男老师_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F3EB': { # 👨🏼‍🏫
        'en' : ':man_teacher_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrer_mittelhelle_hautfarbe:',
        'es': ':docente_hombre_tono_de_piel_claro_medio:',
        'fr': ':enseignant_peau_moyennement_claire:',
        'ja': u':男性の教師_やや薄い肌色:',
        'ko': u':남교사_연한_갈색_피부:',
        'pt': ':professor_pele_morena_clara:',
        'it': ':professore_carnagione_abbastanza_chiara:',
        'fa': u':آموزگار_مرد_پوست_روشن:',
        'id': ':pengajar_pria_warna_kulit_cerah-sedang:',
        'zh': u':男老师_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F3EB': { # 👨🏽‍🏫
        'en' : ':man_teacher_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrer_mittlere_hautfarbe:',
        'es': ':docente_hombre_tono_de_piel_medio:',
        'fr': u':enseignant_peau_légèrement_mate:',
        'ja': u':男性の教師_中間の肌色:',
        'ko': u':남교사_갈색_피부:',
        'pt': ':professor_pele_morena:',
        'it': ':professore_carnagione_olivastra:',
        'fa': u':آموزگار_مرد_پوست_طلایی:',
        'id': ':pengajar_pria_warna_kulit_sedang:',
        'zh': u':男老师_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F4BB': { # 👨‍💻
        'en' : ':man_technologist:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-experte:',
        'es': u':profesional_de_la_tecnología_hombre:',
        'fr': ':informaticien:',
        'ja': u':男性技術者:',
        'ko': u':남자_기술_전문가:',
        'pt': u':tecnólogo:',
        'it': ':tecnologo:',
        'fa': u':کارشناس_فناوری_مرد:',
        'id': ':ahli_teknologi_pria:',
        'zh': u':男程序员:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F4BB': { # 👨🏿‍💻
        'en' : ':man_technologist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-experte_dunkle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_hombre_tono_de_piel_oscuro:',
        'fr': u':informaticien_peau_foncée:',
        'ja': u':男性技術者_濃い肌色:',
        'ko': u':남자_기술_전문가_검은색_피부:',
        'pt': u':tecnólogo_pele_escura:',
        'it': ':tecnologo_carnagione_scura:',
        'fa': u':کارشناس_فناوری_مرد_پوست_آبنوسی:',
        'id': ':ahli_teknologi_pria_warna_kulit_gelap:',
        'zh': u':男程序员_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F4BB': { # 👨🏻‍💻
        'en' : ':man_technologist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-experte_helle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_hombre_tono_de_piel_claro:',
        'fr': ':informaticien_peau_claire:',
        'ja': u':男性技術者_薄い肌色:',
        'ko': u':남자_기술_전문가_하얀_피부:',
        'pt': u':tecnólogo_pele_clara:',
        'it': ':tecnologo_carnagione_chiara:',
        'fa': u':کارشناس_فناوری_مرد_پوست_سفید:',
        'id': ':ahli_teknologi_pria_warna_kulit_cerah:',
        'zh': u':男程序员_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F4BB': { # 👨🏾‍💻
        'en' : ':man_technologist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-experte_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':informaticien_peau_mate:',
        'ja': u':男性技術者_やや濃い肌色:',
        'ko': u':남자_기술_전문가_진한_갈색_피부:',
        'pt': u':tecnólogo_pele_morena_escura:',
        'it': ':tecnologo_carnagione_abbastanza_scura:',
        'fa': u':کارشناس_فناوری_مرد_پوست_گندمی:',
        'id': ':ahli_teknologi_pria_warna_kulit_gelap-sedang:',
        'zh': u':男程序员_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F4BB': { # 👨🏼‍💻
        'en' : ':man_technologist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-experte_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_hombre_tono_de_piel_claro_medio:',
        'fr': ':informaticien_peau_moyennement_claire:',
        'ja': u':男性技術者_やや薄い肌色:',
        'ko': u':남자_기술_전문가_연한_갈색_피부:',
        'pt': u':tecnólogo_pele_morena_clara:',
        'it': ':tecnologo_carnagione_abbastanza_chiara:',
        'fa': u':کارشناس_فناوری_مرد_پوست_روشن:',
        'id': ':ahli_teknologi_pria_warna_kulit_cerah-sedang:',
        'zh': u':男程序员_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F4BB': { # 👨🏽‍💻
        'en' : ':man_technologist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-experte_mittlere_hautfarbe:',
        'es': u':profesional_de_la_tecnología_hombre_tono_de_piel_medio:',
        'fr': u':informaticien_peau_légèrement_mate:',
        'ja': u':男性技術者_中間の肌色:',
        'ko': u':남자_기술_전문가_갈색_피부:',
        'pt': u':tecnólogo_pele_morena:',
        'it': ':tecnologo_carnagione_olivastra:',
        'fa': u':کارشناس_فناوری_مرد_پوست_طلایی:',
        'id': ':ahli_teknologi_pria_warna_kulit_sedang:',
        'zh': u':男程序员_中等肤色:'
    },
    u'\U0001F481\U0000200D\U00002642\U0000FE0F': { # 💁‍♂️
        'en' : ':man_tipping_hand:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':sassy_man:', ':tipping_hand_man:'],
        'de': ':infoschalter-mitarbeiter:',
        'es': u':empleado_de_mostrador_de_información:',
        'fr': ':homme_paume_vers_le_haut:',
        'ja': u':案内する男:',
        'ko': u':손바닥_꺾은_남자:',
        'pt': ':homem_com_a_palma_virada_para_cima:',
        'it': ':uomo_con_suggerimento:',
        'fa': u':مرد_کمک_می_کند:',
        'id': ':pria_menengadahkan_tangan:',
        'zh': u':前台男:'
    },
    u'\U0001F481\U0000200D\U00002642': { # 💁‍♂
        'en' : ':man_tipping_hand:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':sassy_man:', ':tipping_hand_man:'],
        'de': ':infoschalter-mitarbeiter:',
        'es': u':empleado_de_mostrador_de_información:',
        'fr': ':homme_paume_vers_le_haut:',
        'ja': u':案内する男:',
        'ko': u':손바닥_꺾은_남자:',
        'pt': ':homem_com_a_palma_virada_para_cima:',
        'it': ':uomo_al_punto_informazioni:',
        'fa': u':مرد_کمک_می_کند:',
        'id': ':pria_menengadahkan_tangan:',
        'zh': u':前台男:'
    },
    u'\U0001F481\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 💁🏿‍♂️
        'en' : ':man_tipping_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_dunkle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_oscuro:',
        'fr': u':homme_paume_vers_le_haut_peau_foncée:',
        'ja': u':案内する男_濃い肌色:',
        'ko': u':손바닥_꺾은_남자_검은색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_escura:',
        'it': ':uomo_con_suggerimento_carnagione_scura:',
        'fa': u':مرد_کمک_می_کند_پوست_آبنوسی:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_gelap:',
        'zh': u':前台男_较深肤色:'
    },
    u'\U0001F481\U0001F3FF\U0000200D\U00002642': { # 💁🏿‍♂
        'en' : ':man_tipping_hand_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_dunkle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_oscuro:',
        'fr': u':homme_paume_vers_le_haut_peau_foncée:',
        'ja': u':案内する男_濃い肌色:',
        'ko': u':손바닥_꺾은_남자_검은색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_escura:',
        'it': ':uomo_con_suggerimento_carnagione_scura:',
        'fa': u':مرد_کمک_می_کند_پوست_آبنوسی:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_gelap:',
        'zh': u':前台男_较深肤色:'
    },
    u'\U0001F481\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 💁🏻‍♂️
        'en' : ':man_tipping_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_helle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_claro:',
        'fr': ':homme_paume_vers_le_haut_peau_claire:',
        'ja': u':案内する男_薄い肌色:',
        'ko': u':손바닥_꺾은_남자_하얀_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_clara:',
        'it': ':uomo_con_suggerimento_carnagione_chiara:',
        'fa': u':مرد_کمک_می_کند_پوست_سفید:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_cerah:',
        'zh': u':前台男_较浅肤色:'
    },
    u'\U0001F481\U0001F3FB\U0000200D\U00002642': { # 💁🏻‍♂
        'en' : ':man_tipping_hand_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_helle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_claro:',
        'fr': ':homme_paume_vers_le_haut_peau_claire:',
        'ja': u':案内する男_薄い肌色:',
        'ko': u':손바닥_꺾은_남자_하얀_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_clara:',
        'it': ':uomo_con_suggerimento_carnagione_chiara:',
        'fa': u':مرد_کمک_می_کند_پوست_سفید:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_cerah:',
        'zh': u':前台男_较浅肤色:'
    },
    u'\U0001F481\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 💁🏾‍♂️
        'en' : ':man_tipping_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_mitteldunkle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_oscuro_medio:',
        'fr': ':homme_paume_vers_le_haut_peau_mate:',
        'ja': u':案内する男_やや濃い肌色:',
        'ko': u':손바닥_꺾은_남자_진한_갈색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_morena_escura:',
        'it': ':uomo_con_suggerimento_carnagione_abbastanza_scura:',
        'fa': u':مرد_کمک_می_کند_پوست_گندمی:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_gelap-sedang:',
        'zh': u':前台男_中等深肤色:'
    },
    u'\U0001F481\U0001F3FE\U0000200D\U00002642': { # 💁🏾‍♂
        'en' : ':man_tipping_hand_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_mitteldunkle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_oscuro_medio:',
        'fr': ':homme_paume_vers_le_haut_peau_mate:',
        'ja': u':案内する男_やや濃い肌色:',
        'ko': u':손바닥_꺾은_남자_진한_갈색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_morena_escura:',
        'it': ':uomo_con_suggerimento_carnagione_abbastanza_scura:',
        'fa': u':مرد_کمک_می_کند_پوست_گندمی:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_gelap-sedang:',
        'zh': u':前台男_中等深肤色:'
    },
    u'\U0001F481\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 💁🏼‍♂️
        'en' : ':man_tipping_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_mittelhelle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_claro_medio:',
        'fr': ':homme_paume_vers_le_haut_peau_moyennement_claire:',
        'ja': u':案内する男_やや薄い肌色:',
        'ko': u':손바닥_꺾은_남자_연한_갈색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_morena_clara:',
        'it': ':uomo_con_suggerimento_carnagione_abbastanza_chiara:',
        'fa': u':مرد_کمک_می_کند_پوست_روشن:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_cerah-sedang:',
        'zh': u':前台男_中等浅肤色:'
    },
    u'\U0001F481\U0001F3FC\U0000200D\U00002642': { # 💁🏼‍♂
        'en' : ':man_tipping_hand_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_mittelhelle_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_claro_medio:',
        'fr': ':homme_paume_vers_le_haut_peau_moyennement_claire:',
        'ja': u':案内する男_やや薄い肌色:',
        'ko': u':손바닥_꺾은_남자_연한_갈색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_morena_clara:',
        'it': ':uomo_con_suggerimento_carnagione_abbastanza_chiara:',
        'fa': u':مرد_کمک_می_کند_پوست_روشن:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_cerah-sedang:',
        'zh': u':前台男_中等浅肤色:'
    },
    u'\U0001F481\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 💁🏽‍♂️
        'en' : ':man_tipping_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_mittlere_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_medio:',
        'fr': u':homme_paume_vers_le_haut_peau_légèrement_mate:',
        'ja': u':案内する男_中間の肌色:',
        'ko': u':손바닥_꺾은_남자_갈색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_morena:',
        'it': ':uomo_con_suggerimento_carnagione_olivastra:',
        'fa': u':مرد_کمک_می_کند_پوست_طلایی:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_sedang:',
        'zh': u':前台男_中等肤色:'
    },
    u'\U0001F481\U0001F3FD\U0000200D\U00002642': { # 💁🏽‍♂
        'en' : ':man_tipping_hand_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiter_mittlere_hautfarbe:',
        'es': u':empleado_de_mostrador_de_información_tono_de_piel_medio:',
        'fr': u':homme_paume_vers_le_haut_peau_légèrement_mate:',
        'ja': u':案内する男_中間の肌色:',
        'ko': u':손바닥_꺾은_남자_갈색_피부:',
        'pt': ':homem_com_a_palma_virada_para_cima_pele_morena:',
        'it': ':uomo_con_suggerimento_carnagione_olivastra:',
        'fa': u':مرد_کمک_می_کند_پوست_طلایی:',
        'id': ':pria_menengadahkan_tangan_warna_kulit_sedang:',
        'zh': u':前台男_中等肤色:'
    },
    u'\U0001F9DB\U0000200D\U00002642\U0000FE0F': { # 🧛‍♂️
        'en' : ':man_vampire:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':vampire_man:'],
        'de': u':männlicher_vampir:',
        'es': ':vampiro_hombre:',
        'fr': ':vampire_homme:',
        'ja': u':男の吸血鬼:',
        'ko': u':남자_뱀파이어:',
        'pt': ':homem_vampiro:',
        'it': ':vampiro_uomo:',
        'fa': u':خون_آشام_مرد:',
        'id': ':vampir_pria:',
        'zh': u':男吸血鬼:'
    },
    u'\U0001F9DB\U0000200D\U00002642': { # 🧛‍♂
        'en' : ':man_vampire:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':vampire_man:'],
        'de': u':männlicher_vampir:',
        'es': ':vampiro_hombre:',
        'fr': ':vampire_homme:',
        'ja': u':男の吸血鬼:',
        'ko': u':남자_뱀파이어:',
        'pt': ':homem_vampiro:',
        'it': ':vampiro_uomo:',
        'fa': u':خون_آشام_مرد:',
        'id': ':vampir_pria:',
        'zh': u':男吸血鬼:'
    },
    u'\U0001F9DB\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧛🏿‍♂️
        'en' : ':man_vampire_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_dunkle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_oscuro:',
        'fr': u':vampire_homme_peau_foncée:',
        'ja': u':男の吸血鬼_濃い肌色:',
        'ko': u':남자_뱀파이어_검은색_피부:',
        'pt': ':homem_vampiro_pele_escura:',
        'it': ':vampiro_uomo_carnagione_scura:',
        'fa': u':خون_آشام_مرد_پوست_آبنوسی:',
        'id': ':vampir_pria_warna_kulit_gelap:',
        'zh': u':男吸血鬼_较深肤色:'
    },
    u'\U0001F9DB\U0001F3FF\U0000200D\U00002642': { # 🧛🏿‍♂
        'en' : ':man_vampire_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_dunkle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_oscuro:',
        'fr': u':vampire_homme_peau_foncée:',
        'ja': u':男の吸血鬼_濃い肌色:',
        'ko': u':남자_뱀파이어_검은색_피부:',
        'pt': ':homem_vampiro_pele_escura:',
        'it': ':vampiro_uomo_carnagione_scura:',
        'fa': u':خون_آشام_مرد_پوست_آبنوسی:',
        'id': ':vampir_pria_warna_kulit_gelap:',
        'zh': u':男吸血鬼_较深肤色:'
    },
    u'\U0001F9DB\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧛🏻‍♂️
        'en' : ':man_vampire_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_helle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_claro:',
        'fr': ':vampire_homme_peau_claire:',
        'ja': u':男の吸血鬼_薄い肌色:',
        'ko': u':남자_뱀파이어_하얀_피부:',
        'pt': ':homem_vampiro_pele_clara:',
        'it': ':vampiro_uomo_carnagione_chiara:',
        'fa': u':خون_آشام_مرد_پوست_سفید:',
        'id': ':vampir_pria_warna_kulit_cerah:',
        'zh': u':男吸血鬼_较浅肤色:'
    },
    u'\U0001F9DB\U0001F3FB\U0000200D\U00002642': { # 🧛🏻‍♂
        'en' : ':man_vampire_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_helle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_claro:',
        'fr': ':vampire_homme_peau_claire:',
        'ja': u':男の吸血鬼_薄い肌色:',
        'ko': u':남자_뱀파이어_하얀_피부:',
        'pt': ':homem_vampiro_pele_clara:',
        'it': ':vampiro_uomo_carnagione_chiara:',
        'fa': u':خون_آشام_مرد_پوست_سفید:',
        'id': ':vampir_pria_warna_kulit_cerah:',
        'zh': u':男吸血鬼_较浅肤色:'
    },
    u'\U0001F9DB\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧛🏾‍♂️
        'en' : ':man_vampire_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_mitteldunkle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':vampire_homme_peau_mate:',
        'ja': u':男の吸血鬼_やや濃い肌色:',
        'ko': u':남자_뱀파이어_진한_갈색_피부:',
        'pt': ':homem_vampiro_pele_morena_escura:',
        'it': ':vampiro_uomo_carnagione_abbastanza_scura:',
        'fa': u':خون_آشام_مرد_پوست_گندمی:',
        'id': ':vampir_pria_warna_kulit_gelap-sedang:',
        'zh': u':男吸血鬼_中等深肤色:'
    },
    u'\U0001F9DB\U0001F3FE\U0000200D\U00002642': { # 🧛🏾‍♂
        'en' : ':man_vampire_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_mitteldunkle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':vampire_homme_peau_mate:',
        'ja': u':男の吸血鬼_やや濃い肌色:',
        'ko': u':남자_뱀파이어_진한_갈색_피부:',
        'pt': ':homem_vampiro_pele_morena_escura:',
        'it': ':vampiro_uomo_carnagione_abbastanza_scura:',
        'fa': u':خون_آشام_مرد_پوست_گندمی:',
        'id': ':vampir_pria_warna_kulit_gelap-sedang:',
        'zh': u':男吸血鬼_中等深肤色:'
    },
    u'\U0001F9DB\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧛🏼‍♂️
        'en' : ':man_vampire_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_mittelhelle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_claro_medio:',
        'fr': ':vampire_homme_peau_moyennement_claire:',
        'ja': u':男の吸血鬼_やや薄い肌色:',
        'ko': u':남자_뱀파이어_연한_갈색_피부:',
        'pt': ':homem_vampiro_pele_morena_clara:',
        'it': ':vampiro_uomo_carnagione_abbastanza_chiara:',
        'fa': u':خون_آشام_مرد_پوست_روشن:',
        'id': ':vampir_pria_warna_kulit_cerah-sedang:',
        'zh': u':男吸血鬼_中等浅肤色:'
    },
    u'\U0001F9DB\U0001F3FC\U0000200D\U00002642': { # 🧛🏼‍♂
        'en' : ':man_vampire_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_mittelhelle_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_claro_medio:',
        'fr': ':vampire_homme_peau_moyennement_claire:',
        'ja': u':男の吸血鬼_やや薄い肌色:',
        'ko': u':남자_뱀파이어_연한_갈색_피부:',
        'pt': ':homem_vampiro_pele_morena_clara:',
        'it': ':vampiro_uomo_carnagione_abbastanza_chiara:',
        'fa': u':خون_آشام_مرد_پوست_روشن:',
        'id': ':vampir_pria_warna_kulit_cerah-sedang:',
        'zh': u':男吸血鬼_中等浅肤色:'
    },
    u'\U0001F9DB\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧛🏽‍♂️
        'en' : ':man_vampire_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_mittlere_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_medio:',
        'fr': u':vampire_homme_peau_légèrement_mate:',
        'ja': u':男の吸血鬼_中間の肌色:',
        'ko': u':남자_뱀파이어_갈색_피부:',
        'pt': ':homem_vampiro_pele_morena:',
        'it': ':vampiro_uomo_carnagione_olivastra:',
        'fa': u':خون_آشام_مرد_پوست_طلایی:',
        'id': ':vampir_pria_warna_kulit_sedang:',
        'zh': u':男吸血鬼_中等肤色:'
    },
    u'\U0001F9DB\U0001F3FD\U0000200D\U00002642': { # 🧛🏽‍♂
        'en' : ':man_vampire_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': u':männlicher_vampir_mittlere_hautfarbe:',
        'es': ':vampiro_hombre_tono_de_piel_medio:',
        'fr': u':vampire_homme_peau_légèrement_mate:',
        'ja': u':男の吸血鬼_中間の肌色:',
        'ko': u':남자_뱀파이어_갈색_피부:',
        'pt': ':homem_vampiro_pele_morena:',
        'it': ':vampiro_uomo_carnagione_olivastra:',
        'fa': u':خون_آشام_مرد_پوست_طلایی:',
        'id': ':vampir_pria_warna_kulit_sedang:',
        'zh': u':男吸血鬼_中等肤色:'
    },
    u'\U0001F6B6\U0000200D\U00002642\U0000FE0F': { # 🚶‍♂️
        'en' : ':man_walking:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':walking_man:'],
        'de': u':fußgänger:',
        'es': ':hombre_caminando:',
        'fr': ':homme_qui_marche:',
        'ja': u':歩く男:',
        'ko': u':걷는_남자:',
        'pt': ':homem_andando:',
        'it': ':uomo_che_cammina:',
        'fa': u':مرد_پیاده_روی_می_کند:',
        'id': ':pria_berjalan_kaki:',
        'zh': u':男行人:'
    },
    u'\U0001F6B6\U0000200D\U00002642': { # 🚶‍♂
        'en' : ':man_walking:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':walking_man:'],
        'de': u':fußgänger:',
        'es': ':hombre_caminando:',
        'fr': ':homme_qui_marche:',
        'ja': u':歩く男:',
        'ko': u':걷는_남자:',
        'pt': ':homem_andando:',
        'it': ':uomo_che_cammina:',
        'fa': u':مرد_پیاده_روی_می_کند:',
        'id': ':pria_berjalan_kaki:',
        'zh': u':男行人:'
    },
    u'\U0001F6B6\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🚶🏿‍♂️
        'en' : ':man_walking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgänger_dunkle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_oscuro:',
        'fr': u':homme_qui_marche_peau_foncée:',
        'ja': u':歩く男_濃い肌色:',
        'ko': u':걷는_남자_검은색_피부:',
        'pt': ':homem_andando_pele_escura:',
        'it': ':uomo_che_cammina_carnagione_scura:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_آبنوسی:',
        'id': ':pria_berjalan_kaki_warna_kulit_gelap:',
        'zh': u':男行人_较深肤色:'
    },
    u'\U0001F6B6\U0001F3FF\U0000200D\U00002642': { # 🚶🏿‍♂
        'en' : ':man_walking_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgänger_dunkle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_oscuro:',
        'fr': u':homme_qui_marche_peau_foncée:',
        'ja': u':歩く男_濃い肌色:',
        'ko': u':걷는_남자_검은색_피부:',
        'pt': ':homem_andando_pele_escura:',
        'it': ':uomo_che_cammina_carnagione_scura:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_آبنوسی:',
        'id': ':pria_berjalan_kaki_warna_kulit_gelap:',
        'zh': u':男行人_较深肤色:'
    },
    u'\U0001F6B6\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🚶🏻‍♂️
        'en' : ':man_walking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgänger_helle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_claro:',
        'fr': ':homme_qui_marche_peau_claire:',
        'ja': u':歩く男_薄い肌色:',
        'ko': u':걷는_남자_하얀_피부:',
        'pt': ':homem_andando_pele_clara:',
        'it': ':uomo_che_cammina_carnagione_chiara:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_سفید:',
        'id': ':pria_berjalan_kaki_warna_kulit_cerah:',
        'zh': u':男行人_较浅肤色:'
    },
    u'\U0001F6B6\U0001F3FB\U0000200D\U00002642': { # 🚶🏻‍♂
        'en' : ':man_walking_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgänger_helle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_claro:',
        'fr': ':homme_qui_marche_peau_claire:',
        'ja': u':歩く男_薄い肌色:',
        'ko': u':걷는_남자_하얀_피부:',
        'pt': ':homem_andando_pele_clara:',
        'it': ':uomo_che_cammina_carnagione_chiara:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_سفید:',
        'id': ':pria_berjalan_kaki_warna_kulit_cerah:',
        'zh': u':男行人_较浅肤色:'
    },
    u'\U0001F6B6\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🚶🏾‍♂️
        'en' : ':man_walking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgänger_mitteldunkle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_marche_peau_mate:',
        'ja': u':歩く男_やや濃い肌色:',
        'ko': u':걷는_남자_진한_갈색_피부:',
        'pt': ':homem_andando_pele_morena_escura:',
        'it': ':uomo_che_cammina_carnagione_abbastanza_scura:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_گندمی:',
        'id': ':pria_berjalan_kaki_warna_kulit_gelap-sedang:',
        'zh': u':男行人_中等深肤色:'
    },
    u'\U0001F6B6\U0001F3FE\U0000200D\U00002642': { # 🚶🏾‍♂
        'en' : ':man_walking_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgänger_mitteldunkle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_oscuro_medio:',
        'fr': ':homme_qui_marche_peau_mate:',
        'ja': u':歩く男_やや濃い肌色:',
        'ko': u':걷는_남자_진한_갈색_피부:',
        'pt': ':homem_andando_pele_morena_escura:',
        'it': ':uomo_che_cammina_carnagione_abbastanza_scura:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_گندمی:',
        'id': ':pria_berjalan_kaki_warna_kulit_gelap-sedang:',
        'zh': u':男行人_中等深肤色:'
    },
    u'\U0001F6B6\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🚶🏼‍♂️
        'en' : ':man_walking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgänger_mittelhelle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_marche_peau_moyennement_claire:',
        'ja': u':歩く男_やや薄い肌色:',
        'ko': u':걷는_남자_연한_갈색_피부:',
        'pt': ':homem_andando_pele_morena_clara:',
        'it': ':uomo_che_cammina_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_روشن:',
        'id': ':pria_berjalan_kaki_warna_kulit_cerah-sedang:',
        'zh': u':男行人_中等浅肤色:'
    },
    u'\U0001F6B6\U0001F3FC\U0000200D\U00002642': { # 🚶🏼‍♂
        'en' : ':man_walking_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgänger_mittelhelle_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_claro_medio:',
        'fr': ':homme_qui_marche_peau_moyennement_claire:',
        'ja': u':歩く男_やや薄い肌色:',
        'ko': u':걷는_남자_연한_갈색_피부:',
        'pt': ':homem_andando_pele_morena_clara:',
        'it': ':uomo_che_cammina_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_روشن:',
        'id': ':pria_berjalan_kaki_warna_kulit_cerah-sedang:',
        'zh': u':男行人_中等浅肤色:'
    },
    u'\U0001F6B6\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🚶🏽‍♂️
        'en' : ':man_walking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgänger_mittlere_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_medio:',
        'fr': u':homme_qui_marche_peau_légèrement_mate:',
        'ja': u':歩く男_中間の肌色:',
        'ko': u':걷는_남자_갈색_피부:',
        'pt': ':homem_andando_pele_morena:',
        'it': ':uomo_che_cammina_carnagione_olivastra:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_طلایی:',
        'id': ':pria_berjalan_kaki_warna_kulit_sedang:',
        'zh': u':男行人_中等肤色:'
    },
    u'\U0001F6B6\U0001F3FD\U0000200D\U00002642': { # 🚶🏽‍♂
        'en' : ':man_walking_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgänger_mittlere_hautfarbe:',
        'es': ':hombre_caminando_tono_de_piel_medio:',
        'fr': u':homme_qui_marche_peau_légèrement_mate:',
        'ja': u':歩く男_中間の肌色:',
        'ko': u':걷는_남자_갈색_피부:',
        'pt': ':homem_andando_pele_morena:',
        'it': ':uomo_che_cammina_carnagione_olivastra:',
        'fa': u':مرد_پیاده_روی_می_کند_پوست_طلایی:',
        'id': ':pria_berjalan_kaki_warna_kulit_sedang:',
        'zh': u':男行人_中等肤色:'
    },
    u'\U0001F473\U0000200D\U00002642\U0000FE0F': { # 👳‍♂️
        'en' : ':man_wearing_turban:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':man_with_turban:'],
        'de': ':mann_mit_turban:',
        'es': ':hombre_con_turbante:',
        'fr': ':homme_en_turban:',
        'ja': u':ターバンの男性:',
        'ko': u':터번을_쓰고_있는_남자:',
        'pt': ':homem_com_turbante:',
        'it': ':uomo_con_turbante:',
        'fa': u':مرد_با_دستار:',
        'id': ':pria_mengenakan_serban:',
        'zh': u':戴头巾的男人:'
    },
    u'\U0001F473\U0000200D\U00002642': { # 👳‍♂
        'en' : ':man_wearing_turban:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':man_with_turban:'],
        'de': ':mann_mit_turban:',
        'es': ':hombre_con_turbante:',
        'fr': ':homme_en_turban:',
        'ja': u':ターバンの男性:',
        'ko': u':터번을_쓰고_있는_남자:',
        'pt': ':homem_com_turbante:',
        'it': ':uomo_con_turbante:',
        'fa': u':مرد_با_دستار:',
        'id': ':pria_mengenakan_serban:',
        'zh': u':戴头巾的男人:'
    },
    u'\U0001F473\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 👳🏿‍♂️
        'en' : ':man_wearing_turban_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_dunkle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_oscuro:',
        'fr': u':homme_en_turban_peau_foncée:',
        'ja': u':ターバンの男性_濃い肌色:',
        'ko': u':터번을_쓰고_있는_남자_검은색_피부:',
        'pt': ':homem_com_turbante_pele_escura:',
        'it': ':uomo_con_turbante_carnagione_scura:',
        'fa': u':مرد_با_دستار_پوست_آبنوسی:',
        'id': ':pria_mengenakan_serban_warna_kulit_gelap:',
        'zh': u':戴头巾的男人_较深肤色:'
    },
    u'\U0001F473\U0001F3FF\U0000200D\U00002642': { # 👳🏿‍♂
        'en' : ':man_wearing_turban_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_dunkle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_oscuro:',
        'fr': u':homme_en_turban_peau_foncée:',
        'ja': u':ターバンの男性_濃い肌色:',
        'ko': u':터번을_쓰고_있는_남자_검은색_피부:',
        'pt': ':homem_com_turbante_pele_escura:',
        'it': ':uomo_con_turbante_carnagione_scura:',
        'fa': u':مرد_با_دستار_پوست_آبنوسی:',
        'id': ':pria_mengenakan_serban_warna_kulit_gelap:',
        'zh': u':戴头巾的男人_较深肤色:'
    },
    u'\U0001F473\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 👳🏻‍♂️
        'en' : ':man_wearing_turban_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_helle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_claro:',
        'fr': ':homme_en_turban_peau_claire:',
        'ja': u':ターバンの男性_薄い肌色:',
        'ko': u':터번을_쓰고_있는_남자_하얀_피부:',
        'pt': ':homem_com_turbante_pele_clara:',
        'it': ':uomo_con_turbante_carnagione_chiara:',
        'fa': u':مرد_با_دستار_پوست_سفید:',
        'id': ':pria_mengenakan_serban_warna_kulit_cerah:',
        'zh': u':戴头巾的男人_较浅肤色:'
    },
    u'\U0001F473\U0001F3FB\U0000200D\U00002642': { # 👳🏻‍♂
        'en' : ':man_wearing_turban_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_helle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_claro:',
        'fr': ':homme_en_turban_peau_claire:',
        'ja': u':ターバンの男性_薄い肌色:',
        'ko': u':터번을_쓰고_있는_남자_하얀_피부:',
        'pt': ':homem_com_turbante_pele_clara:',
        'it': ':uomo_con_turbante_carnagione_chiara:',
        'fa': u':مرد_با_دستار_پوست_سفید:',
        'id': ':pria_mengenakan_serban_warna_kulit_cerah:',
        'zh': u':戴头巾的男人_较浅肤色:'
    },
    u'\U0001F473\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 👳🏾‍♂️
        'en' : ':man_wearing_turban_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_oscuro_medio:',
        'fr': ':homme_en_turban_peau_mate:',
        'ja': u':ターバンの男性_やや濃い肌色:',
        'ko': u':터번을_쓰고_있는_남자_진한_갈색_피부:',
        'pt': ':homem_com_turbante_pele_morena_escura:',
        'it': ':uomo_con_turbante_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_دستار_پوست_گندمی:',
        'id': ':pria_mengenakan_serban_warna_kulit_gelap-sedang:',
        'zh': u':戴头巾的男人_中等深肤色:'
    },
    u'\U0001F473\U0001F3FE\U0000200D\U00002642': { # 👳🏾‍♂
        'en' : ':man_wearing_turban_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_oscuro_medio:',
        'fr': ':homme_en_turban_peau_mate:',
        'ja': u':ターバンの男性_やや濃い肌色:',
        'ko': u':터번을_쓰고_있는_남자_진한_갈색_피부:',
        'pt': ':homem_com_turbante_pele_morena_escura:',
        'it': ':uomo_con_turbante_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_دستار_پوست_گندمی:',
        'id': ':pria_mengenakan_serban_warna_kulit_gelap-sedang:',
        'zh': u':戴头巾的男人_中等深肤色:'
    },
    u'\U0001F473\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 👳🏼‍♂️
        'en' : ':man_wearing_turban_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_mittelhelle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_claro_medio:',
        'fr': ':homme_en_turban_peau_moyennement_claire:',
        'ja': u':ターバンの男性_やや薄い肌色:',
        'ko': u':터번을_쓰고_있는_남자_연한_갈색_피부:',
        'pt': ':homem_com_turbante_pele_morena_clara:',
        'it': ':uomo_con_turbante_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_دستار_پوست_روشن:',
        'id': ':pria_mengenakan_serban_warna_kulit_cerah-sedang:',
        'zh': u':戴头巾的男人_中等浅肤色:'
    },
    u'\U0001F473\U0001F3FC\U0000200D\U00002642': { # 👳🏼‍♂
        'en' : ':man_wearing_turban_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_mittelhelle_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_claro_medio:',
        'fr': ':homme_en_turban_peau_moyennement_claire:',
        'ja': u':ターバンの男性_やや薄い肌色:',
        'ko': u':터번을_쓰고_있는_남자_연한_갈색_피부:',
        'pt': ':homem_com_turbante_pele_morena_clara:',
        'it': ':uomo_con_turbante_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_دستار_پوست_روشن:',
        'id': ':pria_mengenakan_serban_warna_kulit_cerah-sedang:',
        'zh': u':戴头巾的男人_中等浅肤色:'
    },
    u'\U0001F473\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 👳🏽‍♂️
        'en' : ':man_wearing_turban_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_mittlere_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_medio:',
        'fr': u':homme_en_turban_peau_légèrement_mate:',
        'ja': u':ターバンの男性_中間の肌色:',
        'ko': u':터번을_쓰고_있는_남자_갈색_피부:',
        'pt': ':homem_com_turbante_pele_morena:',
        'it': ':uomo_con_turbante_carnagione_olivastra:',
        'fa': u':مرد_با_دستار_پوست_طلایی:',
        'id': ':pria_mengenakan_serban_warna_kulit_sedang:',
        'zh': u':戴头巾的男人_中等肤色:'
    },
    u'\U0001F473\U0001F3FD\U0000200D\U00002642': { # 👳🏽‍♂
        'en' : ':man_wearing_turban_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mann_mit_turban_mittlere_hautfarbe:',
        'es': ':hombre_con_turbante_tono_de_piel_medio:',
        'fr': u':homme_en_turban_peau_légèrement_mate:',
        'ja': u':ターバンの男性_中間の肌色:',
        'ko': u':터번을_쓰고_있는_남자_갈색_피부:',
        'pt': ':homem_com_turbante_pele_morena:',
        'it': ':uomo_con_turbante_carnagione_olivastra:',
        'fa': u':مرد_با_دستار_پوست_طلایی:',
        'id': ':pria_mengenakan_serban_warna_kulit_sedang:',
        'zh': u':戴头巾的男人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F9B3': { # 👨‍🦳
        'en' : ':man_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':white_haired_man:'],
        'de': u':mann_weißes_haar:',
        'es': ':hombre_pelo_blanco:',
        'fr': ':homme_cheveux_blancs:',
        'ja': u':男性_白髪:',
        'ko': u':남자_백발:',
        'pt': ':homem_cabelo_branco:',
        'it': ':uomo_capelli_bianchi:',
        'fa': u':مرد_موسفید:',
        'id': ':pria_rambut_putih:',
        'zh': u':男人_白发:'
    },
    u'\U0001F470\U0000200D\U00002642\U0000FE0F': { # 👰‍♂️
        'en' : ':man_with_veil:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier:',
        'es': ':hombre_con_velo:',
        'fr': ':homme_avec_voile:',
        'ja': u':ベールの男性:',
        'ko': u':면사포를_쓴_남자:',
        'pt': u':noivo_com_véu:',
        'it': ':sposo_con_velo:',
        'fa': u':مرد_با_تور_عروس:',
        'id': ':pria_berpenutup_kepala:',
        'zh': u':戴头纱的男人:'
    },
    u'\U0001F470\U0000200D\U00002642': { # 👰‍♂
        'en' : ':man_with_veil:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier:',
        'es': ':hombre_con_velo:',
        'fr': ':homme_avec_voile:',
        'ja': u':ベールの男性:',
        'ko': u':면사포를_쓴_남자:',
        'pt': u':noivo_com_véu:',
        'it': ':sposo_con_velo:',
        'fa': u':مرد_با_تور_عروس:',
        'id': ':pria_berpenutup_kepala:',
        'zh': u':戴头纱的男人:'
    },
    u'\U0001F470\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 👰🏿‍♂️
        'en' : ':man_with_veil_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_dunkle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_oscuro:',
        'fr': u':homme_avec_voile_peau_foncée:',
        'ja': u':ベールの男性_濃い肌色:',
        'ko': u':면사포를_쓴_남자_검은색_피부:',
        'pt': u':noivo_com_véu_pele_escura:',
        'it': ':sposo_con_velo_carnagione_scura:',
        'fa': u':مرد_با_تور_عروس_پوست_آبنوسی:',
        'id': ':pria_berpenutup_kepala_warna_kulit_gelap:',
        'zh': u':戴头纱的男人_较深肤色:'
    },
    u'\U0001F470\U0001F3FF\U0000200D\U00002642': { # 👰🏿‍♂
        'en' : ':man_with_veil_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_dunkle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_oscuro:',
        'fr': u':homme_avec_voile_peau_foncée:',
        'ja': u':ベールの男性_濃い肌色:',
        'ko': u':면사포를_쓴_남자_검은색_피부:',
        'pt': u':noivo_com_véu_pele_escura:',
        'it': ':sposo_con_velo_carnagione_scura:',
        'fa': u':مرد_با_تور_عروس_پوست_آبنوسی:',
        'id': ':pria_berpenutup_kepala_warna_kulit_gelap:',
        'zh': u':戴头纱的男人_较深肤色:'
    },
    u'\U0001F470\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 👰🏻‍♂️
        'en' : ':man_with_veil_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_helle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_claro:',
        'fr': ':homme_avec_voile_peau_claire:',
        'ja': u':ベールの男性_薄い肌色:',
        'ko': u':면사포를_쓴_남자_하얀_피부:',
        'pt': u':noivo_com_véu_pele_clara:',
        'it': ':sposo_con_velo_carnagione_chiara:',
        'fa': u':مرد_با_تور_عروس_پوست_سفید:',
        'id': ':pria_berpenutup_kepala_warna_kulit_cerah:',
        'zh': u':戴头纱的男人_较浅肤色:'
    },
    u'\U0001F470\U0001F3FB\U0000200D\U00002642': { # 👰🏻‍♂
        'en' : ':man_with_veil_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_helle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_claro:',
        'fr': ':homme_avec_voile_peau_claire:',
        'ja': u':ベールの男性_薄い肌色:',
        'ko': u':면사포를_쓴_남자_하얀_피부:',
        'pt': u':noivo_com_véu_pele_clara:',
        'it': ':sposo_con_velo_carnagione_chiara:',
        'fa': u':مرد_با_تور_عروس_پوست_سفید:',
        'id': ':pria_berpenutup_kepala_warna_kulit_cerah:',
        'zh': u':戴头纱的男人_较浅肤色:'
    },
    u'\U0001F470\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 👰🏾‍♂️
        'en' : ':man_with_veil_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_voile_peau_mate:',
        'ja': u':ベールの男性_やや濃い肌色:',
        'ko': u':면사포를_쓴_남자_진한_갈색_피부:',
        'pt': u':noivo_com_véu_pele_morena_escura:',
        'it': ':sposo_con_velo_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_تور_عروس_پوست_گندمی:',
        'id': ':pria_berpenutup_kepala_warna_kulit_gelap-sedang:',
        'zh': u':戴头纱的男人_中等深肤色:'
    },
    u'\U0001F470\U0001F3FE\U0000200D\U00002642': { # 👰🏾‍♂
        'en' : ':man_with_veil_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_voile_peau_mate:',
        'ja': u':ベールの男性_やや濃い肌色:',
        'ko': u':면사포를_쓴_남자_진한_갈색_피부:',
        'pt': u':noivo_com_véu_pele_morena_escura:',
        'it': ':sposo_con_velo_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_تور_عروس_پوست_گندمی:',
        'id': ':pria_berpenutup_kepala_warna_kulit_gelap-sedang:',
        'zh': u':戴头纱的男人_中等深肤色:'
    },
    u'\U0001F470\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 👰🏼‍♂️
        'en' : ':man_with_veil_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_mittelhelle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_voile_peau_moyennement_claire:',
        'ja': u':ベールの男性_やや薄い肌色:',
        'ko': u':면사포를_쓴_남자_연한_갈색_피부:',
        'pt': u':noivo_com_véu_pele_morena_clara:',
        'it': ':sposo_con_velo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_تور_عروس_پوست_روشن:',
        'id': ':pria_berpenutup_kepala_warna_kulit_cerah-sedang:',
        'zh': u':戴头纱的男人_中等浅肤色:'
    },
    u'\U0001F470\U0001F3FC\U0000200D\U00002642': { # 👰🏼‍♂
        'en' : ':man_with_veil_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_mittelhelle_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_voile_peau_moyennement_claire:',
        'ja': u':ベールの男性_やや薄い肌色:',
        'ko': u':면사포를_쓴_남자_연한_갈색_피부:',
        'pt': u':noivo_com_véu_pele_morena_clara:',
        'it': ':sposo_con_velo_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_تور_عروس_پوست_روشن:',
        'id': ':pria_berpenutup_kepala_warna_kulit_cerah-sedang:',
        'zh': u':戴头纱的男人_中等浅肤色:'
    },
    u'\U0001F470\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 👰🏽‍♂️
        'en' : ':man_with_veil_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_mittlere_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_medio:',
        'fr': u':homme_avec_voile_peau_légèrement_mate:',
        'ja': u':ベールの男性_中間の肌色:',
        'ko': u':면사포를_쓴_남자_갈색_피부:',
        'pt': u':noivo_com_véu_pele_morena:',
        'it': ':sposo_con_velo_carnagione_olivastra:',
        'fa': u':مرد_با_تور_عروس_پوست_طلایی:',
        'id': ':pria_berpenutup_kepala_warna_kulit_sedang:',
        'zh': u':戴头纱的男人_中等肤色:'
    },
    u'\U0001F470\U0001F3FD\U0000200D\U00002642': { # 👰🏽‍♂
        'en' : ':man_with_veil_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':mann_mit_schleier_mittlere_hautfarbe:',
        'es': ':hombre_con_velo_tono_de_piel_medio:',
        'fr': u':homme_avec_voile_peau_légèrement_mate:',
        'ja': u':ベールの男性_中間の肌色:',
        'ko': u':면사포를_쓴_남자_갈색_피부:',
        'pt': u':noivo_com_véu_pele_morena:',
        'it': ':sposo_con_velo_carnagione_olivastra:',
        'fa': u':مرد_با_تور_عروس_پوست_طلایی:',
        'id': ':pria_berpenutup_kepala_warna_kulit_sedang:',
        'zh': u':戴头纱的男人_中等肤色:'
    },
    u'\U0001F468\U0000200D\U0001F9AF': { # 👨‍🦯
        'en' : ':man_with_white_cane:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':man_with_probing_cane:'],
        'de': ':mann_mit_langstock:',
        'es': u':hombre_con_bastón:',
        'fr': ':homme_avec_canne_blanche:',
        'ja': u':杖をついた男性:',
        'ko': u':지팡이를_든_남자:',
        'pt': ':homem_com_bengala_para_cego:',
        'it': ':uomo_con_bastone_bianco_di_orientamento:',
        'fa': u':مرد_با_عصای_سفید:',
        'id': ':pria_dengan_tongkat:',
        'zh': u':拄盲杖的男人:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F9AF': { # 👨🏿‍🦯
        'en' : ':man_with_white_cane_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_mit_gehstock_dunkle_hautfarbe:',
        'es': u':hombre_con_bastón_tono_de_piel_oscuro:',
        'fr': u':homme_avec_canne_blanche_peau_foncée:',
        'ja': u':杖をついた男性_濃い肌色:',
        'ko': u':지팡이를_든_남자_검은색_피부:',
        'pt': ':homem_com_bengala_para_cego_pele_escura:',
        'it': ':uomo_con_bastone_bianco_di_orientamento_carnagione_scura:',
        'fa': u':مرد_با_عصای_سفید_پوست_آبنوسی:',
        'id': ':pria_dengan_tongkat_warna_kulit_gelap:',
        'zh': u':拄盲杖的男人_较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F9AF': { # 👨🏻‍🦯
        'en' : ':man_with_white_cane_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_mit_gehstock_helle_hautfarbe:',
        'es': u':hombre_con_bastón_tono_de_piel_claro:',
        'fr': ':homme_avec_canne_blanche_peau_claire:',
        'ja': u':杖をついた男性_薄い肌色:',
        'ko': u':지팡이를_든_남자_하얀_피부:',
        'pt': ':homem_com_bengala_para_cego_pele_clara:',
        'it': ':uomo_con_bastone_bianco_di_orientamento_carnagione_chiara:',
        'fa': u':مرد_با_عصای_سفید_پوست_سفید:',
        'id': ':pria_dengan_tongkat_warna_kulit_cerah:',
        'zh': u':拄盲杖的男人_较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F9AF': { # 👨🏾‍🦯
        'en' : ':man_with_white_cane_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_mit_gehstock_mitteldunkle_hautfarbe:',
        'es': u':hombre_con_bastón_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_canne_blanche_peau_mate:',
        'ja': u':杖をついた男性_やや濃い肌色:',
        'ko': u':지팡이를_든_남자_진한_갈색_피부:',
        'pt': ':homem_com_bengala_para_cego_pele_morena_escura:',
        'it': ':uomo_con_bastone_bianco_di_orientamento_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_عصای_سفید_پوست_گندمی:',
        'id': ':pria_dengan_tongkat_warna_kulit_gelap-sedang:',
        'zh': u':拄盲杖的男人_中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F9AF': { # 👨🏼‍🦯
        'en' : ':man_with_white_cane_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_mit_gehstock_mittelhelle_hautfarbe:',
        'es': u':hombre_con_bastón_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_canne_blanche_peau_moyennement_claire:',
        'ja': u':杖をついた男性_やや薄い肌色:',
        'ko': u':지팡이를_든_남자_연한_갈색_피부:',
        'pt': ':homem_com_bengala_para_cego_pele_morena_clara:',
        'it': ':uomo_con_bastone_bianco_di_orientamento_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_عصای_سفید_پوست_روشن:',
        'id': ':pria_dengan_tongkat_warna_kulit_cerah-sedang:',
        'zh': u':拄盲杖的男人_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F9AF': { # 👨🏽‍🦯
        'en' : ':man_with_white_cane_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mann_mit_gehstock_mittlere_hautfarbe:',
        'es': u':hombre_con_bastón_tono_de_piel_medio:',
        'fr': u':homme_avec_canne_blanche_peau_légèrement_mate:',
        'ja': u':杖をついた男性_中間の肌色:',
        'ko': u':지팡이를_든_남자_갈색_피부:',
        'pt': ':homem_com_bengala_para_cego_pele_morena:',
        'it': ':uomo_con_bastone_bianco_di_orientamento_carnagione_olivastra:',
        'fa': u':مرد_با_عصای_سفید_پوست_طلایی:',
        'id': ':pria_dengan_tongkat_warna_kulit_sedang:',
        'zh': u':拄盲杖的男人_中等肤色:'
    },
    u'\U0001F9DF\U0000200D\U00002642\U0000FE0F': { # 🧟‍♂️
        'en' : ':man_zombie:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':zombie_man:'],
        'de': u':männlicher_zombie:',
        'es': ':zombi_hombre:',
        'fr': ':zombie_homme:',
        'ja': u':男のゾンビ:',
        'ko': u':남자_좀비:',
        'pt': ':homem_zumbi:',
        'it': ':zombie_uomo:',
        'fa': u':مرده_متحرک_مرد:',
        'id': ':zombi_pria:',
        'zh': u':男僵尸:'
    },
    u'\U0001F9DF\U0000200D\U00002642': { # 🧟‍♂
        'en' : ':man_zombie:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':zombie_man:'],
        'de': u':männlicher_zombie:',
        'es': ':zombi_hombre:',
        'fr': ':zombie_homme:',
        'ja': u':男のゾンビ:',
        'ko': u':남자_좀비:',
        'pt': ':homem_zumbi:',
        'it': ':zombie_uomo:',
        'fa': u':مرده_متحرک_مرد:',
        'id': ':zombi_pria:',
        'zh': u':男僵尸:'
    },
    u'\U0001F96D': { # 🥭
        'en' : ':mango:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mango:',
        'es': ':mango:',
        'fr': ':mangue:',
        'ja': u':マンゴー:',
        'ko': u':망고:',
        'pt': ':manga:',
        'it': ':mango:',
        'fa': u':انبه:',
        'id': ':mangga:',
        'zh': u':芒果:'
    },
    u'\U0001F570\U0000FE0F': { # 🕰️
        'en' : ':mantelpiece_clock:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kaminuhr:',
        'es': ':reloj_de_sobremesa:',
        'fr': ':pendule:',
        'ja': u':置時計:',
        'ko': u':벽난로_선반_시계:',
        'pt': u':relógio_de_mesa:',
        'it': ':orologio_da_mensola:',
        'fa': u':ساعت_طاقچه_ای:',
        'id': ':jam_perapian:',
        'zh': u':座钟:'
    },
    u'\U0001F570': { # 🕰
        'en' : ':mantelpiece_clock:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kaminuhr:',
        'es': ':reloj_de_sobremesa:',
        'fr': ':pendule:',
        'ja': u':置時計:',
        'ko': u':벽난로_선반_시계:',
        'pt': u':relógio_de_mesa:',
        'it': ':orologio_da_mensola:',
        'fa': u':ساعت_طاقچه_ای:',
        'id': ':jam_perapian:',
        'zh': u':座钟:'
    },
    u'\U0001F9BD': { # 🦽
        'en' : ':manual_wheelchair:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':manueller_rollstuhl:',
        'es': ':silla_de_ruedas_manual:',
        'fr': ':fauteuil_roulant_manuel:',
        'ja': u':手動式車椅子:',
        'ko': u':수동_휠체어:',
        'pt': ':cadeira_de_rodas_manual:',
        'it': ':sedia_a_rotelle_manuale:',
        'fa': u':صندلی_چرخ_دار_دستی:',
        'id': ':kursi_roda_manual:',
        'zh': u':手动轮椅:'
    },
    u'\U0001F45E': { # 👞
        'en' : u':man’s_shoe:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mans_shoe:', ':shoe:'],
        'de': ':herrenschuh:',
        'es': ':zapato_de_hombre:',
        'fr': u':chaussure_d’homme:',
        'ja': u':紳士靴:',
        'ko': u':남성용_구두:',
        'pt': ':sapato_masculino:',
        'it': ':scarpa_da_uomo:',
        'fa': u':کفش_مردانه:',
        'id': ':sepatu_pria:',
        'zh': u':男鞋:'
    },
    u'\U0001F5FE': { # 🗾
        'en' : ':map_of_Japan:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':japan:'],
        'de': ':umriss_von_japan:',
        'es': u':mapa_de_japón:',
        'fr': ':carte_du_japon:',
        'ja': u':日本地図:',
        'ko': u':일본_지도:',
        'pt': u':mapa_do_japão:',
        'it': ':mappa_del_giappone:',
        'fa': u':نقشهٔ_ژاپن:',
        'id': ':peta_jepang:',
        'zh': u':日本地图:'
    },
    u'\U0001F341': { # 🍁
        'en' : ':maple_leaf:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':ahornblatt:',
        'es': ':hoja_de_arce:',
        'fr': u':feuille_d’érable:',
        'ja': u':かえで:',
        'ko': u':단풍잎:',
        'pt': ':folha_de_bordo:',
        'it': u':foglia_d’acero:',
        'fa': u':برگ_افرا:',
        'id': ':daun_maple:',
        'zh': u':枫叶:'
    },
    u'\U0001FA87': { # 🪇
        'en' : ':maracas:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':maracas:',
        'es': ':maracas:',
        'fr': ':maracas:',
        'ja': u':マラカス:',
        'ko': u':마라카스:',
        'pt': u':maracás:',
        'it': ':maracas:',
        'fa': u':ساز_جغجغه_ای:',
        'id': ':marakas:',
        'zh': u':沙球:'
    },
    u'\U0001F94B': { # 🥋
        'en' : ':martial_arts_uniform:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':kampfsportanzug:',
        'es': ':uniforme_de_artes_marciales:',
        'fr': u':tenue_d’arts_martiaux:',
        'ja': u':武道:',
        'ko': u':도복:',
        'pt': ':quimono_de_artes_marciais:',
        'it': ':kimono_per_arti_marziali:',
        'fa': u':لباس_هنرهای_رزمی:',
        'id': ':seragam_beladiri:',
        'zh': u':练武服:'
    },
    u'\U0001F9C9': { # 🧉
        'en' : ':mate:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':mate-tee:',
        'es': ':mate:',
        'fr': u':maté:',
        'ja': u':マテ茶:',
        'ko': u':마테차:',
        'pt': ':mate:',
        'it': ':mate:',
        'fa': u':ماته:',
        'id': ':teh_mate:',
        'zh': u':马黛茶:'
    },
    u'\U0001F356': { # 🍖
        'en' : ':meat_on_bone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':fleischhachse:',
        'es': ':carne_con_hueso:',
        'fr': ':viande_sur_un_os:',
        'ja': u':骨付き肉:',
        'ko': u':고기:',
        'pt': ':carne:',
        'it': ':carne:',
        'fa': u':گوشت_با_استخوان:',
        'id': ':daging_pada_tulang:',
        'zh': u':排骨:'
    },
    u'\U0001F9D1\U0000200D\U0001F527': { # 🧑‍🔧
        'en' : ':mechanic:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':mechaniker(in):',
        'es': u':profesional_de_la_mecánica:',
        'fr': u':mécanicien_(tous_genres):',
        'ja': u':整備士:',
        'ko': u':정비공:',
        'pt': u':mecânico_trabalhando:',
        'it': ':meccanico:',
        'fa': u':مکانیک:',
        'id': ':mekanik:',
        'zh': u':技工:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F527': { # 🧑🏿‍🔧
        'en' : ':mechanic_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':mechaniker(in)_dunkle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_tono_de_piel_oscuro:',
        'fr': u':mécanicien_(tous_genres)_peau_foncée:',
        'ja': u':整備士_濃い肌色:',
        'ko': u':정비공_검은색_피부:',
        'pt': u':mecânico_trabalhando_pele_escura:',
        'it': ':meccanico_carnagione_scura:',
        'fa': u':مکانیک_پوست_آبنوسی:',
        'id': ':mekanik_warna_kulit_gelap:',
        'zh': u':技工_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F527': { # 🧑🏻‍🔧
        'en' : ':mechanic_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':mechaniker(in)_helle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_tono_de_piel_claro:',
        'fr': u':mécanicien_(tous_genres)_peau_claire:',
        'ja': u':整備士_薄い肌色:',
        'ko': u':정비공_하얀_피부:',
        'pt': u':mecânico_trabalhando_pele_clara:',
        'it': ':meccanico_carnagione_chiara:',
        'fa': u':مکانیک_پوست_سفید:',
        'id': ':mekanik_warna_kulit_cerah:',
        'zh': u':技工_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F527': { # 🧑🏾‍🔧
        'en' : ':mechanic_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':mechaniker(in)_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_tono_de_piel_oscuro_medio:',
        'fr': u':mécanicien_(tous_genres)_peau_mate:',
        'ja': u':整備士_やや濃い肌色:',
        'ko': u':정비공_진한_갈색_피부:',
        'pt': u':mecânico_trabalhando_pele_morena_escura:',
        'it': ':meccanico_carnagione_abbastanza_scura:',
        'fa': u':مکانیک_پوست_گندمی:',
        'id': ':mekanik_warna_kulit_gelap-sedang:',
        'zh': u':技工_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F527': { # 🧑🏼‍🔧
        'en' : ':mechanic_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':mechaniker(in)_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_tono_de_piel_claro_medio:',
        'fr': u':mécanicien_(tous_genres)_peau_moyennement_claire:',
        'ja': u':整備士_やや薄い肌色:',
        'ko': u':정비공_연한_갈색_피부:',
        'pt': u':mecânico_trabalhando_pele_morena_clara:',
        'it': ':meccanico_carnagione_abbastanza_chiara:',
        'fa': u':مکانیک_پوست_روشن:',
        'id': ':mekanik_warna_kulit_cerah-sedang:',
        'zh': u':技工_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F527': { # 🧑🏽‍🔧
        'en' : ':mechanic_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':mechaniker(in)_mittlere_hautfarbe:',
        'es': u':profesional_de_la_mecánica_tono_de_piel_medio:',
        'fr': u':mécanicien_(tous_genres)_peau_légèrement_mate:',
        'ja': u':整備士_中間の肌色:',
        'ko': u':정비공_갈색_피부:',
        'pt': u':mecânico_trabalhando_pele_morena:',
        'it': ':meccanico_carnagione_olivastra:',
        'fa': u':مکانیک_پوست_طلایی:',
        'id': ':mekanik_warna_kulit_sedang:',
        'zh': u':技工_中等肤色:'
    },
    u'\U0001F9BE': { # 🦾
        'en' : ':mechanical_arm:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':armprothese:',
        'es': u':brazo_mecánico:',
        'fr': u':bras_mécanique:',
        'ja': u':義手:',
        'ko': u':기계_팔:',
        'pt': u':braço_mecânico:',
        'it': ':protesi_robotica_per_il_braccio:',
        'fa': u':بازوی_مکانیکی:',
        'id': ':lengan_robot:',
        'zh': u':机械手臂:'
    },
    u'\U0001F9BF': { # 🦿
        'en' : ':mechanical_leg:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':beinprothese:',
        'es': u':pierna_mecánica:',
        'fr': u':jambe_mécanique:',
        'ja': u':義足:',
        'ko': u':인공_다리:',
        'pt': u':perna_mecânica:',
        'it': ':protesi_robotica_per_la_gamba:',
        'fa': u':پای_مکانیکی:',
        'id': ':tungkai_robot:',
        'zh': u':机械腿:'
    },
    u'\U00002695\U0000FE0F': { # ⚕️
        'en' : ':medical_symbol:',
        'status' : fully_qualified,
        'E' : 4,
        'variant': True,
        'de': u':äskulapstab:',
        'es': u':símbolo_de_medicina:',
        'fr': u':caducée:',
        'ja': u':医療のシンボル:',
        'ko': u':의학_기호:',
        'pt': u':símbolo_da_medicina:',
        'it': ':simbolo_della_medicina:',
        'fa': u':نماد_پزشکی:',
        'id': ':simbol_kedokteran:',
        'zh': u':医疗标志:'
    },
    u'\U00002695': { # ⚕
        'en' : ':medical_symbol:',
        'status' : unqualified,
        'E' : 4,
        'variant': True,
        'de': u':äskulapstab:',
        'es': u':símbolo_de_medicina:',
        'fr': u':caducée:',
        'ja': u':医療のシンボル:',
        'ko': u':의학_기호:',
        'pt': u':símbolo_da_medicina:',
        'it': ':simbolo_della_medicina:',
        'fa': u':نماد_پزشکی:',
        'id': ':simbol_kedokteran:',
        'zh': u':医疗标志:'
    },
    u'\U0001F3FE': { # 🏾
        'en' : ':medium-dark_skin_tone:',
        'status' : component,
        'E' : 1,
        'alias' : [':emoji_modifier_fitzpatrick_type__5:'],
        'de': ':mitteldunkle_hautfarbe:',
        'es': ':tono_de_piel_oscuro_medio:',
        'fr': ':peau_mate:',
        'ja': u':やや濃い肌色:',
        'ko': u':진한_갈색_피부:',
        'pt': ':pele_morena_escura:',
        'it': ':carnagione_abbastanza_scura:',
        'fa': u':پوست_گندمی:',
        'id': ':warna_kulit_gelap-sedang:',
        'zh': u':中等深肤色:'
    },
    u'\U0001F3FC': { # 🏼
        'en' : ':medium-light_skin_tone:',
        'status' : component,
        'E' : 1,
        'alias' : [':emoji_modifier_fitzpatrick_type__3:'],
        'de': ':mittelhelle_hautfarbe:',
        'es': ':tono_de_piel_claro_medio:',
        'fr': ':peau_moyennement_claire:',
        'ja': u':やや薄い肌色:',
        'ko': u':연한_갈색_피부:',
        'pt': ':pele_morena_clara:',
        'it': ':carnagione_abbastanza_chiara:',
        'fa': u':پوست_روشن:',
        'id': ':warna_kulit_cerah-sedang:',
        'zh': u':中等浅肤色:'
    },
    u'\U0001F3FD': { # 🏽
        'en' : ':medium_skin_tone:',
        'status' : component,
        'E' : 1,
        'alias' : [':emoji_modifier_fitzpatrick_type__4:'],
        'de': ':mittlere_hautfarbe:',
        'es': ':tono_de_piel_medio:',
        'fr': u':peau_légèrement_mate:',
        'ja': u':中間の肌色:',
        'ko': u':갈색_피부:',
        'pt': ':pele_morena:',
        'it': ':carnagione_olivastra:',
        'fa': u':پوست_طلایی:',
        'id': ':warna_kulit_sedang:',
        'zh': u':中等肤色:'
    },
    u'\U0001F4E3': { # 📣
        'en' : ':megaphone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mega:'],
        'de': ':megafon:',
        'es': u':megáfono:',
        'fr': ':porte-voix:',
        'ja': u':メガホン:',
        'ko': u':메가폰:',
        'pt': ':megafone:',
        'it': ':megafono:',
        'fa': u':بلندگوی_دستی:',
        'id': ':megafon:',
        'zh': u':扩音器:'
    },
    u'\U0001F348': { # 🍈
        'en' : ':melon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':honigmelone:',
        'es': u':melón:',
        'fr': ':melon:',
        'ja': u':メロン:',
        'ko': u':멜론:',
        'pt': u':melão:',
        'it': ':melone:',
        'fa': u':طالبی:',
        'id': ':melon:',
        'zh': u':甜瓜:'
    },
    u'\U0001FAE0': { # 🫠
        'en' : ':melting_face:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':schmelzendes_gesicht:',
        'es': u':cara_derritiéndose:',
        'fr': ':visage_qui_fond:',
        'ja': u':溶けている顔:',
        'ko': u':녹아_내리는_얼굴:',
        'pt': ':rosto_derretendo:',
        'it': ':faccina_che_si_scioglie:',
        'fa': u':چهره_درحال_ذوب_شدن:',
        'id': ':wajah_meleleh:',
        'zh': u':融化:'
    },
    u'\U0001F4DD': { # 📝
        'en' : ':memo:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pencil:'],
        'de': ':papier_und_bleistift:',
        'es': ':cuaderno_de_notas:',
        'fr': u':mémo:',
        'ja': u':鉛筆とメモ:',
        'ko': u':메모:',
        'pt': ':memorando:',
        'it': ':memo:',
        'fa': u':یادداشت:',
        'id': ':memo:',
        'zh': u':备忘录:'
    },
    u'\U0001F46C': { # 👬
        'en' : ':men_holding_hands:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':two_men_holding_hands:'],
        'de': u':händchen_haltende_männer:',
        'es': ':hombres_de_la_mano:',
        'fr': ':deux_hommes_se_tenant_la_main:',
        'ja': u':手をつなぐ男性:',
        'ko': u':손을_잡고_있는_두_명의_남자:',
        'pt': u':dois_homens_de_mãos_dadas:',
        'it': ':due_uomini_che_si_tengono_per_mano:',
        'fa': u':دو_مرد_دست_در_دست:',
        'id': ':dua_pria_bergandengan:',
        'zh': u':手拉手的两个男人:'
    },
    u'\U0001F46C\U0001F3FF': { # 👬🏿
        'en' : ':men_holding_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_dunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_foncée:',
        'ja': u':手をつなぐ男性_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_검은색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_آبنوسی:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap:',
        'zh': u':手拉手的两个男人_较深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👨🏿‍🤝‍👨🏻
        'en' : ':men_holding_hands_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_dunkle_hautfarbe,_helle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_foncée_et_peau_claire:',
        'ja': u':手をつなぐ男性_濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_검은색_피부_하얀_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_escura_e_pele_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_scura_e_carnagione_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_آبنوسی_پوست_سفید:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':手拉手的两个男人_较深肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👨🏿‍🤝‍👨🏾
        'en' : ':men_holding_hands_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_dunkle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_oscuro_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_foncée_et_peau_mate:',
        'ja': u':手をつなぐ男性_濃い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_검은색_피부_진한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_escura_e_pele_morena_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_آبنوسی_پوست_گندمی:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个男人_较深肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👨🏿‍🤝‍👨🏼
        'en' : ':men_holding_hands_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_dunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男性_濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_검은색_피부_연한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_escura_e_pele_morena_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_آبنوسی_پوست_روشن:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个男人_较深肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👨🏿‍🤝‍👨🏽
        'en' : ':men_holding_hands_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_dunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男性_濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_검은색_피부_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_escura_e_pele_morena:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':دو_مرد_دست_در_دست_پوست_آبنوسی_پوست_طلایی:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':手拉手的两个男人_较深肤色中等肤色:'
    },
    u'\U0001F46C\U0001F3FB': { # 👬🏻
        'en' : ':men_holding_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_helle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_claire:',
        'ja': u':手をつなぐ男性_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_하얀_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_سفید:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah:',
        'zh': u':手拉手的两个男人_较浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👨🏻‍🤝‍👨🏿
        'en' : ':men_holding_hands_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_helle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_claire_et_peau_foncée:',
        'ja': u':手をつなぐ男性_薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_하얀_피부_검은색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_clara_e_pele_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_سفید_پوست_آبنوسی:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':手拉手的两个男人_较浅肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👨🏻‍🤝‍👨🏾
        'en' : ':men_holding_hands_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_helle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro_medio:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_claire_et_peau_mate:',
        'ja': u':手をつなぐ男性_薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_하얀_피부_진한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_clara_e_pele_morena_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_سفید_پوست_گندمی:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个男人_较浅肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👨🏻‍🤝‍👨🏼
        'en' : ':men_holding_hands_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_helle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_claro_medio:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_claire_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男性_薄い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_하얀_피부_연한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_clara_e_pele_morena_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_سفید_پوست_روشن:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个男人_较浅肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👨🏻‍🤝‍👨🏽
        'en' : ':men_holding_hands_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_helle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男性_薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_하얀_피부_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_clara_e_pele_morena:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':دو_مرد_دست_در_دست_پوست_سفید_پوست_طلایی:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':手拉手的两个男人_较浅肤色中等肤色:'
    },
    u'\U0001F46C\U0001F3FE': { # 👬🏾
        'en' : ':men_holding_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mitteldunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_medio:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_mate:',
        'ja': u':手をつなぐ男性_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_진한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_گندمی:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个男人_中等深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👨🏾‍🤝‍👨🏿
        'en' : ':men_holding_hands_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_mitteldunkle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_mate_et_peau_foncée:',
        'ja': u':手をつなぐ男性_やや濃い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_진한_갈색_피부_검은색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_escura_e_pele_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_گندمی_پوست_آبنوسی:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个男人_中等深肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👨🏾‍🤝‍👨🏻
        'en' : ':men_holding_hands_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mitteldunkle_hautfarbe,_helle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_mate_et_peau_claire:',
        'ja': u':手をつなぐ男性_やや濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_진한_갈색_피부_하얀_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_escura_e_pele_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_گندمی_پوست_سفید:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个男人_中等深肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👨🏾‍🤝‍👨🏼
        'en' : ':men_holding_hands_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mitteldunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro_medio:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男性_やや濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_진한_갈색_피부_연한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_escura_e_pele_morena_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_گندمی_پوست_روشن:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个男人_中等深肤色中等浅肤色:'
    },
    u'\U0001F468\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👨🏾‍🤝‍👨🏽
        'en' : ':men_holding_hands_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mitteldunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_mate_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男性_やや濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_진한_갈색_피부_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_escura_e_pele_morena:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':دو_مرد_دست_در_دست_پوست_گندمی_پوست_طلایی:',
        'id': ':dua_pria_bergandengan_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的两个男人_中等深肤色中等肤色:'
    },
    u'\U0001F46C\U0001F3FC': { # 👬🏼
        'en' : ':men_holding_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mittelhelle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_medio:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_moyennement_claire:',
        'ja': u':手をつなぐ男性_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_연한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_روشن:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个男人_中等浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👨🏼‍🤝‍👨🏿
        'en' : ':men_holding_hands_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_mittelhelle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':手をつなぐ男性_やや薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_연한_갈색_피부_검은색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_clara_e_pele_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_روشن_پوست_آبنوسی:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个男人_中等浅肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👨🏼‍🤝‍👨🏻
        'en' : ':men_holding_hands_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mittelhelle_hautfarbe,_helle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_claro:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_moyennement_claire_et_peau_claire:',
        'ja': u':手をつなぐ男性_やや薄い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_연한_갈색_피부_하얀_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_clara_e_pele_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_روشن_پوست_سفید:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个男人_中等浅肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👨🏼‍🤝‍👨🏾
        'en' : ':men_holding_hands_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_mittelhelle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro_medio:',
        'fr': ':deux_hommes_se_tenant_la_main_peau_moyennement_claire_et_peau_mate:',
        'ja': u':手をつなぐ男性_やや薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_연한_갈색_피부_진한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_clara_e_pele_morena_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_روشن_پوست_گندمی:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个男人_中等浅肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👨🏼‍🤝‍👨🏽
        'en' : ':men_holding_hands_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_mittelhelle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男性_やや薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_연한_갈색_피부_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_clara_e_pele_morena:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':دو_مرد_دست_در_دست_پوست_روشن_پوست_طلایی:',
        'id': ':dua_pria_bergandengan_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的两个男人_中等浅肤色中等肤色:'
    },
    u'\U0001F46C\U0001F3FD': { # 👬🏽
        'en' : ':men_holding_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mittlere_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_légèrement_mate:',
        'ja': u':手をつなぐ男性_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_olivastra:',
        'fa': u':دو_مرد_دست_در_دست_پوست_طلایی:',
        'id': ':dua_pria_bergandengan_warna_kulit_sedang:',
        'zh': u':手拉手的两个男人_中等肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👨🏽‍🤝‍👨🏿
        'en' : ':men_holding_hands_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_mittlere_hautfarbe,_dunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':手をつなぐ男性_中間の肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_갈색_피부_검은색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_e_pele_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_طلایی_پوست_آبنوسی:',
        'id': ':dua_pria_bergandengan_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个男人_中等肤色较深肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👨🏽‍🤝‍👨🏻
        'en' : ':men_holding_hands_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mittlere_hautfarbe,_helle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_claro:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_légèrement_mate_et_peau_claire:',
        'ja': u':手をつなぐ男性_中間の肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_갈색_피부_하얀_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_e_pele_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_طلایی_پوست_سفید:',
        'id': ':dua_pria_bergandengan_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个男人_中等肤色较浅肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👨🏽‍🤝‍👨🏾
        'en' : ':men_holding_hands_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_männer_mittlere_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_légèrement_mate_et_peau_mate:',
        'ja': u':手をつなぐ男性_中間の肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_갈색_피부_진한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_e_pele_morena_escura:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':دو_مرد_دست_در_دست_پوست_طلایی_پوست_گندمی:',
        'id': ':dua_pria_bergandengan_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个男人_中等肤色中等深肤色:'
    },
    u'\U0001F468\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👨🏽‍🤝‍👨🏼
        'en' : ':men_holding_hands_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_männer_mittlere_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':hombres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_claro_medio:',
        'fr': u':deux_hommes_se_tenant_la_main_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男性_中間の肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_남자_갈색_피부_연한_갈색_피부:',
        'pt': u':dois_homens_de_mãos_dadas_pele_morena_e_pele_morena_clara:',
        'it': ':due_uomini_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_مرد_دست_در_دست_پوست_طلایی_پوست_روشن:',
        'id': ':dua_pria_bergandengan_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个男人_中等肤色中等浅肤色:'
    },
    u'\U0001F46F\U0000200D\U00002642\U0000FE0F': { # 👯‍♂️
        'en' : ':men_with_bunny_ears:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':dancing_men:'],
        'de': u':männer_mit_hasenohren:',
        'es': ':hombres_con_orejas_de_conejo:',
        'fr': ':hommes_avec_des_oreilles_de_lapin:',
        'ja': u':バニーボーイ:',
        'ko': u':토끼_귀를_쓰고_춤추는_남자들:',
        'pt': ':homens_com_orelhas_de_coelho:',
        'it': ':uomini_con_orecchie_da_coniglio:',
        'fa': u':مردان_در_پارتی:',
        'id': ':pria_dengan_telinga_kelinci:',
        'zh': u':兔先生:'
    },
    u'\U0001F46F\U0000200D\U00002642': { # 👯‍♂
        'en' : ':men_with_bunny_ears:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':dancing_men:'],
        'de': u':männer_mit_hasenohren:',
        'es': ':hombres_con_orejas_de_conejo:',
        'fr': ':hommes_avec_des_oreilles_de_lapin:',
        'ja': u':バニーボーイ:',
        'ko': u':토끼_귀를_쓰고_춤추는_남자들:',
        'pt': ':homens_com_orelhas_de_coelho:',
        'it': ':uomini_con_orecchie_da_coniglio:',
        'fa': u':مردان_در_پارتی:',
        'id': ':pria_dengan_telinga_kelinci:',
        'zh': u':兔先生:'
    },
    u'\U0001F93C\U0000200D\U00002642\U0000FE0F': { # 🤼‍♂️
        'en' : ':men_wrestling:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':ringende_männer:',
        'es': ':hombres_luchando:',
        'fr': ':lutteurs:',
        'ja': u':レスリングする男:',
        'ko': u':레슬링하는_남자:',
        'pt': ':homens_lutando:',
        'it': ':lottatori:',
        'fa': u':کُشتی_گیر_مرد:',
        'id': ':pria_bergulat:',
        'zh': u':男生摔跤:'
    },
    u'\U0001F93C\U0000200D\U00002642': { # 🤼‍♂
        'en' : ':men_wrestling:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':ringende_männer:',
        'es': ':hombres_luchando:',
        'fr': ':lutteurs:',
        'ja': u':レスリングする男:',
        'ko': u':레슬링하는_남자:',
        'pt': ':homens_lutando:',
        'it': ':lottatori:',
        'fa': u':کُشتی_گیر_مرد:',
        'id': ':pria_bergulat:',
        'zh': u':男生摔跤:'
    },
    u'\U00002764\U0000FE0F\U0000200D\U0001FA79': { # ❤️‍🩹
        'en' : ':mending_heart:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':herz_mit_verband:',
        'es': u':corazón_curándose:',
        'fr': u':cœur_avec_bandages:',
        'ja': u':包帯を巻いたハート:',
        'ko': u':낫고_있는_하트:',
        'pt': u':coração_remendado:',
        'it': ':cuore_guarito:',
        'fa': u':قلب_التیام_یافته:',
        'id': ':mengobati_hati_terluka:',
        'zh': u':修复受伤的心灵:'
    },
    u'\U00002764\U0000200D\U0001FA79': { # ❤‍🩹
        'en' : ':mending_heart:',
        'status' : unqualified,
        'E' : 13.1,
        'de': ':herz_mit_verband:',
        'es': u':corazón_curándose:',
        'fr': u':cœur_avec_bandages:',
        'ja': u':包帯を巻いたハート:',
        'ko': u':낫고_있는_하트:',
        'pt': u':coração_remendado:',
        'it': ':cuore_guarito:',
        'fa': u':قلب_التیام_یافته:',
        'id': ':mengobati_hati_terluka:',
        'zh': u':修复受伤的心灵:'
    },
    u'\U0001F54E': { # 🕎
        'en' : ':menorah:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':menorah_with_nine_branches:'],
        'de': ':menora:',
        'es': u':menorá:',
        'fr': u':chandelier_à_sept_branches:',
        'ja': u':メノーラー:',
        'ko': u':메노라:',
        'pt': u':menorá:',
        'it': ':menorah:',
        'fa': u':منورا:',
        'id': ':menorah:',
        'zh': u':烛台:'
    },
    u'\U0001F6B9': { # 🚹
        'en' : u':men’s_room:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mens:'],
        'variant': True,
        'de': ':herren:',
        'es': ':aseo_para_hombres:',
        'fr': ':symbole_toilettes_hommes:',
        'ja': u':男子トイレ:',
        'ko': u':남자_화장실:',
        'pt': ':banheiro_masculino:',
        'it': ':simbolo_del_bagno_degli_uomini:',
        'fa': u':توالت_مردانه:',
        'id': ':toilet_pria:',
        'zh': u':男厕:'
    },
    u'\U0001F9DC\U0000200D\U00002640\U0000FE0F': { # 🧜‍♀️
        'en' : ':mermaid:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':meerjungfrau:',
        'es': ':sirena:',
        'fr': u':sirène:',
        'ja': u':マーメイド:',
        'ko': u':여자_인어:',
        'pt': ':sereia:',
        'it': ':sirena_donna:',
        'fa': u':پری_دریایی:',
        'id': ':putri_duyung:',
        'zh': u':美人鱼:'
    },
    u'\U0001F9DC\U0000200D\U00002640': { # 🧜‍♀
        'en' : ':mermaid:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':meerjungfrau:',
        'es': ':sirena:',
        'fr': u':sirène:',
        'ja': u':マーメイド:',
        'ko': u':여자_인어:',
        'pt': ':sereia:',
        'it': ':sirena_donna:',
        'fa': u':پری_دریایی:',
        'id': ':putri_duyung:',
        'zh': u':美人鱼:'
    },
    u'\U0001F9DC\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧜🏿‍♀️
        'en' : ':mermaid_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':meerjungfrau_dunkle_hautfarbe:',
        'es': ':sirena_tono_de_piel_oscuro:',
        'fr': u':sirène_peau_foncée:',
        'ja': u':マーメイド_濃い肌色:',
        'ko': u':여자_인어_검은색_피부:',
        'pt': ':sereia_pele_escura:',
        'it': ':sirena_donna_carnagione_scura:',
        'fa': u':پری_دریایی_پوست_آبنوسی:',
        'id': ':putri_duyung_warna_kulit_gelap:',
        'zh': u':美人鱼_较深肤色:'
    },
    u'\U0001F9DC\U0001F3FF\U0000200D\U00002640': { # 🧜🏿‍♀
        'en' : ':mermaid_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':meerjungfrau_dunkle_hautfarbe:',
        'es': ':sirena_tono_de_piel_oscuro:',
        'fr': u':sirène_peau_foncée:',
        'ja': u':マーメイド_濃い肌色:',
        'ko': u':여자_인어_검은색_피부:',
        'pt': ':sereia_pele_escura:',
        'it': ':sirena_donna_carnagione_scura:',
        'fa': u':پری_دریایی_پوست_آبنوسی:',
        'id': ':putri_duyung_warna_kulit_gelap:',
        'zh': u':美人鱼_较深肤色:'
    },
    u'\U0001F9DC\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧜🏻‍♀️
        'en' : ':mermaid_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':meerjungfrau_helle_hautfarbe:',
        'es': ':sirena_tono_de_piel_claro:',
        'fr': u':sirène_peau_claire:',
        'ja': u':マーメイド_薄い肌色:',
        'ko': u':여자_인어_하얀_피부:',
        'pt': ':sereia_pele_clara:',
        'it': ':sirena_donna_carnagione_chiara:',
        'fa': u':پری_دریایی_پوست_سفید:',
        'id': ':putri_duyung_warna_kulit_cerah:',
        'zh': u':美人鱼_较浅肤色:'
    },
    u'\U0001F9DC\U0001F3FB\U0000200D\U00002640': { # 🧜🏻‍♀
        'en' : ':mermaid_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':meerjungfrau_helle_hautfarbe:',
        'es': ':sirena_tono_de_piel_claro:',
        'fr': u':sirène_peau_claire:',
        'ja': u':マーメイド_薄い肌色:',
        'ko': u':여자_인어_하얀_피부:',
        'pt': ':sereia_pele_clara:',
        'it': ':sirena_donna_carnagione_chiara:',
        'fa': u':پری_دریایی_پوست_سفید:',
        'id': ':putri_duyung_warna_kulit_cerah:',
        'zh': u':美人鱼_较浅肤色:'
    },
    u'\U0001F9DC\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧜🏾‍♀️
        'en' : ':mermaid_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':meerjungfrau_mitteldunkle_hautfarbe:',
        'es': ':sirena_tono_de_piel_oscuro_medio:',
        'fr': u':sirène_peau_mate:',
        'ja': u':マーメイド_やや濃い肌色:',
        'ko': u':여자_인어_진한_갈색_피부:',
        'pt': ':sereia_pele_morena_escura:',
        'it': ':sirena_donna_carnagione_abbastanza_scura:',
        'fa': u':پری_دریایی_پوست_گندمی:',
        'id': ':putri_duyung_warna_kulit_gelap-sedang:',
        'zh': u':美人鱼_中等深肤色:'
    },
    u'\U0001F9DC\U0001F3FE\U0000200D\U00002640': { # 🧜🏾‍♀
        'en' : ':mermaid_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':meerjungfrau_mitteldunkle_hautfarbe:',
        'es': ':sirena_tono_de_piel_oscuro_medio:',
        'fr': u':sirène_peau_mate:',
        'ja': u':マーメイド_やや濃い肌色:',
        'ko': u':여자_인어_진한_갈색_피부:',
        'pt': ':sereia_pele_morena_escura:',
        'it': ':sirena_donna_carnagione_abbastanza_scura:',
        'fa': u':پری_دریایی_پوست_گندمی:',
        'id': ':putri_duyung_warna_kulit_gelap-sedang:',
        'zh': u':美人鱼_中等深肤色:'
    },
    u'\U0001F9DC\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧜🏼‍♀️
        'en' : ':mermaid_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':meerjungfrau_mittelhelle_hautfarbe:',
        'es': ':sirena_tono_de_piel_claro_medio:',
        'fr': u':sirène_peau_moyennement_claire:',
        'ja': u':マーメイド_やや薄い肌色:',
        'ko': u':여자_인어_연한_갈색_피부:',
        'pt': ':sereia_pele_morena_clara:',
        'it': ':sirena_donna_carnagione_abbastanza_chiara:',
        'fa': u':پری_دریایی_پوست_روشن:',
        'id': ':putri_duyung_warna_kulit_cerah-sedang:',
        'zh': u':美人鱼_中等浅肤色:'
    },
    u'\U0001F9DC\U0001F3FC\U0000200D\U00002640': { # 🧜🏼‍♀
        'en' : ':mermaid_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':meerjungfrau_mittelhelle_hautfarbe:',
        'es': ':sirena_tono_de_piel_claro_medio:',
        'fr': u':sirène_peau_moyennement_claire:',
        'ja': u':マーメイド_やや薄い肌色:',
        'ko': u':여자_인어_연한_갈색_피부:',
        'pt': ':sereia_pele_morena_clara:',
        'it': ':sirena_donna_carnagione_abbastanza_chiara:',
        'fa': u':پری_دریایی_پوست_روشن:',
        'id': ':putri_duyung_warna_kulit_cerah-sedang:',
        'zh': u':美人鱼_中等浅肤色:'
    },
    u'\U0001F9DC\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧜🏽‍♀️
        'en' : ':mermaid_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':meerjungfrau_mittlere_hautfarbe:',
        'es': ':sirena_tono_de_piel_medio:',
        'fr': u':sirène_peau_légèrement_mate:',
        'ja': u':マーメイド_中間の肌色:',
        'ko': u':여자_인어_갈색_피부:',
        'pt': ':sereia_pele_morena:',
        'it': ':sirena_donna_carnagione_olivastra:',
        'fa': u':پری_دریایی_پوست_طلایی:',
        'id': ':putri_duyung_warna_kulit_sedang:',
        'zh': u':美人鱼_中等肤色:'
    },
    u'\U0001F9DC\U0001F3FD\U0000200D\U00002640': { # 🧜🏽‍♀
        'en' : ':mermaid_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':meerjungfrau_mittlere_hautfarbe:',
        'es': ':sirena_tono_de_piel_medio:',
        'fr': u':sirène_peau_légèrement_mate:',
        'ja': u':マーメイド_中間の肌色:',
        'ko': u':여자_인어_갈색_피부:',
        'pt': ':sereia_pele_morena:',
        'it': ':sirena_donna_carnagione_olivastra:',
        'fa': u':پری_دریایی_پوست_طلایی:',
        'id': ':putri_duyung_warna_kulit_sedang:',
        'zh': u':美人鱼_中等肤色:'
    },
    u'\U0001F9DC\U0000200D\U00002642\U0000FE0F': { # 🧜‍♂️
        'en' : ':merman:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermann:',
        'es': ':sirena_hombre:',
        'fr': ':triton:',
        'ja': u':マーマン:',
        'ko': u':남자_인어:',
        'pt': ':sereio:',
        'it': ':tritone:',
        'fa': u':دریامرد:',
        'id': ':pria_duyung:',
        'zh': u':男人鱼:'
    },
    u'\U0001F9DC\U0000200D\U00002642': { # 🧜‍♂
        'en' : ':merman:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':wassermann:',
        'es': ':sirena_hombre:',
        'fr': ':triton:',
        'ja': u':マーマン:',
        'ko': u':남자_인어:',
        'pt': ':sereio:',
        'it': ':tritone:',
        'fa': u':دریامرد:',
        'id': ':pria_duyung:',
        'zh': u':男人鱼:'
    },
    u'\U0001F9DC\U0001F3FF\U0000200D\U00002642\U0000FE0F': { # 🧜🏿‍♂️
        'en' : ':merman_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermann_dunkle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_oscuro:',
        'fr': u':triton_peau_foncée:',
        'ja': u':マーマン_濃い肌色:',
        'ko': u':남자_인어_검은색_피부:',
        'pt': ':sereio_pele_escura:',
        'it': ':tritone_carnagione_scura:',
        'fa': u':دریامرد_پوست_آبنوسی:',
        'id': ':pria_duyung_warna_kulit_gelap:',
        'zh': u':男人鱼_较深肤色:'
    },
    u'\U0001F9DC\U0001F3FF\U0000200D\U00002642': { # 🧜🏿‍♂
        'en' : ':merman_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':wassermann_dunkle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_oscuro:',
        'fr': u':triton_peau_foncée:',
        'ja': u':マーマン_濃い肌色:',
        'ko': u':남자_인어_검은색_피부:',
        'pt': ':sereio_pele_escura:',
        'it': ':tritone_carnagione_scura:',
        'fa': u':دریامرد_پوست_آبنوسی:',
        'id': ':pria_duyung_warna_kulit_gelap:',
        'zh': u':男人鱼_较深肤色:'
    },
    u'\U0001F9DC\U0001F3FB\U0000200D\U00002642\U0000FE0F': { # 🧜🏻‍♂️
        'en' : ':merman_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermann_helle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_claro:',
        'fr': ':triton_peau_claire:',
        'ja': u':マーマン_薄い肌色:',
        'ko': u':남자_인어_하얀_피부:',
        'pt': ':sereio_pele_clara:',
        'it': ':tritone_carnagione_chiara:',
        'fa': u':دریامرد_پوست_سفید:',
        'id': ':pria_duyung_warna_kulit_cerah:',
        'zh': u':男人鱼_较浅肤色:'
    },
    u'\U0001F9DC\U0001F3FB\U0000200D\U00002642': { # 🧜🏻‍♂
        'en' : ':merman_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':wassermann_helle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_claro:',
        'fr': ':triton_peau_claire:',
        'ja': u':マーマン_薄い肌色:',
        'ko': u':남자_인어_하얀_피부:',
        'pt': ':sereio_pele_clara:',
        'it': ':tritone_carnagione_chiara:',
        'fa': u':دریامرد_پوست_سفید:',
        'id': ':pria_duyung_warna_kulit_cerah:',
        'zh': u':男人鱼_较浅肤色:'
    },
    u'\U0001F9DC\U0001F3FE\U0000200D\U00002642\U0000FE0F': { # 🧜🏾‍♂️
        'en' : ':merman_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermann_mitteldunkle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':triton_peau_mate:',
        'ja': u':マーマン_やや濃い肌色:',
        'ko': u':남자_인어_진한_갈색_피부:',
        'pt': ':sereio_pele_morena_escura:',
        'it': ':tritone_carnagione_abbastanza_scura:',
        'fa': u':دریامرد_پوست_گندمی:',
        'id': ':pria_duyung_warna_kulit_gelap-sedang:',
        'zh': u':男人鱼_中等深肤色:'
    },
    u'\U0001F9DC\U0001F3FE\U0000200D\U00002642': { # 🧜🏾‍♂
        'en' : ':merman_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':wassermann_mitteldunkle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_oscuro_medio:',
        'fr': ':triton_peau_mate:',
        'ja': u':マーマン_やや濃い肌色:',
        'ko': u':남자_인어_진한_갈색_피부:',
        'pt': ':sereio_pele_morena_escura:',
        'it': ':tritone_carnagione_abbastanza_scura:',
        'fa': u':دریامرد_پوست_گندمی:',
        'id': ':pria_duyung_warna_kulit_gelap-sedang:',
        'zh': u':男人鱼_中等深肤色:'
    },
    u'\U0001F9DC\U0001F3FC\U0000200D\U00002642\U0000FE0F': { # 🧜🏼‍♂️
        'en' : ':merman_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermann_mittelhelle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_claro_medio:',
        'fr': ':triton_peau_moyennement_claire:',
        'ja': u':マーマン_やや薄い肌色:',
        'ko': u':남자_인어_연한_갈색_피부:',
        'pt': ':sereio_pele_morena_clara:',
        'it': ':tritone_carnagione_abbastanza_chiara:',
        'fa': u':دریامرد_پوست_روشن:',
        'id': ':pria_duyung_warna_kulit_cerah-sedang:',
        'zh': u':男人鱼_中等浅肤色:'
    },
    u'\U0001F9DC\U0001F3FC\U0000200D\U00002642': { # 🧜🏼‍♂
        'en' : ':merman_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':wassermann_mittelhelle_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_claro_medio:',
        'fr': ':triton_peau_moyennement_claire:',
        'ja': u':マーマン_やや薄い肌色:',
        'ko': u':남자_인어_연한_갈색_피부:',
        'pt': ':sereio_pele_morena_clara:',
        'it': ':tritone_carnagione_abbastanza_chiara:',
        'fa': u':دریامرد_پوست_روشن:',
        'id': ':pria_duyung_warna_kulit_cerah-sedang:',
        'zh': u':男人鱼_中等浅肤色:'
    },
    u'\U0001F9DC\U0001F3FD\U0000200D\U00002642\U0000FE0F': { # 🧜🏽‍♂️
        'en' : ':merman_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermann_mittlere_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_medio:',
        'fr': u':triton_peau_légèrement_mate:',
        'ja': u':マーマン_中間の肌色:',
        'ko': u':남자_인어_갈색_피부:',
        'pt': ':sereio_pele_morena:',
        'it': ':tritone_carnagione_olivastra:',
        'fa': u':دریامرد_پوست_طلایی:',
        'id': ':pria_duyung_warna_kulit_sedang:',
        'zh': u':男人鱼_中等肤色:'
    },
    u'\U0001F9DC\U0001F3FD\U0000200D\U00002642': { # 🧜🏽‍♂
        'en' : ':merman_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':wassermann_mittlere_hautfarbe:',
        'es': ':sirena_hombre_tono_de_piel_medio:',
        'fr': u':triton_peau_légèrement_mate:',
        'ja': u':マーマン_中間の肌色:',
        'ko': u':남자_인어_갈색_피부:',
        'pt': ':sereio_pele_morena:',
        'it': ':tritone_carnagione_olivastra:',
        'fa': u':دریامرد_پوست_طلایی:',
        'id': ':pria_duyung_warna_kulit_sedang:',
        'zh': u':男人鱼_中等肤色:'
    },
    u'\U0001F9DC': { # 🧜
        'en' : ':merperson:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermensch:',
        'es': ':persona_sirena:',
        'fr': u':créature_aquatique:',
        'ja': u':人魚:',
        'ko': u':인어:',
        'pt': ':pessoa_sereia:',
        'it': ':sirena:',
        'fa': u':دریامردمان:',
        'id': ':orang_duyung:',
        'zh': u':人鱼:'
    },
    u'\U0001F9DC\U0001F3FF': { # 🧜🏿
        'en' : ':merperson_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermensch_dunkle_hautfarbe:',
        'es': ':persona_sirena_tono_de_piel_oscuro:',
        'fr': u':créature_aquatique_peau_foncée:',
        'ja': u':人魚_濃い肌色:',
        'ko': u':인어_검은색_피부:',
        'pt': ':pessoa_sereia_pele_escura:',
        'it': ':sirena_carnagione_scura:',
        'fa': u':دریامردمان_پوست_آبنوسی:',
        'id': ':orang_duyung_warna_kulit_gelap:',
        'zh': u':人鱼_较深肤色:'
    },
    u'\U0001F9DC\U0001F3FB': { # 🧜🏻
        'en' : ':merperson_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermensch_helle_hautfarbe:',
        'es': ':persona_sirena_tono_de_piel_claro:',
        'fr': u':créature_aquatique_peau_claire:',
        'ja': u':人魚_薄い肌色:',
        'ko': u':인어_하얀_피부:',
        'pt': ':pessoa_sereia_pele_clara:',
        'it': ':sirena_carnagione_chiara:',
        'fa': u':دریامردمان_پوست_سفید:',
        'id': ':orang_duyung_warna_kulit_cerah:',
        'zh': u':人鱼_较浅肤色:'
    },
    u'\U0001F9DC\U0001F3FE': { # 🧜🏾
        'en' : ':merperson_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermensch_mitteldunkle_hautfarbe:',
        'es': ':persona_sirena_tono_de_piel_oscuro_medio:',
        'fr': u':créature_aquatique_peau_mate:',
        'ja': u':人魚_やや濃い肌色:',
        'ko': u':인어_진한_갈색_피부:',
        'pt': ':pessoa_sereia_pele_morena_escura:',
        'it': ':sirena_carnagione_abbastanza_scura:',
        'fa': u':دریامردمان_پوست_گندمی:',
        'id': ':orang_duyung_warna_kulit_gelap-sedang:',
        'zh': u':人鱼_中等深肤色:'
    },
    u'\U0001F9DC\U0001F3FC': { # 🧜🏼
        'en' : ':merperson_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermensch_mittelhelle_hautfarbe:',
        'es': ':persona_sirena_tono_de_piel_claro_medio:',
        'fr': u':créature_aquatique_peau_moyennement_claire:',
        'ja': u':人魚_やや薄い肌色:',
        'ko': u':인어_연한_갈색_피부:',
        'pt': ':pessoa_sereia_pele_morena_clara:',
        'it': ':sirena_carnagione_abbastanza_chiara:',
        'fa': u':دریامردمان_پوست_روشن:',
        'id': ':orang_duyung_warna_kulit_cerah-sedang:',
        'zh': u':人鱼_中等浅肤色:'
    },
    u'\U0001F9DC\U0001F3FD': { # 🧜🏽
        'en' : ':merperson_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':wassermensch_mittlere_hautfarbe:',
        'es': ':persona_sirena_tono_de_piel_medio:',
        'fr': u':créature_aquatique_peau_légèrement_mate:',
        'ja': u':人魚_中間の肌色:',
        'ko': u':인어_갈색_피부:',
        'pt': ':pessoa_sereia_pele_morena:',
        'it': ':sirena_carnagione_olivastra:',
        'fa': u':دریامردمان_پوست_طلایی:',
        'id': ':orang_duyung_warna_kulit_sedang:',
        'zh': u':人鱼_中等肤色:'
    },
    u'\U0001F687': { # 🚇
        'en' : ':metro:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':u-bahn:',
        'es': ':metro:',
        'fr': u':métro:',
        'ja': u':地下鉄:',
        'ko': u':지하철:',
        'pt': u':metrô:',
        'it': ':metropolitana:',
        'fa': u':قطار_شهری:',
        'id': ':kereta_bawah_tanah:',
        'zh': u':地铁:'
    },
    u'\U0001F9A0': { # 🦠
        'en' : ':microbe:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mikrobe:',
        'es': ':microbio:',
        'fr': ':microbe:',
        'ja': u':微生物:',
        'ko': u':미생물:',
        'pt': u':micróbio:',
        'it': ':microbo:',
        'fa': u':میکروب:',
        'id': ':mikroba:',
        'zh': u':细菌:'
    },
    u'\U0001F3A4': { # 🎤
        'en' : ':microphone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':mikrofon:',
        'es': u':micrófono:',
        'fr': ':micro:',
        'ja': u':マイク:',
        'ko': u':마이크:',
        'pt': ':microfone:',
        'it': ':microfono:',
        'fa': u':میکروفون:',
        'id': ':mikrofon:',
        'zh': u':麦克风:'
    },
    u'\U0001F52C': { # 🔬
        'en' : ':microscope:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mikroskop:',
        'es': ':microscopio:',
        'fr': ':microscope:',
        'ja': u':顕微鏡:',
        'ko': u':현미경:',
        'pt': u':microscópio:',
        'it': ':microscopio:',
        'fa': u':میکروسکوپ:',
        'id': ':mikroskop:',
        'zh': u':显微镜:'
    },
    u'\U0001F595': { # 🖕
        'en' : ':middle_finger:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':fu:', ':reversed_hand_with_middle_finger_extended:'],
        'de': ':mittelfinger:',
        'es': u':dedo_corazón_hacia_arriba:',
        'fr': u':doigt_d’honneur:',
        'ja': u':立てた中指:',
        'ko': u':중지:',
        'pt': ':dedo_do_meio:',
        'it': ':dito_medio:',
        'fa': u':انگشت_میانه:',
        'id': ':jari_tengah:',
        'zh': u':竖中指:'
    },
    u'\U0001F595\U0001F3FF': { # 🖕🏿
        'en' : ':middle_finger_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mittelfinger_dunkle_hautfarbe:',
        'es': u':dedo_corazón_hacia_arriba_tono_de_piel_oscuro:',
        'fr': u':doigt_d’honneur_peau_foncée:',
        'ja': u':立てた中指_濃い肌色:',
        'ko': u':중지_검은색_피부:',
        'pt': ':dedo_do_meio_pele_escura:',
        'it': ':dito_medio_carnagione_scura:',
        'fa': u':انگشت_میانه_پوست_آبنوسی:',
        'id': ':jari_tengah_warna_kulit_gelap:',
        'zh': u':竖中指_较深肤色:'
    },
    u'\U0001F595\U0001F3FB': { # 🖕🏻
        'en' : ':middle_finger_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mittelfinger_helle_hautfarbe:',
        'es': u':dedo_corazón_hacia_arriba_tono_de_piel_claro:',
        'fr': u':doigt_d’honneur_peau_claire:',
        'ja': u':立てた中指_薄い肌色:',
        'ko': u':중지_하얀_피부:',
        'pt': ':dedo_do_meio_pele_clara:',
        'it': ':dito_medio_carnagione_chiara:',
        'fa': u':انگشت_میانه_پوست_سفید:',
        'id': ':jari_tengah_warna_kulit_cerah:',
        'zh': u':竖中指_较浅肤色:'
    },
    u'\U0001F595\U0001F3FE': { # 🖕🏾
        'en' : ':middle_finger_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mittelfinger_mitteldunkle_hautfarbe:',
        'es': u':dedo_corazón_hacia_arriba_tono_de_piel_oscuro_medio:',
        'fr': u':doigt_d’honneur_peau_mate:',
        'ja': u':立てた中指_やや濃い肌色:',
        'ko': u':중지_진한_갈색_피부:',
        'pt': ':dedo_do_meio_pele_morena_escura:',
        'it': ':dito_medio_carnagione_abbastanza_scura:',
        'fa': u':انگشت_میانه_پوست_گندمی:',
        'id': ':jari_tengah_warna_kulit_gelap-sedang:',
        'zh': u':竖中指_中等深肤色:'
    },
    u'\U0001F595\U0001F3FC': { # 🖕🏼
        'en' : ':middle_finger_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mittelfinger_mittelhelle_hautfarbe:',
        'es': u':dedo_corazón_hacia_arriba_tono_de_piel_claro_medio:',
        'fr': u':doigt_d’honneur_peau_moyennement_claire:',
        'ja': u':立てた中指_やや薄い肌色:',
        'ko': u':중지_연한_갈색_피부:',
        'pt': ':dedo_do_meio_pele_morena_clara:',
        'it': ':dito_medio_carnagione_abbastanza_chiara:',
        'fa': u':انگشت_میانه_پوست_روشن:',
        'id': ':jari_tengah_warna_kulit_cerah-sedang:',
        'zh': u':竖中指_中等浅肤色:'
    },
    u'\U0001F595\U0001F3FD': { # 🖕🏽
        'en' : ':middle_finger_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mittelfinger_mittlere_hautfarbe:',
        'es': u':dedo_corazón_hacia_arriba_tono_de_piel_medio:',
        'fr': u':doigt_d’honneur_peau_légèrement_mate:',
        'ja': u':立てた中指_中間の肌色:',
        'ko': u':중지_갈색_피부:',
        'pt': ':dedo_do_meio_pele_morena:',
        'it': ':dito_medio_carnagione_olivastra:',
        'fa': u':انگشت_میانه_پوست_طلایی:',
        'id': ':jari_tengah_warna_kulit_sedang:',
        'zh': u':竖中指_中等肤色:'
    },
    u'\U0001FA96': { # 🪖
        'en' : ':military_helmet:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':militärhelm:',
        'es': ':casco_militar:',
        'fr': ':casque_militaire:',
        'ja': u':軍用ヘルメット:',
        'ko': u':군용_헬멧:',
        'pt': ':capacete_militar:',
        'it': ':elmetto_militare:',
        'fa': u':کلاه_خود:',
        'id': ':helm_tentara:',
        'zh': u':军用头盔:'
    },
    u'\U0001F396\U0000FE0F': { # 🎖️
        'en' : ':military_medal:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':medal_military:'],
        'variant': True,
        'de': u':militärorden:',
        'es': ':medalla_militar:',
        'fr': u':médaille_militaire:',
        'ja': u':勲章:',
        'ko': u':무공_훈장:',
        'pt': ':medalha_militar:',
        'it': ':medaglia_militare:',
        'fa': u':مدال_ارتشی:',
        'id': ':medali_militer:',
        'zh': u':军功章:'
    },
    u'\U0001F396': { # 🎖
        'en' : ':military_medal:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':medal_military:'],
        'variant': True,
        'de': u':militärorden:',
        'es': ':medalla_militar:',
        'fr': u':médaille_militaire:',
        'ja': u':勲章:',
        'ko': u':무공_훈장:',
        'pt': ':medalha_militar:',
        'it': ':medaglia_militare:',
        'fa': u':مدال_ارتشی:',
        'id': ':medali_militer:',
        'zh': u':军功章:'
    },
    u'\U0001F30C': { # 🌌
        'en' : ':milky_way:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':milchstraße:',
        'es': u':vía_láctea:',
        'fr': u':voie_lactée:',
        'ja': u':天の川:',
        'ko': u':은하수:',
        'pt': u':via_láctea:',
        'it': ':via_lattea:',
        'fa': u':راه_شیری:',
        'id': ':bima_sakti:',
        'zh': u':银河:'
    },
    u'\U0001F690': { # 🚐
        'en' : ':minibus:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':kleinbus:',
        'es': u':minibús:',
        'fr': ':minibus:',
        'ja': u':マイクロバス:',
        'ko': u':미니버스:',
        'pt': ':van:',
        'it': ':pulmino:',
        'fa': u':مینی_بوس:',
        'id': ':minibus:',
        'zh': u':小巴:'
    },
    u'\U00002796': { # ➖
        'en' : ':minus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heavy_minus_sign:'],
        'de': ':minus:',
        'es': ':menos:',
        'fr': ':moins:',
        'ja': u':マイナス:',
        'ko': u':빼기:',
        'pt': u':símbolo_de_subtração:',
        'it': ':sottrazione:',
        'fa': u':تفریق:',
        'id': ':kurang:',
        'zh': u':减:'
    },
    u'\U0001FA9E': { # 🪞
        'en' : ':mirror:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':spiegel:',
        'es': ':espejo:',
        'fr': ':miroir:',
        'ja': u':鏡:',
        'ko': u':거울:',
        'pt': ':espelho:',
        'it': ':specchio:',
        'fa': u':آینه:',
        'id': ':cermin:',
        'zh': u':镜子:'
    },
    u'\U0001FAA9': { # 🪩
        'en' : ':mirror_ball:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':discokugel:',
        'es': ':bola_de_espejos:',
        'fr': u':boule_à_facettes:',
        'ja': u':ミラーボール:',
        'ko': u':미러볼:',
        'pt': ':globo_de_espelhos:',
        'it': ':palla_da_discoteca:',
        'fa': u':توپ_آینه_ای:',
        'id': ':bola_disko:',
        'zh': u':镜球:'
    },
    u'\U0001F5FF': { # 🗿
        'en' : ':moai:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':moyai:'],
        'de': ':statue:',
        'es': u':estatua_moái:',
        'fr': ':moai:',
        'ja': u':モアイ:',
        'ko': u':모아이:',
        'pt': ':moai:',
        'it': ':moai:',
        'fa': u':سردیس_موآی:',
        'id': ':moai:',
        'zh': u':摩埃:'
    },
    u'\U0001F4F1': { # 📱
        'en' : ':mobile_phone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':iphone:'],
        'de': ':mobiltelefon:',
        'es': u':teléfono_móvil:',
        'fr': u':téléphone_portable:',
        'ja': u':携帯電話:',
        'ko': u':휴대전화:',
        'pt': ':telefone_celular:',
        'it': ':telefono_cellulare:',
        'fa': u':تلفن_همراه:',
        'id': ':ponsel:',
        'zh': u':手机:'
    },
    u'\U0001F4F4': { # 📴
        'en' : ':mobile_phone_off:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':mobiltelefon_aus:',
        'es': u':teléfono_móvil_apagado:',
        'fr': u':téléphone_éteint:',
        'ja': u':携帯電話電源オフ:',
        'ko': u':휴대전화_끄기:',
        'pt': ':telefone_celular_desligado:',
        'it': ':cellulare_spento:',
        'fa': u':تلفن_همراه_خاموش:',
        'id': ':ponsel_nonaktif:',
        'zh': u':手机关机:'
    },
    u'\U0001F4F2': { # 📲
        'en' : ':mobile_phone_with_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':calling:'],
        'de': ':mobiltelefon_mit_pfeil:',
        'es': u':móvil_con_una_flecha:',
        'fr': ':appel_entrant:',
        'ja': u':着信中:',
        'ko': u':왼쪽에_화살표가_있는_휴대전화:',
        'pt': ':telefone_celular_com_seta:',
        'it': ':telefono_cellulare_con_freccia:',
        'fa': u':تلفن_همراه_با_پیکان:',
        'id': ':telepon_masuk:',
        'zh': u':带有箭头的手机:'
    },
    u'\U0001F911': { # 🤑
        'en' : ':money-mouth_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':money_mouth_face:', ':money__mouth_face:'],
        'de': ':gesicht_mit_dollarzeichen:',
        'es': ':cara_con_lengua_de_dinero:',
        'fr': ':argent_dans_les_yeux_et_la_bouche:',
        'ja': u':お金の顔:',
        'ko': u':돈_모양의_입이_있는_얼굴:',
        'pt': u':rosto_com_cifrões:',
        'it': ':faccina_avida_di_denaro:',
        'fa': u':صورت_پول_دوست:',
        'id': ':wajah_materialistis:',
        'zh': u':发财:'
    },
    u'\U0001F4B0': { # 💰
        'en' : ':money_bag:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':moneybag:'],
        'variant': True,
        'de': ':geldsack:',
        'es': ':bolsa_de_dinero:',
        'fr': u':sac_plein_d’argent:',
        'ja': u':ドル袋:',
        'ko': u':돈주머니:',
        'pt': ':saco_de_dinheiro:',
        'it': ':sacco_di_soldi:',
        'fa': u':کیسهٔ_پول:',
        'id': ':kantung_uang:',
        'zh': u':钱袋:'
    },
    u'\U0001F4B8': { # 💸
        'en' : ':money_with_wings:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':geldschein_mit_flügeln:',
        'es': ':billete_con_alas:',
        'fr': ':billet_avec_des_ailes:',
        'ja': u':羽が生えたお金:',
        'ko': u':날개_달린_돈:',
        'pt': ':dinheiro_voando:',
        'it': ':soldi_con_le_ali:',
        'fa': u':اسکناس_بال_دار:',
        'id': ':uang_bersayap:',
        'zh': u':长翅膀的钱:'
    },
    u'\U0001F412': { # 🐒
        'en' : ':monkey:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':affe:',
        'es': ':mono:',
        'fr': ':singe:',
        'ja': u':サル:',
        'ko': u':원숭이:',
        'pt': ':macaco:',
        'it': ':scimmia:',
        'fa': u':میمون:',
        'id': ':monyet:',
        'zh': u':猴子:'
    },
    u'\U0001F435': { # 🐵
        'en' : ':monkey_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':affengesicht:',
        'es': ':cara_de_mono:',
        'fr': u':tête_de_singe:',
        'ja': u':サルの顔:',
        'ko': u':원숭이_얼굴:',
        'pt': ':rosto_de_macaco:',
        'it': ':muso_di_scimmia:',
        'fa': u':صورت_میمون:',
        'id': ':wajah_monyet:',
        'zh': u':猴头:'
    },
    u'\U0001F69D': { # 🚝
        'en' : ':monorail:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':einschienenbahn:',
        'es': u':monorraíl:',
        'fr': ':monorail:',
        'ja': u':モノレール:',
        'ko': u':모노레일:',
        'pt': ':monotrilho:',
        'it': ':monorotaia:',
        'fa': u':تک_ریل:',
        'id': ':monorel:',
        'zh': u':单轨:'
    },
    u'\U0001F96E': { # 🥮
        'en' : ':moon_cake:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':mondkuchen:',
        'es': ':pastel_de_luna:',
        'fr': u':gâteau_de_lune:',
        'ja': u':月餅:',
        'ko': u':월병:',
        'pt': ':bolo_lunar:',
        'it': ':torta_della_luna:',
        'fa': u':کیک_ماه:',
        'id': ':kue_bulan:',
        'zh': u':月饼:'
    },
    u'\U0001F391': { # 🎑
        'en' : ':moon_viewing_ceremony:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':rice_scene:'],
        'de': ':traditionelles_mondfest:',
        'es': u':ceremonia_de_contemplación_de_la_luna:',
        'fr': u':cérémonie_de_la_lune:',
        'ja': u':月見:',
        'ko': u':달맞이:',
        'pt': u':contemplação_da_lua:',
        'it': ':contemplazione_della_luna:',
        'fa': u':آئین_مشاهدهٔ_ماه_کامل:',
        'id': ':perayaan_bulan:',
        'zh': u':赏月:'
    },
    u'\U0001FACE': { # 🫎
        'en' : ':moose:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':elch:',
        'es': ':alce:',
        'fr': u':élan:',
        'ja': u':ヘラジカ:',
        'ko': u':무스:',
        'pt': ':alce:',
        'it': ':alce:',
        'fa': u':موس:',
        'id': ':rusa_besar:',
        'zh': u':驼鹿:'
    },
    u'\U0001F54C': { # 🕌
        'en' : ':mosque:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':moschee:',
        'es': ':mezquita:',
        'fr': u':mosquée:',
        'ja': u':モスク:',
        'ko': u':모스크:',
        'pt': ':mesquita:',
        'it': ':moschea:',
        'fa': u':مسجد:',
        'id': ':masjid:',
        'zh': u':清真寺:'
    },
    u'\U0001F99F': { # 🦟
        'en' : ':mosquito:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':mücke:',
        'es': ':mosquito:',
        'fr': ':moustique:',
        'ja': u':蚊:',
        'ko': u':모기:',
        'pt': ':mosquito:',
        'it': ':zanzara:',
        'fa': u':پشه:',
        'id': ':nyamuk:',
        'zh': u':蚊子:'
    },
    u'\U0001F6E5\U0000FE0F': { # 🛥️
        'en' : ':motor_boat:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':motorboot:',
        'es': ':barco_a_motor:',
        'fr': u':bateau_à_moteur:',
        'ja': u':モーターボート:',
        'ko': u':모터보트:',
        'pt': ':barco:',
        'it': ':barca_a_motore:',
        'fa': u':قایق_موتوری:',
        'id': ':perahu_bermotor:',
        'zh': u':摩托艇:'
    },
    u'\U0001F6E5': { # 🛥
        'en' : ':motor_boat:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':motorboot:',
        'es': ':barco_a_motor:',
        'fr': u':bateau_à_moteur:',
        'ja': u':モーターボート:',
        'ko': u':모터보트:',
        'pt': ':barco:',
        'it': ':barca_a_motore:',
        'fa': u':قایق_موتوری:',
        'id': ':perahu_bermotor:',
        'zh': u':摩托艇:'
    },
    u'\U0001F6F5': { # 🛵
        'en' : ':motor_scooter:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':motorroller:',
        'es': ':scooter:',
        'fr': ':scooter:',
        'ja': u':スクーター:',
        'ko': u':스쿠터:',
        'pt': ':scooter:',
        'it': ':scooter:',
        'fa': u':اسکوتر:',
        'id': ':motor_skuter:',
        'zh': u':小型摩托车:'
    },
    u'\U0001F3CD\U0000FE0F': { # 🏍️
        'en' : ':motorcycle:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':racing_motorcycle:'],
        'variant': True,
        'de': ':motorrad:',
        'es': ':moto:',
        'fr': ':moto:',
        'ja': u':オートバイ:',
        'ko': u':오토바이:',
        'pt': ':motocicleta:',
        'it': ':motocicletta:',
        'fa': u':موتورسیکلت:',
        'id': ':sepeda_motor:',
        'zh': u':摩托车:'
    },
    u'\U0001F3CD': { # 🏍
        'en' : ':motorcycle:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':racing_motorcycle:'],
        'variant': True,
        'de': ':motorrad:',
        'es': ':moto:',
        'fr': ':moto:',
        'ja': u':オートバイ:',
        'ko': u':오토바이:',
        'pt': ':motocicleta:',
        'it': ':motocicletta:',
        'fa': u':موتورسیکلت:',
        'id': ':sepeda_motor:',
        'zh': u':摩托车:'
    },
    u'\U0001F9BC': { # 🦼
        'en' : ':motorized_wheelchair:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':elektrischer_rollstuhl:',
        'es': u':silla_de_ruedas_eléctrica:',
        'fr': u':fauteuil_motorisé:',
        'ja': u':電動車椅子:',
        'ko': u':전동_휠체어:',
        'pt': ':cadeira_de_rodas_motorizada:',
        'it': ':sedia_a_rotelle_motorizzata:',
        'fa': u':صندلی_چرخ_دار_برقی:',
        'id': ':kursi_roda_bermotor:',
        'zh': u':电动轮椅:'
    },
    u'\U0001F6E3\U0000FE0F': { # 🛣️
        'en' : ':motorway:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':autobahn:',
        'es': ':autopista:',
        'fr': ':autoroute:',
        'ja': u':高速道路:',
        'ko': u':고속도로:',
        'pt': ':estrada:',
        'it': ':autostrada:',
        'fa': u':بزرگراه:',
        'id': ':jalan_raya:',
        'zh': u':高速公路:'
    },
    u'\U0001F6E3': { # 🛣
        'en' : ':motorway:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':autobahn:',
        'es': ':autopista:',
        'fr': ':autoroute:',
        'ja': u':高速道路:',
        'ko': u':고속도로:',
        'pt': ':estrada:',
        'it': ':autostrada:',
        'fa': u':بزرگراه:',
        'id': ':jalan_raya:',
        'zh': u':高速公路:'
    },
    u'\U0001F5FB': { # 🗻
        'en' : ':mount_fuji:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':fuji:',
        'es': ':monte_fuji:',
        'fr': ':mont_fuji:',
        'ja': u':富士山:',
        'ko': u':후지산:',
        'pt': ':monte_fuji:',
        'it': ':monte_fuji:',
        'fa': u':کوه_فوجی:',
        'id': ':gunung_fuji:',
        'zh': u':富士山:'
    },
    u'\U000026F0\U0000FE0F': { # ⛰️
        'en' : ':mountain:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':berg:',
        'es': u':montaña:',
        'fr': ':montagne:',
        'ja': u':山:',
        'ko': u':산:',
        'pt': ':montanha:',
        'it': ':montagna:',
        'fa': u':کوه:',
        'id': ':gunung:',
        'zh': u':山:'
    },
    u'\U000026F0': { # ⛰
        'en' : ':mountain:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':berg:',
        'es': u':montaña:',
        'fr': ':montagne:',
        'ja': u':山:',
        'ko': u':산:',
        'pt': ':montanha:',
        'it': ':montagna:',
        'fa': u':کوه:',
        'id': ':gunung:',
        'zh': u':山:'
    },
    u'\U0001F6A0': { # 🚠
        'en' : ':mountain_cableway:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bergschwebebahn:',
        'es': u':teleférico_de_montaña:',
        'fr': u':téléphérique:',
        'ja': u':ケーブルカー:',
        'ko': u':산악_케이블카:',
        'pt': u':cabo_suspenso_usado_em_teleféricos_nas_montanhas:',
        'it': ':funivia:',
        'fa': u':تله_کابین_کوهستانی:',
        'id': ':kereta_gantung:',
        'zh': u':缆车:'
    },
    u'\U0001F69E': { # 🚞
        'en' : ':mountain_railway:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':bergbahn:',
        'es': u':ferrocarril_de_montaña:',
        'fr': ':train_de_montagne:',
        'ja': u':登山鉄道:',
        'ko': u':기차_터널:',
        'pt': ':estrada_de_ferro_na_montanha:',
        'it': ':ferrovia_di_montagna:',
        'fa': u':ریل_کوهستانی:',
        'id': ':jalur_kereta_pegunungan:',
        'zh': u':山区铁路:'
    },
    u'\U0001F401': { # 🐁
        'en' : ':mouse:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':mouse2:'],
        'de': ':maus:',
        'es': u':ratón:',
        'fr': ':souris:',
        'ja': u':ハツカネズミ:',
        'ko': u':생쥐:',
        'pt': ':camundongo:',
        'it': ':topo:',
        'fa': u':موش:',
        'id': ':tikus_putih:',
        'zh': u':老鼠:'
    },
    u'\U0001F42D': { # 🐭
        'en' : ':mouse_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':mouse:'],
        'de': u':mäusegesicht:',
        'es': u':cara_de_ratón:',
        'fr': u':tête_de_souris:',
        'ja': u':ネズミの顔:',
        'ko': u':쥐_얼굴:',
        'pt': ':rosto_de_camundongo:',
        'it': ':muso_di_topo:',
        'fa': u':صورت_موش:',
        'id': ':wajah_tikus:',
        'zh': u':老鼠头:'
    },
    u'\U0001FAA4': { # 🪤
        'en' : ':mouse_trap:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':mausefalle:',
        'es': ':trampa_de_ratones:',
        'fr': u':tapette_à_souris:',
        'ja': u':ねずみ捕り:',
        'ko': u':쥐덫:',
        'pt': ':ratoeira:',
        'it': ':trappola_per_topi:',
        'fa': u':تله_موش:',
        'id': ':perangkap_tikus:',
        'zh': u':捕鼠器:'
    },
    u'\U0001F444': { # 👄
        'en' : ':mouth:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':lips:'],
        'de': ':mund:',
        'es': ':boca:',
        'fr': ':bouche:',
        'ja': u':口:',
        'ko': u':입:',
        'pt': ':boca:',
        'it': ':bocca:',
        'fa': u':لب:',
        'id': ':mulut:',
        'zh': u':嘴:'
    },
    u'\U0001F3A5': { # 🎥
        'en' : ':movie_camera:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':filmkamera:',
        'es': u':cámara_de_cine:',
        'fr': u':caméra:',
        'ja': u':映画カメラ:',
        'ko': u':영화_카메라:',
        'pt': u':câmera_de_cinema:',
        'it': ':cinepresa:',
        'fa': u':دوربین_سینمایی:',
        'id': ':kamera_film:',
        'zh': u':电影摄影机:'
    },
    u'\U00002716\U0000FE0F': { # ✖️
        'en' : ':multiply:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heavy_multiplication_x:'],
        'variant': True,
        'de': ':multiplikationszeichen:',
        'es': u':multiplicación:',
        'fr': ':signe_multiplier:',
        'ja': u':掛け算:',
        'ko': u':곱하기:',
        'pt': u':sinal_de_multiplicação:',
        'it': ':segno_moltiplicazione:',
        'fa': u':ضرب_کردن:',
        'id': ':kali:',
        'zh': u':乘:'
    },
    u'\U00002716': { # ✖
        'en' : ':multiply:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':heavy_multiplication_x:'],
        'variant': True,
        'de': ':mal:',
        'es': u':multiplicación:',
        'fr': ':signe_multiplier:',
        'ja': u':掛け算:',
        'ko': u':곱하기:',
        'pt': u':sinal_de_multiplicação:',
        'it': ':moltiplicazione:',
        'fa': u':ضرب_کردن:',
        'id': ':kali:',
        'zh': u':乘:'
    },
    u'\U0001F344': { # 🍄
        'en' : ':mushroom:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':fliegenpilz:',
        'es': u':champiñón:',
        'fr': ':champignon:',
        'ja': u':キノコ:',
        'ko': u':버섯:',
        'pt': ':cogumelo:',
        'it': ':fungo:',
        'fa': u':قارچ:',
        'id': ':jamur:',
        'zh': u':蘑菇:'
    },
    u'\U0001F3B9': { # 🎹
        'en' : ':musical_keyboard:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':klaviatur:',
        'es': ':teclado_musical:',
        'fr': ':piano:',
        'ja': u':鍵盤:',
        'ko': u':피아노:',
        'pt': ':teclado_musical:',
        'it': ':piano:',
        'fa': u':کیبورد_موسیقی:',
        'id': ':keyboard_musik:',
        'zh': u':音乐键盘:'
    },
    u'\U0001F3B5': { # 🎵
        'en' : ':musical_note:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':musiknote:',
        'es': ':nota_musical:',
        'fr': ':note_de_musique:',
        'ja': u':音符:',
        'ko': u':음표:',
        'pt': ':nota_musical:',
        'it': ':nota_musicale:',
        'fa': u':نت_موسیقی:',
        'id': ':not_musik:',
        'zh': u':音符:'
    },
    u'\U0001F3B6': { # 🎶
        'en' : ':musical_notes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':notes:'],
        'de': ':musiknoten:',
        'es': ':notas_musicales:',
        'fr': ':notes_de_musique:',
        'ja': u':複数の音符:',
        'ko': u':노래_음표:',
        'pt': ':notas_musicais:',
        'it': ':note_musicali:',
        'fa': u':نت_های_موسیقی:',
        'id': ':not-not_musik:',
        'zh': u':多个音符:'
    },
    u'\U0001F3BC': { # 🎼
        'en' : ':musical_score:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':notenschlüssel:',
        'es': ':pentagrama:',
        'fr': ':partition:',
        'ja': u':楽譜:',
        'ko': u':높은음자리표:',
        'pt': ':partitura_musical:',
        'it': ':pentagramma:',
        'fa': u':پارتیتور:',
        'id': ':naskah_musik:',
        'zh': u':乐谱:'
    },
    u'\U0001F507': { # 🔇
        'en' : ':muted_speaker:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':mute:'],
        'de': ':durchgestrichener_lautsprecher:',
        'es': ':altavoz_silenciado:',
        'fr': ':muet:',
        'ja': u':スピーカー消音:',
        'ko': u':무음:',
        'pt': ':alto-falante_silenciado:',
        'it': ':altoparlante_disattivato:',
        'fa': u':بلندگوی_خاموش:',
        'id': ':speaker_mati:',
        'zh': u':已静音的扬声器:'
    },
    u'\U0001F9D1\U0000200D\U0001F384': { # 🧑‍🎄
        'en' : ':mx_claus:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':weihnachtsperson:',
        'es': ':noel:',
        'fr': ':santa:',
        'ja': u':サンタさん:',
        'ko': u':산타:',
        'pt': ':noel:',
        'it': ':santa_claus:',
        'fa': u':نوئل:',
        'id': ':manusia_sinterklas:',
        'zh': u':圣诞人:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F384': { # 🧑🏿‍🎄
        'en' : ':mx_claus_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':weihnachtsperson_dunkle_hautfarbe:',
        'es': ':noel_tono_de_piel_oscuro:',
        'fr': u':santa_peau_foncée:',
        'ja': u':サンタさん_濃い肌色:',
        'ko': u':산타_검은색_피부:',
        'pt': ':noel_pele_escura:',
        'it': ':santa_claus_carnagione_scura:',
        'fa': u':نوئل_پوست_آبنوسی:',
        'id': ':manusia_sinterklas_warna_kulit_gelap:',
        'zh': u':圣诞人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F384': { # 🧑🏻‍🎄
        'en' : ':mx_claus_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':weihnachtsperson_helle_hautfarbe:',
        'es': ':noel_tono_de_piel_claro:',
        'fr': ':santa_peau_claire:',
        'ja': u':サンタさん_薄い肌色:',
        'ko': u':산타_하얀_피부:',
        'pt': ':noel_pele_clara:',
        'it': ':santa_claus_carnagione_chiara:',
        'fa': u':نوئل_پوست_سفید:',
        'id': ':manusia_sinterklas_warna_kulit_cerah:',
        'zh': u':圣诞人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F384': { # 🧑🏾‍🎄
        'en' : ':mx_claus_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':weihnachtsperson_mitteldunkle_hautfarbe:',
        'es': ':noel_tono_de_piel_oscuro_medio:',
        'fr': ':santa_peau_mate:',
        'ja': u':サンタさん_やや濃い肌色:',
        'ko': u':산타_진한_갈색_피부:',
        'pt': ':noel_pele_morena_escura:',
        'it': ':santa_claus_carnagione_abbastanza_scura:',
        'fa': u':نوئل_پوست_گندمی:',
        'id': ':manusia_sinterklas_warna_kulit_gelap-sedang:',
        'zh': u':圣诞人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F384': { # 🧑🏼‍🎄
        'en' : ':mx_claus_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':weihnachtsperson_mittelhelle_hautfarbe:',
        'es': ':noel_tono_de_piel_claro_medio:',
        'fr': ':santa_peau_moyennement_claire:',
        'ja': u':サンタさん_やや薄い肌色:',
        'ko': u':산타_연한_갈색_피부:',
        'pt': ':noel_pele_morena_clara:',
        'it': ':santa_claus_carnagione_abbastanza_chiara:',
        'fa': u':نوئل_پوست_روشن:',
        'id': ':manusia_sinterklas_warna_kulit_cerah-sedang:',
        'zh': u':圣诞人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F384': { # 🧑🏽‍🎄
        'en' : ':mx_claus_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':weihnachtsperson_mittlere_hautfarbe:',
        'es': ':noel_tono_de_piel_medio:',
        'fr': u':santa_peau_légèrement_mate:',
        'ja': u':サンタさん_中間の肌色:',
        'ko': u':산타_갈색_피부:',
        'pt': ':noel_pele_morena:',
        'it': ':santa_claus_carnagione_olivastra:',
        'fa': u':نوئل_پوست_طلایی:',
        'id': ':manusia_sinterklas_warna_kulit_sedang:',
        'zh': u':圣诞人_中等肤色:'
    },
    u'\U0001F485': { # 💅
        'en' : ':nail_polish:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':nail_care:'],
        'de': ':nagellack:',
        'es': u':pintarse_las_uñas:',
        'fr': u':vernis_à_ongles:',
        'ja': u':マニキュアを塗る手:',
        'ko': u':매니큐어:',
        'pt': ':esmalte_de_unha:',
        'it': ':smalto_per_unghie:',
        'fa': u':لاک_زدن:',
        'id': ':poles_kuku:',
        'zh': u':涂指甲油:'
    },
    u'\U0001F485\U0001F3FF': { # 💅🏿
        'en' : ':nail_polish_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nagellack_dunkle_hautfarbe:',
        'es': u':pintarse_las_uñas_tono_de_piel_oscuro:',
        'fr': u':vernis_à_ongles_peau_foncée:',
        'ja': u':マニキュアを塗る手_濃い肌色:',
        'ko': u':매니큐어_검은색_피부:',
        'pt': ':esmalte_de_unha_pele_escura:',
        'it': ':smalto_per_unghie_carnagione_scura:',
        'fa': u':لاک_زدن_پوست_آبنوسی:',
        'id': ':poles_kuku_warna_kulit_gelap:',
        'zh': u':涂指甲油_较深肤色:'
    },
    u'\U0001F485\U0001F3FB': { # 💅🏻
        'en' : ':nail_polish_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nagellack_helle_hautfarbe:',
        'es': u':pintarse_las_uñas_tono_de_piel_claro:',
        'fr': u':vernis_à_ongles_peau_claire:',
        'ja': u':マニキュアを塗る手_薄い肌色:',
        'ko': u':매니큐어_하얀_피부:',
        'pt': ':esmalte_de_unha_pele_clara:',
        'it': ':smalto_per_unghie_carnagione_chiara:',
        'fa': u':لاک_زدن_پوست_سفید:',
        'id': ':poles_kuku_warna_kulit_cerah:',
        'zh': u':涂指甲油_较浅肤色:'
    },
    u'\U0001F485\U0001F3FE': { # 💅🏾
        'en' : ':nail_polish_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nagellack_mitteldunkle_hautfarbe:',
        'es': u':pintarse_las_uñas_tono_de_piel_oscuro_medio:',
        'fr': u':vernis_à_ongles_peau_mate:',
        'ja': u':マニキュアを塗る手_やや濃い肌色:',
        'ko': u':매니큐어_진한_갈색_피부:',
        'pt': ':esmalte_de_unha_pele_morena_escura:',
        'it': ':smalto_per_unghie_carnagione_abbastanza_scura:',
        'fa': u':لاک_زدن_پوست_گندمی:',
        'id': ':poles_kuku_warna_kulit_gelap-sedang:',
        'zh': u':涂指甲油_中等深肤色:'
    },
    u'\U0001F485\U0001F3FC': { # 💅🏼
        'en' : ':nail_polish_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nagellack_mittelhelle_hautfarbe:',
        'es': u':pintarse_las_uñas_tono_de_piel_claro_medio:',
        'fr': u':vernis_à_ongles_peau_moyennement_claire:',
        'ja': u':マニキュアを塗る手_やや薄い肌色:',
        'ko': u':매니큐어_연한_갈색_피부:',
        'pt': ':esmalte_de_unha_pele_morena_clara:',
        'it': ':smalto_per_unghie_carnagione_abbastanza_chiara:',
        'fa': u':لاک_زدن_پوست_روشن:',
        'id': ':poles_kuku_warna_kulit_cerah-sedang:',
        'zh': u':涂指甲油_中等浅肤色:'
    },
    u'\U0001F485\U0001F3FD': { # 💅🏽
        'en' : ':nail_polish_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nagellack_mittlere_hautfarbe:',
        'es': u':pintarse_las_uñas_tono_de_piel_medio:',
        'fr': u':vernis_à_ongles_peau_légèrement_mate:',
        'ja': u':マニキュアを塗る手_中間の肌色:',
        'ko': u':매니큐어_갈색_피부:',
        'pt': ':esmalte_de_unha_pele_morena:',
        'it': ':smalto_per_unghie_carnagione_olivastra:',
        'fa': u':لاک_زدن_پوست_طلایی:',
        'id': ':poles_kuku_warna_kulit_sedang:',
        'zh': u':涂指甲油_中等肤色:'
    },
    u'\U0001F4DB': { # 📛
        'en' : ':name_badge:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':namensschild:',
        'es': ':etiqueta_identificativa:',
        'fr': ':badge_nominatif:',
        'ja': u':名札:',
        'ko': u':이름표:',
        'pt': u':crachá:',
        'it': ':tesserino_per_nome:',
        'fa': u':برچسب_نام:',
        'id': ':lencana_nama:',
        'zh': u':姓名牌:'
    },
    u'\U0001F3DE\U0000FE0F': { # 🏞️
        'en' : ':national_park:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':nationalpark:',
        'es': ':parque_nacional:',
        'fr': ':parc_national:',
        'ja': u':国立公園:',
        'ko': u':국립공원:',
        'pt': ':parque_nacional:',
        'it': ':parco_nazionale:',
        'fa': u':پارک_ملی:',
        'id': ':taman_nasional:',
        'zh': u':国家公园:'
    },
    u'\U0001F3DE': { # 🏞
        'en' : ':national_park:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':nationalpark:',
        'es': ':parque_nacional:',
        'fr': ':parc_national:',
        'ja': u':国立公園:',
        'ko': u':국립공원:',
        'pt': ':parque_nacional:',
        'it': ':parco_nazionale:',
        'fa': u':پارک_ملی:',
        'id': ':taman_nasional:',
        'zh': u':国家公园:'
    },
    u'\U0001F922': { # 🤢
        'en' : ':nauseated_face:',
        'status' : fully_qualified,
        'E' : 3,
        'de': u':würgendes_gesicht:',
        'es': u':cara_de_náuseas:',
        'fr': u':visage_nauséeux:',
        'ja': u':吐き気を催している顔:',
        'ko': u':구역질을_하는_얼굴:',
        'pt': ':rosto_nauseado:',
        'it': ':faccina_nauseata:',
        'fa': u':حالت_تهوع:',
        'id': ':mual:',
        'zh': u':恶心:'
    },
    u'\U0001F9FF': { # 🧿
        'en' : ':nazar_amulet:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':nazar-amulett:',
        'es': ':ojo_turco:',
        'fr': u':mauvais_œil:',
        'ja': u':ナザール・ボンジュウ:',
        'ko': u':악마의_눈:',
        'pt': ':olho_grego:',
        'it': ':occhio_di_allah:',
        'fa': u':نظرقربانی:',
        'id': ':jimat_nazar:',
        'zh': u':纳扎尔护身符:'
    },
    u'\U0001F454': { # 👔
        'en' : ':necktie:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':hemd_mit_krawatte:',
        'es': ':corbata:',
        'fr': ':cravate:',
        'ja': u':ネクタイ:',
        'ko': u':넥타이:',
        'pt': ':gravata:',
        'it': ':cravatta:',
        'fa': u':کراوات:',
        'id': ':dasi:',
        'zh': u':领带:'
    },
    u'\U0001F913': { # 🤓
        'en' : ':nerd_face:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':strebergesicht:',
        'es': u':cara_de_empollón:',
        'fr': ':visage_de_geek:',
        'ja': u':オタク:',
        'ko': u':모범생_얼굴:',
        'pt': ':rosto_de_nerd:',
        'it': ':faccina_nerd:',
        'fa': u':خوره:',
        'id': ':wajah_kutu_buku:',
        'zh': u':书呆子脸:'
    },
    u'\U0001FABA': { # 🪺
        'en' : ':nest_with_eggs:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':nest_mit_eiern:',
        'es': ':nido_con_huevos:',
        'fr': u':nid_avec_œufs:',
        'ja': u':鳥の卵と巣:',
        'ko': u':알이_들어_있는_둥지:',
        'pt': ':ninho_com_ovos:',
        'it': ':nido_con_uova:',
        'fa': u':آشیانه_با_تخم:',
        'id': ':sarang_dengan_telur:',
        'zh': u':有蛋的巢:'
    },
    u'\U0001FA86': { # 🪆
        'en' : ':nesting_dolls:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':matroschka:',
        'es': u':muñeca_rusa:',
        'fr': u':poupées_russes:',
        'ja': u':マトリョーシカ:',
        'ko': u':네스팅_인형:',
        'pt': ':boneca_russa:',
        'it': ':matrioska:',
        'fa': u':عروسک_تودرتو:',
        'id': ':boneka_bersarang:',
        'zh': u':套娃:'
    },
    u'\U0001F610': { # 😐
        'en' : ':neutral_face:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':neutrales_gesicht:',
        'es': ':cara_neutral:',
        'fr': ':visage_neutre:',
        'ja': u':ポーカーフェイス:',
        'ko': u':덤덤한_얼굴:',
        'pt': ':rosto_neutro:',
        'it': ':faccina_neutra:',
        'fa': u':خنثی:',
        'id': ':wajah_netral:',
        'zh': u':冷漠:'
    },
    u'\U0001F311': { # 🌑
        'en' : ':new_moon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':neumond:',
        'es': ':luna_nueva:',
        'fr': ':nouvelle_lune:',
        'ja': u':新月:',
        'ko': u':삭:',
        'pt': ':lua_nova:',
        'it': ':luna_nuova:',
        'fa': u':ماه_نو:',
        'id': ':bulan_baru:',
        'zh': u':朔月:'
    },
    u'\U0001F31A': { # 🌚
        'en' : ':new_moon_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':new_moon_with_face:'],
        'de': ':neumond_mit_gesicht:',
        'es': ':luna_nueva_con_cara:',
        'fr': ':nouvelle_lune_avec_visage:',
        'ja': u':顔のある新月:',
        'ko': u':얼굴이_있는_삭:',
        'pt': ':rosto_da_lua_nova:',
        'it': ':faccina_luna_nuova:',
        'fa': u':صورت_ماه_نو:',
        'id': ':wajah_bulan_baru:',
        'zh': u':微笑的朔月:'
    },
    u'\U0001F4F0': { # 📰
        'en' : ':newspaper:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':zeitung:',
        'es': u':periódico:',
        'fr': ':journal:',
        'ja': u':新聞:',
        'ko': u':신문:',
        'pt': ':jornal:',
        'it': ':quotidiano:',
        'fa': u':روزنامه:',
        'id': ':koran:',
        'zh': u':报纸:'
    },
    u'\U000023ED\U0000FE0F': { # ⏭️
        'en' : ':next_track_button:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':black_right__pointing_double_triangle_with_vertical_bar:'],
        'variant': True,
        'de': u':nächster_titel:',
        'es': ':pista_siguiente:',
        'fr': ':bouton_piste_suivante:',
        'ja': u':次の曲ボタン:',
        'ko': u':다음_트랙_버튼:',
        'pt': u':botão_de_próxima_faixa:',
        'it': ':traccia_successiva:',
        'fa': u':دکمه_آهنگ_بعدی:',
        'id': ':tombol_lagu_berikutnya:',
        'zh': u':下一个音轨按钮:'
    },
    u'\U000023ED': { # ⏭
        'en' : ':next_track_button:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':black_right__pointing_double_triangle_with_vertical_bar:'],
        'variant': True,
        'de': u':nächster_titel:',
        'es': ':pista_siguiente:',
        'fr': ':bouton_piste_suivante:',
        'ja': u':次の曲ボタン:',
        'ko': u':다음_트랙_버튼:',
        'pt': u':botão_de_próxima_faixa:',
        'it': ':traccia_successiva:',
        'fa': u':دکمهٔ_آهنگ_بعدی:',
        'id': ':tombol_lagu_berikutnya:',
        'zh': u':下一个音轨按钮:'
    },
    u'\U0001F303': { # 🌃
        'en' : ':night_with_stars:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':sternenhimmel:',
        'es': ':noche_estrellada:',
        'fr': u':nuit_étoilée:',
        'ja': u':夜の都会:',
        'ko': u':밤하늘_별:',
        'pt': ':noite_estrelada:',
        'it': ':notte_stellata:',
        'fa': u':شب_پرستاره:',
        'id': ':malam_berbintang:',
        'zh': u':夜晚:'
    },
    u'\U0001F564': { # 🕤
        'en' : ':nine-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock930:'],
        'variant': True,
        'de': ':9.30_uhr:',
        'es': ':nueve_y_media:',
        'fr': ':neuf_heures_et_demie:',
        'ja': u':9時半:',
        'ko': u':아홉_시_반:',
        'pt': ':nove_e_meia:',
        'it': ':ore_nove_e_mezza:',
        'fa': u':ساعت_نه_و_نیم:',
        'id': ':jam_setengah_sepuluh:',
        'zh': u':九点半:'
    },
    u'\U0001F558': { # 🕘
        'en' : u':nine_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock9:'],
        'variant': True,
        'de': ':9.00_uhr:',
        'es': ':9_en_punto:',
        'fr': ':neuf_heures:',
        'ja': u':9時:',
        'ko': u':아홉_시:',
        'pt': ':9_horas:',
        'it': ':ore_nove:',
        'fa': u':ساعت_نه:',
        'id': ':jam_sembilan_tepat:',
        'zh': u':九点:'
    },
    u'\U0001F977': { # 🥷
        'en' : ':ninja:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':ninja:',
        'es': ':ninja:',
        'fr': ':ninja:',
        'ja': u':忍者:',
        'ko': u':닌자:',
        'pt': ':ninja:',
        'it': ':ninja:',
        'fa': u':نینجا:',
        'id': ':ninja:',
        'zh': u':忍者:'
    },
    u'\U0001F977\U0001F3FF': { # 🥷🏿
        'en' : ':ninja_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':ninja_dunkle_hautfarbe:',
        'es': ':ninja_tono_de_piel_oscuro:',
        'fr': u':ninja_peau_foncée:',
        'ja': u':忍者_濃い肌色:',
        'ko': u':닌자_검은색_피부:',
        'pt': ':ninja_pele_escura:',
        'it': ':ninja_carnagione_scura:',
        'fa': u':نینجا_پوست_آبنوسی:',
        'id': ':ninja_warna_kulit_gelap:',
        'zh': u':忍者_较深肤色:'
    },
    u'\U0001F977\U0001F3FB': { # 🥷🏻
        'en' : ':ninja_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':ninja_helle_hautfarbe:',
        'es': ':ninja_tono_de_piel_claro:',
        'fr': ':ninja_peau_claire:',
        'ja': u':忍者_薄い肌色:',
        'ko': u':닌자_하얀_피부:',
        'pt': ':ninja_pele_clara:',
        'it': ':ninja_carnagione_chiara:',
        'fa': u':نینجا_پوست_سفید:',
        'id': ':ninja_warna_kulit_cerah:',
        'zh': u':忍者_较浅肤色:'
    },
    u'\U0001F977\U0001F3FE': { # 🥷🏾
        'en' : ':ninja_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':ninja_mitteldunkle_hautfarbe:',
        'es': ':ninja_tono_de_piel_oscuro_medio:',
        'fr': ':ninja_peau_mate:',
        'ja': u':忍者_やや濃い肌色:',
        'ko': u':닌자_진한_갈색_피부:',
        'pt': ':ninja_pele_morena_escura:',
        'it': ':ninja_carnagione_abbastanza_scura:',
        'fa': u':نینجا_پوست_گندمی:',
        'id': ':ninja_warna_kulit_gelap-sedang:',
        'zh': u':忍者_中等深肤色:'
    },
    u'\U0001F977\U0001F3FC': { # 🥷🏼
        'en' : ':ninja_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':ninja_mittelhelle_hautfarbe:',
        'es': ':ninja_tono_de_piel_claro_medio:',
        'fr': ':ninja_peau_moyennement_claire:',
        'ja': u':忍者_やや薄い肌色:',
        'ko': u':닌자_연한_갈색_피부:',
        'pt': ':ninja_pele_morena_clara:',
        'it': ':ninja_carnagione_abbastanza_chiara:',
        'fa': u':نینجا_پوست_روشن:',
        'id': ':ninja_warna_kulit_cerah-sedang:',
        'zh': u':忍者_中等浅肤色:'
    },
    u'\U0001F977\U0001F3FD': { # 🥷🏽
        'en' : ':ninja_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':ninja_mittlere_hautfarbe:',
        'es': ':ninja_tono_de_piel_medio:',
        'fr': u':ninja_peau_légèrement_mate:',
        'ja': u':忍者_中間の肌色:',
        'ko': u':닌자_갈색_피부:',
        'pt': ':ninja_pele_morena:',
        'it': ':ninja_carnagione_olivastra:',
        'fa': u':نینجا_پوست_طلایی:',
        'id': ':ninja_warna_kulit_sedang:',
        'zh': u':忍者_中等肤色:'
    },
    u'\U0001F6B3': { # 🚳
        'en' : ':no_bicycles:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':fahrräder_verboten:',
        'es': ':bicicletas_prohibidas:',
        'fr': u':vélos_interdits:',
        'ja': u':自転車禁止:',
        'ko': u':자전거_금지:',
        'pt': ':proibido_andar_de_bicicleta:',
        'it': ':segnale_di_divieto_di_transito_delle_biciclette:',
        'fa': u':دوچرخه_ممنوع:',
        'id': ':dilarang_bersepeda:',
        'zh': u':禁止自行车:'
    },
    u'\U000026D4': { # ⛔
        'en' : ':no_entry:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':zutritt_verboten:',
        'es': u':dirección_prohibida:',
        'fr': ':sens_interdit:',
        'ja': u':車両進入禁止:',
        'ko': u':진입_금지:',
        'pt': ':entrada_proibida:',
        'it': ':segnale_di_divieto_di_accesso:',
        'fa': u':ورود_ممنوع:',
        'id': ':dilarang_masuk:',
        'zh': u':禁止通行:'
    },
    u'\U0001F6AF': { # 🚯
        'en' : ':no_littering:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':do_not_litter:'],
        'de': ':abfall_verboten:',
        'es': ':prohibido_tirar_basura:',
        'fr': u':dépôt_d’ordures_interdit:',
        'ja': u':ポイ捨て禁止:',
        'ko': u':쓰레기_투기_금지:',
        'pt': u':proibido_jogar_lixo_no_chão:',
        'it': ':simbolo_del_divieto_di_gettare_rifiuti:',
        'fa': u':ریختن_زباله_ممنوع:',
        'id': ':dilarang_membuang_sampah_sembarangan:',
        'zh': u':禁止乱扔垃圾:'
    },
    u'\U0001F4F5': { # 📵
        'en' : ':no_mobile_phones:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mobiltelefone_verboten:',
        'es': u':prohibido_el_uso_de_móviles:',
        'fr': u':téléphones_portables_interdits:',
        'ja': u':携帯電話禁止:',
        'ko': u':휴대전화_사용금지:',
        'pt': ':proibido_o_uso_de_telefone_celular:',
        'it': u':simbolo_che_vieta_l’uso_dei_cellulari:',
        'fa': u':تلفن_همراه_ممنوع:',
        'id': ':dilarang_menggunakan_ponsel:',
        'zh': u':禁止使用手机:'
    },
    u'\U0001F51E': { # 🔞
        'en' : ':no_one_under_eighteen:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':underage:'],
        'de': u':minderjährige_verboten:',
        'es': u':prohibido_para_menos_de_18_años:',
        'fr': ':18_ans_et_plus:',
        'ja': u':18歳未満禁止:',
        'ko': u':성인용:',
        'pt': ':proibido_para_menores_de_18_anos:',
        'it': ':simbolo_di_divieto_ai_minorenni:',
        'fa': u':زیر_۱۸_سال_ممنوع:',
        'id': ':di_bawah_18_tahun_dilarang:',
        'zh': u':18禁:'
    },
    u'\U0001F6B7': { # 🚷
        'en' : ':no_pedestrians:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':fußgänger_verboten:',
        'es': ':prohibido_el_paso_de_peatones:',
        'fr': u':interdit_aux_piétons:',
        'ja': u':歩行者立入禁止:',
        'ko': u':보행자_금지:',
        'pt': ':proibida_a_passagem_de_pedestres:',
        'it': ':simbolo_del_divieto_di_transito_pedoni:',
        'fa': u':عابر_پیاده_ممنوع:',
        'id': ':pejalan_kaki_dilarang_masuk:',
        'zh': u':禁止行人通行:'
    },
    u'\U0001F6AD': { # 🚭
        'en' : ':no_smoking:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':rauchverbot:',
        'es': ':prohibido_fumar:',
        'fr': ':interdiction_de_fumer:',
        'ja': u':禁煙:',
        'ko': u':금연_신호:',
        'pt': ':proibido_fumar:',
        'it': ':segnale_di_vietato_fumare:',
        'fa': u':سیگار_کشیدن_ممنوع:',
        'id': ':dilarang_merokok:',
        'zh': u':禁止吸烟:'
    },
    u'\U0001F6B1': { # 🚱
        'en' : ':non-potable_water:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':non__potable_water:'],
        'de': ':kein_trinkwasser:',
        'es': ':agua_no_potable:',
        'fr': ':eau_non_potable:',
        'ja': u':飲用不可:',
        'ko': u':마실_수_없는_물:',
        'pt': u':água_não_potável:',
        'it': ':simbolo_di_acqua_non_potabile:',
        'fa': u':آب_غیرآشامیدنی:',
        'id': ':air_tidak_dapat_diminum:',
        'zh': u':非饮用水:'
    },
    u'\U0001F443': { # 👃
        'en' : ':nose:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':nase:',
        'es': ':nariz:',
        'fr': ':nez:',
        'ja': u':鼻:',
        'ko': u':코:',
        'pt': ':nariz:',
        'it': ':naso:',
        'fa': u':بینی:',
        'id': ':hidung:',
        'zh': u':鼻子:'
    },
    u'\U0001F443\U0001F3FF': { # 👃🏿
        'en' : ':nose_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nase_dunkle_hautfarbe:',
        'es': ':nariz_tono_de_piel_oscuro:',
        'fr': u':nez_peau_foncée:',
        'ja': u':鼻_濃い肌色:',
        'ko': u':코_검은색_피부:',
        'pt': ':nariz_pele_escura:',
        'it': ':naso_carnagione_scura:',
        'fa': u':بینی_پوست_آبنوسی:',
        'id': ':hidung_warna_kulit_gelap:',
        'zh': u':鼻子_较深肤色:'
    },
    u'\U0001F443\U0001F3FB': { # 👃🏻
        'en' : ':nose_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nase_helle_hautfarbe:',
        'es': ':nariz_tono_de_piel_claro:',
        'fr': ':nez_peau_claire:',
        'ja': u':鼻_薄い肌色:',
        'ko': u':코_하얀_피부:',
        'pt': ':nariz_pele_clara:',
        'it': ':naso_carnagione_chiara:',
        'fa': u':بینی_پوست_سفید:',
        'id': ':hidung_warna_kulit_cerah:',
        'zh': u':鼻子_较浅肤色:'
    },
    u'\U0001F443\U0001F3FE': { # 👃🏾
        'en' : ':nose_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nase_mitteldunkle_hautfarbe:',
        'es': ':nariz_tono_de_piel_oscuro_medio:',
        'fr': ':nez_peau_mate:',
        'ja': u':鼻_やや濃い肌色:',
        'ko': u':코_진한_갈색_피부:',
        'pt': ':nariz_pele_morena_escura:',
        'it': ':naso_carnagione_abbastanza_scura:',
        'fa': u':بینی_پوست_گندمی:',
        'id': ':hidung_warna_kulit_gelap-sedang:',
        'zh': u':鼻子_中等深肤色:'
    },
    u'\U0001F443\U0001F3FC': { # 👃🏼
        'en' : ':nose_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nase_mittelhelle_hautfarbe:',
        'es': ':nariz_tono_de_piel_claro_medio:',
        'fr': ':nez_peau_moyennement_claire:',
        'ja': u':鼻_やや薄い肌色:',
        'ko': u':코_연한_갈색_피부:',
        'pt': ':nariz_pele_morena_clara:',
        'it': ':naso_carnagione_abbastanza_chiara:',
        'fa': u':بینی_پوست_روشن:',
        'id': ':hidung_warna_kulit_cerah-sedang:',
        'zh': u':鼻子_中等浅肤色:'
    },
    u'\U0001F443\U0001F3FD': { # 👃🏽
        'en' : ':nose_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':nase_mittlere_hautfarbe:',
        'es': ':nariz_tono_de_piel_medio:',
        'fr': u':nez_peau_légèrement_mate:',
        'ja': u':鼻_中間の肌色:',
        'ko': u':코_갈색_피부:',
        'pt': ':nariz_pele_morena:',
        'it': ':naso_carnagione_olivastra:',
        'fa': u':بینی_پوست_طلایی:',
        'id': ':hidung_warna_kulit_sedang:',
        'zh': u':鼻子_中等肤色:'
    },
    u'\U0001F4D3': { # 📓
        'en' : ':notebook:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':notizbuch:',
        'es': ':cuaderno:',
        'fr': ':carnet:',
        'ja': u':ノート:',
        'ko': u':공책:',
        'pt': ':caderno:',
        'it': ':quaderno:',
        'fa': u':دفتر_یادداشت:',
        'id': ':buku_catatan:',
        'zh': u':笔记本:'
    },
    u'\U0001F4D4': { # 📔
        'en' : ':notebook_with_decorative_cover:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':notizbuch_mit_dekorativem_einband:',
        'es': ':cuaderno_con_tapa_decorativa:',
        'fr': ':carnet_avec_couverture:',
        'ja': u':表紙付きノート:',
        'ko': u':표지가_있는_노트:',
        'pt': ':caderno_decorado:',
        'it': ':quaderno_con_copertina_decorata:',
        'fa': u':دفتر_با_جلد_سخت:',
        'id': ':buku_catatan_bersampul:',
        'zh': u':精装笔记本:'
    },
    u'\U0001F529': { # 🔩
        'en' : ':nut_and_bolt:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':mutter_und_schraube:',
        'es': ':tornillo_y_tuerca:',
        'fr': u':vis_et_écrou:',
        'ja': u':ボルトとナット:',
        'ko': u':볼트와_너트:',
        'pt': ':porca_e_parafuso:',
        'it': ':vite_e_bullone:',
        'fa': u':پیچ_و_مهره:',
        'id': ':mur_dan_baut:',
        'zh': u':螺母与螺栓:'
    },
    u'\U0001F419': { # 🐙
        'en' : ':octopus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':oktopus:',
        'es': ':pulpo:',
        'fr': ':pieuvre:',
        'ja': u':タコ:',
        'ko': u':문어:',
        'pt': ':polvo:',
        'it': ':polpo:',
        'fa': u':هشت_پا:',
        'id': ':gurita:',
        'zh': u':章鱼:'
    },
    u'\U0001F362': { # 🍢
        'en' : ':oden:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':oden:',
        'es': ':brocheta:',
        'fr': ':brochette_de_poisson:',
        'ja': u':おでん:',
        'ko': u':오뎅:',
        'pt': ':oden:',
        'it': ':oden_giapponese:',
        'fa': u':اودن:',
        'id': ':oden:',
        'zh': u':关东煮:'
    },
    u'\U0001F3E2': { # 🏢
        'en' : ':office_building:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':office:'],
        'de': u':bürogebäude:',
        'es': ':edificio_de_oficinas:',
        'fr': ':immeuble_de_bureaux:',
        'ja': u':オフィスビル:',
        'ko': u':빌딩:',
        'pt': u':edifício_comercial:',
        'it': ':edificio:',
        'fa': u':ساختمان_اداری:',
        'id': ':gedung_perkantoran:',
        'zh': u':办公楼:'
    },
    u'\U0001F9D1\U0000200D\U0001F4BC': { # 🧑‍💼
        'en' : ':office_worker:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':büroangestellte(r):',
        'es': ':oficinista:',
        'fr': u':employé_de_bureau_(tous_genres):',
        'ja': u':会社員:',
        'ko': u':회사원:',
        'pt': u':trabalhador_de_escritório:',
        'it': u':persona_che_fa_un_lavoro_d’ufficio:',
        'fa': u':کارمند:',
        'id': ':pekerja_kantoran:',
        'zh': u':白领:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F4BC': { # 🧑🏿‍💼
        'en' : ':office_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':büroangestellte(r)_dunkle_hautfarbe:',
        'es': ':oficinista_tono_de_piel_oscuro:',
        'fr': u':employé_de_bureau_(tous_genres)_peau_foncée:',
        'ja': u':会社員_濃い肌色:',
        'ko': u':회사원_검은색_피부:',
        'pt': u':trabalhador_de_escritório_pele_escura:',
        'it': u':persona_che_fa_un_lavoro_d’ufficio_carnagione_scura:',
        'fa': u':کارمند_پوست_آبنوسی:',
        'id': ':pekerja_kantoran_warna_kulit_gelap:',
        'zh': u':白领_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F4BC': { # 🧑🏻‍💼
        'en' : ':office_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':büroangestellte(r)_helle_hautfarbe:',
        'es': ':oficinista_tono_de_piel_claro:',
        'fr': u':employé_de_bureau_(tous_genres)_peau_claire:',
        'ja': u':会社員_薄い肌色:',
        'ko': u':회사원_하얀_피부:',
        'pt': u':trabalhador_de_escritório_pele_clara:',
        'it': u':persona_che_fa_un_lavoro_d’ufficio_carnagione_chiara:',
        'fa': u':کارمند_پوست_سفید:',
        'id': ':pekerja_kantoran_warna_kulit_cerah:',
        'zh': u':白领_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F4BC': { # 🧑🏾‍💼
        'en' : ':office_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':büroangestellte(r)_mitteldunkle_hautfarbe:',
        'es': ':oficinista_tono_de_piel_oscuro_medio:',
        'fr': u':employé_de_bureau_(tous_genres)_peau_mate:',
        'ja': u':会社員_やや濃い肌色:',
        'ko': u':회사원_진한_갈색_피부:',
        'pt': u':trabalhador_de_escritório_pele_morena_escura:',
        'it': u':persona_che_fa_un_lavoro_d’ufficio_carnagione_abbastanza_scura:',
        'fa': u':کارمند_پوست_گندمی:',
        'id': ':pekerja_kantoran_warna_kulit_gelap-sedang:',
        'zh': u':白领_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F4BC': { # 🧑🏼‍💼
        'en' : ':office_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':büroangestellte(r)_mittelhelle_hautfarbe:',
        'es': ':oficinista_tono_de_piel_claro_medio:',
        'fr': u':employé_de_bureau_(tous_genres)_peau_moyennement_claire:',
        'ja': u':会社員_やや薄い肌色:',
        'ko': u':회사원_연한_갈색_피부:',
        'pt': u':trabalhador_de_escritório_pele_morena_clara:',
        'it': u':persona_che_fa_un_lavoro_d’ufficio_carnagione_abbastanza_chiara:',
        'fa': u':کارمند_پوست_روشن:',
        'id': ':pekerja_kantoran_warna_kulit_cerah-sedang:',
        'zh': u':白领_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F4BC': { # 🧑🏽‍💼
        'en' : ':office_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':büroangestellte(r)_mittlere_hautfarbe:',
        'es': ':oficinista_tono_de_piel_medio:',
        'fr': u':employé_de_bureau_(tous_genres)_peau_légèrement_mate:',
        'ja': u':会社員_中間の肌色:',
        'ko': u':회사원_갈색_피부:',
        'pt': u':trabalhador_de_escritório_pele_morena:',
        'it': u':persona_che_fa_un_lavoro_d’ufficio_carnagione_olivastra:',
        'fa': u':کارمند_پوست_طلایی:',
        'id': ':pekerja_kantoran_warna_kulit_sedang:',
        'zh': u':白领_中等肤色:'
    },
    u'\U0001F479': { # 👹
        'en' : ':ogre:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':japanese_ogre:'],
        'de': ':ungeheuer:',
        'es': u':demonio_japonés_oni:',
        'fr': ':ogre:',
        'ja': u':鬼:',
        'ko': u':도깨비_가면:',
        'pt': ':ogro:',
        'it': ':orco:',
        'fa': u':دیو:',
        'id': ':wajah_monster:',
        'zh': u':食人魔:'
    },
    u'\U0001F6E2\U0000FE0F': { # 🛢️
        'en' : ':oil_drum:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':ölfass:',
        'es': u':barril_de_petróleo:',
        'fr': u':baril_de_pétrole:',
        'ja': u':ドラム缶:',
        'ko': u':기름통:',
        'pt': u':barril_de_óleo:',
        'it': ':barile_di_petrolio:',
        'fa': u':بشکه_نفت:',
        'id': ':drum_minyak:',
        'zh': u':石油桶:'
    },
    u'\U0001F6E2': { # 🛢
        'en' : ':oil_drum:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':ölfass:',
        'es': u':barril_de_petróleo:',
        'fr': u':baril_de_pétrole:',
        'ja': u':ドラム缶:',
        'ko': u':기름통:',
        'pt': u':barril_de_óleo:',
        'it': ':barile_di_petrolio:',
        'fa': u':بشکه_نفت:',
        'id': ':drum_minyak:',
        'zh': u':石油桶:'
    },
    u'\U0001F5DD\U0000FE0F': { # 🗝️
        'en' : ':old_key:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':alter_schlüssel:',
        'es': ':llave_antigua:',
        'fr': u':clé_ancienne:',
        'ja': u':古い鍵:',
        'ko': u':오래된_열쇠:',
        'pt': ':chave_antiga:',
        'it': ':chiave_antica:',
        'fa': u':کلید_قدیمی:',
        'id': ':kunci_antik:',
        'zh': u':老式钥匙:'
    },
    u'\U0001F5DD': { # 🗝
        'en' : ':old_key:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':alter_schlüssel:',
        'es': ':llave_antigua:',
        'fr': u':clé_ancienne:',
        'ja': u':古い鍵:',
        'ko': u':오래된_열쇠:',
        'pt': ':chave_antiga:',
        'it': ':chiave_antica:',
        'fa': u':کلید_قدیمی:',
        'id': ':kunci_antik:',
        'zh': u':老式钥匙:'
    },
    u'\U0001F474': { # 👴
        'en' : ':old_man:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':older_man:'],
        'de': u':älterer_mann:',
        'es': ':anciano:',
        'fr': u':homme_âgé:',
        'ja': u':おじいさん:',
        'ko': u':할아버지:',
        'pt': ':homem_idoso:',
        'it': ':uomo_anziano:',
        'fa': u':پیرمرد:',
        'id': ':pria_tua:',
        'zh': u':老爷爷:'
    },
    u'\U0001F474\U0001F3FF': { # 👴🏿
        'en' : ':old_man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':älterer_mann_dunkle_hautfarbe:',
        'es': ':anciano_tono_de_piel_oscuro:',
        'fr': u':homme_âgé_peau_foncée:',
        'ja': u':おじいさん_濃い肌色:',
        'ko': u':할아버지_검은색_피부:',
        'pt': ':homem_idoso_pele_escura:',
        'it': ':uomo_anziano_carnagione_scura:',
        'fa': u':پیرمرد_پوست_آبنوسی:',
        'id': ':pria_tua_warna_kulit_gelap:',
        'zh': u':老爷爷_较深肤色:'
    },
    u'\U0001F474\U0001F3FB': { # 👴🏻
        'en' : ':old_man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':älterer_mann_helle_hautfarbe:',
        'es': ':anciano_tono_de_piel_claro:',
        'fr': u':homme_âgé_peau_claire:',
        'ja': u':おじいさん_薄い肌色:',
        'ko': u':할아버지_하얀_피부:',
        'pt': ':homem_idoso_pele_clara:',
        'it': ':uomo_anziano_carnagione_chiara:',
        'fa': u':پیرمرد_پوست_سفید:',
        'id': ':pria_tua_warna_kulit_cerah:',
        'zh': u':老爷爷_较浅肤色:'
    },
    u'\U0001F474\U0001F3FE': { # 👴🏾
        'en' : ':old_man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':älterer_mann_mitteldunkle_hautfarbe:',
        'es': ':anciano_tono_de_piel_oscuro_medio:',
        'fr': u':homme_âgé_peau_mate:',
        'ja': u':おじいさん_やや濃い肌色:',
        'ko': u':할아버지_진한_갈색_피부:',
        'pt': ':homem_idoso_pele_morena_escura:',
        'it': ':uomo_anziano_carnagione_abbastanza_scura:',
        'fa': u':پیرمرد_پوست_گندمی:',
        'id': ':pria_tua_warna_kulit_gelap-sedang:',
        'zh': u':老爷爷_中等深肤色:'
    },
    u'\U0001F474\U0001F3FC': { # 👴🏼
        'en' : ':old_man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':älterer_mann_mittelhelle_hautfarbe:',
        'es': ':anciano_tono_de_piel_claro_medio:',
        'fr': u':homme_âgé_peau_moyennement_claire:',
        'ja': u':おじいさん_やや薄い肌色:',
        'ko': u':할아버지_연한_갈색_피부:',
        'pt': ':homem_idoso_pele_morena_clara:',
        'it': ':uomo_anziano_carnagione_abbastanza_chiara:',
        'fa': u':پیرمرد_پوست_روشن:',
        'id': ':pria_tua_warna_kulit_cerah-sedang:',
        'zh': u':老爷爷_中等浅肤色:'
    },
    u'\U0001F474\U0001F3FD': { # 👴🏽
        'en' : ':old_man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':älterer_mann_mittlere_hautfarbe:',
        'es': ':anciano_tono_de_piel_medio:',
        'fr': u':homme_âgé_peau_légèrement_mate:',
        'ja': u':おじいさん_中間の肌色:',
        'ko': u':할아버지_갈색_피부:',
        'pt': ':homem_idoso_pele_morena:',
        'it': ':uomo_anziano_carnagione_olivastra:',
        'fa': u':پیرمرد_پوست_طلایی:',
        'id': ':pria_tua_warna_kulit_sedang:',
        'zh': u':老爷爷_中等肤色:'
    },
    u'\U0001F475': { # 👵
        'en' : ':old_woman:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':older_woman:'],
        'de': u':ältere_frau:',
        'es': ':anciana:',
        'fr': u':femme_âgée:',
        'ja': u':おばあさん:',
        'ko': u':할머니:',
        'pt': ':idosa:',
        'it': ':donna_anziana:',
        'fa': u':پیرزن:',
        'id': ':wanita_tua:',
        'zh': u':老奶奶:'
    },
    u'\U0001F475\U0001F3FF': { # 👵🏿
        'en' : ':old_woman_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':ältere_frau_dunkle_hautfarbe:',
        'es': ':anciana_tono_de_piel_oscuro:',
        'fr': u':femme_âgée_peau_foncée:',
        'ja': u':おばあさん_濃い肌色:',
        'ko': u':할머니_검은색_피부:',
        'pt': ':idosa_pele_escura:',
        'it': ':donna_anziana_carnagione_scura:',
        'fa': u':پیرزن_پوست_آبنوسی:',
        'id': ':wanita_tua_warna_kulit_gelap:',
        'zh': u':老奶奶_较深肤色:'
    },
    u'\U0001F475\U0001F3FB': { # 👵🏻
        'en' : ':old_woman_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':ältere_frau_helle_hautfarbe:',
        'es': ':anciana_tono_de_piel_claro:',
        'fr': u':femme_âgée_peau_claire:',
        'ja': u':おばあさん_薄い肌色:',
        'ko': u':할머니_하얀_피부:',
        'pt': ':idosa_pele_clara:',
        'it': ':donna_anziana_carnagione_chiara:',
        'fa': u':پیرزن_پوست_سفید:',
        'id': ':wanita_tua_warna_kulit_cerah:',
        'zh': u':老奶奶_较浅肤色:'
    },
    u'\U0001F475\U0001F3FE': { # 👵🏾
        'en' : ':old_woman_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':ältere_frau_mitteldunkle_hautfarbe:',
        'es': ':anciana_tono_de_piel_oscuro_medio:',
        'fr': u':femme_âgée_peau_mate:',
        'ja': u':おばあさん_やや濃い肌色:',
        'ko': u':할머니_진한_갈색_피부:',
        'pt': ':idosa_pele_morena_escura:',
        'it': ':donna_anziana_carnagione_abbastanza_scura:',
        'fa': u':پیرزن_پوست_گندمی:',
        'id': ':wanita_tua_warna_kulit_gelap-sedang:',
        'zh': u':老奶奶_中等深肤色:'
    },
    u'\U0001F475\U0001F3FC': { # 👵🏼
        'en' : ':old_woman_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':ältere_frau_mittelhelle_hautfarbe:',
        'es': ':anciana_tono_de_piel_claro_medio:',
        'fr': u':femme_âgée_peau_moyennement_claire:',
        'ja': u':おばあさん_やや薄い肌色:',
        'ko': u':할머니_연한_갈색_피부:',
        'pt': ':idosa_pele_morena_clara:',
        'it': ':donna_anziana_carnagione_abbastanza_chiara:',
        'fa': u':پیرزن_پوست_روشن:',
        'id': ':wanita_tua_warna_kulit_cerah-sedang:',
        'zh': u':老奶奶_中等浅肤色:'
    },
    u'\U0001F475\U0001F3FD': { # 👵🏽
        'en' : ':old_woman_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':ältere_frau_mittlere_hautfarbe:',
        'es': ':anciana_tono_de_piel_medio:',
        'fr': u':femme_âgée_peau_légèrement_mate:',
        'ja': u':おばあさん_中間の肌色:',
        'ko': u':할머니_갈색_피부:',
        'pt': ':idosa_pele_morena:',
        'it': ':donna_anziana_carnagione_olivastra:',
        'fa': u':پیرزن_پوست_طلایی:',
        'id': ':wanita_tua_warna_kulit_sedang:',
        'zh': u':老奶奶_中等肤色:'
    },
    u'\U0001F9D3': { # 🧓
        'en' : ':older_person:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':older_adult:'],
        'de': u':ältere_person:',
        'es': ':persona_mayor:',
        'fr': u':personne_âgée:',
        'ja': u':お年寄り:',
        'ko': u':노인:',
        'pt': ':idoso:',
        'it': ':persona_anziana:',
        'fa': u':میان_سال:',
        'id': ':lanjut_usia:',
        'zh': u':老年人:'
    },
    u'\U0001F9D3\U0001F3FF': { # 🧓🏿
        'en' : ':older_person_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':älterer_erwachsener_dunkle_hautfarbe:',
        'es': ':persona_adulta_madura_tono_de_piel_oscuro:',
        'fr': u':personne_âgée_peau_foncée:',
        'ja': u':お年寄り_濃い肌色:',
        'ko': u':노인_검은색_피부:',
        'pt': ':idoso_pele_escura:',
        'it': ':persona_anziana_carnagione_scura:',
        'fa': u':میان_سال_پوست_آبنوسی:',
        'id': ':lanjut_usia_warna_kulit_gelap:',
        'zh': u':老年人_较深肤色:'
    },
    u'\U0001F9D3\U0001F3FB': { # 🧓🏻
        'en' : ':older_person_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':älterer_erwachsener_helle_hautfarbe:',
        'es': ':persona_adulta_madura_tono_de_piel_claro:',
        'fr': u':personne_âgée_peau_claire:',
        'ja': u':お年寄り_薄い肌色:',
        'ko': u':노인_하얀_피부:',
        'pt': ':idoso_pele_clara:',
        'it': ':persona_anziana_carnagione_chiara:',
        'fa': u':میان_سال_پوست_سفید:',
        'id': ':lanjut_usia_warna_kulit_cerah:',
        'zh': u':老年人_较浅肤色:'
    },
    u'\U0001F9D3\U0001F3FE': { # 🧓🏾
        'en' : ':older_person_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':älterer_erwachsener_mitteldunkle_hautfarbe:',
        'es': ':persona_adulta_madura_tono_de_piel_oscuro_medio:',
        'fr': u':personne_âgée_peau_mate:',
        'ja': u':お年寄り_やや濃い肌色:',
        'ko': u':노인_진한_갈색_피부:',
        'pt': ':idoso_pele_morena_escura:',
        'it': ':persona_anziana_carnagione_abbastanza_scura:',
        'fa': u':میان_سال_پوست_گندمی:',
        'id': ':lanjut_usia_warna_kulit_gelap-sedang:',
        'zh': u':老年人_中等深肤色:'
    },
    u'\U0001F9D3\U0001F3FC': { # 🧓🏼
        'en' : ':older_person_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':älterer_erwachsener_mittelhelle_hautfarbe:',
        'es': ':persona_adulta_madura_tono_de_piel_claro_medio:',
        'fr': u':personne_âgée_peau_moyennement_claire:',
        'ja': u':お年寄り_やや薄い肌色:',
        'ko': u':노인_연한_갈색_피부:',
        'pt': ':idoso_pele_morena_clara:',
        'it': ':persona_anziana_carnagione_abbastanza_chiara:',
        'fa': u':میان_سال_پوست_روشن:',
        'id': ':lanjut_usia_warna_kulit_cerah-sedang:',
        'zh': u':老年人_中等浅肤色:'
    },
    u'\U0001F9D3\U0001F3FD': { # 🧓🏽
        'en' : ':older_person_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':älterer_erwachsener_mittlere_hautfarbe:',
        'es': ':persona_adulta_madura_tono_de_piel_medio:',
        'fr': u':personne_âgée_peau_légèrement_mate:',
        'ja': u':お年寄り_中間の肌色:',
        'ko': u':노인_갈색_피부:',
        'pt': ':idoso_pele_morena:',
        'it': ':persona_anziana_carnagione_olivastra:',
        'fa': u':میان_سال_پوست_طلایی:',
        'id': ':lanjut_usia_warna_kulit_sedang:',
        'zh': u':老年人_中等肤色:'
    },
    u'\U0001FAD2': { # 🫒
        'en' : ':olive:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':olive:',
        'es': ':aceituna:',
        'fr': ':olive:',
        'ja': u':オリーブ:',
        'ko': u':올리브:',
        'pt': ':azeitona:',
        'it': ':oliva:',
        'fa': u':زیتون:',
        'id': ':zaitun:',
        'zh': u':橄榄:'
    },
    u'\U0001F549\U0000FE0F': { # 🕉️
        'en' : ':om:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':om_symbol:'],
        'variant': True,
        'de': ':om:',
        'es': ':om:',
        'fr': ':om:',
        'ja': u':オーム:',
        'ko': u':옴:',
        'pt': ':om:',
        'it': ':om:',
        'fa': u':ام:',
        'id': ':om:',
        'zh': u':奥姆:'
    },
    u'\U0001F549': { # 🕉
        'en' : ':om:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':om_symbol:'],
        'variant': True,
        'de': ':om:',
        'es': ':om:',
        'fr': ':om:',
        'ja': u':オーム:',
        'ko': u':옴:',
        'pt': ':om:',
        'it': ':om:',
        'fa': u':اُم:',
        'id': ':om:',
        'zh': u':奥姆:'
    },
    u'\U0001F698': { # 🚘
        'en' : ':oncoming_automobile:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':auto_von_vorne:',
        'es': u':coche_próximo:',
        'fr': ':voiture_de_face:',
        'ja': u':自動車正面:',
        'ko': u':오고_있는_자동차:',
        'pt': ':carro_se_aproximando:',
        'it': ':auto_in_arrivo:',
        'fa': u':خودرویی_که_نزدیک_می_شود:',
        'id': ':mobil_datang:',
        'zh': u':迎面驶来的汽车:'
    },
    u'\U0001F68D': { # 🚍
        'en' : ':oncoming_bus:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':bus_von_vorne:',
        'es': u':autobús_próximo:',
        'fr': ':bus_de_face:',
        'ja': u':バス正面:',
        'ko': u':오고_있는_버스:',
        'pt': u':ônibus_se_aproximando:',
        'it': ':bus_in_arrivo:',
        'fa': u':اتوبوس_روبه_جلو:',
        'id': ':bus_datang:',
        'zh': u':迎面驶来的公交车:'
    },
    u'\U0001F44A': { # 👊
        'en' : ':oncoming_fist:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fist_oncoming:', ':punch:', ':facepunch:'],
        'de': ':geballte_faust:',
        'es': u':puño_cerrado:',
        'fr': ':poing_de_face:',
        'ja': u':グー:',
        'ko': u':주먹_전면:',
        'pt': ':soco:',
        'it': ':pugno_chiuso:',
        'fa': u':مشت_گره_کرده:',
        'id': ':tangan_terkepal_ke_depan:',
        'zh': u':出拳:'
    },
    u'\U0001F44A\U0001F3FF': { # 👊🏿
        'en' : ':oncoming_fist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':geballte_faust_dunkle_hautfarbe:',
        'es': u':puño_cerrado_tono_de_piel_oscuro:',
        'fr': u':poing_de_face_peau_foncée:',
        'ja': u':グー_濃い肌色:',
        'ko': u':주먹_전면_검은색_피부:',
        'pt': ':soco_pele_escura:',
        'it': ':pugno_chiuso_carnagione_scura:',
        'fa': u':با_مشت_کوبیدن_پوست_آبنوسی:',
        'id': ':tangan_terkepal_ke_depan_warna_kulit_gelap:',
        'zh': u':出拳_较深肤色:'
    },
    u'\U0001F44A\U0001F3FB': { # 👊🏻
        'en' : ':oncoming_fist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':geballte_faust_helle_hautfarbe:',
        'es': u':puño_cerrado_tono_de_piel_claro:',
        'fr': ':poing_de_face_peau_claire:',
        'ja': u':グー_薄い肌色:',
        'ko': u':주먹_전면_하얀_피부:',
        'pt': ':soco_pele_clara:',
        'it': ':pugno_chiuso_carnagione_chiara:',
        'fa': u':با_مشت_کوبیدن_پوست_سفید:',
        'id': ':tangan_terkepal_ke_depan_warna_kulit_cerah:',
        'zh': u':出拳_较浅肤色:'
    },
    u'\U0001F44A\U0001F3FE': { # 👊🏾
        'en' : ':oncoming_fist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':geballte_faust_mitteldunkle_hautfarbe:',
        'es': u':puño_cerrado_tono_de_piel_oscuro_medio:',
        'fr': ':poing_de_face_peau_mate:',
        'ja': u':グー_やや濃い肌色:',
        'ko': u':주먹_전면_진한_갈색_피부:',
        'pt': ':soco_pele_morena_escura:',
        'it': ':pugno_chiuso_carnagione_abbastanza_scura:',
        'fa': u':با_مشت_کوبیدن_پوست_گندمی:',
        'id': ':tangan_terkepal_ke_depan_warna_kulit_gelap-sedang:',
        'zh': u':出拳_中等深肤色:'
    },
    u'\U0001F44A\U0001F3FC': { # 👊🏼
        'en' : ':oncoming_fist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':geballte_faust_mittelhelle_hautfarbe:',
        'es': u':puño_cerrado_tono_de_piel_claro_medio:',
        'fr': ':poing_de_face_peau_moyennement_claire:',
        'ja': u':グー_やや薄い肌色:',
        'ko': u':주먹_전면_연한_갈색_피부:',
        'pt': ':soco_pele_morena_clara:',
        'it': ':pugno_chiuso_carnagione_abbastanza_chiara:',
        'fa': u':با_مشت_کوبیدن_پوست_روشن:',
        'id': ':tangan_terkepal_ke_depan_warna_kulit_cerah-sedang:',
        'zh': u':出拳_中等浅肤色:'
    },
    u'\U0001F44A\U0001F3FD': { # 👊🏽
        'en' : ':oncoming_fist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':geballte_faust_mittlere_hautfarbe:',
        'es': u':puño_cerrado_tono_de_piel_medio:',
        'fr': u':poing_de_face_peau_légèrement_mate:',
        'ja': u':グー_中間の肌色:',
        'ko': u':주먹_전면_갈색_피부:',
        'pt': ':soco_pele_morena:',
        'it': ':pugno_chiuso_carnagione_olivastra:',
        'fa': u':با_مشت_کوبیدن_پوست_طلایی:',
        'id': ':tangan_terkepal_ke_depan_warna_kulit_sedang:',
        'zh': u':出拳_中等肤色:'
    },
    u'\U0001F694': { # 🚔
        'en' : ':oncoming_police_car:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':polizeiwagen_von_vorne:',
        'es': u':coche_de_policía_próximo:',
        'fr': ':voiture_de_police_de_face:',
        'ja': u':パトカー正面:',
        'ko': u':오고_있는_경찰차:',
        'pt': ':viatura_policial_se_aproximando:',
        'it': ':macchina_della_polizia_in_arrivo:',
        'fa': u':ماشین_پلیسی_که_نزدیک_می_شود:',
        'id': ':mobil_polisi_datang:',
        'zh': u':迎面驶来的警车:'
    },
    u'\U0001F696': { # 🚖
        'en' : ':oncoming_taxi:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':taxi_von_vorne:',
        'es': u':taxi_próximo:',
        'fr': ':taxi_de_face:',
        'ja': u':タクシー正面:',
        'ko': u':오고_있는_택시:',
        'pt': u':táxi_se_aproximando:',
        'it': ':taxi_in_arrivo:',
        'fa': u':تاکسی_ای_که_نزدیک_می_شود:',
        'id': ':taksi_datang:',
        'zh': u':迎面驶来的出租车:'
    },
    u'\U0001FA71': { # 🩱
        'en' : ':one-piece_swimsuit:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':one_piece_swimsuit:'],
        'de': ':einteiliger_badeanzug:',
        'es': u':traje_de_baño_de_una_pieza:',
        'fr': u':maillot_de_bain_une_pièce:',
        'ja': u':ワンピースの水着:',
        'ko': u':원피스_수영복:',
        'pt': u':maiô:',
        'it': ':costume_da_bagno_intero:',
        'fa': u':مایو_یک_تکه:',
        'id': ':pakaian_renang_one-piece:',
        'zh': u':连体泳衣:'
    },
    u'\U0001F55C': { # 🕜
        'en' : ':one-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock130:'],
        'variant': True,
        'de': ':1.30_uhr:',
        'es': ':una_y_media:',
        'fr': ':une_heure_et_demie:',
        'ja': u':1時半:',
        'ko': u':한_시_반:',
        'pt': ':uma_e_meia:',
        'it': ':ore_una_e_mezza:',
        'fa': u':ساعت_یک_و_نیم:',
        'id': ':jam_setengah_dua:',
        'zh': u':一点半:'
    },
    u'\U0001F550': { # 🕐
        'en' : u':one_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock1:'],
        'variant': True,
        'de': ':1.00_uhr:',
        'es': ':1_en_punto:',
        'fr': ':une_heure:',
        'ja': u':1時:',
        'ko': u':한_시:',
        'pt': ':1_hora:',
        'it': ':ore_una:',
        'fa': u':ساعت_یک:',
        'id': ':jam_satu_tepat:',
        'zh': u':一点:'
    },
    u'\U0001F9C5': { # 🧅
        'en' : ':onion:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':zwiebel:',
        'es': ':cebolla:',
        'fr': ':oignon:',
        'ja': u':タマネギ:',
        'ko': u':양파:',
        'pt': ':cebola:',
        'it': ':cipolla:',
        'fa': u':پیاز:',
        'id': ':bawang_bombay:',
        'zh': u':洋葱:'
    },
    u'\U0001F4D6': { # 📖
        'en' : ':open_book:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':book:'],
        'de': ':offenes_buch:',
        'es': ':libro_abierto:',
        'fr': ':livre_ouvert:',
        'ja': u':開いた本:',
        'ko': u':펼쳐진_책:',
        'pt': ':livro_aberto:',
        'it': ':libro_aperto:',
        'fa': u':کتاب_باز:',
        'id': ':buku_terbuka:',
        'zh': u':打开的书本:'
    },
    u'\U0001F4C2': { # 📂
        'en' : ':open_file_folder:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':geöffneter_ordner:',
        'es': ':carpeta_de_archivos_abierta:',
        'fr': ':dossier_ouvert:',
        'ja': u':開いたフォルダー:',
        'ko': u':폴더_열기:',
        'pt': ':pasta_de_arquivos_aberta:',
        'it': ':cartella_aperta:',
        'fa': u':پوشهٔ_باز:',
        'id': ':folder_file_terbuka:',
        'zh': u':打开的文件夹:'
    },
    u'\U0001F450': { # 👐
        'en' : ':open_hands:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':offene_hände:',
        'es': ':manos_abiertas:',
        'fr': ':mains_ouvertes:',
        'ja': u':両手のひら:',
        'ko': u':양손을_모아서_벌린_모양:',
        'pt': u':mãos_abertas:',
        'it': ':mani_aperte:',
        'fa': u':دست_های_باز:',
        'id': ':tangan_terbuka:',
        'zh': u':张开双手:'
    },
    u'\U0001F450\U0001F3FF': { # 👐🏿
        'en' : ':open_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':offene_hände_dunkle_hautfarbe:',
        'es': ':manos_abiertas_tono_de_piel_oscuro:',
        'fr': u':mains_ouvertes_peau_foncée:',
        'ja': u':両手のひら_濃い肌色:',
        'ko': u':양손을_모아서_벌린_모양_검은색_피부:',
        'pt': u':mãos_abertas_pele_escura:',
        'it': ':mani_aperte_carnagione_scura:',
        'fa': u':دست_های_باز_پوست_آبنوسی:',
        'id': ':tangan_terbuka_warna_kulit_gelap:',
        'zh': u':张开双手_较深肤色:'
    },
    u'\U0001F450\U0001F3FB': { # 👐🏻
        'en' : ':open_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':offene_hände_helle_hautfarbe:',
        'es': ':manos_abiertas_tono_de_piel_claro:',
        'fr': ':mains_ouvertes_peau_claire:',
        'ja': u':両手のひら_薄い肌色:',
        'ko': u':양손을_모아서_벌린_모양_하얀_피부:',
        'pt': u':mãos_abertas_pele_clara:',
        'it': ':mani_aperte_carnagione_chiara:',
        'fa': u':دست_های_باز_پوست_سفید:',
        'id': ':tangan_terbuka_warna_kulit_cerah:',
        'zh': u':张开双手_较浅肤色:'
    },
    u'\U0001F450\U0001F3FE': { # 👐🏾
        'en' : ':open_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':offene_hände_mitteldunkle_hautfarbe:',
        'es': ':manos_abiertas_tono_de_piel_oscuro_medio:',
        'fr': ':mains_ouvertes_peau_mate:',
        'ja': u':両手のひら_やや濃い肌色:',
        'ko': u':양손을_모아서_벌린_모양_진한_갈색_피부:',
        'pt': u':mãos_abertas_pele_morena_escura:',
        'it': ':mani_aperte_carnagione_abbastanza_scura:',
        'fa': u':دست_های_باز_پوست_گندمی:',
        'id': ':tangan_terbuka_warna_kulit_gelap-sedang:',
        'zh': u':张开双手_中等深肤色:'
    },
    u'\U0001F450\U0001F3FC': { # 👐🏼
        'en' : ':open_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':offene_hände_mittelhelle_hautfarbe:',
        'es': ':manos_abiertas_tono_de_piel_claro_medio:',
        'fr': ':mains_ouvertes_peau_moyennement_claire:',
        'ja': u':両手のひら_やや薄い肌色:',
        'ko': u':양손을_모아서_벌린_모양_연한_갈색_피부:',
        'pt': u':mãos_abertas_pele_morena_clara:',
        'it': ':mani_aperte_carnagione_abbastanza_chiara:',
        'fa': u':دست_های_باز_پوست_روشن:',
        'id': ':tangan_terbuka_warna_kulit_cerah-sedang:',
        'zh': u':张开双手_中等浅肤色:'
    },
    u'\U0001F450\U0001F3FD': { # 👐🏽
        'en' : ':open_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':offene_hände_mittlere_hautfarbe:',
        'es': ':manos_abiertas_tono_de_piel_medio:',
        'fr': u':mains_ouvertes_peau_légèrement_mate:',
        'ja': u':両手のひら_中間の肌色:',
        'ko': u':양손을_모아서_벌린_모양_갈색_피부:',
        'pt': u':mãos_abertas_pele_morena:',
        'it': ':mani_aperte_carnagione_olivastra:',
        'fa': u':دست_های_باز_پوست_طلایی:',
        'id': ':tangan_terbuka_warna_kulit_sedang:',
        'zh': u':张开双手_中等肤色:'
    },
    u'\U0001F4ED': { # 📭
        'en' : ':open_mailbox_with_lowered_flag:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':mailbox_with_no_mail:'],
        'variant': True,
        'de': ':offener_briefkasten_ohne_post:',
        'es': u':buzón_abierto_con_la_bandera_bajada:',
        'fr': u':boîte_aux_lettres_ouverte_drapeau_baissé:',
        'ja': u':開いた郵便受け(手紙なし):',
        'ko': u':표지가_내려간_열린_우편함:',
        'pt': ':caixa_de_correio_aberta_com_bandeira_abaixada:',
        'it': ':cassetta_postale_aperta_bandierina_abbassata:',
        'fa': u':صندوق_پستی_باز_با_پرچم_پایین:',
        'id': ':kotak_surat_terbuka_dengan_bendera_turun:',
        'zh': u':无新信件:'
    },
    u'\U0001F4EC': { # 📬
        'en' : ':open_mailbox_with_raised_flag:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':mailbox_with_mail:'],
        'variant': True,
        'de': ':offener_briefkasten_mit_post:',
        'es': u':buzón_abierto_con_la_bandera_levantada:',
        'fr': u':boîte_aux_lettres_ouverte_drapeau_levé:',
        'ja': u':開いた郵便受け(手紙あり):',
        'ko': u':표지가_올라간_열린_우편함:',
        'pt': ':caixa_de_correio_aberta_com_bandeira_levantada:',
        'it': ':cassetta_postale_aperta_bandierina_alzata:',
        'fa': u':صندوق_پستی_باز_با_پرچم_بالا:',
        'id': ':kotak_surat_terbuka_dengan_bendera_terangkat:',
        'zh': u':有新信件:'
    },
    u'\U0001F4BF': { # 💿
        'en' : ':optical_disk:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cd:'],
        'variant': True,
        'de': ':cd:',
        'es': u':disco_óptico:',
        'fr': ':cd:',
        'ja': ':cd:',
        'ko': u':씨디:',
        'pt': ':cd:',
        'it': ':disco_ottico:',
        'fa': u':سی_دی:',
        'id': ':disk_optik:',
        'zh': u':光盘:'
    },
    u'\U0001F4D9': { # 📙
        'en' : ':orange_book:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':orangefarbenes_buch:',
        'es': ':libro_naranja:',
        'fr': ':livre_orange:',
        'ja': u':オレンジの本:',
        'ko': u':주황색_책:',
        'pt': ':livro_laranja:',
        'it': ':libro_arancione:',
        'fa': u':کتاب_نارنجی:',
        'id': ':buku_oranye:',
        'zh': u':橙色书本:'
    },
    u'\U0001F7E0': { # 🟠
        'en' : ':orange_circle:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':oranger_punkt:',
        'es': u':círculo_naranja:',
        'fr': ':disque_orange:',
        'ja': u':オレンジの丸:',
        'ko': u':오렌지색_원:',
        'pt': u':círculo_laranja:',
        'it': ':cerchio_arancione:',
        'fa': u':دایره_نارنجی:',
        'id': ':lingkaran_oranye:',
        'zh': u':橙色圆:'
    },
    u'\U0001F9E1': { # 🧡
        'en' : ':orange_heart:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':oranges_herz:',
        'es': u':corazón_naranja:',
        'fr': u':cœur_orange:',
        'ja': u':オレンジのハート:',
        'ko': u':주황색_하트:',
        'pt': u':coração_laranja:',
        'it': ':cuore_arancione:',
        'fa': u':قلب_نارنجی:',
        'id': ':hati_oranye:',
        'zh': u':橙心:'
    },
    u'\U0001F7E7': { # 🟧
        'en' : ':orange_square:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':oranges_quadrat:',
        'es': ':cuadrado_naranja:',
        'fr': u':carré_orange:',
        'ja': u':オレンジの四角:',
        'ko': u':오렌지색_사각형:',
        'pt': ':quadrado_laranja:',
        'it': ':quadrato_arancione:',
        'fa': u':مربع_نارنجی:',
        'id': ':persegi_oranye:',
        'zh': u':橙色方块:'
    },
    u'\U0001F9A7': { # 🦧
        'en' : ':orangutan:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':orang-utan:',
        'es': u':orangután:',
        'fr': ':orang-outan:',
        'ja': u':オランウータン:',
        'ko': u':오랑우탄:',
        'pt': ':orangotango:',
        'it': ':orangotango:',
        'fa': u':اورانگوتان:',
        'id': ':orangutan:',
        'zh': u':红毛猩猩:'
    },
    u'\U00002626\U0000FE0F': { # ☦️
        'en' : ':orthodox_cross:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':orthodoxes_kreuz:',
        'es': ':cruz_ortodoxa:',
        'fr': ':croix_orthodoxe:',
        'ja': u':八端十字架:',
        'ko': u':전통적인_십자가:',
        'pt': ':cruz_ortodoxa:',
        'it': ':croce_ortodossa:',
        'fa': u':صلیب_ارتدوکسی:',
        'id': ':salib_ortodoks:',
        'zh': u':东正教十字架:'
    },
    u'\U00002626': { # ☦
        'en' : ':orthodox_cross:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':orthodoxes_kreuz:',
        'es': ':cruz_ortodoxa:',
        'fr': ':croix_orthodoxe:',
        'ja': u':八端十字架:',
        'ko': u':전통적인_십자가:',
        'pt': ':cruz_ortodoxa:',
        'it': ':croce_ortodossa:',
        'fa': u':صلیب_ارتدوکسی:',
        'id': ':salib_ortodoks:',
        'zh': u':东正教十字架:'
    },
    u'\U0001F9A6': { # 🦦
        'en' : ':otter:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':otter:',
        'es': ':nutria:',
        'fr': ':loutre:',
        'ja': u':カワウソ:',
        'ko': u':수달:',
        'pt': ':lontra:',
        'it': ':lontra:',
        'fa': u':سمور_آبی:',
        'id': ':berang-berang:',
        'zh': u':水獭:'
    },
    u'\U0001F4E4': { # 📤
        'en' : ':outbox_tray:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':postausgang:',
        'es': ':bandeja_de_salida:',
        'fr': u':boîte_d’envoi:',
        'ja': u':送信トレイ:',
        'ko': u':보낸_편지함:',
        'pt': u':bandeja_de_saída:',
        'it': ':posta_inviata:',
        'fa': u':صندوق_خروجی:',
        'id': ':baki_kotak_keluar:',
        'zh': u':发件箱:'
    },
    u'\U0001F989': { # 🦉
        'en' : ':owl:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':eule:',
        'es': u':búho:',
        'fr': ':chouette:',
        'ja': u':フクロウ:',
        'ko': u':부엉이:',
        'pt': ':coruja:',
        'it': ':gufo:',
        'fa': u':جغد:',
        'id': ':burung_hantu:',
        'zh': u':猫头鹰:'
    },
    u'\U0001F402': { # 🐂
        'en' : ':ox:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ochse:',
        'es': ':buey:',
        'fr': u':bœuf:',
        'ja': u':牡牛:',
        'ko': u':소:',
        'pt': ':boi:',
        'it': ':bue:',
        'fa': u':گاو_نر:',
        'id': ':lembu:',
        'zh': u':公牛:'
    },
    u'\U0001F9AA': { # 🦪
        'en' : ':oyster:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':auster:',
        'es': ':ostra:',
        'fr': u':huître:',
        'ja': u':牡蠣:',
        'ko': u':굴:',
        'pt': ':ostra:',
        'it': ':ostrica:',
        'fa': u':صدف_خوراکی:',
        'id': ':tiram:',
        'zh': u':牡蛎:'
    },
    u'\U0001F4E6': { # 📦
        'en' : ':package:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':paket:',
        'es': ':paquete:',
        'fr': ':colis:',
        'ja': u':荷物:',
        'ko': u':소포:',
        'pt': ':pacote:',
        'it': ':pacco:',
        'fa': u':بسته:',
        'id': ':paket:',
        'zh': u':包裹:'
    },
    u'\U0001F4C4': { # 📄
        'en' : ':page_facing_up:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':vorderseite_eines_blattes:',
        'es': u':página_hacia_arriba:',
        'fr': ':page:',
        'ja': u':ページ:',
        'ko': u':오른쪽_모서리가_접힌_문서:',
        'pt': u':página_voltada_para_cima:',
        'it': ':pagina:',
        'fa': u':صفحهٔ_روبه_بالا:',
        'id': ':halaman_tampak_depan:',
        'zh': u':文件:'
    },
    u'\U0001F4C3': { # 📃
        'en' : ':page_with_curl:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':teilweise_eingerolltes_blatt:',
        'es': u':página_doblada:',
        'fr': u':page_enroulée:',
        'ja': u':巻きページ:',
        'ko': u':안으로_말린_문서:',
        'pt': u':página_dobrada:',
        'it': ':pagina_con_piega:',
        'fa': u':صفحهٔ_تاشده:',
        'id': ':halaman_tergulung:',
        'zh': u':带卷边的页面:'
    },
    u'\U0001F4DF': { # 📟
        'en' : ':pager:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':pager:',
        'es': ':busca:',
        'fr': ':bipeur:',
        'ja': u':ポケベル:',
        'ko': u':삐삐:',
        'pt': ':pager:',
        'it': ':cercapersone:',
        'fa': u':پیجر:',
        'id': ':pager:',
        'zh': u':寻呼机:'
    },
    u'\U0001F58C\U0000FE0F': { # 🖌️
        'en' : ':paintbrush:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':lower_left_paintbrush:'],
        'variant': True,
        'de': ':pinsel:',
        'es': ':pincel:',
        'fr': ':pinceau:',
        'ja': u':絵筆:',
        'ko': u':붓:',
        'pt': ':pincel:',
        'it': ':pennello:',
        'fa': u':قلم_مو:',
        'id': ':kuas:',
        'zh': u':画笔:'
    },
    u'\U0001F58C': { # 🖌
        'en' : ':paintbrush:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':lower_left_paintbrush:'],
        'variant': True,
        'de': ':pinsel:',
        'es': ':pincel:',
        'fr': ':pinceau:',
        'ja': u':絵筆:',
        'ko': u':붓:',
        'pt': ':pincel:',
        'it': ':pennello:',
        'fa': u':قلم_مو:',
        'id': ':kuas:',
        'zh': u':画笔:'
    },
    u'\U0001FAF3': { # 🫳
        'en' : ':palm_down_hand:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':hand_mit_handfläche_nach_unten:',
        'es': ':mano_con_la_palma_hacia_abajo:',
        'fr': ':main_paume_vers_le_bas:',
        'ja': u':下に向けた手:',
        'ko': u':손바닥을_아래로_향한_손:',
        'pt': u':mão_com_a_palma_para_baixo:',
        'it': ':mano_con_il_palmo_verso_il_basso:',
        'fa': u':کف_دست_به_پایین:',
        'id': ':telapak_tangan_menghadap_ke_bawah:',
        'zh': u':掌心向下的手:'
    },
    u'\U0001FAF3\U0001F3FF': { # 🫳🏿
        'en' : ':palm_down_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF3\U0001F3FB': { # 🫳🏻
        'en' : ':palm_down_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF3\U0001F3FE': { # 🫳🏾
        'en' : ':palm_down_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF3\U0001F3FC': { # 🫳🏼
        'en' : ':palm_down_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF3\U0001F3FD': { # 🫳🏽
        'en' : ':palm_down_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F334': { # 🌴
        'en' : ':palm_tree:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':palme:',
        'es': ':palmera:',
        'fr': ':palmier:',
        'ja': u':ヤシの木:',
        'ko': u':야자수:',
        'pt': ':palmeira:',
        'it': ':palma:',
        'fa': u':نخل:',
        'id': ':pohon_palem:',
        'zh': u':棕榈树:'
    },
    u'\U0001FAF4': { # 🫴
        'en' : ':palm_up_hand:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':hand_mit_handfläche_nach_oben:',
        'es': ':mano_con_la_palma_hacia_arriba:',
        'fr': ':main_paume_vers_le_haut:',
        'ja': u':上に向けた手:',
        'ko': u':손바닥을_위로_향한_손:',
        'pt': u':mão_com_a_palma_para_cima:',
        'it': u':mano_con_il_palmo_verso_l’alto:',
        'fa': u':کف_دست_به_بالا:',
        'id': ':telapak_tangan_menghadap_ke_atas:',
        'zh': u':掌心向上的手:'
    },
    u'\U0001FAF4\U0001F3FF': { # 🫴🏿
        'en' : ':palm_up_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF4\U0001F3FB': { # 🫴🏻
        'en' : ':palm_up_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF4\U0001F3FE': { # 🫴🏾
        'en' : ':palm_up_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF4\U0001F3FC': { # 🫴🏼
        'en' : ':palm_up_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF4\U0001F3FD': { # 🫴🏽
        'en' : ':palm_up_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F932': { # 🤲
        'en' : ':palms_up_together:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':handflächen_nach_oben:',
        'es': ':palmas_hacia_arriba_juntas:',
        'fr': ':paume_contre_paume_doigts_vers_le_haut:',
        'ja': u':手のひらを揃えた両手:',
        'ko': u':내민_두_손:',
        'pt': ':palmas_unidas_para_cima:',
        'it': ':mani_unite_in_alto:',
        'fa': u':دست_دعا:',
        'id': ':tangan_diangkat_dan_dirapatkan_bersama:',
        'zh': u':掌心向上托起:'
    },
    u'\U0001F932\U0001F3FF': { # 🤲🏿
        'en' : ':palms_up_together_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':handflächen_nach_oben_dunkle_hautfarbe:',
        'es': ':palmas_hacia_arriba_juntas_tono_de_piel_oscuro:',
        'fr': u':paume_contre_paume_doigts_vers_le_haut_peau_foncée:',
        'ja': u':手のひらを揃えた両手_濃い肌色:',
        'ko': u':내민_두_손_검은색_피부:',
        'pt': ':palmas_unidas_para_cima_pele_escura:',
        'it': ':mani_unite_in_alto_carnagione_scura:',
        'fa': u':دست_دعا_پوست_آبنوسی:',
        'id': ':tangan_diangkat_dan_dirapatkan_bersama_warna_kulit_gelap:',
        'zh': u':掌心向上托起_较深肤色:'
    },
    u'\U0001F932\U0001F3FB': { # 🤲🏻
        'en' : ':palms_up_together_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':handflächen_nach_oben_helle_hautfarbe:',
        'es': ':palmas_hacia_arriba_juntas_tono_de_piel_claro:',
        'fr': ':paume_contre_paume_doigts_vers_le_haut_peau_claire:',
        'ja': u':手のひらを揃えた両手_薄い肌色:',
        'ko': u':내민_두_손_하얀_피부:',
        'pt': ':palmas_unidas_para_cima_pele_clara:',
        'it': ':mani_unite_in_alto_carnagione_chiara:',
        'fa': u':دست_دعا_پوست_سفید:',
        'id': ':tangan_diangkat_dan_dirapatkan_bersama_warna_kulit_cerah:',
        'zh': u':掌心向上托起_较浅肤色:'
    },
    u'\U0001F932\U0001F3FE': { # 🤲🏾
        'en' : ':palms_up_together_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':handflächen_nach_oben_mitteldunkle_hautfarbe:',
        'es': ':palmas_hacia_arriba_juntas_tono_de_piel_oscuro_medio:',
        'fr': ':paume_contre_paume_doigts_vers_le_haut_peau_mate:',
        'ja': u':手のひらを揃えた両手_やや濃い肌色:',
        'ko': u':내민_두_손_진한_갈색_피부:',
        'pt': ':palmas_unidas_para_cima_pele_morena_escura:',
        'it': ':mani_unite_in_alto_carnagione_abbastanza_scura:',
        'fa': u':دست_دعا_پوست_گندمی:',
        'id': ':tangan_diangkat_dan_dirapatkan_bersama_warna_kulit_gelap-sedang:',
        'zh': u':掌心向上托起_中等深肤色:'
    },
    u'\U0001F932\U0001F3FC': { # 🤲🏼
        'en' : ':palms_up_together_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':handflächen_nach_oben_mittelhelle_hautfarbe:',
        'es': ':palmas_hacia_arriba_juntas_tono_de_piel_claro_medio:',
        'fr': ':paume_contre_paume_doigts_vers_le_haut_peau_moyennement_claire:',
        'ja': u':手のひらを揃えた両手_やや薄い肌色:',
        'ko': u':내민_두_손_연한_갈색_피부:',
        'pt': ':palmas_unidas_para_cima_pele_morena_clara:',
        'it': ':mani_unite_in_alto_carnagione_abbastanza_chiara:',
        'fa': u':دست_دعا_پوست_روشن:',
        'id': ':tangan_diangkat_dan_dirapatkan_bersama_warna_kulit_cerah-sedang:',
        'zh': u':掌心向上托起_中等浅肤色:'
    },
    u'\U0001F932\U0001F3FD': { # 🤲🏽
        'en' : ':palms_up_together_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': u':handflächen_nach_oben_mittlere_hautfarbe:',
        'es': ':palmas_hacia_arriba_juntas_tono_de_piel_medio:',
        'fr': u':paume_contre_paume_doigts_vers_le_haut_peau_légèrement_mate:',
        'ja': u':手のひらを揃えた両手_中間の肌色:',
        'ko': u':내민_두_손_갈색_피부:',
        'pt': ':palmas_unidas_para_cima_pele_morena:',
        'it': ':mani_unite_in_alto_carnagione_olivastra:',
        'fa': u':دست_دعا_پوست_طلایی:',
        'id': ':tangan_diangkat_dan_dirapatkan_bersama_warna_kulit_sedang:',
        'zh': u':掌心向上托起_中等肤色:'
    },
    u'\U0001F95E': { # 🥞
        'en' : ':pancakes:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':pfannkuchen:',
        'es': ':tortitas:',
        'fr': ':pancakes:',
        'ja': u':パンケーキ:',
        'ko': u':팬케이크:',
        'pt': ':panquecas:',
        'it': ':pancake:',
        'fa': u':پنکیک:',
        'id': ':panekuk:',
        'zh': u':烙饼:'
    },
    u'\U0001F43C': { # 🐼
        'en' : ':panda:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':panda_face:'],
        'de': ':panda:',
        'es': ':panda:',
        'fr': ':panda:',
        'ja': u':パンダの顔:',
        'ko': u':판다_얼굴:',
        'pt': ':rosto_de_panda:',
        'it': ':panda:',
        'fa': u':پاندا:',
        'id': ':panda:',
        'zh': u':熊猫:'
    },
    u'\U0001F4CE': { # 📎
        'en' : ':paperclip:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':büroklammer:',
        'es': ':clip:',
        'fr': ':trombone:',
        'ja': u':クリップ:',
        'ko': u':클립:',
        'pt': ':clipe_de_papel:',
        'it': ':graffetta:',
        'fa': u':گیرهٔ_کاغذ:',
        'id': ':klip_kertas:',
        'zh': u':回形针:'
    },
    u'\U0001FA82': { # 🪂
        'en' : ':parachute:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':fallschirm:',
        'es': u':paracaídas:',
        'fr': ':parachute:',
        'ja': u':パラシュート:',
        'ko': u':낙하산:',
        'pt': ':paraquedas:',
        'it': ':paracadute:',
        'fa': u':چتر_نجات:',
        'id': ':parasut:',
        'zh': u':降落伞:'
    },
    u'\U0001F99C': { # 🦜
        'en' : ':parrot:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':papagei:',
        'es': ':loro:',
        'fr': ':perroquet:',
        'ja': u':オウム:',
        'ko': u':앵무새:',
        'pt': ':papagaio:',
        'it': ':pappagallo:',
        'fa': u':طوطی:',
        'id': ':nuri:',
        'zh': u':鹦鹉:'
    },
    u'\U0000303D\U0000FE0F': { # 〽️
        'en' : ':part_alternation_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':teilalternationszeichen:',
        'es': ':marca_de_alternancia:',
        'fr': ':alternance:',
        'ja': u':いおりてん:',
        'ko': u':부분_교체_기호:',
        'pt': u':sinal_japonês_indicando_início_de_música:',
        'it': ':simbolo_di_alternanza_delle_parti:',
        'fa': u':علامت_تناوب_بخش:',
        'id': ':tanda_alternasi_bagian:',
        'zh': u':庵点:'
    },
    u'\U0000303D': { # 〽
        'en' : ':part_alternation_mark:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':teilalternationszeichen:',
        'es': ':marca_de_alternancia:',
        'fr': ':alternance:',
        'ja': u':いおりてん:',
        'ko': u':부분_교체_기호:',
        'pt': u':sinal_japonês_indicando_início_de_música:',
        'it': ':simbolo_di_alternanza_delle_parti:',
        'fa': u':علامت_تناوب_بخش:',
        'id': ':tanda_alternasi_bagian:',
        'zh': u':庵点:'
    },
    u'\U0001F389': { # 🎉
        'en' : ':party_popper:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tada:'],
        'de': ':konfettibombe:',
        'es': u':cañón_de_confeti:',
        'fr': ':cotillons:',
        'ja': u':クラッカー:',
        'ko': u':파티:',
        'pt': ':cone_de_festa:',
        'it': ':spara_coriandoli:',
        'fa': u':بمب_کاغذ_رنگی:',
        'id': ':party_popper:',
        'zh': u':拉炮彩带:'
    },
    u'\U0001F973': { # 🥳
        'en' : ':partying_face:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':partygesicht:',
        'es': ':cara_de_fiesta:',
        'fr': ':visage_festif:',
        'ja': u':パーティーの顔:',
        'ko': u':파티하는_얼굴:',
        'pt': ':rosto_festivo:',
        'it': ':faccina_che_festeggia:',
        'fa': u':جشن_و_سور:',
        'id': ':wajah_pesta:',
        'zh': u':聚会笑脸:'
    },
    u'\U0001F6F3\U0000FE0F': { # 🛳️
        'en' : ':passenger_ship:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':passagierschiff:',
        'es': ':barco_de_pasajeros:',
        'fr': ':paquebot:',
        'ja': u':客船:',
        'ko': u':여객선:',
        'pt': ':cruzeiro:',
        'it': ':nave_da_crociera:',
        'fa': u':کشتی_مسافربری:',
        'id': ':kapal_penumpang:',
        'zh': u':客轮:'
    },
    u'\U0001F6F3': { # 🛳
        'en' : ':passenger_ship:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':passagierschiff:',
        'es': ':barco_de_pasajeros:',
        'fr': ':paquebot:',
        'ja': u':客船:',
        'ko': u':여객선:',
        'pt': ':cruzeiro:',
        'it': ':nave_da_crociera:',
        'fa': u':کشتی_مسافربری:',
        'id': ':kapal_penumpang:',
        'zh': u':客轮:'
    },
    u'\U0001F6C2': { # 🛂
        'en' : ':passport_control:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':passkontrolle:',
        'es': ':control_de_pasaportes:',
        'fr': u':contrôle_des_passeports:',
        'ja': u':出入国審査:',
        'ko': u':출입국_심사:',
        'pt': ':controle_de_passaportes:',
        'it': ':simbolo_del_controllo_passaporti:',
        'fa': u':کنترل_گذرنامه:',
        'id': ':kontrol_paspor:',
        'zh': u':护照检查:'
    },
    u'\U000023F8\U0000FE0F': { # ⏸️
        'en' : ':pause_button:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':double_vertical_bar:'],
        'variant': True,
        'de': ':pause:',
        'es': ':pausa:',
        'fr': ':bouton_pause:',
        'ja': u':一時停止ボタン:',
        'ko': u':일시_정지_버튼:',
        'pt': u':botão_pausar:',
        'it': ':pulsante_pausa:',
        'fa': u':دکمه_مکث:',
        'id': ':tombol_jeda:',
        'zh': u':暂停按钮:'
    },
    u'\U000023F8': { # ⏸
        'en' : ':pause_button:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':double_vertical_bar:'],
        'variant': True,
        'de': ':pause:',
        'es': ':pausa:',
        'fr': ':bouton_pause:',
        'ja': u':一時停止ボタン:',
        'ko': u':일시_정지_버튼:',
        'pt': u':botão_pausar:',
        'it': ':pulsante_pausa:',
        'fa': u':دکمهٔ_مکث:',
        'id': ':tombol_jeda:',
        'zh': u':暂停按钮:'
    },
    u'\U0001F43E': { # 🐾
        'en' : ':paw_prints:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':feet:'],
        'de': u':tatzenabdrücke:',
        'es': u':huellas_de_pezuñas:',
        'fr': u':empreintes_d’animaux:',
        'ja': u':肉球:',
        'ko': u':곰발바닥:',
        'pt': ':patas:',
        'it': ':impronte_di_zampe:',
        'fa': u':رد_پنجه:',
        'id': ':jejak_kaki_hewan:',
        'zh': u':爪印:'
    },
    u'\U0001FADB': { # 🫛
        'en' : ':pea_pod:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':erbsenschote:',
        'es': ':vaina:',
        'fr': ':cosse_de_petits_pois:',
        'ja': u':エンドウ豆:',
        'ko': u':완두콩_꼬투리:',
        'pt': ':vagem:',
        'it': ':baccello_di_piselli:',
        'fa': u':نخودفرنگی:',
        'id': ':kacang_polong:',
        'zh': u':豌豆荚:'
    },
    u'\U0000262E\U0000FE0F': { # ☮️
        'en' : ':peace_symbol:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':friedenszeichen:',
        'es': u':símbolo_de_la_paz:',
        'fr': ':symbole_de_paix:',
        'ja': u':ピースマーク:',
        'ko': u':평화_기호:',
        'pt': u':símbolo_da_paz:',
        'it': ':simbolo_della_pace:',
        'fa': u':نماد_صلح:',
        'id': ':simbol_damai:',
        'zh': u':和平符号:'
    },
    u'\U0000262E': { # ☮
        'en' : ':peace_symbol:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':friedenszeichen:',
        'es': u':símbolo_de_la_paz:',
        'fr': ':symbole_de_paix:',
        'ja': u':ピースマーク:',
        'ko': u':평화_기호:',
        'pt': u':símbolo_da_paz:',
        'it': ':simbolo_della_pace:',
        'fa': u':نماد_صلح:',
        'id': ':simbol_damai:',
        'zh': u':和平符号:'
    },
    u'\U0001F351': { # 🍑
        'en' : ':peach:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':pfirsich:',
        'es': u':melocotón:',
        'fr': u':pêche:',
        'ja': u':桃:',
        'ko': u':복숭아:',
        'pt': u':pêssego:',
        'it': ':pesca:',
        'fa': u':هلو:',
        'id': ':persik:',
        'zh': u':桃:'
    },
    u'\U0001F99A': { # 🦚
        'en' : ':peacock:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':pfau:',
        'es': ':pavo_real:',
        'fr': ':paon:',
        'ja': u':クジャク:',
        'ko': u':공작:',
        'pt': u':pavão:',
        'it': ':pavone:',
        'fa': u':طاووس:',
        'id': ':merak:',
        'zh': u':孔雀:'
    },
    u'\U0001F95C': { # 🥜
        'en' : ':peanuts:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':erdnuss:',
        'es': ':cacahuetes:',
        'fr': u':cacahuètes:',
        'ja': u':ピーナッツ:',
        'ko': u':땅콩:',
        'pt': ':amendoim:',
        'it': ':arachidi:',
        'fa': u':بادام_زمینی:',
        'id': ':kacang_tanah:',
        'zh': u':花生:'
    },
    u'\U0001F350': { # 🍐
        'en' : ':pear:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':birne:',
        'es': ':pera:',
        'fr': ':poire:',
        'ja': u':洋ナシ:',
        'ko': u':배:',
        'pt': ':pera:',
        'it': ':pera:',
        'fa': u':گلابی:',
        'id': ':pir:',
        'zh': u':梨:'
    },
    u'\U0001F58A\U0000FE0F': { # 🖊️
        'en' : ':pen:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':lower_left_ballpoint_pen:'],
        'variant': True,
        'de': ':kugelschreiber:',
        'es': u':bolígrafo:',
        'fr': ':stylo:',
        'ja': u':ペン:',
        'ko': u':펜:',
        'pt': ':caneta:',
        'it': ':penna_a_sfera:',
        'fa': u':خودکار:',
        'id': ':pena:',
        'zh': u':笔:'
    },
    u'\U0001F58A': { # 🖊
        'en' : ':pen:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':lower_left_ballpoint_pen:'],
        'variant': True,
        'de': ':kugelschreiber:',
        'es': u':bolígrafo:',
        'fr': ':stylo:',
        'ja': u':ペン:',
        'ko': u':펜:',
        'pt': ':caneta:',
        'it': ':penna_a_sfera:',
        'fa': u':خودکار:',
        'id': ':pena:',
        'zh': u':笔:'
    },
    u'\U0000270F\U0000FE0F': { # ✏️
        'en' : ':pencil:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pencil2:'],
        'variant': True,
        'de': ':bleistift:',
        'es': u':lápiz:',
        'fr': ':crayon:',
        'ja': u':鉛筆:',
        'ko': u':연필:',
        'pt': u':lápis:',
        'it': ':matita:',
        'fa': u':مداد:',
        'id': ':pensil:',
        'zh': u':铅笔:'
    },
    u'\U0000270F': { # ✏
        'en' : ':pencil:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':pencil2:'],
        'variant': True,
        'de': ':bleistift:',
        'es': u':lápiz:',
        'fr': ':crayon:',
        'ja': u':鉛筆:',
        'ko': u':연필:',
        'pt': u':lápis:',
        'it': ':matita:',
        'fa': u':مداد:',
        'id': ':pensil:',
        'zh': u':铅笔:'
    },
    u'\U0001F427': { # 🐧
        'en' : ':penguin:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':pinguin:',
        'es': u':pingüino:',
        'fr': ':pingouin:',
        'ja': u':ペンギン:',
        'ko': u':펭귄:',
        'pt': ':pinguim:',
        'it': ':pinguino:',
        'fa': u':پنگوئن:',
        'id': ':pinguin:',
        'zh': u':企鹅:'
    },
    u'\U0001F614': { # 😔
        'en' : ':pensive_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pensive:'],
        'de': ':nachdenkliches_gesicht:',
        'es': ':cara_desanimada:',
        'fr': ':visage_pensif:',
        'ja': u':しょぼーん:',
        'ko': u':수심_어린_얼굴:',
        'pt': ':rosto_deprimido:',
        'it': ':faccina_pensierosa:',
        'fa': u':افسرده:',
        'id': ':wajah_merenung:',
        'zh': u':沉思:'
    },
    u'\U0001F9D1\U0000200D\U0001F91D\U0000200D\U0001F9D1': { # 🧑‍🤝‍🧑
        'en' : ':people_holding_hands:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen:',
        'es': ':dos_personas_de_la_mano:',
        'fr': ':deux_personnes_se_tenant_la_main:',
        'ja': u':手をつなぐ2人:',
        'ko': u':손을_잡고_있는_두_명의_사람:',
        'pt': u':pessoas_de_mãos_dadas:',
        'it': ':persone_che_si_tengono_per_mano:',
        'fa': u':اشخاصی_دست_در_دست_هم:',
        'id': ':orang_bergandengan:',
        'zh': u':手拉手的两个人:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏿‍🤝‍🧑🏿
        'en' : ':people_holding_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_dunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_foncée:',
        'ja': u':手をつなぐ2人_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_검은색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_آبنوسی:',
        'id': ':orang_bergandengan_warna_kulit_gelap:',
        'zh': u':手拉手的两个人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏿‍🤝‍🧑🏻
        'en' : ':people_holding_hands_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_dunkle_hautfarbe,_helle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_foncée_et_peau_claire:',
        'ja': u':手をつなぐ2人_濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_검은색_피부_하얀_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_escura_e_pele_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_scura_e_carnagione_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_آبنوسی_پوست_سفید:',
        'id': ':orang_bergandengan_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':手拉手的两个人_较深肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏿‍🤝‍🧑🏾
        'en' : ':people_holding_hands_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_dunkle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_y_tono_de_piel_oscuro_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_foncée_et_peau_mate:',
        'ja': u':手をつなぐ2人_濃い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_검은색_피부_진한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_escura_e_pele_morena_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_آبنوسی_پوست_گندمی:',
        'id': ':orang_bergandengan_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个人_较深肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏿‍🤝‍🧑🏼
        'en' : ':people_holding_hands_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_dunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ2人_濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_검은색_피부_연한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_escura_e_pele_morena_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_آبنوسی_پوست_روشن:',
        'id': ':orang_bergandengan_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个人_较深肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏿‍🤝‍🧑🏽
        'en' : ':people_holding_hands_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_dunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_y_tono_de_piel_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ2人_濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_검은색_피부_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_escura_e_pele_morena:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_آبنوسی_پوست_طلایی:',
        'id': ':orang_bergandengan_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':手拉手的两个人_较深肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏻‍🤝‍🧑🏻
        'en' : ':people_holding_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_helle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_claire:',
        'ja': u':手をつなぐ2人_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_하얀_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_سفید:',
        'id': ':orang_bergandengan_warna_kulit_cerah:',
        'zh': u':手拉手的两个人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏻‍🤝‍🧑🏿
        'en' : ':people_holding_hands_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_helle_hautfarbe,_dunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_claire_et_peau_foncée:',
        'ja': u':手をつなぐ2人_薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_하얀_피부_검은색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_clara_e_pele_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_سفید_پوست_آبنوسی:',
        'id': ':orang_bergandengan_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':手拉手的两个人_较浅肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏻‍🤝‍🧑🏾
        'en' : ':people_holding_hands_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_helle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro_medio:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_claire_et_peau_mate:',
        'ja': u':手をつなぐ2人_薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_하얀_피부_진한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_clara_e_pele_morena_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_سفید_پوست_گندمی:',
        'id': ':orang_bergandengan_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个人_较浅肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏻‍🤝‍🧑🏼
        'en' : ':people_holding_hands_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_helle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_y_tono_de_piel_claro_medio:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_claire_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ2人_薄い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_하얀_피부_연한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_clara_e_pele_morena_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_سفید_پوست_روشن:',
        'id': ':orang_bergandengan_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个人_较浅肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏻‍🤝‍🧑🏽
        'en' : ':people_holding_hands_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_helle_hautfarbe,_mittlere_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_y_tono_de_piel_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ2人_薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_하얀_피부_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_clara_e_pele_morena:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_سفید_پوست_طلایی:',
        'id': ':orang_bergandengan_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':手拉手的两个人_较浅肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏾‍🤝‍🧑🏾
        'en' : ':people_holding_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mitteldunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_medio:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_mate:',
        'ja': u':手をつなぐ2人_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_진한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_گندمی:',
        'id': ':orang_bergandengan_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏾‍🤝‍🧑🏿
        'en' : ':people_holding_hands_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_mitteldunkle_hautfarbe,_dunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_mate_et_peau_foncée:',
        'ja': u':手をつなぐ2人_やや濃い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_진한_갈색_피부_검은색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_escura_e_pele_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_گندمی_پوست_آبنوسی:',
        'id': ':orang_bergandengan_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个人_中等深肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏾‍🤝‍🧑🏻
        'en' : ':people_holding_hands_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mitteldunkle_hautfarbe,_helle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_mate_et_peau_claire:',
        'ja': u':手をつなぐ2人_やや濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_진한_갈색_피부_하얀_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_escura_e_pele_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_گندمی_پوست_سفید:',
        'id': ':orang_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个人_中等深肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏾‍🤝‍🧑🏼
        'en' : ':people_holding_hands_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mitteldunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro_medio:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ2人_やや濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_진한_갈색_피부_연한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_escura_e_pele_morena_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_گندمی_پوست_روشن:',
        'id': ':orang_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个人_中等深肤色中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏾‍🤝‍🧑🏽
        'en' : ':people_holding_hands_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mitteldunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_mate_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ2人_やや濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_진한_갈색_피부_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_escura_e_pele_morena:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_گندمی_پوست_طلایی:',
        'id': ':orang_bergandengan_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的两个人_中等深肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏼‍🤝‍🧑🏼
        'en' : ':people_holding_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mittelhelle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_medio:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_moyennement_claire:',
        'ja': u':手をつなぐ2人_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_연한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_روشن:',
        'id': ':orang_bergandengan_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏼‍🤝‍🧑🏿
        'en' : ':people_holding_hands_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_mittelhelle_hautfarbe,_dunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':手をつなぐ2人_やや薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_연한_갈색_피부_검은색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_clara_e_pele_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_روشن_پوست_آبنوسی:',
        'id': ':orang_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个人_中等浅肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏼‍🤝‍🧑🏻
        'en' : ':people_holding_hands_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mittelhelle_hautfarbe,_helle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_claro:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_moyennement_claire_et_peau_claire:',
        'ja': u':手をつなぐ2人_やや薄い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_연한_갈색_피부_하얀_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_clara_e_pele_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_روشن_پوست_سفید:',
        'id': ':orang_bergandengan_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个人_中等浅肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏼‍🤝‍🧑🏾
        'en' : ':people_holding_hands_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_mittelhelle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro_medio:',
        'fr': ':deux_personnes_se_tenant_la_main_peau_moyennement_claire_et_peau_mate:',
        'ja': u':手をつなぐ2人_やや薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_연한_갈색_피부_진한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_clara_e_pele_morena_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_روشن_پوست_گندمی:',
        'id': ':orang_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个人_中等浅肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏼‍🤝‍🧑🏽
        'en' : ':people_holding_hands_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_mittelhelle_hautfarbe,_mittlere_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ2人_やや薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_연한_갈색_피부_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_clara_e_pele_morena:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_روشن_پوست_طلایی:',
        'id': ':orang_bergandengan_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的两个人_中等浅肤色中等肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FD': { # 🧑🏽‍🤝‍🧑🏽
        'en' : ':people_holding_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mittlere_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_légèrement_mate:',
        'ja': u':手をつなぐ2人_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_olivastra:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_طلایی:',
        'id': ':orang_bergandengan_warna_kulit_sedang:',
        'zh': u':手拉手的两个人_中等肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FF': { # 🧑🏽‍🤝‍🧑🏿
        'en' : ':people_holding_hands_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_mittlere_hautfarbe,_dunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':手をつなぐ2人_中間の肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_갈색_피부_검은색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_e_pele_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_طلایی_پوست_آبنوسی:',
        'id': ':orang_bergandengan_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个人_中等肤色较深肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FB': { # 🧑🏽‍🤝‍🧑🏻
        'en' : ':people_holding_hands_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mittlere_hautfarbe,_helle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_medio_y_tono_de_piel_claro:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_légèrement_mate_et_peau_claire:',
        'ja': u':手をつなぐ2人_中間の肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_갈색_피부_하얀_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_e_pele_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_طلایی_پوست_سفید:',
        'id': ':orang_bergandengan_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个人_中等肤色较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FE': { # 🧑🏽‍🤝‍🧑🏾
        'en' : ':people_holding_hands_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sich_an_den_händen_haltende_personen_mittlere_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_légèrement_mate_et_peau_mate:',
        'ja': u':手をつなぐ2人_中間の肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_갈색_피부_진한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_e_pele_morena_escura:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_طلایی_پوست_گندمی:',
        'id': ':orang_bergandengan_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个人_中等肤色中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F9D1\U0001F3FC': { # 🧑🏽‍🤝‍🧑🏼
        'en' : ':people_holding_hands_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':sich_an_den_händen_haltende_personen_mittlere_hautfarbe,_mittelhelle_hautfarbe:',
        'es': u':dos_personas_dándose_la_mano_tono_de_piel_medio_y_tono_de_piel_claro_medio:',
        'fr': u':deux_personnes_se_tenant_la_main_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ2人_中間の肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_사람_갈색_피부_연한_갈색_피부:',
        'pt': u':pessoas_de_mãos_dadas_pele_morena_e_pele_morena_clara:',
        'it': ':persone_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':اشخاصی_دست_در_دست_هم_پوست_طلایی_پوست_روشن:',
        'id': ':orang_bergandengan_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个人_中等肤色中等浅肤色:'
    },
    u'\U0001FAC2': { # 🫂
        'en' : ':people_hugging:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':sich_umarmende_personen:',
        'es': u':personas_abrazándose:',
        'fr': u':étreinte:',
        'ja': u':ハグする人:',
        'ko': u':포옹하는_사람:',
        'pt': u':pessoas_se_abraçando:',
        'it': ':persone_che_si_abbracciano:',
        'fa': u':درآغوش_گرفتن:',
        'id': ':orang_berpelukan:',
        'zh': u':人的拥抱:'
    },
    u'\U0001F46F': { # 👯
        'en' : ':people_with_bunny_ears:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dancers:'],
        'de': ':personen_mit_hasenohren:',
        'es': ':personas_con_orejas_de_conejo:',
        'fr': ':personnes_avec_des_oreilles_de_lapin:',
        'ja': u':バニー:',
        'ko': u':토끼_귀를_쓰고_춤추는_사람들:',
        'pt': ':pessoas_com_orelhas_de_coelho:',
        'it': ':persone_con_orecchie_da_coniglio:',
        'fa': u':رقص:',
        'id': ':orang_dengan_telinga_kelinci:',
        'zh': u':戴兔耳朵的人:'
    },
    u'\U0001F93C': { # 🤼
        'en' : ':people_wrestling:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':wrestling:'],
        'de': ':ringer(in):',
        'es': ':personas_luchando:',
        'fr': ':personnes_faisant_de_la_lutte:',
        'ja': u':レスリングする人:',
        'ko': u':레슬링하는_사람:',
        'pt': ':pessoas_lutando:',
        'it': ':persone_che_fanno_la_lotta:',
        'fa': u':کُشتی_گیران:',
        'id': ':orang_bergulat:',
        'zh': u':摔跤选手:'
    },
    u'\U0001F3AD': { # 🎭
        'en' : ':performing_arts:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':masken:',
        'es': u':máscaras_de_teatro:',
        'fr': ':spectacle_vivant:',
        'ja': u':舞台芸術:',
        'ko': u':가면:',
        'pt': u':máscara:',
        'it': ':maschere:',
        'fa': u':هنرهای_نمایشی:',
        'id': ':seni_drama:',
        'zh': u':表演艺术:'
    },
    u'\U0001F623': { # 😣
        'en' : ':persevering_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':persevere:'],
        'de': ':entschlossenes_gesicht:',
        'es': ':cara_desesperada:',
        'fr': u':visage_persévérant:',
        'ja': u':我慢:',
        'ko': u':참아내는_얼굴:',
        'pt': ':rosto_perseverante:',
        'it': ':faccina_perseverante:',
        'fa': u':پافشاری:',
        'id': ':wajah_tidak_setuju:',
        'zh': u':痛苦:'
    },
    u'\U0001F9D1': { # 🧑
        'en' : ':person:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':adult:'],
        'de': ':person:',
        'es': ':persona_adulta:',
        'fr': ':adulte:',
        'ja': u':大人:',
        'ko': u':사람:',
        'pt': ':pessoa:',
        'it': ':persona:',
        'fa': u':شخص:',
        'id': ':dewasa:',
        'zh': u':成人:'
    },
    u'\U0001F9D1\U0000200D\U0001F9B2': { # 🧑‍🦲
        'en' : ':person_bald:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_glatze:',
        'es': ':persona_adulta_sin_pelo:',
        'fr': ':adulte_chauve:',
        'ja': u':大人_はげ頭:',
        'ko': u':사람_대머리:',
        'pt': ':pessoa_careca:',
        'it': ':persona_calvo:',
        'fa': u':بزرگسال_تاس:',
        'id': ':dewasa_gundul:',
        'zh': u':成人_秃顶:'
    },
    u'\U0001F9D4': { # 🧔
        'en' : ':person_beard:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':bearded_person:'],
        'de': ':person_bart:',
        'es': ':persona_con_barba:',
        'fr': ':personne_barbue:',
        'ja': u':あごひげの人:',
        'ko': u':수염_난_사람:',
        'pt': ':homem_barba:',
        'it': ':persona_con_la_barba:',
        'fa': u':مرد_ریش_دار:',
        'id': ':orang_janggut:',
        'zh': u':有胡子的人:'
    },
    u'\U0001F6B4': { # 🚴
        'en' : ':person_biking:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':bicyclist:'],
        'de': ':radfahrer(in):',
        'es': ':persona_en_bicicleta:',
        'fr': ':cycliste:',
        'ja': u':自転車に乗る人:',
        'ko': u':자전거_타는_사람:',
        'pt': ':ciclista:',
        'it': ':ciclista:',
        'fa': u':دوچرخه_سوار:',
        'id': ':orang_bersepeda:',
        'zh': u':骑自行车:'
    },
    u'\U0001F6B4\U0001F3FF': { # 🚴🏿
        'en' : ':person_biking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':radfahrer(in)_dunkle_hautfarbe:',
        'es': ':persona_en_bicicleta_tono_de_piel_oscuro:',
        'fr': u':cycliste_peau_foncée:',
        'ja': u':自転車に乗る人_濃い肌色:',
        'ko': u':자전거_타는_사람_검은색_피부:',
        'pt': ':ciclista_pele_escura:',
        'it': ':ciclista_carnagione_scura:',
        'fa': u':دوچرخه_سوار_پوست_آبنوسی:',
        'id': ':orang_bersepeda_warna_kulit_gelap:',
        'zh': u':骑自行车_较深肤色:'
    },
    u'\U0001F6B4\U0001F3FB': { # 🚴🏻
        'en' : ':person_biking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':radfahrer(in)_helle_hautfarbe:',
        'es': ':persona_en_bicicleta_tono_de_piel_claro:',
        'fr': ':cycliste_peau_claire:',
        'ja': u':自転車に乗る人_薄い肌色:',
        'ko': u':자전거_타는_사람_하얀_피부:',
        'pt': ':ciclista_pele_clara:',
        'it': ':ciclista_carnagione_chiara:',
        'fa': u':دوچرخه_سوار_پوست_سفید:',
        'id': ':orang_bersepeda_warna_kulit_cerah:',
        'zh': u':骑自行车_较浅肤色:'
    },
    u'\U0001F6B4\U0001F3FE': { # 🚴🏾
        'en' : ':person_biking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':radfahrer(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_en_bicicleta_tono_de_piel_oscuro_medio:',
        'fr': ':cycliste_peau_mate:',
        'ja': u':自転車に乗る人_やや濃い肌色:',
        'ko': u':자전거_타는_사람_진한_갈색_피부:',
        'pt': ':ciclista_pele_morena_escura:',
        'it': ':ciclista_carnagione_abbastanza_scura:',
        'fa': u':دوچرخه_سوار_پوست_گندمی:',
        'id': ':orang_bersepeda_warna_kulit_gelap-sedang:',
        'zh': u':骑自行车_中等深肤色:'
    },
    u'\U0001F6B4\U0001F3FC': { # 🚴🏼
        'en' : ':person_biking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':radfahrer(in)_mittelhelle_hautfarbe:',
        'es': ':persona_en_bicicleta_tono_de_piel_claro_medio:',
        'fr': ':cycliste_peau_moyennement_claire:',
        'ja': u':自転車に乗る人_やや薄い肌色:',
        'ko': u':자전거_타는_사람_연한_갈색_피부:',
        'pt': ':ciclista_pele_morena_clara:',
        'it': ':ciclista_carnagione_abbastanza_chiara:',
        'fa': u':دوچرخه_سوار_پوست_روشن:',
        'id': ':orang_bersepeda_warna_kulit_cerah-sedang:',
        'zh': u':骑自行车_中等浅肤色:'
    },
    u'\U0001F6B4\U0001F3FD': { # 🚴🏽
        'en' : ':person_biking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':radfahrer(in)_mittlere_hautfarbe:',
        'es': ':persona_en_bicicleta_tono_de_piel_medio:',
        'fr': u':cycliste_peau_légèrement_mate:',
        'ja': u':自転車に乗る人_中間の肌色:',
        'ko': u':자전거_타는_사람_갈색_피부:',
        'pt': ':ciclista_pele_morena:',
        'it': ':ciclista_carnagione_olivastra:',
        'fa': u':دوچرخه_سوار_پوست_طلایی:',
        'id': ':orang_bersepeda_warna_kulit_sedang:',
        'zh': u':骑自行车_中等肤色:'
    },
    u'\U0001F471': { # 👱
        'en' : ':person_blond_hair:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':blond_haired_person:', ':person_with_blond_hair:'],
        'de': ':person_blondes_haar:',
        'es': ':persona_adulta_rubia:',
        'fr': ':personne_blonde:',
        'ja': u':金髪の人:',
        'ko': u':금발인_사람:',
        'pt': ':pessoa_cabelo_louro:',
        'it': ':persona_bionda:',
        'fa': u':آدم_موبلوند:',
        'id': ':orang_rambut_pirang:',
        'zh': u':金色头发的人:'
    },
    u'\U000026F9\U0000FE0F': { # ⛹️
        'en' : ':person_bouncing_ball:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':bouncing_ball_person:', ':person_with_ball:'],
        'variant': True,
        'de': ':person_mit_ball:',
        'es': u':persona_botando_un_balón:',
        'fr': ':personne_avec_ballon:',
        'ja': u':バスケットボールをする人:',
        'ko': u':공을_갖고_있는_사람:',
        'pt': ':pessoa_jogando_basquete:',
        'it': ':persona_che_fa_rimbalzare_una_palla:',
        'fa': u':شخص_با_توپ:',
        'id': ':orang_memantulkan_bola:',
        'zh': u':玩球:'
    },
    u'\U000026F9': { # ⛹
        'en' : ':person_bouncing_ball:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':bouncing_ball_person:', ':person_with_ball:'],
        'variant': True,
        'de': ':person_mit_ball:',
        'es': u':persona_botando_un_balón:',
        'fr': ':personne_avec_ballon:',
        'ja': u':バスケットボールをする人:',
        'ko': u':공을_갖고_있는_사람:',
        'pt': ':pessoa_jogando_basquete:',
        'it': ':persona_che_fa_rimbalzare_una_palla:',
        'fa': u':شخص_با_توپ:',
        'id': ':orang_memantulkan_bola:',
        'zh': u':玩球:'
    },
    u'\U000026F9\U0001F3FF': { # ⛹🏿
        'en' : ':person_bouncing_ball_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':person_mit_ball_dunkle_hautfarbe:',
        'es': u':persona_botando_un_balón_tono_de_piel_oscuro:',
        'fr': u':personne_avec_ballon_peau_foncée:',
        'ja': u':バスケットボールをする人_濃い肌色:',
        'ko': u':공을_갖고_있는_사람_검은색_피부:',
        'pt': ':pessoa_jogando_basquete_pele_escura:',
        'it': ':persona_che_fa_rimbalzare_una_palla_carnagione_scura:',
        'fa': u':شخص_با_توپ_پوست_آبنوسی:',
        'id': ':orang_memantulkan_bola_warna_kulit_gelap:',
        'zh': u':玩球_较深肤色:'
    },
    u'\U000026F9\U0001F3FB': { # ⛹🏻
        'en' : ':person_bouncing_ball_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':person_mit_ball_helle_hautfarbe:',
        'es': u':persona_botando_un_balón_tono_de_piel_claro:',
        'fr': ':personne_avec_ballon_peau_claire:',
        'ja': u':バスケットボールをする人_薄い肌色:',
        'ko': u':공을_갖고_있는_사람_하얀_피부:',
        'pt': ':pessoa_jogando_basquete_pele_clara:',
        'it': ':persona_che_fa_rimbalzare_una_palla_carnagione_chiara:',
        'fa': u':شخص_با_توپ_پوست_سفید:',
        'id': ':orang_memantulkan_bola_warna_kulit_cerah:',
        'zh': u':玩球_较浅肤色:'
    },
    u'\U000026F9\U0001F3FE': { # ⛹🏾
        'en' : ':person_bouncing_ball_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':person_mit_ball_mitteldunkle_hautfarbe:',
        'es': u':persona_botando_un_balón_tono_de_piel_oscuro_medio:',
        'fr': ':personne_avec_ballon_peau_mate:',
        'ja': u':バスケットボールをする人_やや濃い肌色:',
        'ko': u':공을_갖고_있는_사람_진한_갈색_피부:',
        'pt': ':pessoa_jogando_basquete_pele_morena_escura:',
        'it': ':persona_che_fa_rimbalzare_una_palla_carnagione_abbastanza_scura:',
        'fa': u':شخص_با_توپ_پوست_گندمی:',
        'id': ':orang_memantulkan_bola_warna_kulit_gelap-sedang:',
        'zh': u':玩球_中等深肤色:'
    },
    u'\U000026F9\U0001F3FC': { # ⛹🏼
        'en' : ':person_bouncing_ball_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':person_mit_ball_mittelhelle_hautfarbe:',
        'es': u':persona_botando_un_balón_tono_de_piel_claro_medio:',
        'fr': ':personne_avec_ballon_peau_moyennement_claire:',
        'ja': u':バスケットボールをする人_やや薄い肌色:',
        'ko': u':공을_갖고_있는_사람_연한_갈색_피부:',
        'pt': ':pessoa_jogando_basquete_pele_morena_clara:',
        'it': ':persona_che_fa_rimbalzare_una_palla_carnagione_abbastanza_chiara:',
        'fa': u':شخص_با_توپ_پوست_روشن:',
        'id': ':orang_memantulkan_bola_warna_kulit_cerah-sedang:',
        'zh': u':玩球_中等浅肤色:'
    },
    u'\U000026F9\U0001F3FD': { # ⛹🏽
        'en' : ':person_bouncing_ball_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':person_mit_ball_mittlere_hautfarbe:',
        'es': u':persona_botando_un_balón_tono_de_piel_medio:',
        'fr': u':personne_avec_ballon_peau_légèrement_mate:',
        'ja': u':バスケットボールをする人_中間の肌色:',
        'ko': u':공을_갖고_있는_사람_갈색_피부:',
        'pt': ':pessoa_jogando_basquete_pele_morena:',
        'it': ':persona_che_fa_rimbalzare_una_palla_carnagione_olivastra:',
        'fa': u':شخص_با_توپ_پوست_طلایی:',
        'id': ':orang_memantulkan_bola_warna_kulit_sedang:',
        'zh': u':玩球_中等肤色:'
    },
    u'\U0001F647': { # 🙇
        'en' : ':person_bowing:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bow:'],
        'de': ':sich_verbeugende_person:',
        'es': ':persona_haciendo_una_reverencia:',
        'fr': u':personne_qui_s’incline:',
        'ja': u':おじぎする人:',
        'ko': u':절하는_사람:',
        'pt': u':pessoa_fazendo_reverência:',
        'it': ':persona_che_fa_un_inchino_profondo:',
        'fa': u':عذرخواهی:',
        'id': ':orang_membungkuk:',
        'zh': u':鞠躬:'
    },
    u'\U0001F647\U0001F3FF': { # 🙇🏿
        'en' : ':person_bowing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':sich_verbeugende_person_dunkle_hautfarbe:',
        'es': ':persona_haciendo_una_reverencia_tono_de_piel_oscuro:',
        'fr': u':personne_qui_s’incline_peau_foncée:',
        'ja': u':おじぎする人_濃い肌色:',
        'ko': u':절하는_사람_검은색_피부:',
        'pt': u':pessoa_fazendo_reverência_pele_escura:',
        'it': ':persona_che_fa_un_inchino_profondo_carnagione_scura:',
        'fa': u':عذرخواهی_پوست_آبنوسی:',
        'id': ':orang_membungkuk_warna_kulit_gelap:',
        'zh': u':鞠躬_较深肤色:'
    },
    u'\U0001F647\U0001F3FB': { # 🙇🏻
        'en' : ':person_bowing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':sich_verbeugende_person_helle_hautfarbe:',
        'es': ':persona_haciendo_una_reverencia_tono_de_piel_claro:',
        'fr': u':personne_qui_s’incline_peau_claire:',
        'ja': u':おじぎする人_薄い肌色:',
        'ko': u':절하는_사람_하얀_피부:',
        'pt': u':pessoa_fazendo_reverência_pele_clara:',
        'it': ':persona_che_fa_un_inchino_profondo_carnagione_chiara:',
        'fa': u':عذرخواهی_پوست_سفید:',
        'id': ':orang_membungkuk_warna_kulit_cerah:',
        'zh': u':鞠躬_较浅肤色:'
    },
    u'\U0001F647\U0001F3FE': { # 🙇🏾
        'en' : ':person_bowing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':sich_verbeugende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_haciendo_una_reverencia_tono_de_piel_oscuro_medio:',
        'fr': u':personne_qui_s’incline_peau_mate:',
        'ja': u':おじぎする人_やや濃い肌色:',
        'ko': u':절하는_사람_진한_갈색_피부:',
        'pt': u':pessoa_fazendo_reverência_pele_morena_escura:',
        'it': ':persona_che_fa_un_inchino_profondo_carnagione_abbastanza_scura:',
        'fa': u':عذرخواهی_پوست_گندمی:',
        'id': ':orang_membungkuk_warna_kulit_gelap-sedang:',
        'zh': u':鞠躬_中等深肤色:'
    },
    u'\U0001F647\U0001F3FC': { # 🙇🏼
        'en' : ':person_bowing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':sich_verbeugende_person_mittelhelle_hautfarbe:',
        'es': ':persona_haciendo_una_reverencia_tono_de_piel_claro_medio:',
        'fr': u':personne_qui_s’incline_peau_moyennement_claire:',
        'ja': u':おじぎする人_やや薄い肌色:',
        'ko': u':절하는_사람_연한_갈색_피부:',
        'pt': u':pessoa_fazendo_reverência_pele_morena_clara:',
        'it': ':persona_che_fa_un_inchino_profondo_carnagione_abbastanza_chiara:',
        'fa': u':عذرخواهی_پوست_روشن:',
        'id': ':orang_membungkuk_warna_kulit_cerah-sedang:',
        'zh': u':鞠躬_中等浅肤色:'
    },
    u'\U0001F647\U0001F3FD': { # 🙇🏽
        'en' : ':person_bowing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':sich_verbeugende_person_mittlere_hautfarbe:',
        'es': ':persona_haciendo_una_reverencia_tono_de_piel_medio:',
        'fr': u':personne_qui_s’incline_peau_légèrement_mate:',
        'ja': u':おじぎする人_中間の肌色:',
        'ko': u':절하는_사람_갈색_피부:',
        'pt': u':pessoa_fazendo_reverência_pele_morena:',
        'it': ':persona_che_fa_un_inchino_profondo_carnagione_olivastra:',
        'fa': u':عذرخواهی_پوست_طلایی:',
        'id': ':orang_membungkuk_warna_kulit_sedang:',
        'zh': u':鞠躬_中等肤色:'
    },
    u'\U0001F938': { # 🤸
        'en' : ':person_cartwheeling:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':cartwheeling:'],
        'de': ':rad_schlagende_person:',
        'es': ':persona_haciendo_voltereta_lateral:',
        'fr': ':personne_faisant_la_roue:',
        'ja': u':側転する人:',
        'ko': u':옆돌기하는_사람:',
        'pt': ':pessoa_fazendo_estrela:',
        'it': ':persona_che_fa_la_ruota:',
        'fa': u':حرکت_چرخ_و_فلک:',
        'id': ':orang_melakukan_gerakan_meroda:',
        'zh': u':侧手翻:'
    },
    u'\U0001F938\U0001F3FF': { # 🤸🏿
        'en' : ':person_cartwheeling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':rad_schlagende_person_dunkle_hautfarbe:',
        'es': ':persona_haciendo_voltereta_lateral_tono_de_piel_oscuro:',
        'fr': u':personne_faisant_la_roue_peau_foncée:',
        'ja': u':側転する人_濃い肌色:',
        'ko': u':옆돌기하는_사람_검은색_피부:',
        'pt': ':pessoa_fazendo_estrela_pele_escura:',
        'it': ':persona_che_fa_la_ruota_carnagione_scura:',
        'fa': u':حرکت_چرخ_و_فلک_پوست_آبنوسی:',
        'id': ':orang_melakukan_gerakan_meroda_warna_kulit_gelap:',
        'zh': u':侧手翻_较深肤色:'
    },
    u'\U0001F938\U0001F3FB': { # 🤸🏻
        'en' : ':person_cartwheeling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':rad_schlagende_person_helle_hautfarbe:',
        'es': ':persona_haciendo_voltereta_lateral_tono_de_piel_claro:',
        'fr': ':personne_faisant_la_roue_peau_claire:',
        'ja': u':側転する人_薄い肌色:',
        'ko': u':옆돌기하는_사람_하얀_피부:',
        'pt': ':pessoa_fazendo_estrela_pele_clara:',
        'it': ':persona_che_fa_la_ruota_carnagione_chiara:',
        'fa': u':حرکت_چرخ_و_فلک_پوست_سفید:',
        'id': ':orang_melakukan_gerakan_meroda_warna_kulit_cerah:',
        'zh': u':侧手翻_较浅肤色:'
    },
    u'\U0001F938\U0001F3FE': { # 🤸🏾
        'en' : ':person_cartwheeling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':rad_schlagende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_haciendo_voltereta_lateral_tono_de_piel_oscuro_medio:',
        'fr': ':personne_faisant_la_roue_peau_mate:',
        'ja': u':側転する人_やや濃い肌色:',
        'ko': u':옆돌기하는_사람_진한_갈색_피부:',
        'pt': ':pessoa_fazendo_estrela_pele_morena_escura:',
        'it': ':persona_che_fa_la_ruota_carnagione_abbastanza_scura:',
        'fa': u':حرکت_چرخ_و_فلک_پوست_گندمی:',
        'id': ':orang_melakukan_gerakan_meroda_warna_kulit_gelap-sedang:',
        'zh': u':侧手翻_中等深肤色:'
    },
    u'\U0001F938\U0001F3FC': { # 🤸🏼
        'en' : ':person_cartwheeling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':rad_schlagende_person_mittelhelle_hautfarbe:',
        'es': ':persona_haciendo_voltereta_lateral_tono_de_piel_claro_medio:',
        'fr': ':personne_faisant_la_roue_peau_moyennement_claire:',
        'ja': u':側転する人_やや薄い肌色:',
        'ko': u':옆돌기하는_사람_연한_갈색_피부:',
        'pt': ':pessoa_fazendo_estrela_pele_morena_clara:',
        'it': ':persona_che_fa_la_ruota_carnagione_abbastanza_chiara:',
        'fa': u':حرکت_چرخ_و_فلک_پوست_روشن:',
        'id': ':orang_melakukan_gerakan_meroda_warna_kulit_cerah-sedang:',
        'zh': u':侧手翻_中等浅肤色:'
    },
    u'\U0001F938\U0001F3FD': { # 🤸🏽
        'en' : ':person_cartwheeling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':rad_schlagende_person_mittlere_hautfarbe:',
        'es': ':persona_haciendo_voltereta_lateral_tono_de_piel_medio:',
        'fr': u':personne_faisant_la_roue_peau_légèrement_mate:',
        'ja': u':側転する人_中間の肌色:',
        'ko': u':옆돌기하는_사람_갈색_피부:',
        'pt': ':pessoa_fazendo_estrela_pele_morena:',
        'it': ':persona_che_fa_la_ruota_carnagione_olivastra:',
        'fa': u':حرکت_چرخ_و_فلک_پوست_طلایی:',
        'id': ':orang_melakukan_gerakan_meroda_warna_kulit_sedang:',
        'zh': u':侧手翻_中等肤色:'
    },
    u'\U0001F9D7': { # 🧗
        'en' : ':person_climbing:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':climbing:'],
        'de': ':bergsteiger(in):',
        'es': ':persona_escalando:',
        'fr': ':personne_qui_grimpe:',
        'ja': u':山を登る人:',
        'ko': u':클라이밍하는_사람:',
        'pt': ':pessoa_escalando:',
        'it': ':persona_che_scala:',
        'fa': u':فردی_کوه_نوردی_می_کند:',
        'id': ':orang_memanjat:',
        'zh': u':攀爬的人:'
    },
    u'\U0001F9D7\U0001F3FF': { # 🧗🏿
        'en' : ':person_climbing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger(in)_dunkle_hautfarbe:',
        'es': ':persona_escalando_tono_de_piel_oscuro:',
        'fr': u':personne_qui_grimpe_peau_foncée:',
        'ja': u':山を登る人_濃い肌色:',
        'ko': u':클라이밍하는_사람_검은색_피부:',
        'pt': ':pessoa_escalando_pele_escura:',
        'it': ':persona_che_scala_carnagione_scura:',
        'fa': u':فردی_کوه_نوردی_می_کند_پوست_آبنوسی:',
        'id': ':orang_memanjat_warna_kulit_gelap:',
        'zh': u':攀爬的人_较深肤色:'
    },
    u'\U0001F9D7\U0001F3FB': { # 🧗🏻
        'en' : ':person_climbing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger(in)_helle_hautfarbe:',
        'es': ':persona_escalando_tono_de_piel_claro:',
        'fr': ':personne_qui_grimpe_peau_claire:',
        'ja': u':山を登る人_薄い肌色:',
        'ko': u':클라이밍하는_사람_하얀_피부:',
        'pt': ':pessoa_escalando_pele_clara:',
        'it': ':persona_che_scala_carnagione_chiara:',
        'fa': u':فردی_کوه_نوردی_می_کند_پوست_سفید:',
        'id': ':orang_memanjat_warna_kulit_cerah:',
        'zh': u':攀爬的人_较浅肤色:'
    },
    u'\U0001F9D7\U0001F3FE': { # 🧗🏾
        'en' : ':person_climbing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_escalando_tono_de_piel_oscuro_medio:',
        'fr': ':personne_qui_grimpe_peau_mate:',
        'ja': u':山を登る人_やや濃い肌色:',
        'ko': u':클라이밍하는_사람_진한_갈색_피부:',
        'pt': ':pessoa_escalando_pele_morena_escura:',
        'it': ':persona_che_scala_carnagione_abbastanza_scura:',
        'fa': u':فردی_کوه_نوردی_می_کند_پوست_گندمی:',
        'id': ':orang_memanjat_warna_kulit_gelap-sedang:',
        'zh': u':攀爬的人_中等深肤色:'
    },
    u'\U0001F9D7\U0001F3FC': { # 🧗🏼
        'en' : ':person_climbing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger(in)_mittelhelle_hautfarbe:',
        'es': ':persona_escalando_tono_de_piel_claro_medio:',
        'fr': ':personne_qui_grimpe_peau_moyennement_claire:',
        'ja': u':山を登る人_やや薄い肌色:',
        'ko': u':클라이밍하는_사람_연한_갈색_피부:',
        'pt': ':pessoa_escalando_pele_morena_clara:',
        'it': ':persona_che_scala_carnagione_abbastanza_chiara:',
        'fa': u':فردی_کوه_نوردی_می_کند_پوست_روشن:',
        'id': ':orang_memanjat_warna_kulit_cerah-sedang:',
        'zh': u':攀爬的人_中等浅肤色:'
    },
    u'\U0001F9D7\U0001F3FD': { # 🧗🏽
        'en' : ':person_climbing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteiger(in)_mittlere_hautfarbe:',
        'es': ':persona_escalando_tono_de_piel_medio:',
        'fr': u':personne_qui_grimpe_peau_légèrement_mate:',
        'ja': u':山を登る人_中間の肌色:',
        'ko': u':클라이밍하는_사람_갈색_피부:',
        'pt': ':pessoa_escalando_pele_morena:',
        'it': ':persona_che_scala_carnagione_olivastra:',
        'fa': u':فردی_کوه_نوردی_می_کند_پوست_طلایی:',
        'id': ':orang_memanjat_warna_kulit_sedang:',
        'zh': u':攀爬的人_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F9B1': { # 🧑‍🦱
        'en' : ':person_curly_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_lockiges_haar:',
        'es': ':persona_adulta_pelo_rizado:',
        'fr': u':adulte_cheveux_bouclés:',
        'ja': u':大人_巻き毛:',
        'ko': u':사람_곱슬머리:',
        'pt': ':pessoa_cabelo_cacheado:',
        'it': ':persona_capelli_ricci:',
        'fa': u':بزرگسال_موفرفری:',
        'id': ':dewasa_rambut_keriting:',
        'zh': u':成人_卷发:'
    },
    u'\U0001F9D1\U0001F3FF': { # 🧑🏿
        'en' : ':person_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':erwachsener_dunkle_hautfarbe:',
        'es': ':persona_adulta_tono_de_piel_oscuro:',
        'fr': u':adulte_peau_foncée:',
        'ja': u':大人_濃い肌色:',
        'ko': u':사람_검은색_피부:',
        'pt': ':pessoa_pele_escura:',
        'it': ':persona_carnagione_scura:',
        'fa': u':بزرگسال_پوست_آبنوسی:',
        'id': ':dewasa_warna_kulit_gelap:',
        'zh': u':成人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F9B2': { # 🧑🏿‍🦲
        'en' : ':person_dark_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_dunkle_hautfarbe,_glatze:',
        'es': ':persona_adulta_tono_de_piel_oscuro_y_sin_pelo:',
        'fr': u':adulte_peau_foncée_et_chauve:',
        'ja': u':大人_濃い肌色_はげ頭:',
        'ko': u':사람_검은색_피부_대머리:',
        'pt': ':pessoa_pele_escura_e_careca:',
        'it': ':persona_carnagione_scura_e_calvo:',
        'fa': u':بزرگسال_پوست_آبنوسی_تاس:',
        'id': ':dewasa_warna_kulit_gelap_gundul:',
        'zh': u':成人_较深肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FF': { # 🧔🏿
        'en' : ':person_dark_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_dunkle_hautfarbe,_bart:',
        'es': ':persona_con_barba_tono_de_piel_oscuro:',
        'fr': u':personne_barbu_peau_foncée:',
        'ja': u':あごひげの人_濃い肌色:',
        'ko': u':수염_난_사람_검은색_피부:',
        'pt': ':pessoa_pele_escura_e_barba:',
        'it': ':persona_con_la_barba_carnagione_scura:',
        'fa': u':مرد_پوست_آبنوسی_ریش_دار:',
        'id': ':orang_warna_kulit_gelap_janggut:',
        'zh': u':有胡子的人_较深肤色:'
    },
    u'\U0001F471\U0001F3FF': { # 👱🏿
        'en' : ':person_dark_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_dunkle_hautfarbe,_blondes_haar:',
        'es': ':persona_adulta_rubia_tono_de_piel_oscuro:',
        'fr': u':personne_blonde_peau_foncée:',
        'ja': u':金髪の人_濃い肌色:',
        'ko': u':금발인_사람_검은색_피부:',
        'pt': ':pessoa_pele_escura_e_cabelo_louro:',
        'it': ':persona_bionda_carnagione_scura:',
        'fa': u':آدم_پوست_آبنوسی_موبلوند:',
        'id': ':orang_warna_kulit_gelap_rambut_pirang:',
        'zh': u':金色头发的人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F9B1': { # 🧑🏿‍🦱
        'en' : ':person_dark_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_dunkle_hautfarbe,_lockiges_haar:',
        'es': ':persona_adulta_tono_de_piel_oscuro_y_pelo_rizado:',
        'fr': u':adulte_peau_foncée_et_cheveux_bouclés:',
        'ja': u':大人_濃い肌色_巻き毛:',
        'ko': u':사람_검은색_피부_곱슬머리:',
        'pt': ':pessoa_pele_escura_e_cabelo_cacheado:',
        'it': ':persona_carnagione_scura_e_capelli_ricci:',
        'fa': u':بزرگسال_پوست_آبنوسی_موفرفری:',
        'id': ':dewasa_warna_kulit_gelap_rambut_keriting:',
        'zh': u':成人_较深肤色卷发:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F9B0': { # 🧑🏿‍🦰
        'en' : ':person_dark_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_dunkle_hautfarbe,_rotes_haar:',
        'es': ':persona_adulta_tono_de_piel_oscuro_y_pelo_pelirrojo:',
        'fr': u':adulte_peau_foncée_et_cheveux_roux:',
        'ja': u':大人_濃い肌色_赤毛:',
        'ko': u':사람_검은색_피부_빨간_머리:',
        'pt': ':pessoa_pele_escura_e_cabelo_vermelho:',
        'it': ':persona_carnagione_scura_e_capelli_rossi:',
        'fa': u':بزرگسال_پوست_آبنوسی_موقرمز:',
        'id': ':dewasa_warna_kulit_gelap_rambut_merah:',
        'zh': u':成人_较深肤色红发:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F9B3': { # 🧑🏿‍🦳
        'en' : ':person_dark_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':erwachsener_dunkle_hautfarbe,_weißes_haar:',
        'es': ':persona_adulta_tono_de_piel_oscuro_y_pelo_blanco:',
        'fr': u':adulte_peau_foncée_et_cheveux_blancs:',
        'ja': u':大人_濃い肌色_白髪:',
        'ko': u':사람_검은색_피부_백발:',
        'pt': ':pessoa_pele_escura_e_cabelo_branco:',
        'it': ':persona_carnagione_scura_e_capelli_bianchi:',
        'fa': u':بزرگسال_پوست_آبنوسی_موسفید:',
        'id': ':dewasa_warna_kulit_gelap_rambut_putih:',
        'zh': u':成人_较深肤色白发:'
    },
    u'\U0001F926': { # 🤦
        'en' : ':person_facepalming:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':facepalm:'],
        'de': ':sich_an_den_kopf_fassende_person:',
        'es': ':persona_con_la_mano_en_la_frente:',
        'fr': ':personne_avec_la_paume_sur_le_visage:',
        'ja': u':ひたいに手をあてる人:',
        'ko': u':골치_아파하는_사람:',
        'pt': ':pessoa_decepcionada:',
        'it': ':persona_esasperata:',
        'fa': u':با_کف_دست_به_پیشانی_زدن:',
        'id': ':orang_tepuk_jidat:',
        'zh': u':捂脸:'
    },
    u'\U0001F926\U0001F3FF': { # 🤦🏿
        'en' : ':person_facepalming_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':sich_an_den_kopf_fassende_person_dunkle_hautfarbe:',
        'es': ':persona_con_la_mano_en_la_frente_tono_de_piel_oscuro:',
        'fr': u':personne_avec_la_paume_sur_le_visage_peau_foncée:',
        'ja': u':ひたいに手をあてる人_濃い肌色:',
        'ko': u':골치_아파하는_사람_검은색_피부:',
        'pt': ':pessoa_decepcionada_pele_escura:',
        'it': ':persona_esasperata_carnagione_scura:',
        'fa': u':با_کف_دست_به_پیشانی_زدن_پوست_آبنوسی:',
        'id': ':orang_tepuk_jidat_warna_kulit_gelap:',
        'zh': u':捂脸_较深肤色:'
    },
    u'\U0001F926\U0001F3FB': { # 🤦🏻
        'en' : ':person_facepalming_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':sich_an_den_kopf_fassende_person_helle_hautfarbe:',
        'es': ':persona_con_la_mano_en_la_frente_tono_de_piel_claro:',
        'fr': ':personne_avec_la_paume_sur_le_visage_peau_claire:',
        'ja': u':ひたいに手をあてる人_薄い肌色:',
        'ko': u':골치_아파하는_사람_하얀_피부:',
        'pt': ':pessoa_decepcionada_pele_clara:',
        'it': ':persona_esasperata_carnagione_chiara:',
        'fa': u':با_کف_دست_به_پیشانی_زدن_پوست_سفید:',
        'id': ':orang_tepuk_jidat_warna_kulit_cerah:',
        'zh': u':捂脸_较浅肤色:'
    },
    u'\U0001F926\U0001F3FE': { # 🤦🏾
        'en' : ':person_facepalming_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':sich_an_den_kopf_fassende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_con_la_mano_en_la_frente_tono_de_piel_oscuro_medio:',
        'fr': ':personne_avec_la_paume_sur_le_visage_peau_mate:',
        'ja': u':ひたいに手をあてる人_やや濃い肌色:',
        'ko': u':골치_아파하는_사람_진한_갈색_피부:',
        'pt': ':pessoa_decepcionada_pele_morena_escura:',
        'it': ':persona_esasperata_carnagione_abbastanza_scura:',
        'fa': u':با_کف_دست_به_پیشانی_زدن_پوست_گندمی:',
        'id': ':orang_tepuk_jidat_warna_kulit_gelap-sedang:',
        'zh': u':捂脸_中等深肤色:'
    },
    u'\U0001F926\U0001F3FC': { # 🤦🏼
        'en' : ':person_facepalming_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':sich_an_den_kopf_fassende_person_mittelhelle_hautfarbe:',
        'es': ':persona_con_la_mano_en_la_frente_tono_de_piel_claro_medio:',
        'fr': ':personne_avec_la_paume_sur_le_visage_peau_moyennement_claire:',
        'ja': u':ひたいに手をあてる人_やや薄い肌色:',
        'ko': u':골치_아파하는_사람_연한_갈색_피부:',
        'pt': ':pessoa_decepcionada_pele_morena_clara:',
        'it': ':persona_esasperata_carnagione_abbastanza_chiara:',
        'fa': u':با_کف_دست_به_پیشانی_زدن_پوست_روشن:',
        'id': ':orang_tepuk_jidat_warna_kulit_cerah-sedang:',
        'zh': u':捂脸_中等浅肤色:'
    },
    u'\U0001F926\U0001F3FD': { # 🤦🏽
        'en' : ':person_facepalming_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':sich_an_den_kopf_fassende_person_mittlere_hautfarbe:',
        'es': ':persona_con_la_mano_en_la_frente_tono_de_piel_medio:',
        'fr': u':personne_avec_la_paume_sur_le_visage_peau_légèrement_mate:',
        'ja': u':ひたいに手をあてる人_中間の肌色:',
        'ko': u':골치_아파하는_사람_갈색_피부:',
        'pt': ':pessoa_decepcionada_pele_morena:',
        'it': ':persona_esasperata_carnagione_olivastra:',
        'fa': u':با_کف_دست_به_پیشانی_زدن_پوست_طلایی:',
        'id': ':orang_tepuk_jidat_warna_kulit_sedang:',
        'zh': u':捂脸_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F37C': { # 🧑‍🍼
        'en' : ':person_feeding_baby:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_person:',
        'es': u':persona_alimentando_a_bebé:',
        'fr': u':personne_allaitant_un_bébé:',
        'ja': u':授乳する人:',
        'ko': u':수유_중인_사람:',
        'pt': u':pessoa_alimentando_bebê:',
        'it': ':persona_che_allatta:',
        'fa': u':شخصی_که_به_بچه_شیر_می_دهد:',
        'id': ':orang_menyusui_bayi:',
        'zh': u':哺乳的人:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F37C': { # 🧑🏿‍🍼
        'en' : ':person_feeding_baby_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_person_dunkle_hautfarbe:',
        'es': u':persona_alimentando_a_bebé_tono_de_piel_oscuro:',
        'fr': u':personne_allaitant_un_bébé_peau_foncée:',
        'ja': u':授乳する人_濃い肌色:',
        'ko': u':수유_중인_사람_검은색_피부:',
        'pt': u':pessoa_alimentando_bebê_pele_escura:',
        'it': ':persona_che_allatta_carnagione_scura:',
        'fa': u':شخصی_که_به_بچه_شیر_می_دهد_پوست_آبنوسی:',
        'id': ':orang_menyusui_bayi_warna_kulit_gelap:',
        'zh': u':哺乳的人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F37C': { # 🧑🏻‍🍼
        'en' : ':person_feeding_baby_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_person_helle_hautfarbe:',
        'es': u':persona_alimentando_a_bebé_tono_de_piel_claro:',
        'fr': u':personne_allaitant_un_bébé_peau_claire:',
        'ja': u':授乳する人_薄い肌色:',
        'ko': u':수유_중인_사람_하얀_피부:',
        'pt': u':pessoa_alimentando_bebê_pele_clara:',
        'it': ':persona_che_allatta_carnagione_chiara:',
        'fa': u':شخصی_که_به_بچه_شیر_می_دهد_پوست_سفید:',
        'id': ':orang_menyusui_bayi_warna_kulit_cerah:',
        'zh': u':哺乳的人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F37C': { # 🧑🏾‍🍼
        'en' : ':person_feeding_baby_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_person_mitteldunkle_hautfarbe:',
        'es': u':persona_alimentando_a_bebé_tono_de_piel_oscuro_medio:',
        'fr': u':personne_allaitant_un_bébé_peau_mate:',
        'ja': u':授乳する人_やや濃い肌色:',
        'ko': u':수유_중인_사람_진한_갈색_피부:',
        'pt': u':pessoa_alimentando_bebê_pele_morena_escura:',
        'it': ':persona_che_allatta_carnagione_abbastanza_scura:',
        'fa': u':شخصی_که_به_بچه_شیر_می_دهد_پوست_گندمی:',
        'id': ':orang_menyusui_bayi_warna_kulit_gelap-sedang:',
        'zh': u':哺乳的人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F37C': { # 🧑🏼‍🍼
        'en' : ':person_feeding_baby_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_person_mittelhelle_hautfarbe:',
        'es': u':persona_alimentando_a_bebé_tono_de_piel_claro_medio:',
        'fr': u':personne_allaitant_un_bébé_peau_moyennement_claire:',
        'ja': u':授乳する人_やや薄い肌色:',
        'ko': u':수유_중인_사람_연한_갈색_피부:',
        'pt': u':pessoa_alimentando_bebê_pele_morena_clara:',
        'it': ':persona_che_allatta_carnagione_abbastanza_chiara:',
        'fa': u':شخصی_که_به_بچه_شیر_می_دهد_پوست_روشن:',
        'id': ':orang_menyusui_bayi_warna_kulit_cerah-sedang:',
        'zh': u':哺乳的人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F37C': { # 🧑🏽‍🍼
        'en' : ':person_feeding_baby_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_person_mittlere_hautfarbe:',
        'es': u':persona_alimentando_a_bebé_tono_de_piel_medio:',
        'fr': u':personne_allaitant_un_bébé_peau_légèrement_mate:',
        'ja': u':授乳する人_中間の肌色:',
        'ko': u':수유_중인_사람_갈색_피부:',
        'pt': u':pessoa_alimentando_bebê_pele_morena:',
        'it': ':persona_che_allatta_carnagione_olivastra:',
        'fa': u':شخصی_که_به_بچه_شیر_می_دهد_پوست_طلایی:',
        'id': ':orang_menyusui_bayi_warna_kulit_sedang:',
        'zh': u':哺乳的人_中等肤色:'
    },
    u'\U0001F93A': { # 🤺
        'en' : ':person_fencing:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':fechter(in):',
        'es': ':persona_haciendo_esgrima:',
        'fr': ':escrimeur:',
        'ja': u':フェンシングをする人:',
        'ko': u':펜싱하는_사람:',
        'pt': ':esgrimista:',
        'it': ':schermidore:',
        'fa': u':شمشیربازی:',
        'id': ':orang_berolahraga_anggar:',
        'zh': u':击剑选手:'
    },
    u'\U0001F64D': { # 🙍
        'en' : ':person_frowning:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':frowning_person:'],
        'de': ':missmutige_person:',
        'es': u':persona_frunciendo_el_ceño:',
        'fr': u':personne_fronçant_les_sourcils:',
        'ja': u':しかめ面の人:',
        'ko': u':찌푸린_사람:',
        'pt': ':franzindo_a_sobrancelha:',
        'it': ':persona_corrucciata:',
        'fa': u':آدم_اخمو:',
        'id': ':orang_marah:',
        'zh': u':皱眉:'
    },
    u'\U0001F64D\U0001F3FF': { # 🙍🏿
        'en' : ':person_frowning_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':missmutige_person_dunkle_hautfarbe:',
        'es': u':persona_frunciendo_el_ceño_tono_de_piel_oscuro:',
        'fr': u':personne_fronçant_les_sourcils_peau_foncée:',
        'ja': u':しかめ面の人_濃い肌色:',
        'ko': u':찌푸린_사람_검은색_피부:',
        'pt': ':franzindo_a_sobrancelha_pele_escura:',
        'it': ':persona_corrucciata_carnagione_scura:',
        'fa': u':آدم_اخمو_پوست_آبنوسی:',
        'id': ':orang_marah_warna_kulit_gelap:',
        'zh': u':皱眉_较深肤色:'
    },
    u'\U0001F64D\U0001F3FB': { # 🙍🏻
        'en' : ':person_frowning_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':missmutige_person_helle_hautfarbe:',
        'es': u':persona_frunciendo_el_ceño_tono_de_piel_claro:',
        'fr': u':personne_fronçant_les_sourcils_peau_claire:',
        'ja': u':しかめ面の人_薄い肌色:',
        'ko': u':찌푸린_사람_하얀_피부:',
        'pt': ':franzindo_a_sobrancelha_pele_clara:',
        'it': ':persona_corrucciata_carnagione_chiara:',
        'fa': u':آدم_اخمو_پوست_سفید:',
        'id': ':orang_marah_warna_kulit_cerah:',
        'zh': u':皱眉_较浅肤色:'
    },
    u'\U0001F64D\U0001F3FE': { # 🙍🏾
        'en' : ':person_frowning_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':missmutige_person_mitteldunkle_hautfarbe:',
        'es': u':persona_frunciendo_el_ceño_tono_de_piel_oscuro_medio:',
        'fr': u':personne_fronçant_les_sourcils_peau_mate:',
        'ja': u':しかめ面の人_やや濃い肌色:',
        'ko': u':찌푸린_사람_진한_갈색_피부:',
        'pt': ':franzindo_a_sobrancelha_pele_morena_escura:',
        'it': ':persona_corrucciata_carnagione_abbastanza_scura:',
        'fa': u':آدم_اخمو_پوست_گندمی:',
        'id': ':orang_marah_warna_kulit_gelap-sedang:',
        'zh': u':皱眉_中等深肤色:'
    },
    u'\U0001F64D\U0001F3FC': { # 🙍🏼
        'en' : ':person_frowning_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':missmutige_person_mittelhelle_hautfarbe:',
        'es': u':persona_frunciendo_el_ceño_tono_de_piel_claro_medio:',
        'fr': u':personne_fronçant_les_sourcils_peau_moyennement_claire:',
        'ja': u':しかめ面の人_やや薄い肌色:',
        'ko': u':찌푸린_사람_연한_갈색_피부:',
        'pt': ':franzindo_a_sobrancelha_pele_morena_clara:',
        'it': ':persona_corrucciata_carnagione_abbastanza_chiara:',
        'fa': u':آدم_اخمو_پوست_روشن:',
        'id': ':orang_marah_warna_kulit_cerah-sedang:',
        'zh': u':皱眉_中等浅肤色:'
    },
    u'\U0001F64D\U0001F3FD': { # 🙍🏽
        'en' : ':person_frowning_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':missmutige_person_mittlere_hautfarbe:',
        'es': u':persona_frunciendo_el_ceño_tono_de_piel_medio:',
        'fr': u':personne_fronçant_les_sourcils_peau_légèrement_mate:',
        'ja': u':しかめ面の人_中間の肌色:',
        'ko': u':찌푸린_사람_갈색_피부:',
        'pt': ':franzindo_a_sobrancelha_pele_morena:',
        'it': ':persona_corrucciata_carnagione_olivastra:',
        'fa': u':آدم_اخمو_پوست_طلایی:',
        'id': ':orang_marah_warna_kulit_sedang:',
        'zh': u':皱眉_中等肤色:'
    },
    u'\U0001F645': { # 🙅
        'en' : ':person_gesturing_NO:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':no_good:'],
        'de': u':person_mit_überkreuzten_armen:',
        'es': ':persona_haciendo_el_gesto_de_no:',
        'fr': u':personne_faisant_un_geste_d’interdiction:',
        'ja': u':ダメのポーズをする人:',
        'ko': u':안_된다는_제스처를_하는_사람:',
        'pt': u':pessoa_fazendo_gesto_de_“não”:',
        'it': ':persona_che_fa_segno_di_no:',
        'fa': u':ابداً_نه:',
        'id': ':orang_mengisyaratkan_tidak:',
        'zh': u':禁止手势:'
    },
    u'\U0001F645\U0001F3FF': { # 🙅🏿
        'en' : ':person_gesturing_NO_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_überkreuzten_armen_dunkle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_no_tono_de_piel_oscuro:',
        'fr': u':personne_faisant_un_geste_d’interdiction_peau_foncée:',
        'ja': u':ダメのポーズをする人_濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_사람_검은색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“não”_pele_escura:',
        'it': ':persona_che_fa_segno_di_no_carnagione_scura:',
        'fa': u':ابداً_نه_پوست_آبنوسی:',
        'id': ':orang_mengisyaratkan_tidak_warna_kulit_gelap:',
        'zh': u':禁止手势_较深肤色:'
    },
    u'\U0001F645\U0001F3FB': { # 🙅🏻
        'en' : ':person_gesturing_NO_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_überkreuzten_armen_helle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_no_tono_de_piel_claro:',
        'fr': u':personne_faisant_un_geste_d’interdiction_peau_claire:',
        'ja': u':ダメのポーズをする人_薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_사람_하얀_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“não”_pele_clara:',
        'it': ':persona_che_fa_segno_di_no_carnagione_chiara:',
        'fa': u':ابداً_نه_پوست_سفید:',
        'id': ':orang_mengisyaratkan_tidak_warna_kulit_cerah:',
        'zh': u':禁止手势_较浅肤色:'
    },
    u'\U0001F645\U0001F3FE': { # 🙅🏾
        'en' : ':person_gesturing_NO_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_überkreuzten_armen_mitteldunkle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_no_tono_de_piel_oscuro_medio:',
        'fr': u':personne_faisant_un_geste_d’interdiction_peau_mate:',
        'ja': u':ダメのポーズをする人_やや濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_사람_진한_갈색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“não”_pele_morena_escura:',
        'it': ':persona_che_fa_segno_di_no_carnagione_abbastanza_scura:',
        'fa': u':ابداً_نه_پوست_گندمی:',
        'id': ':orang_mengisyaratkan_tidak_warna_kulit_gelap-sedang:',
        'zh': u':禁止手势_中等深肤色:'
    },
    u'\U0001F645\U0001F3FC': { # 🙅🏼
        'en' : ':person_gesturing_NO_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_überkreuzten_armen_mittelhelle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_no_tono_de_piel_claro_medio:',
        'fr': u':personne_faisant_un_geste_d’interdiction_peau_moyennement_claire:',
        'ja': u':ダメのポーズをする人_やや薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_사람_연한_갈색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“não”_pele_morena_clara:',
        'it': ':persona_che_fa_segno_di_no_carnagione_abbastanza_chiara:',
        'fa': u':ابداً_نه_پوست_روشن:',
        'id': ':orang_mengisyaratkan_tidak_warna_kulit_cerah-sedang:',
        'zh': u':禁止手势_中等浅肤色:'
    },
    u'\U0001F645\U0001F3FD': { # 🙅🏽
        'en' : ':person_gesturing_NO_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_überkreuzten_armen_mittlere_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_no_tono_de_piel_medio:',
        'fr': u':personne_faisant_un_geste_d’interdiction_peau_légèrement_mate:',
        'ja': u':ダメのポーズをする人_中間の肌色:',
        'ko': u':안_된다는_제스처를_하는_사람_갈색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“não”_pele_morena:',
        'it': ':persona_che_fa_segno_di_no_carnagione_olivastra:',
        'fa': u':ابداً_نه_پوست_طلایی:',
        'id': ':orang_mengisyaratkan_tidak_warna_kulit_sedang:',
        'zh': u':禁止手势_中等肤色:'
    },
    u'\U0001F646': { # 🙆
        'en' : ':person_gesturing_OK:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ok_person:'],
        'de': u':person_mit_händen_auf_dem_kopf:',
        'es': ':persona_haciendo_el_gesto_de_de_acuerdo:',
        'fr': u':personne_faisant_un_geste_d’acceptation:',
        'ja': u':okのポーズをする人:',
        'ko': u':오케이라는_제스처를_하는_사람:',
        'pt': u':pessoa_fazendo_gesto_de_“ok”:',
        'it': ':persona_con_gesto_ok:',
        'fa': u':باشه:',
        'id': ':orang_mengisyaratkan_oke:',
        'zh': u':OK手势:'
    },
    u'\U0001F646\U0001F3FF': { # 🙆🏿
        'en' : ':person_gesturing_OK_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_händen_auf_dem_kopf_dunkle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro:',
        'fr': u':personne_faisant_un_geste_d’acceptation_peau_foncée:',
        'ja': u':okのポーズをする人_濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_사람_검은색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“ok”_pele_escura:',
        'it': ':persona_con_gesto_ok_carnagione_scura:',
        'fa': u':باشه_پوست_آبنوسی:',
        'id': ':orang_mengisyaratkan_oke_warna_kulit_gelap:',
        'zh': u':OK手势_较深肤色:'
    },
    u'\U0001F646\U0001F3FB': { # 🙆🏻
        'en' : ':person_gesturing_OK_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_händen_auf_dem_kopf_helle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro:',
        'fr': u':personne_faisant_un_geste_d’acceptation_peau_claire:',
        'ja': u':okのポーズをする人_薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_사람_하얀_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“ok”_pele_clara:',
        'it': ':persona_con_gesto_ok_carnagione_chiara:',
        'fa': u':باشه_پوست_سفید:',
        'id': ':orang_mengisyaratkan_oke_warna_kulit_cerah:',
        'zh': u':OK手势_较浅肤色:'
    },
    u'\U0001F646\U0001F3FE': { # 🙆🏾
        'en' : ':person_gesturing_OK_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_händen_auf_dem_kopf_mitteldunkle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro_medio:',
        'fr': u':personne_faisant_un_geste_d’acceptation_peau_mate:',
        'ja': u':okのポーズをする人_やや濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_사람_진한_갈색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“ok”_pele_morena_escura:',
        'it': ':persona_con_gesto_ok_carnagione_abbastanza_scura:',
        'fa': u':باشه_پوست_گندمی:',
        'id': ':orang_mengisyaratkan_oke_warna_kulit_gelap-sedang:',
        'zh': u':OK手势_中等深肤色:'
    },
    u'\U0001F646\U0001F3FC': { # 🙆🏼
        'en' : ':person_gesturing_OK_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_händen_auf_dem_kopf_mittelhelle_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro_medio:',
        'fr': u':personne_faisant_un_geste_d’acceptation_peau_moyennement_claire:',
        'ja': u':okのポーズをする人_やや薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_사람_연한_갈색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“ok”_pele_morena_clara:',
        'it': ':persona_con_gesto_ok_carnagione_abbastanza_chiara:',
        'fa': u':باشه_پوست_روشن:',
        'id': ':orang_mengisyaratkan_oke_warna_kulit_cerah-sedang:',
        'zh': u':OK手势_中等浅肤色:'
    },
    u'\U0001F646\U0001F3FD': { # 🙆🏽
        'en' : ':person_gesturing_OK_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':person_mit_händen_auf_dem_kopf_mittlere_hautfarbe:',
        'es': ':persona_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_medio:',
        'fr': u':personne_faisant_un_geste_d’acceptation_peau_légèrement_mate:',
        'ja': u':okのポーズをする人_中間の肌色:',
        'ko': u':오케이라는_제스처를_하는_사람_갈색_피부:',
        'pt': u':pessoa_fazendo_gesto_de_“ok”_pele_morena:',
        'it': ':persona_con_gesto_ok_carnagione_olivastra:',
        'fa': u':باشه_پوست_طلایی:',
        'id': ':orang_mengisyaratkan_oke_warna_kulit_sedang:',
        'zh': u':OK手势_中等肤色:'
    },
    u'\U0001F487': { # 💇
        'en' : ':person_getting_haircut:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':haircut:'],
        'de': ':person_beim_haareschneiden:',
        'es': u':persona_cortándose_el_pelo:',
        'fr': ':personne_qui_se_fait_couper_les_cheveux:',
        'ja': u':散髪される人:',
        'ko': u':헤어컷:',
        'pt': ':pessoa_cortando_o_cabelo:',
        'it': ':taglio_di_capelli:',
        'fa': u':آرایشگاه:',
        'id': ':orang_potong_rambut:',
        'zh': u':理发:'
    },
    u'\U0001F487\U0001F3FF': { # 💇🏿
        'en' : ':person_getting_haircut_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_beim_haareschneiden_dunkle_hautfarbe:',
        'es': u':persona_cortándose_el_pelo_tono_de_piel_oscuro:',
        'fr': u':personne_qui_se_fait_couper_les_cheveux_peau_foncée:',
        'ja': u':散髪される人_濃い肌色:',
        'ko': u':헤어컷_검은색_피부:',
        'pt': ':pessoa_cortando_o_cabelo_pele_escura:',
        'it': ':taglio_di_capelli_carnagione_scura:',
        'fa': u':آرایشگاه_پوست_آبنوسی:',
        'id': ':orang_potong_rambut_warna_kulit_gelap:',
        'zh': u':理发_较深肤色:'
    },
    u'\U0001F487\U0001F3FB': { # 💇🏻
        'en' : ':person_getting_haircut_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_beim_haareschneiden_helle_hautfarbe:',
        'es': u':persona_cortándose_el_pelo_tono_de_piel_claro:',
        'fr': ':personne_qui_se_fait_couper_les_cheveux_peau_claire:',
        'ja': u':散髪される人_薄い肌色:',
        'ko': u':헤어컷_하얀_피부:',
        'pt': ':pessoa_cortando_o_cabelo_pele_clara:',
        'it': ':taglio_di_capelli_carnagione_chiara:',
        'fa': u':آرایشگاه_پوست_سفید:',
        'id': ':orang_potong_rambut_warna_kulit_cerah:',
        'zh': u':理发_较浅肤色:'
    },
    u'\U0001F487\U0001F3FE': { # 💇🏾
        'en' : ':person_getting_haircut_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_beim_haareschneiden_mitteldunkle_hautfarbe:',
        'es': u':persona_cortándose_el_pelo_tono_de_piel_oscuro_medio:',
        'fr': ':personne_qui_se_fait_couper_les_cheveux_peau_mate:',
        'ja': u':散髪される人_やや濃い肌色:',
        'ko': u':헤어컷_진한_갈색_피부:',
        'pt': ':pessoa_cortando_o_cabelo_pele_morena_escura:',
        'it': ':taglio_di_capelli_carnagione_abbastanza_scura:',
        'fa': u':آرایشگاه_پوست_گندمی:',
        'id': ':orang_potong_rambut_warna_kulit_gelap-sedang:',
        'zh': u':理发_中等深肤色:'
    },
    u'\U0001F487\U0001F3FC': { # 💇🏼
        'en' : ':person_getting_haircut_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_beim_haareschneiden_mittelhelle_hautfarbe:',
        'es': u':persona_cortándose_el_pelo_tono_de_piel_claro_medio:',
        'fr': ':personne_qui_se_fait_couper_les_cheveux_peau_moyennement_claire:',
        'ja': u':散髪される人_やや薄い肌色:',
        'ko': u':헤어컷_연한_갈색_피부:',
        'pt': ':pessoa_cortando_o_cabelo_pele_morena_clara:',
        'it': ':taglio_di_capelli_carnagione_abbastanza_chiara:',
        'fa': u':آرایشگاه_پوست_روشن:',
        'id': ':orang_potong_rambut_warna_kulit_cerah-sedang:',
        'zh': u':理发_中等浅肤色:'
    },
    u'\U0001F487\U0001F3FD': { # 💇🏽
        'en' : ':person_getting_haircut_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_beim_haareschneiden_mittlere_hautfarbe:',
        'es': u':persona_cortándose_el_pelo_tono_de_piel_medio:',
        'fr': u':personne_qui_se_fait_couper_les_cheveux_peau_légèrement_mate:',
        'ja': u':散髪される人_中間の肌色:',
        'ko': u':헤어컷_갈색_피부:',
        'pt': ':pessoa_cortando_o_cabelo_pele_morena:',
        'it': ':taglio_di_capelli_carnagione_olivastra:',
        'fa': u':آرایشگاه_پوست_طلایی:',
        'id': ':orang_potong_rambut_warna_kulit_sedang:',
        'zh': u':理发_中等肤色:'
    },
    u'\U0001F486': { # 💆
        'en' : ':person_getting_massage:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':massage:'],
        'de': ':person_die_eine_kopfmassage_bekommt:',
        'es': ':persona_recibiendo_masaje:',
        'fr': ':personne_qui_se_fait_masser:',
        'ja': u':フェイスマッサージ中の人:',
        'ko': u':마사지_받는_사람:',
        'pt': ':pessoa_recebendo_massagem_facial:',
        'it': ':persona_che_riceve_un_massaggio:',
        'fa': u':ماساژ_صورت:',
        'id': ':pria_dipijat:',
        'zh': u':按摩:'
    },
    u'\U0001F486\U0001F3FF': { # 💆🏿
        'en' : ':person_getting_massage_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person,_die_eine_kopfmassage_bekommt_dunkle_hautfarbe:',
        'es': ':persona_recibiendo_masaje_tono_de_piel_oscuro:',
        'fr': u':personne_qui_se_fait_masser_peau_foncée:',
        'ja': u':フェイスマッサージ中の人_濃い肌色:',
        'ko': u':마사지_받는_사람_검은색_피부:',
        'pt': ':pessoa_recebendo_massagem_facial_pele_escura:',
        'it': ':persona_che_riceve_un_massaggio_carnagione_scura:',
        'fa': u':ماساژ_صورت_پوست_آبنوسی:',
        'id': ':pria_dipijat_warna_kulit_gelap:',
        'zh': u':按摩_较深肤色:'
    },
    u'\U0001F486\U0001F3FB': { # 💆🏻
        'en' : ':person_getting_massage_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person,_die_eine_kopfmassage_bekommt_helle_hautfarbe:',
        'es': ':persona_recibiendo_masaje_tono_de_piel_claro:',
        'fr': ':personne_qui_se_fait_masser_peau_claire:',
        'ja': u':フェイスマッサージ中の人_薄い肌色:',
        'ko': u':마사지_받는_사람_하얀_피부:',
        'pt': ':pessoa_recebendo_massagem_facial_pele_clara:',
        'it': ':persona_che_riceve_un_massaggio_carnagione_chiara:',
        'fa': u':ماساژ_صورت_پوست_سفید:',
        'id': ':pria_dipijat_warna_kulit_cerah:',
        'zh': u':按摩_较浅肤色:'
    },
    u'\U0001F486\U0001F3FE': { # 💆🏾
        'en' : ':person_getting_massage_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person,_die_eine_kopfmassage_bekommt_mitteldunkle_hautfarbe:',
        'es': ':persona_recibiendo_masaje_tono_de_piel_oscuro_medio:',
        'fr': ':personne_qui_se_fait_masser_peau_mate:',
        'ja': u':フェイスマッサージ中の人_やや濃い肌色:',
        'ko': u':마사지_받는_사람_진한_갈색_피부:',
        'pt': ':pessoa_recebendo_massagem_facial_pele_morena_escura:',
        'it': ':persona_che_riceve_un_massaggio_carnagione_abbastanza_scura:',
        'fa': u':ماساژ_صورت_پوست_گندمی:',
        'id': ':pria_dipijat_warna_kulit_gelap-sedang:',
        'zh': u':按摩_中等深肤色:'
    },
    u'\U0001F486\U0001F3FC': { # 💆🏼
        'en' : ':person_getting_massage_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person,_die_eine_kopfmassage_bekommt_mittelhelle_hautfarbe:',
        'es': ':persona_recibiendo_masaje_tono_de_piel_claro_medio:',
        'fr': ':personne_qui_se_fait_masser_peau_moyennement_claire:',
        'ja': u':フェイスマッサージ中の人_やや薄い肌色:',
        'ko': u':마사지_받는_사람_연한_갈색_피부:',
        'pt': ':pessoa_recebendo_massagem_facial_pele_morena_clara:',
        'it': ':persona_che_riceve_un_massaggio_carnagione_abbastanza_chiara:',
        'fa': u':ماساژ_صورت_پوست_روشن:',
        'id': ':pria_dipijat_warna_kulit_cerah-sedang:',
        'zh': u':按摩_中等浅肤色:'
    },
    u'\U0001F486\U0001F3FD': { # 💆🏽
        'en' : ':person_getting_massage_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person,_die_eine_kopfmassage_bekommt_mittlere_hautfarbe:',
        'es': ':persona_recibiendo_masaje_tono_de_piel_medio:',
        'fr': u':personne_qui_se_fait_masser_peau_légèrement_mate:',
        'ja': u':フェイスマッサージ中の人_中間の肌色:',
        'ko': u':마사지_받는_사람_갈색_피부:',
        'pt': ':pessoa_recebendo_massagem_facial_pele_morena:',
        'it': ':persona_che_riceve_un_massaggio_carnagione_olivastra:',
        'fa': u':ماساژ_صورت_پوست_طلایی:',
        'id': ':pria_dipijat_warna_kulit_sedang:',
        'zh': u':按摩_中等肤色:'
    },
    u'\U0001F3CC\U0000FE0F': { # 🏌️
        'en' : ':person_golfing:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':golfing:', ':golfer:'],
        'variant': True,
        'de': ':golfer(in):',
        'es': ':golfista:',
        'fr': ':joueur_de_golf:',
        'ja': u':ゴルフをする人:',
        'ko': u':골프치는_사람:',
        'pt': ':golfista:',
        'it': ':persona_che_gioca_a_golf:',
        'fa': u':گلف_باز:',
        'id': ':orang_bermain_golf:',
        'zh': u':打高尔夫的人:'
    },
    u'\U0001F3CC': { # 🏌
        'en' : ':person_golfing:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':golfing:', ':golfer:'],
        'variant': True,
        'de': ':golfer(in):',
        'es': ':persona_jugando_al_golf:',
        'fr': ':joueur_de_golf:',
        'ja': u':ゴルフをする人:',
        'ko': u':골프치는_사람:',
        'pt': ':golfista:',
        'it': ':persona_che_gioca_a_golf:',
        'fa': u':گلف_باز:',
        'id': ':orang_bermain_golf:',
        'zh': u':打高尔夫的人:'
    },
    u'\U0001F3CC\U0001F3FF': { # 🏌🏿
        'en' : ':person_golfing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer(in)_dunkle_hautfarbe:',
        'es': ':golfista_tono_de_piel_oscuro:',
        'fr': u':joueur_de_golf_peau_foncée:',
        'ja': u':ゴルフをする人_濃い肌色:',
        'ko': u':골프치는_사람_검은색_피부:',
        'pt': ':golfista_pele_escura:',
        'it': ':persona_che_gioca_a_golf_carnagione_scura:',
        'fa': u':گلف_باز_پوست_آبنوسی:',
        'id': ':orang_bermain_golf_warna_kulit_gelap:',
        'zh': u':打高尔夫的人_较深肤色:'
    },
    u'\U0001F3CC\U0001F3FB': { # 🏌🏻
        'en' : ':person_golfing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer(in)_helle_hautfarbe:',
        'es': ':golfista_tono_de_piel_claro:',
        'fr': ':joueur_de_golf_peau_claire:',
        'ja': u':ゴルフをする人_薄い肌色:',
        'ko': u':골프치는_사람_하얀_피부:',
        'pt': ':golfista_pele_clara:',
        'it': ':persona_che_gioca_a_golf_carnagione_chiara:',
        'fa': u':گلف_باز_پوست_سفید:',
        'id': ':orang_bermain_golf_warna_kulit_cerah:',
        'zh': u':打高尔夫的人_较浅肤色:'
    },
    u'\U0001F3CC\U0001F3FE': { # 🏌🏾
        'en' : ':person_golfing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer(in)_mitteldunkle_hautfarbe:',
        'es': ':golfista_tono_de_piel_oscuro_medio:',
        'fr': ':joueur_de_golf_peau_mate:',
        'ja': u':ゴルフをする人_やや濃い肌色:',
        'ko': u':골프치는_사람_진한_갈색_피부:',
        'pt': ':golfista_pele_morena_escura:',
        'it': ':persona_che_gioca_a_golf_carnagione_abbastanza_scura:',
        'fa': u':گلف_باز_پوست_گندمی:',
        'id': ':orang_bermain_golf_warna_kulit_gelap-sedang:',
        'zh': u':打高尔夫的人_中等深肤色:'
    },
    u'\U0001F3CC\U0001F3FC': { # 🏌🏼
        'en' : ':person_golfing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer(in)_mittelhelle_hautfarbe:',
        'es': ':golfista_tono_de_piel_claro_medio:',
        'fr': ':joueur_de_golf_peau_moyennement_claire:',
        'ja': u':ゴルフをする人_やや薄い肌色:',
        'ko': u':골프치는_사람_연한_갈색_피부:',
        'pt': ':golfista_pele_morena_clara:',
        'it': ':persona_che_gioca_a_golf_carnagione_abbastanza_chiara:',
        'fa': u':گلف_باز_پوست_روشن:',
        'id': ':orang_bermain_golf_warna_kulit_cerah-sedang:',
        'zh': u':打高尔夫的人_中等浅肤色:'
    },
    u'\U0001F3CC\U0001F3FD': { # 🏌🏽
        'en' : ':person_golfing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golfer(in)_mittlere_hautfarbe:',
        'es': ':golfista_tono_de_piel_medio:',
        'fr': u':joueur_de_golf_peau_légèrement_mate:',
        'ja': u':ゴルフをする人_中間の肌色:',
        'ko': u':골프치는_사람_갈색_피부:',
        'pt': ':golfista_pele_morena:',
        'it': ':persona_che_gioca_a_golf_carnagione_olivastra:',
        'fa': u':گلف_باز_پوست_طلایی:',
        'id': ':orang_bermain_golf_warna_kulit_sedang:',
        'zh': u':打高尔夫的人_中等肤色:'
    },
    u'\U0001F6CC': { # 🛌
        'en' : ':person_in_bed:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':sleeping_bed:', ':sleeping_accommodation:'],
        'de': ':im_bett_liegende_person:',
        'es': ':persona_en_la_cama:',
        'fr': ':personne_au_lit:',
        'ja': u':ベッドに寝る人:',
        'ko': u':침대에_누운_사람:',
        'pt': ':pessoa_deitada_na_cama:',
        'it': ':persona_a_letto:',
        'fa': u':فرد_در_تختخواب:',
        'id': ':orang_di_tempat_tidur:',
        'zh': u':躺在床上的人:'
    },
    u'\U0001F6CC\U0001F3FF': { # 🛌🏿
        'en' : ':person_in_bed_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':im_bett_liegende_person_dunkle_hautfarbe:',
        'es': ':persona_en_la_cama_tono_de_piel_oscuro:',
        'fr': u':personne_au_lit_peau_foncée:',
        'ja': u':ベッドに寝る人_濃い肌色:',
        'ko': u':침대에_누운_사람_검은색_피부:',
        'pt': ':pessoa_deitada_na_cama_pele_escura:',
        'it': ':persona_a_letto_carnagione_scura:',
        'fa': u':فرد_در_تختخواب_پوست_آبنوسی:',
        'id': ':orang_di_tempat_tidur_warna_kulit_gelap:',
        'zh': u':躺在床上的人_较深肤色:'
    },
    u'\U0001F6CC\U0001F3FB': { # 🛌🏻
        'en' : ':person_in_bed_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':im_bett_liegende_person_helle_hautfarbe:',
        'es': ':persona_en_la_cama_tono_de_piel_claro:',
        'fr': ':personne_au_lit_peau_claire:',
        'ja': u':ベッドに寝る人_薄い肌色:',
        'ko': u':침대에_누운_사람_하얀_피부:',
        'pt': ':pessoa_deitada_na_cama_pele_clara:',
        'it': ':persona_a_letto_carnagione_chiara:',
        'fa': u':فرد_در_تختخواب_پوست_سفید:',
        'id': ':orang_di_tempat_tidur_warna_kulit_cerah:',
        'zh': u':躺在床上的人_较浅肤色:'
    },
    u'\U0001F6CC\U0001F3FE': { # 🛌🏾
        'en' : ':person_in_bed_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':im_bett_liegende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_en_la_cama_tono_de_piel_oscuro_medio:',
        'fr': ':personne_au_lit_peau_mate:',
        'ja': u':ベッドに寝る人_やや濃い肌色:',
        'ko': u':침대에_누운_사람_진한_갈색_피부:',
        'pt': ':pessoa_deitada_na_cama_pele_morena_escura:',
        'it': ':persona_a_letto_carnagione_abbastanza_scura:',
        'fa': u':فرد_در_تختخواب_پوست_گندمی:',
        'id': ':orang_di_tempat_tidur_warna_kulit_gelap-sedang:',
        'zh': u':躺在床上的人_中等深肤色:'
    },
    u'\U0001F6CC\U0001F3FC': { # 🛌🏼
        'en' : ':person_in_bed_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':im_bett_liegende_person_mittelhelle_hautfarbe:',
        'es': ':persona_en_la_cama_tono_de_piel_claro_medio:',
        'fr': ':personne_au_lit_peau_moyennement_claire:',
        'ja': u':ベッドに寝る人_やや薄い肌色:',
        'ko': u':침대에_누운_사람_연한_갈색_피부:',
        'pt': ':pessoa_deitada_na_cama_pele_morena_clara:',
        'it': ':persona_a_letto_carnagione_abbastanza_chiara:',
        'fa': u':فرد_در_تختخواب_پوست_روشن:',
        'id': ':orang_di_tempat_tidur_warna_kulit_cerah-sedang:',
        'zh': u':躺在床上的人_中等浅肤色:'
    },
    u'\U0001F6CC\U0001F3FD': { # 🛌🏽
        'en' : ':person_in_bed_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':im_bett_liegende_person_mittlere_hautfarbe:',
        'es': ':persona_en_la_cama_tono_de_piel_medio:',
        'fr': u':personne_au_lit_peau_légèrement_mate:',
        'ja': u':ベッドに寝る人_中間の肌色:',
        'ko': u':침대에_누운_사람_갈색_피부:',
        'pt': ':pessoa_deitada_na_cama_pele_morena:',
        'it': ':persona_a_letto_carnagione_olivastra:',
        'fa': u':فرد_در_تختخواب_پوست_طلایی:',
        'id': ':orang_di_tempat_tidur_warna_kulit_sedang:',
        'zh': u':躺在床上的人_中等肤色:'
    },
    u'\U0001F9D8': { # 🧘
        'en' : ':person_in_lotus_position:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':lotus_position:'],
        'de': ':person_im_lotossitz:',
        'es': u':persona_en_posición_de_loto:',
        'fr': ':personne_dans_la_posture_du_lotus:',
        'ja': u':ヨガのポーズをする人:',
        'ko': u':가부좌한_사람:',
        'pt': u':pessoa_na_posição_de_lótus:',
        'it': ':persona_in_posizione_del_loto:',
        'fa': u':فرد_در_حالت_خلسه:',
        'id': ':orang_dalam_posisi_teratai:',
        'zh': u':盘腿的人:'
    },
    u'\U0001F9D8\U0001F3FF': { # 🧘🏿
        'en' : ':person_in_lotus_position_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_im_lotossitz_dunkle_hautfarbe:',
        'es': u':persona_en_posición_de_loto_tono_de_piel_oscuro:',
        'fr': u':personne_dans_la_posture_du_lotus_peau_foncée:',
        'ja': u':ヨガのポーズをする人_濃い肌色:',
        'ko': u':가부좌한_사람_검은색_피부:',
        'pt': u':pessoa_na_posição_de_lótus_pele_escura:',
        'it': ':persona_in_posizione_del_loto_carnagione_scura:',
        'fa': u':فرد_در_حالت_خلسه_پوست_آبنوسی:',
        'id': ':orang_dalam_posisi_teratai_warna_kulit_gelap:',
        'zh': u':盘腿的人_较深肤色:'
    },
    u'\U0001F9D8\U0001F3FB': { # 🧘🏻
        'en' : ':person_in_lotus_position_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_im_lotossitz_helle_hautfarbe:',
        'es': u':persona_en_posición_de_loto_tono_de_piel_claro:',
        'fr': ':personne_dans_la_posture_du_lotus_peau_claire:',
        'ja': u':ヨガのポーズをする人_薄い肌色:',
        'ko': u':가부좌한_사람_하얀_피부:',
        'pt': u':pessoa_na_posição_de_lótus_pele_clara:',
        'it': ':persona_in_posizione_del_loto_carnagione_chiara:',
        'fa': u':فرد_در_حالت_خلسه_پوست_سفید:',
        'id': ':orang_dalam_posisi_teratai_warna_kulit_cerah:',
        'zh': u':盘腿的人_较浅肤色:'
    },
    u'\U0001F9D8\U0001F3FE': { # 🧘🏾
        'en' : ':person_in_lotus_position_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_im_lotossitz_mitteldunkle_hautfarbe:',
        'es': u':persona_en_posición_de_loto_tono_de_piel_oscuro_medio:',
        'fr': ':personne_dans_la_posture_du_lotus_peau_mate:',
        'ja': u':ヨガのポーズをする人_やや濃い肌色:',
        'ko': u':가부좌한_사람_진한_갈색_피부:',
        'pt': u':pessoa_na_posição_de_lótus_pele_morena_escura:',
        'it': ':persona_in_posizione_del_loto_carnagione_abbastanza_scura:',
        'fa': u':فرد_در_حالت_خلسه_پوست_گندمی:',
        'id': ':orang_dalam_posisi_teratai_warna_kulit_gelap-sedang:',
        'zh': u':盘腿的人_中等深肤色:'
    },
    u'\U0001F9D8\U0001F3FC': { # 🧘🏼
        'en' : ':person_in_lotus_position_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_im_lotossitz_mittelhelle_hautfarbe:',
        'es': u':persona_en_posición_de_loto_tono_de_piel_claro_medio:',
        'fr': ':personne_dans_la_posture_du_lotus_peau_moyennement_claire:',
        'ja': u':ヨガのポーズをする人_やや薄い肌色:',
        'ko': u':가부좌한_사람_연한_갈색_피부:',
        'pt': u':pessoa_na_posição_de_lótus_pele_morena_clara:',
        'it': ':persona_in_posizione_del_loto_carnagione_abbastanza_chiara:',
        'fa': u':فرد_در_حالت_خلسه_پوست_روشن:',
        'id': ':orang_dalam_posisi_teratai_warna_kulit_cerah-sedang:',
        'zh': u':盘腿的人_中等浅肤色:'
    },
    u'\U0001F9D8\U0001F3FD': { # 🧘🏽
        'en' : ':person_in_lotus_position_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_im_lotossitz_mittlere_hautfarbe:',
        'es': u':persona_en_posición_de_loto_tono_de_piel_medio:',
        'fr': u':personne_dans_la_posture_du_lotus_peau_légèrement_mate:',
        'ja': u':ヨガのポーズをする人_中間の肌色:',
        'ko': u':가부좌한_사람_갈색_피부:',
        'pt': u':pessoa_na_posição_de_lótus_pele_morena:',
        'it': ':persona_in_posizione_del_loto_carnagione_olivastra:',
        'fa': u':فرد_در_حالت_خلسه_پوست_طلایی:',
        'id': ':orang_dalam_posisi_teratai_warna_kulit_sedang:',
        'zh': u':盘腿的人_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F9BD': { # 🧑‍🦽
        'en' : ':person_in_manual_wheelchair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_manuellem_rollstuhl:',
        'es': ':persona_en_silla_de_ruedas_manual:',
        'fr': ':personne_en_fauteuil_roulant_manuel:',
        'ja': u':手動式車椅子の人:',
        'ko': u':수동_휠체어를_탄_사람:',
        'pt': ':pessoa_em_cadeira_de_rodas_manual:',
        'it': ':persona_su_sedia_a_rotelle_manuale:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_دستی:',
        'id': ':orang_dengan_kursi_roda_manual:',
        'zh': u':坐手动轮椅的人:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F9BD': { # 🧑🏿‍🦽
        'en' : ':person_in_manual_wheelchair_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_manuellem_rollstuhl_dunkle_hautfarbe:',
        'es': ':persona_en_silla_de_ruedas_manual_tono_de_piel_oscuro:',
        'fr': u':personne_en_fauteuil_roulant_manuel_peau_foncée:',
        'ja': u':手動式車椅子の人_濃い肌色:',
        'ko': u':수동_휠체어를_탄_사람_검은색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_manual_pele_escura:',
        'it': ':persona_su_sedia_a_rotelle_manuale_carnagione_scura:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_دستی_پوست_آبنوسی:',
        'id': ':orang_dengan_kursi_roda_manual_warna_kulit_gelap:',
        'zh': u':坐手动轮椅的人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F9BD': { # 🧑🏻‍🦽
        'en' : ':person_in_manual_wheelchair_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_manuellem_rollstuhl_helle_hautfarbe:',
        'es': ':persona_en_silla_de_ruedas_manual_tono_de_piel_claro:',
        'fr': ':personne_en_fauteuil_roulant_manuel_peau_claire:',
        'ja': u':手動式車椅子の人_薄い肌色:',
        'ko': u':수동_휠체어를_탄_사람_하얀_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_manual_pele_clara:',
        'it': ':persona_su_sedia_a_rotelle_manuale_carnagione_chiara:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_دستی_پوست_سفید:',
        'id': ':orang_dengan_kursi_roda_manual_warna_kulit_cerah:',
        'zh': u':坐手动轮椅的人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F9BD': { # 🧑🏾‍🦽
        'en' : ':person_in_manual_wheelchair_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_manuellem_rollstuhl_mitteldunkle_hautfarbe:',
        'es': ':persona_en_silla_de_ruedas_manual_tono_de_piel_oscuro_medio:',
        'fr': ':personne_en_fauteuil_roulant_manuel_peau_mate:',
        'ja': u':手動式車椅子の人_やや濃い肌色:',
        'ko': u':수동_휠체어를_탄_사람_진한_갈색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_manual_pele_morena_escura:',
        'it': ':persona_su_sedia_a_rotelle_manuale_carnagione_abbastanza_scura:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_دستی_پوست_گندمی:',
        'id': ':orang_dengan_kursi_roda_manual_warna_kulit_gelap-sedang:',
        'zh': u':坐手动轮椅的人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F9BD': { # 🧑🏼‍🦽
        'en' : ':person_in_manual_wheelchair_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_manuellem_rollstuhl_mittelhelle_hautfarbe:',
        'es': ':persona_en_silla_de_ruedas_manual_tono_de_piel_claro_medio:',
        'fr': ':personne_en_fauteuil_roulant_manuel_peau_moyennement_claire:',
        'ja': u':手動式車椅子の人_やや薄い肌色:',
        'ko': u':수동_휠체어를_탄_사람_연한_갈색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_manual_pele_morena_clara:',
        'it': ':persona_su_sedia_a_rotelle_manuale_carnagione_abbastanza_chiara:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_دستی_پوست_روشن:',
        'id': ':orang_dengan_kursi_roda_manual_warna_kulit_cerah-sedang:',
        'zh': u':坐手动轮椅的人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F9BD': { # 🧑🏽‍🦽
        'en' : ':person_in_manual_wheelchair_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_manuellem_rollstuhl_mittlere_hautfarbe:',
        'es': ':persona_en_silla_de_ruedas_manual_tono_de_piel_medio:',
        'fr': u':personne_en_fauteuil_roulant_manuel_peau_légèrement_mate:',
        'ja': u':手動式車椅子の人_中間の肌色:',
        'ko': u':수동_휠체어를_탄_사람_갈색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_manual_pele_morena:',
        'it': ':persona_su_sedia_a_rotelle_manuale_carnagione_olivastra:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_دستی_پوست_طلایی:',
        'id': ':orang_dengan_kursi_roda_manual_warna_kulit_sedang:',
        'zh': u':坐手动轮椅的人_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F9BC': { # 🧑‍🦼
        'en' : ':person_in_motorized_wheelchair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_motorisiertem_rollstuhl:',
        'es': u':persona_en_silla_de_ruedas_eléctrica:',
        'fr': u':personne_en_fauteuil_motorisé:',
        'ja': u':電動車椅子の人:',
        'ko': u':전동_휠체어를_탄_사람:',
        'pt': ':pessoa_em_cadeira_de_rodas_motorizada:',
        'it': ':persona_su_sedia_a_rotelle_motorizzata:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_موتوری:',
        'id': ':orang_dengan_kursi_roda_bermotor:',
        'zh': u':坐电动轮椅的人:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F9BC': { # 🧑🏿‍🦼
        'en' : ':person_in_motorized_wheelchair_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_motorisiertem_rollstuhl_dunkle_hautfarbe:',
        'es': u':persona_en_silla_de_ruedas_eléctrica_tono_de_piel_oscuro:',
        'fr': u':personne_en_fauteuil_motorisé_peau_foncée:',
        'ja': u':電動車椅子の人_濃い肌色:',
        'ko': u':전동_휠체어를_탄_사람_검은색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_motorizada_pele_escura:',
        'it': ':persona_su_sedia_a_rotelle_motorizzata_carnagione_scura:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_موتوری_پوست_آبنوسی:',
        'id': ':orang_dengan_kursi_roda_bermotor_warna_kulit_gelap:',
        'zh': u':坐电动轮椅的人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F9BC': { # 🧑🏻‍🦼
        'en' : ':person_in_motorized_wheelchair_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_motorisiertem_rollstuhl_helle_hautfarbe:',
        'es': u':persona_en_silla_de_ruedas_eléctrica_tono_de_piel_claro:',
        'fr': u':personne_en_fauteuil_motorisé_peau_claire:',
        'ja': u':電動車椅子の人_薄い肌色:',
        'ko': u':전동_휠체어를_탄_사람_하얀_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_motorizada_pele_clara:',
        'it': ':persona_su_sedia_a_rotelle_motorizzata_carnagione_chiara:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_موتوری_پوست_سفید:',
        'id': ':orang_dengan_kursi_roda_bermotor_warna_kulit_cerah:',
        'zh': u':坐电动轮椅的人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F9BC': { # 🧑🏾‍🦼
        'en' : ':person_in_motorized_wheelchair_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_motorisiertem_rollstuhl_mitteldunkle_hautfarbe:',
        'es': u':persona_en_silla_de_ruedas_eléctrica_tono_de_piel_oscuro_medio:',
        'fr': u':personne_en_fauteuil_motorisé_peau_mate:',
        'ja': u':電動車椅子の人_やや濃い肌色:',
        'ko': u':전동_휠체어를_탄_사람_진한_갈색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_motorizada_pele_morena_escura:',
        'it': ':persona_su_sedia_a_rotelle_motorizzata_carnagione_abbastanza_scura:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_موتوری_پوست_گندمی:',
        'id': ':orang_dengan_kursi_roda_bermotor_warna_kulit_gelap-sedang:',
        'zh': u':坐电动轮椅的人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F9BC': { # 🧑🏼‍🦼
        'en' : ':person_in_motorized_wheelchair_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_motorisiertem_rollstuhl_mittelhelle_hautfarbe:',
        'es': u':persona_en_silla_de_ruedas_eléctrica_tono_de_piel_claro_medio:',
        'fr': u':personne_en_fauteuil_motorisé_peau_moyennement_claire:',
        'ja': u':電動車椅子の人_やや薄い肌色:',
        'ko': u':전동_휠체어를_탄_사람_연한_갈색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_motorizada_pele_morena_clara:',
        'it': ':persona_su_sedia_a_rotelle_motorizzata_carnagione_abbastanza_chiara:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_موتوری_پوست_روشن:',
        'id': ':orang_dengan_kursi_roda_bermotor_warna_kulit_cerah-sedang:',
        'zh': u':坐电动轮椅的人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F9BC': { # 🧑🏽‍🦼
        'en' : ':person_in_motorized_wheelchair_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_in_motorisiertem_rollstuhl_mittlere_hautfarbe:',
        'es': u':persona_en_silla_de_ruedas_eléctrica_tono_de_piel_medio:',
        'fr': u':personne_en_fauteuil_motorisé_peau_légèrement_mate:',
        'ja': u':電動車椅子の人_中間の肌色:',
        'ko': u':전동_휠체어를_탄_사람_갈색_피부:',
        'pt': ':pessoa_em_cadeira_de_rodas_motorizada_pele_morena:',
        'it': ':persona_su_sedia_a_rotelle_motorizzata_carnagione_olivastra:',
        'fa': u':شخصی_با_صندلی_چرخ_دار_موتوری_پوست_طلایی:',
        'id': ':orang_dengan_kursi_roda_bermotor_warna_kulit_sedang:',
        'zh': u':坐电动轮椅的人_中等肤色:'
    },
    u'\U0001F9D6': { # 🧖
        'en' : ':person_in_steamy_room:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':sauna_person:'],
        'de': ':person_in_dampfsauna:',
        'es': ':persona_en_una_sauna:',
        'fr': ':personne_au_hammam:',
        'ja': u':サウナに入る人:',
        'ko': u':사우나_하는_사람:',
        'pt': ':pessoa_na_sauna:',
        'it': ':persona_in_sauna:',
        'fa': u':فردی_در_حمام_بخار:',
        'id': ':orang_di_ruangan_beruap:',
        'zh': u':蒸房里的人:'
    },
    u'\U0001F9D6\U0001F3FF': { # 🧖🏿
        'en' : ':person_in_steamy_room_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_in_dampfsauna_dunkle_hautfarbe:',
        'es': ':persona_en_una_sauna_tono_de_piel_oscuro:',
        'fr': u':personne_au_hammam_peau_foncée:',
        'ja': u':サウナに入る人_濃い肌色:',
        'ko': u':사우나_하는_사람_검은색_피부:',
        'pt': ':pessoa_na_sauna_pele_escura:',
        'it': ':persona_in_sauna_carnagione_scura:',
        'fa': u':فردی_در_حمام_بخار_پوست_آبنوسی:',
        'id': ':orang_di_ruangan_beruap_warna_kulit_gelap:',
        'zh': u':蒸房里的人_较深肤色:'
    },
    u'\U0001F9D6\U0001F3FB': { # 🧖🏻
        'en' : ':person_in_steamy_room_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_in_dampfsauna_helle_hautfarbe:',
        'es': ':persona_en_una_sauna_tono_de_piel_claro:',
        'fr': ':personne_au_hammam_peau_claire:',
        'ja': u':サウナに入る人_薄い肌色:',
        'ko': u':사우나_하는_사람_하얀_피부:',
        'pt': ':pessoa_na_sauna_pele_clara:',
        'it': ':persona_in_sauna_carnagione_chiara:',
        'fa': u':فردی_در_حمام_بخار_پوست_سفید:',
        'id': ':orang_di_ruangan_beruap_warna_kulit_cerah:',
        'zh': u':蒸房里的人_较浅肤色:'
    },
    u'\U0001F9D6\U0001F3FE': { # 🧖🏾
        'en' : ':person_in_steamy_room_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_in_dampfsauna_mitteldunkle_hautfarbe:',
        'es': ':persona_en_una_sauna_tono_de_piel_oscuro_medio:',
        'fr': ':personne_au_hammam_peau_mate:',
        'ja': u':サウナに入る人_やや濃い肌色:',
        'ko': u':사우나_하는_사람_진한_갈색_피부:',
        'pt': ':pessoa_na_sauna_pele_morena_escura:',
        'it': ':persona_in_sauna_carnagione_abbastanza_scura:',
        'fa': u':فردی_در_حمام_بخار_پوست_گندمی:',
        'id': ':orang_di_ruangan_beruap_warna_kulit_gelap-sedang:',
        'zh': u':蒸房里的人_中等深肤色:'
    },
    u'\U0001F9D6\U0001F3FC': { # 🧖🏼
        'en' : ':person_in_steamy_room_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_in_dampfsauna_mittelhelle_hautfarbe:',
        'es': ':persona_en_una_sauna_tono_de_piel_claro_medio:',
        'fr': ':personne_au_hammam_peau_moyennement_claire:',
        'ja': u':サウナに入る人_やや薄い肌色:',
        'ko': u':사우나_하는_사람_연한_갈색_피부:',
        'pt': ':pessoa_na_sauna_pele_morena_clara:',
        'it': ':persona_in_sauna_carnagione_abbastanza_chiara:',
        'fa': u':فردی_در_حمام_بخار_پوست_روشن:',
        'id': ':orang_di_ruangan_beruap_warna_kulit_cerah-sedang:',
        'zh': u':蒸房里的人_中等浅肤色:'
    },
    u'\U0001F9D6\U0001F3FD': { # 🧖🏽
        'en' : ':person_in_steamy_room_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_in_dampfsauna_mittlere_hautfarbe:',
        'es': ':persona_en_una_sauna_tono_de_piel_medio:',
        'fr': u':personne_au_hammam_peau_légèrement_mate:',
        'ja': u':サウナに入る人_中間の肌色:',
        'ko': u':사우나_하는_사람_갈색_피부:',
        'pt': ':pessoa_na_sauna_pele_morena:',
        'it': ':persona_in_sauna_carnagione_olivastra:',
        'fa': u':فردی_در_حمام_بخار_پوست_طلایی:',
        'id': ':orang_di_ruangan_beruap_warna_kulit_sedang:',
        'zh': u':蒸房里的人_中等肤色:'
    },
    u'\U0001F574\U0000FE0F': { # 🕴️
        'en' : ':person_in_suit_levitating:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':business_suit_levitating:', ':man_in_business_suit_levitating:'],
        'variant': True,
        'de': ':schwebender_mann_im_anzug:',
        'es': ':hombre_trajeado_levitando:',
        'fr': u':homme_d’affaires_en_lévitation:',
        'ja': u':浮いてるビジネスマン:',
        'ko': u':공중에_떠_있는_정장_입은_남자:',
        'pt': ':homem_de_terno_levitando:',
        'it': ':uomo_con_completo_che_levita:',
        'fa': u':پرواز_مرد_با_لباس_رسمی:',
        'id': ':pria_melayang_mengenakan_jas:',
        'zh': u':西装革履的人:'
    },
    u'\U0001F574': { # 🕴
        'en' : ':person_in_suit_levitating:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':business_suit_levitating:', ':man_in_business_suit_levitating:'],
        'variant': True,
        'de': ':schwebender_mann_im_anzug:',
        'es': ':persona_trajeada_levitando:',
        'fr': u':homme_d’affaires_en_lévitation:',
        'ja': u':浮いてるビジネスマン:',
        'ko': u':공중에_떠_있는_정장_입은_남자:',
        'pt': ':homem_de_terno_levitando:',
        'it': ':uomo_con_completo_che_levita:',
        'fa': u':پرواز_مرد_با_لباس_رسمی:',
        'id': ':pria_melayang_mengenakan_jas:',
        'zh': u':西装革履的人:'
    },
    u'\U0001F574\U0001F3FF': { # 🕴🏿
        'en' : ':person_in_suit_levitating_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwebender_mann_im_anzug_dunkle_hautfarbe:',
        'es': ':hombre_trajeado_levitando_tono_de_piel_oscuro:',
        'fr': u':homme_d’affaires_en_lévitation_peau_foncée:',
        'ja': u':浮いてるビジネスマン_濃い肌色:',
        'ko': u':공중에_떠_있는_정장_입은_남자_검은색_피부:',
        'pt': ':homem_de_terno_levitando_pele_escura:',
        'it': ':uomo_con_completo_che_levita_carnagione_scura:',
        'fa': u':پرواز_مرد_با_لباس_رسمی_پوست_آبنوسی:',
        'id': ':pria_melayang_mengenakan_jas_warna_kulit_gelap:',
        'zh': u':西装革履的人_较深肤色:'
    },
    u'\U0001F574\U0001F3FB': { # 🕴🏻
        'en' : ':person_in_suit_levitating_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwebender_mann_im_anzug_helle_hautfarbe:',
        'es': ':hombre_trajeado_levitando_tono_de_piel_claro:',
        'fr': u':homme_d’affaires_en_lévitation_peau_claire:',
        'ja': u':浮いてるビジネスマン_薄い肌色:',
        'ko': u':공중에_떠_있는_정장_입은_남자_하얀_피부:',
        'pt': ':homem_de_terno_levitando_pele_clara:',
        'it': ':uomo_con_completo_che_levita_carnagione_chiara:',
        'fa': u':پرواز_مرد_با_لباس_رسمی_پوست_سفید:',
        'id': ':pria_melayang_mengenakan_jas_warna_kulit_cerah:',
        'zh': u':西装革履的人_较浅肤色:'
    },
    u'\U0001F574\U0001F3FE': { # 🕴🏾
        'en' : ':person_in_suit_levitating_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwebender_mann_im_anzug_mitteldunkle_hautfarbe:',
        'es': ':hombre_trajeado_levitando_tono_de_piel_oscuro_medio:',
        'fr': u':homme_d’affaires_en_lévitation_peau_mate:',
        'ja': u':浮いてるビジネスマン_やや濃い肌色:',
        'ko': u':공중에_떠_있는_정장_입은_남자_진한_갈색_피부:',
        'pt': ':homem_de_terno_levitando_pele_morena_escura:',
        'it': ':uomo_con_completo_che_levita_carnagione_abbastanza_scura:',
        'fa': u':پرواز_مرد_با_لباس_رسمی_پوست_گندمی:',
        'id': ':pria_melayang_mengenakan_jas_warna_kulit_gelap-sedang:',
        'zh': u':西装革履的人_中等深肤色:'
    },
    u'\U0001F574\U0001F3FC': { # 🕴🏼
        'en' : ':person_in_suit_levitating_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwebender_mann_im_anzug_mittelhelle_hautfarbe:',
        'es': ':hombre_trajeado_levitando_tono_de_piel_claro_medio:',
        'fr': u':homme_d’affaires_en_lévitation_peau_moyennement_claire:',
        'ja': u':浮いてるビジネスマン_やや薄い肌色:',
        'ko': u':공중에_떠_있는_정장_입은_남자_연한_갈색_피부:',
        'pt': ':homem_de_terno_levitando_pele_morena_clara:',
        'it': ':uomo_con_completo_che_levita_carnagione_abbastanza_chiara:',
        'fa': u':پرواز_مرد_با_لباس_رسمی_پوست_روشن:',
        'id': ':pria_melayang_mengenakan_jas_warna_kulit_cerah-sedang:',
        'zh': u':西装革履的人_中等浅肤色:'
    },
    u'\U0001F574\U0001F3FD': { # 🕴🏽
        'en' : ':person_in_suit_levitating_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwebender_mann_im_anzug_mittlere_hautfarbe:',
        'es': ':hombre_trajeado_levitando_tono_de_piel_medio:',
        'fr': u':homme_d’affaires_en_lévitation_peau_légèrement_mate:',
        'ja': u':浮いてるビジネスマン_中間の肌色:',
        'ko': u':공중에_떠_있는_정장_입은_남자_갈색_피부:',
        'pt': ':homem_de_terno_levitando_pele_morena:',
        'it': ':uomo_con_completo_che_levita_carnagione_olivastra:',
        'fa': u':پرواز_مرد_با_لباس_رسمی_پوست_طلایی:',
        'id': ':pria_melayang_mengenakan_jas_warna_kulit_sedang:',
        'zh': u':西装革履的人_中等肤色:'
    },
    u'\U0001F935': { # 🤵
        'en' : ':person_in_tuxedo:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':person_im_smoking:',
        'es': ':persona_con_esmoquin:',
        'fr': ':personne_en_smoking:',
        'ja': u':タキシードの人:',
        'ko': u':턱시도를_입은_사람:',
        'pt': ':pessoa_de_smoking:',
        'it': ':persona_in_smoking:',
        'fa': u':شخص_با_کت_و_شلوار_و_پاپیون:',
        'id': ':orang_bertuksedo:',
        'zh': u':穿燕尾服的人:'
    },
    u'\U0001F935\U0001F3FF': { # 🤵🏿
        'en' : ':person_in_tuxedo_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':person_im_smoking_dunkle_hautfarbe:',
        'es': ':persona_con_esmoquin_tono_de_piel_oscuro:',
        'fr': u':personne_en_smoking_peau_foncée:',
        'ja': u':タキシードの人_濃い肌色:',
        'ko': u':턱시도를_입은_사람_검은색_피부:',
        'pt': ':pessoa_de_smoking_pele_escura:',
        'it': ':persona_in_smoking_carnagione_scura:',
        'fa': u':شخص_با_کت_و_شلوار_و_پاپیون_پوست_آبنوسی:',
        'id': ':orang_bertuksedo_warna_kulit_gelap:',
        'zh': u':穿燕尾服的人_较深肤色:'
    },
    u'\U0001F935\U0001F3FB': { # 🤵🏻
        'en' : ':person_in_tuxedo_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':person_im_smoking_helle_hautfarbe:',
        'es': ':persona_con_esmoquin_tono_de_piel_claro:',
        'fr': ':personne_en_smoking_peau_claire:',
        'ja': u':タキシードの人_薄い肌色:',
        'ko': u':턱시도를_입은_사람_하얀_피부:',
        'pt': ':pessoa_de_smoking_pele_clara:',
        'it': ':persona_in_smoking_carnagione_chiara:',
        'fa': u':شخص_با_کت_و_شلوار_و_پاپیون_پوست_سفید:',
        'id': ':orang_bertuksedo_warna_kulit_cerah:',
        'zh': u':穿燕尾服的人_较浅肤色:'
    },
    u'\U0001F935\U0001F3FE': { # 🤵🏾
        'en' : ':person_in_tuxedo_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':person_im_smoking_mitteldunkle_hautfarbe:',
        'es': ':persona_con_esmoquin_tono_de_piel_oscuro_medio:',
        'fr': ':personne_en_smoking_peau_mate:',
        'ja': u':タキシードの人_やや濃い肌色:',
        'ko': u':턱시도를_입은_사람_진한_갈색_피부:',
        'pt': ':pessoa_de_smoking_pele_morena_escura:',
        'it': ':persona_in_smoking_carnagione_abbastanza_scura:',
        'fa': u':شخص_با_کت_و_شلوار_و_پاپیون_پوست_گندمی:',
        'id': ':orang_bertuksedo_warna_kulit_gelap-sedang:',
        'zh': u':穿燕尾服的人_中等深肤色:'
    },
    u'\U0001F935\U0001F3FC': { # 🤵🏼
        'en' : ':person_in_tuxedo_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':person_im_smoking_mittelhelle_hautfarbe:',
        'es': ':persona_con_esmoquin_tono_de_piel_claro_medio:',
        'fr': ':personne_en_smoking_peau_moyennement_claire:',
        'ja': u':タキシードの人_やや薄い肌色:',
        'ko': u':턱시도를_입은_사람_연한_갈색_피부:',
        'pt': ':pessoa_de_smoking_pele_morena_clara:',
        'it': ':persona_in_smoking_carnagione_abbastanza_chiara:',
        'fa': u':شخص_با_کت_و_شلوار_و_پاپیون_پوست_روشن:',
        'id': ':orang_bertuksedo_warna_kulit_cerah-sedang:',
        'zh': u':穿燕尾服的人_中等浅肤色:'
    },
    u'\U0001F935\U0001F3FD': { # 🤵🏽
        'en' : ':person_in_tuxedo_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':person_im_smoking_mittlere_hautfarbe:',
        'es': ':persona_con_esmoquin_tono_de_piel_medio:',
        'fr': u':personne_en_smoking_peau_légèrement_mate:',
        'ja': u':タキシードの人_中間の肌色:',
        'ko': u':턱시도를_입은_사람_갈색_피부:',
        'pt': ':pessoa_de_smoking_pele_morena:',
        'it': ':persona_in_smoking_carnagione_olivastra:',
        'fa': u':شخص_با_کت_و_شلوار_و_پاپیون_پوست_طلایی:',
        'id': ':orang_bertuksedo_warna_kulit_sedang:',
        'zh': u':穿燕尾服的人_中等肤色:'
    },
    u'\U0001F939': { # 🤹
        'en' : ':person_juggling:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':juggling_person:'],
        'de': ':jongleur(in):',
        'es': ':persona_haciendo_malabares:',
        'fr': ':personne_qui_jongle:',
        'ja': u':ジャグリングをする人:',
        'ko': u':저글링하는_사람:',
        'pt': ':malabarista:',
        'it': ':persona_che_fa_giocoleria:',
        'fa': u':ژانگولربازی:',
        'id': ':orang_melempar:',
        'zh': u':抛接杂耍:'
    },
    u'\U0001F939\U0001F3FF': { # 🤹🏿
        'en' : ':person_juggling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':jongleur(in)_dunkle_hautfarbe:',
        'es': ':persona_haciendo_malabares_tono_de_piel_oscuro:',
        'fr': u':personne_qui_jongle_peau_foncée:',
        'ja': u':ジャグリングをする人_濃い肌色:',
        'ko': u':저글링하는_사람_검은색_피부:',
        'pt': ':malabarista_pele_escura:',
        'it': ':persona_che_fa_giocoleria_carnagione_scura:',
        'fa': u':ژانگولربازی_پوست_آبنوسی:',
        'id': ':orang_melempar_warna_kulit_gelap:',
        'zh': u':抛接杂耍_较深肤色:'
    },
    u'\U0001F939\U0001F3FB': { # 🤹🏻
        'en' : ':person_juggling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':jongleur(in)_helle_hautfarbe:',
        'es': ':persona_haciendo_malabares_tono_de_piel_claro:',
        'fr': ':personne_qui_jongle_peau_claire:',
        'ja': u':ジャグリングをする人_薄い肌色:',
        'ko': u':저글링하는_사람_하얀_피부:',
        'pt': ':malabarista_pele_clara:',
        'it': ':persona_che_fa_giocoleria_carnagione_chiara:',
        'fa': u':ژانگولربازی_پوست_سفید:',
        'id': ':orang_melempar_warna_kulit_cerah:',
        'zh': u':抛接杂耍_较浅肤色:'
    },
    u'\U0001F939\U0001F3FE': { # 🤹🏾
        'en' : ':person_juggling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':jongleur(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_haciendo_malabares_tono_de_piel_oscuro_medio:',
        'fr': ':personne_qui_jongle_peau_mate:',
        'ja': u':ジャグリングをする人_やや濃い肌色:',
        'ko': u':저글링하는_사람_진한_갈색_피부:',
        'pt': ':malabarista_pele_morena_escura:',
        'it': ':persona_che_fa_giocoleria_carnagione_abbastanza_scura:',
        'fa': u':ژانگولربازی_پوست_گندمی:',
        'id': ':orang_melempar_warna_kulit_gelap-sedang:',
        'zh': u':抛接杂耍_中等深肤色:'
    },
    u'\U0001F939\U0001F3FC': { # 🤹🏼
        'en' : ':person_juggling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':jongleur(in)_mittelhelle_hautfarbe:',
        'es': ':persona_haciendo_malabares_tono_de_piel_claro_medio:',
        'fr': ':personne_qui_jongle_peau_moyennement_claire:',
        'ja': u':ジャグリングをする人_やや薄い肌色:',
        'ko': u':저글링하는_사람_연한_갈색_피부:',
        'pt': ':malabarista_pele_morena_clara:',
        'it': ':persona_che_fa_giocoleria_carnagione_abbastanza_chiara:',
        'fa': u':ژانگولربازی_پوست_روشن:',
        'id': ':orang_melempar_warna_kulit_cerah-sedang:',
        'zh': u':抛接杂耍_中等浅肤色:'
    },
    u'\U0001F939\U0001F3FD': { # 🤹🏽
        'en' : ':person_juggling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':jongleur(in)_mittlere_hautfarbe:',
        'es': ':persona_haciendo_malabares_tono_de_piel_medio:',
        'fr': u':personne_qui_jongle_peau_légèrement_mate:',
        'ja': u':ジャグリングをする人_中間の肌色:',
        'ko': u':저글링하는_사람_갈색_피부:',
        'pt': ':malabarista_pele_morena:',
        'it': ':persona_che_fa_giocoleria_carnagione_olivastra:',
        'fa': u':ژانگولربازی_پوست_طلایی:',
        'id': ':orang_melempar_warna_kulit_sedang:',
        'zh': u':抛接杂耍_中等肤色:'
    },
    u'\U0001F9CE': { # 🧎
        'en' : ':person_kneeling:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':kneeling_person:'],
        'de': ':kniende_person:',
        'es': ':persona_de_rodillas:',
        'fr': u':personne_à_genoux:',
        'ja': u':正座する人:',
        'ko': u':무릎을_꿇은_사람:',
        'pt': ':pessoa_ajoelhando:',
        'it': ':persona_inginocchiata:',
        'fa': u':آدم_زانوزده:',
        'id': ':orang_berlutut:',
        'zh': u':下跪者:'
    },
    u'\U0001F9CE\U0001F3FF': { # 🧎🏿
        'en' : ':person_kneeling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_person_dunkle_hautfarbe:',
        'es': ':persona_de_rodillas_tono_de_piel_oscuro:',
        'fr': u':personne_à_genoux_peau_foncée:',
        'ja': u':正座する人_濃い肌色:',
        'ko': u':무릎을_꿇은_사람_검은색_피부:',
        'pt': ':pessoa_ajoelhando_pele_escura:',
        'it': ':persona_inginocchiata_carnagione_scura:',
        'fa': u':آدم_زانوزده_پوست_آبنوسی:',
        'id': ':orang_berlutut_warna_kulit_gelap:',
        'zh': u':下跪者_较深肤色:'
    },
    u'\U0001F9CE\U0001F3FB': { # 🧎🏻
        'en' : ':person_kneeling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_person_helle_hautfarbe:',
        'es': ':persona_de_rodillas_tono_de_piel_claro:',
        'fr': u':personne_à_genoux_peau_claire:',
        'ja': u':正座する人_薄い肌色:',
        'ko': u':무릎을_꿇은_사람_하얀_피부:',
        'pt': ':pessoa_ajoelhando_pele_clara:',
        'it': ':persona_inginocchiata_carnagione_chiara:',
        'fa': u':آدم_زانوزده_پوست_سفید:',
        'id': ':orang_berlutut_warna_kulit_cerah:',
        'zh': u':下跪者_较浅肤色:'
    },
    u'\U0001F9CE\U0001F3FE': { # 🧎🏾
        'en' : ':person_kneeling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_de_rodillas_tono_de_piel_oscuro_medio:',
        'fr': u':personne_à_genoux_peau_mate:',
        'ja': u':正座する人_やや濃い肌色:',
        'ko': u':무릎을_꿇은_사람_진한_갈색_피부:',
        'pt': ':pessoa_ajoelhando_pele_morena_escura:',
        'it': ':persona_inginocchiata_carnagione_abbastanza_scura:',
        'fa': u':آدم_زانوزده_پوست_گندمی:',
        'id': ':orang_berlutut_warna_kulit_gelap-sedang:',
        'zh': u':下跪者_中等深肤色:'
    },
    u'\U0001F9CE\U0001F3FC': { # 🧎🏼
        'en' : ':person_kneeling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_person_mittelhelle_hautfarbe:',
        'es': ':persona_de_rodillas_tono_de_piel_claro_medio:',
        'fr': u':personne_à_genoux_peau_moyennement_claire:',
        'ja': u':正座する人_やや薄い肌色:',
        'ko': u':무릎을_꿇은_사람_연한_갈색_피부:',
        'pt': ':pessoa_ajoelhando_pele_morena_clara:',
        'it': ':persona_inginocchiata_carnagione_abbastanza_chiara:',
        'fa': u':آدم_زانوزده_پوست_روشن:',
        'id': ':orang_berlutut_warna_kulit_cerah-sedang:',
        'zh': u':下跪者_中等浅肤色:'
    },
    u'\U0001F9CE\U0001F3FD': { # 🧎🏽
        'en' : ':person_kneeling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_person_mittlere_hautfarbe:',
        'es': ':persona_de_rodillas_tono_de_piel_medio:',
        'fr': u':personne_à_genoux_peau_légèrement_mate:',
        'ja': u':正座する人_中間の肌色:',
        'ko': u':무릎을_꿇은_사람_갈색_피부:',
        'pt': ':pessoa_ajoelhando_pele_morena:',
        'it': ':persona_inginocchiata_carnagione_olivastra:',
        'fa': u':آدم_زانوزده_پوست_طلایی:',
        'id': ':orang_berlutut_warna_kulit_sedang:',
        'zh': u':下跪者_中等肤色:'
    },
    u'\U0001F3CB\U0000FE0F': { # 🏋️
        'en' : ':person_lifting_weights:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':weight_lifting:', ':weight_lifter:'],
        'variant': True,
        'de': ':gewichtheber(in):',
        'es': ':persona_levantando_pesas:',
        'fr': u':haltérophile:',
        'ja': u':重量挙げをする人:',
        'ko': u':역도_선수:',
        'pt': ':pessoa_levantando_peso:',
        'it': ':persona_che_solleva_pesi:',
        'fa': u':وزنه_بردار:',
        'id': ':orang_mengangkat_beban:',
        'zh': u':举重:'
    },
    u'\U0001F3CB': { # 🏋
        'en' : ':person_lifting_weights:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':weight_lifting:', ':weight_lifter:'],
        'variant': True,
        'de': ':gewichtheber(in):',
        'es': ':persona_levantando_pesas:',
        'fr': u':haltérophile:',
        'ja': u':重量挙げをする人:',
        'ko': u':역도_선수:',
        'pt': ':pessoa_levantando_peso:',
        'it': ':persona_che_solleva_pesi:',
        'fa': u':وزنه_بردار:',
        'id': ':orang_mengangkat_beban:',
        'zh': u':举重:'
    },
    u'\U0001F3CB\U0001F3FF': { # 🏋🏿
        'en' : ':person_lifting_weights_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':gewichtheber(in)_dunkle_hautfarbe:',
        'es': ':persona_levantando_pesas_tono_de_piel_oscuro:',
        'fr': u':haltérophile_peau_foncée:',
        'ja': u':重量挙げをする人_濃い肌色:',
        'ko': u':역도_선수_검은색_피부:',
        'pt': ':pessoa_levantando_peso_pele_escura:',
        'it': ':persona_che_solleva_pesi_carnagione_scura:',
        'fa': u':وزنه_بردار_پوست_آبنوسی:',
        'id': ':orang_mengangkat_beban_warna_kulit_gelap:',
        'zh': u':举重_较深肤色:'
    },
    u'\U0001F3CB\U0001F3FB': { # 🏋🏻
        'en' : ':person_lifting_weights_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':gewichtheber(in)_helle_hautfarbe:',
        'es': ':persona_levantando_pesas_tono_de_piel_claro:',
        'fr': u':haltérophile_peau_claire:',
        'ja': u':重量挙げをする人_薄い肌色:',
        'ko': u':역도_선수_하얀_피부:',
        'pt': ':pessoa_levantando_peso_pele_clara:',
        'it': ':persona_che_solleva_pesi_carnagione_chiara:',
        'fa': u':وزنه_بردار_پوست_سفید:',
        'id': ':orang_mengangkat_beban_warna_kulit_cerah:',
        'zh': u':举重_较浅肤色:'
    },
    u'\U0001F3CB\U0001F3FE': { # 🏋🏾
        'en' : ':person_lifting_weights_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':gewichtheber(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_levantando_pesas_tono_de_piel_oscuro_medio:',
        'fr': u':haltérophile_peau_mate:',
        'ja': u':重量挙げをする人_やや濃い肌色:',
        'ko': u':역도_선수_진한_갈색_피부:',
        'pt': ':pessoa_levantando_peso_pele_morena_escura:',
        'it': ':persona_che_solleva_pesi_carnagione_abbastanza_scura:',
        'fa': u':وزنه_بردار_پوست_گندمی:',
        'id': ':orang_mengangkat_beban_warna_kulit_gelap-sedang:',
        'zh': u':举重_中等深肤色:'
    },
    u'\U0001F3CB\U0001F3FC': { # 🏋🏼
        'en' : ':person_lifting_weights_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':gewichtheber(in)_mittelhelle_hautfarbe:',
        'es': ':persona_levantando_pesas_tono_de_piel_claro_medio:',
        'fr': u':haltérophile_peau_moyennement_claire:',
        'ja': u':重量挙げをする人_やや薄い肌色:',
        'ko': u':역도_선수_연한_갈색_피부:',
        'pt': ':pessoa_levantando_peso_pele_morena_clara:',
        'it': ':persona_che_solleva_pesi_carnagione_abbastanza_chiara:',
        'fa': u':وزنه_بردار_پوست_روشن:',
        'id': ':orang_mengangkat_beban_warna_kulit_cerah-sedang:',
        'zh': u':举重_中等浅肤色:'
    },
    u'\U0001F3CB\U0001F3FD': { # 🏋🏽
        'en' : ':person_lifting_weights_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 2,
        'de': ':gewichtheber(in)_mittlere_hautfarbe:',
        'es': ':persona_levantando_pesas_tono_de_piel_medio:',
        'fr': u':haltérophile_peau_légèrement_mate:',
        'ja': u':重量挙げをする人_中間の肌色:',
        'ko': u':역도_선수_갈색_피부:',
        'pt': ':pessoa_levantando_peso_pele_morena:',
        'it': ':persona_che_solleva_pesi_carnagione_olivastra:',
        'fa': u':وزنه_بردار_پوست_طلایی:',
        'id': ':orang_mengangkat_beban_warna_kulit_sedang:',
        'zh': u':举重_中等肤色:'
    },
    u'\U0001F9D1\U0001F3FB': { # 🧑🏻
        'en' : ':person_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':erwachsener_helle_hautfarbe:',
        'es': ':persona_adulta_tono_de_piel_claro:',
        'fr': ':adulte_peau_claire:',
        'ja': u':大人_薄い肌色:',
        'ko': u':사람_하얀_피부:',
        'pt': ':pessoa_pele_clara:',
        'it': ':persona_carnagione_chiara:',
        'fa': u':بزرگسال_پوست_سفید:',
        'id': ':dewasa_warna_kulit_cerah:',
        'zh': u':成人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F9B2': { # 🧑🏻‍🦲
        'en' : ':person_light_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_helle_hautfarbe,_glatze:',
        'es': ':persona_adulta_tono_de_piel_claro_y_sin_pelo:',
        'fr': ':adulte_peau_claire_et_chauve:',
        'ja': u':大人_薄い肌色_はげ頭:',
        'ko': u':사람_하얀_피부_대머리:',
        'pt': ':pessoa_pele_clara_e_careca:',
        'it': ':persona_carnagione_chiara_e_calvo:',
        'fa': u':بزرگسال_پوست_سفید_تاس:',
        'id': ':dewasa_warna_kulit_cerah_gundul:',
        'zh': u':成人_较浅肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FB': { # 🧔🏻
        'en' : ':person_light_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_helle_hautfarbe_bart:',
        'es': ':hombre_con_barba_tono_de_piel_claro:',
        'fr': ':personne_barbue__peau_claire:',
        'ja': u':あごひげの人_薄い肌色:',
        'ko': u':수염_난_사람_하얀_피부:',
        'pt': ':homem_pele_clara_e_barba:',
        'it': ':persona_con_la_barba_carnagione_chiara:',
        'fa': u':مرد_پوست_سفید_ریش_دار:',
        'id': ':orang_warna_kulit_cerah_janggut:',
        'zh': u':有胡子的人_较浅肤色:'
    },
    u'\U0001F471\U0001F3FB': { # 👱🏻
        'en' : ':person_light_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_helle_hautfarbe,_blondes_haar:',
        'es': ':persona_adulta_rubia_tono_de_piel_claro:',
        'fr': ':personne_blonde_peau_claire:',
        'ja': u':金髪の人_薄い肌色:',
        'ko': u':금발인_사람_하얀_피부:',
        'pt': ':pessoa_pele_clara_e_cabelo_louro:',
        'it': ':persona_bionda_carnagione_chiara:',
        'fa': u':آدم_پوست_سفید_موبلوند:',
        'id': ':orang_warna_kulit_cerah_rambut_pirang:',
        'zh': u':金色头发的人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F9B1': { # 🧑🏻‍🦱
        'en' : ':person_light_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_helle_hautfarbe,_lockiges_haar:',
        'es': ':persona_adulta_tono_de_piel_claro_y_pelo_rizado:',
        'fr': u':adulte_peau_claire_et_cheveux_bouclés:',
        'ja': u':大人_薄い肌色_巻き毛:',
        'ko': u':사람_하얀_피부_곱슬머리:',
        'pt': ':pessoa_pele_clara_e_cabelo_cacheado:',
        'it': ':persona_carnagione_chiara_e_capelli_ricci:',
        'fa': u':بزرگسال_پوست_سفید_موفرفری:',
        'id': ':dewasa_warna_kulit_cerah_rambut_keriting:',
        'zh': u':成人_较浅肤色卷发:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F9B0': { # 🧑🏻‍🦰
        'en' : ':person_light_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_helle_hautfarbe,_rotes_haar:',
        'es': ':persona_adulta_tono_de_piel_claro_y_pelo_pelirrojo:',
        'fr': ':adulte_peau_claire_et_cheveux_roux:',
        'ja': u':大人_薄い肌色_赤毛:',
        'ko': u':사람_하얀_피부_빨간_머리:',
        'pt': ':pessoa_pele_clara_e_cabelo_vermelho:',
        'it': ':persona_carnagione_chiara_e_capelli_rossi:',
        'fa': u':بزرگسال_پوست_سفید_موقرمز:',
        'id': ':dewasa_warna_kulit_cerah_rambut_merah:',
        'zh': u':成人_较浅肤色红发:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F9B3': { # 🧑🏻‍🦳
        'en' : ':person_light_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':erwachsener_helle_hautfarbe,_weißes_haar:',
        'es': ':persona_adulta_tono_de_piel_claro_y_pelo_blanco:',
        'fr': ':adulte_peau_claire_et_cheveux_blancs:',
        'ja': u':大人_薄い肌色_白髪:',
        'ko': u':사람_하얀_피부_백발:',
        'pt': ':pessoa_pele_clara_e_cabelo_branco:',
        'it': ':persona_carnagione_chiara_e_capelli_bianchi:',
        'fa': u':بزرگسال_پوست_سفید_موسفید:',
        'id': ':dewasa_warna_kulit_cerah_rambut_putih:',
        'zh': u':成人_较浅肤色白发:'
    },
    u'\U0001F9D1\U0001F3FE': { # 🧑🏾
        'en' : ':person_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':erwachsener_mitteldunkle_hautfarbe:',
        'es': ':persona_adulta_tono_de_piel_oscuro_medio:',
        'fr': ':adulte_peau_mate:',
        'ja': u':大人_やや濃い肌色:',
        'ko': u':사람_진한_갈색_피부:',
        'pt': ':pessoa_pele_morena_escura:',
        'it': ':persona_carnagione_abbastanza_scura:',
        'fa': u':بزرگسال_پوست_گندمی:',
        'id': ':dewasa_warna_kulit_gelap-sedang:',
        'zh': u':成人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F9B2': { # 🧑🏾‍🦲
        'en' : ':person_medium-dark_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mitteldunkle_hautfarbe,_glatze:',
        'es': ':persona_adulta_tono_de_piel_oscuro_medio_y_sin_pelo:',
        'fr': ':adulte_peau_mate_et_chauve:',
        'ja': u':大人_やや濃い肌色_はげ頭:',
        'ko': u':사람_진한_갈색_피부_대머리:',
        'pt': ':pessoa_pele_morena_escura_e_careca:',
        'it': ':persona_carnagione_abbastanza_scura_e_calvo:',
        'fa': u':بزرگسال_پوست_گندمی_تاس:',
        'id': ':dewasa_warna_kulit_gelap-sedang_gundul:',
        'zh': u':成人_中等深肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FE': { # 🧔🏾
        'en' : ':person_medium-dark_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_mitteldunkle_hautfarbe_bart:',
        'es': ':hombre_con_barba_tono_de_piel_oscuro_medio:',
        'fr': ':personne_barbue__peau_mate:',
        'ja': u':あごひげの人_やや濃い肌色:',
        'ko': u':수염_난_사람_진한_갈색_피부:',
        'pt': ':homem_pele_morena_escura_e_barba:',
        'it': ':persona_con_la_barba_carnagione_abbastanza_scura:',
        'fa': u':مرد_پوست_گندمی_ریش_دار:',
        'id': ':orang_warna_kulit_gelap-sedang_janggut:',
        'zh': u':有胡子的人_中等深肤色:'
    },
    u'\U0001F471\U0001F3FE': { # 👱🏾
        'en' : ':person_medium-dark_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mitteldunkle_hautfarbe,_blondes_haar:',
        'es': ':persona_adulta_rubia_tono_de_piel_oscuro_medio:',
        'fr': ':personne_blonde_peau_mate:',
        'ja': u':金髪の人_やや濃い肌色:',
        'ko': u':금발인_사람_진한_갈색_피부:',
        'pt': ':pessoa_pele_morena_escura_e_cabelo_louro:',
        'it': ':persona_bionda_carnagione_abbastanza_scura:',
        'fa': u':آدم_پوست_گندمی_موبلوند:',
        'id': ':orang_warna_kulit_gelap-sedang_rambut_pirang:',
        'zh': u':金色头发的人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F9B1': { # 🧑🏾‍🦱
        'en' : ':person_medium-dark_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mitteldunkle_hautfarbe,_lockiges_haar:',
        'es': ':persona_adulta_tono_de_piel_oscuro_medio_y_pelo_rizado:',
        'fr': u':adulte_peau_mate_et_cheveux_bouclés:',
        'ja': u':大人_やや濃い肌色_巻き毛:',
        'ko': u':사람_진한_갈색_피부_곱슬머리:',
        'pt': ':pessoa_pele_morena_escura_e_cabelo_cacheado:',
        'it': ':persona_carnagione_abbastanza_scura_e_capelli_ricci:',
        'fa': u':بزرگسال_پوست_گندمی_موفرفری:',
        'id': ':dewasa_warna_kulit_gelap-sedang_rambut_keriting:',
        'zh': u':成人_中等深肤色卷发:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F9B0': { # 🧑🏾‍🦰
        'en' : ':person_medium-dark_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mitteldunkle_hautfarbe,_rotes_haar:',
        'es': ':persona_adulta_tono_de_piel_oscuro_medio_y_pelo_pelirrojo:',
        'fr': ':adulte_peau_mate_et_cheveux_roux:',
        'ja': u':大人_やや濃い肌色_赤毛:',
        'ko': u':사람_진한_갈색_피부_빨간_머리:',
        'pt': ':pessoa_pele_morena_escura_e_cabelo_vermelho:',
        'it': ':persona_carnagione_abbastanza_scura_e_capelli_rossi:',
        'fa': u':بزرگسال_پوست_گندمی_موقرمز:',
        'id': ':dewasa_warna_kulit_gelap-sedang_rambut_merah:',
        'zh': u':成人_中等深肤色红发:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F9B3': { # 🧑🏾‍🦳
        'en' : ':person_medium-dark_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':erwachsener_mitteldunkle_hautfarbe,_weißes_haar:',
        'es': ':persona_adulta_tono_de_piel_oscuro_medio_y_pelo_blanco:',
        'fr': ':adulte_peau_mate_et_cheveux_blancs:',
        'ja': u':大人_やや濃い肌色_白髪:',
        'ko': u':사람_진한_갈색_피부_백발:',
        'pt': ':pessoa_pele_morena_escura_e_cabelo_branco:',
        'it': ':persona_carnagione_abbastanza_scura_e_capelli_bianchi:',
        'fa': u':بزرگسال_پوست_گندمی_موسفید:',
        'id': ':dewasa_warna_kulit_gelap-sedang_rambut_putih:',
        'zh': u':成人_中等深肤色白发:'
    },
    u'\U0001F9D1\U0001F3FC': { # 🧑🏼
        'en' : ':person_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':erwachsener_mittelhelle_hautfarbe:',
        'es': ':persona_adulta_tono_de_piel_claro_medio:',
        'fr': ':adulte_peau_moyennement_claire:',
        'ja': u':大人_やや薄い肌色:',
        'ko': u':사람_연한_갈색_피부:',
        'pt': ':pessoa_pele_morena_clara:',
        'it': ':persona_carnagione_abbastanza_chiara:',
        'fa': u':بزرگسال_پوست_روشن:',
        'id': ':dewasa_warna_kulit_cerah-sedang:',
        'zh': u':成人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F9B2': { # 🧑🏼‍🦲
        'en' : ':person_medium-light_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mittelhelle_hautfarbe,_glatze:',
        'es': ':persona_adulta_tono_de_piel_claro_medio_y_sin_pelo:',
        'fr': ':adulte_peau_moyennement_claire_et_chauve:',
        'ja': u':大人_やや薄い肌色_はげ頭:',
        'ko': u':사람_연한_갈색_피부_대머리:',
        'pt': ':pessoa_pele_morena_clara_e_careca:',
        'it': ':persona_carnagione_abbastanza_chiara_e_calvo:',
        'fa': u':بزرگسال_پوست_روشن_تاس:',
        'id': ':dewasa_warna_kulit_cerah-sedang_gundul:',
        'zh': u':成人_中等浅肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FC': { # 🧔🏼
        'en' : ':person_medium-light_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_mittelhelle_hautfarbe_bart:',
        'es': ':hombre_con_barba_tono_de_piel_claro_medio:',
        'fr': ':personne_barbue__peau_moyennement_claire:',
        'ja': u':あごひげの人_やや薄い肌色:',
        'ko': u':수염_난_사람_연한_갈색_피부:',
        'pt': ':homem_pele_morena_clara_e_barba:',
        'it': ':persona_con_la_barba_carnagione_abbastanza_chiara:',
        'fa': u':مرد_پوست_روشن_ریش_دار:',
        'id': ':orang_warna_kulit_cerah-sedang_janggut:',
        'zh': u':有胡子的人_中等浅肤色:'
    },
    u'\U0001F471\U0001F3FC': { # 👱🏼
        'en' : ':person_medium-light_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mittelhelle_hautfarbe,_blondes_haar:',
        'es': ':persona_adulta_rubia_tono_de_piel_claro_medio:',
        'fr': ':personne_blonde_peau_moyennement_claire:',
        'ja': u':金髪の人_やや薄い肌色:',
        'ko': u':금발인_사람_연한_갈색_피부:',
        'pt': ':pessoa_pele_morena_clara_e_cabelo_louro:',
        'it': ':persona_bionda_carnagione_abbastanza_chiara:',
        'fa': u':آدم_پوست_روشن_موبلوند:',
        'id': ':orang_warna_kulit_cerah-sedang_rambut_pirang:',
        'zh': u':金色头发的人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F9B1': { # 🧑🏼‍🦱
        'en' : ':person_medium-light_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mittelhelle_hautfarbe,_lockiges_haar:',
        'es': ':persona_adulta_tono_de_piel_claro_medio_y_pelo_rizado:',
        'fr': u':adulte_peau_moyennement_claire_et_cheveux_bouclés:',
        'ja': u':大人_やや薄い肌色_巻き毛:',
        'ko': u':사람_연한_갈색_피부_곱슬머리:',
        'pt': ':pessoa_pele_morena_clara_e_cabelo_cacheado:',
        'it': ':persona_carnagione_abbastanza_chiara_e_capelli_ricci:',
        'fa': u':بزرگسال_پوست_روشن_موفرفری:',
        'id': ':dewasa_warna_kulit_cerah-sedang_rambut_keriting:',
        'zh': u':成人_中等浅肤色卷发:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F9B0': { # 🧑🏼‍🦰
        'en' : ':person_medium-light_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mittelhelle_hautfarbe,_rotes_haar:',
        'es': ':persona_adulta_tono_de_piel_claro_medio_y_pelo_pelirrojo:',
        'fr': ':adulte_peau_moyennement_claire_et_cheveux_roux:',
        'ja': u':大人_やや薄い肌色_赤毛:',
        'ko': u':사람_연한_갈색_피부_빨간_머리:',
        'pt': ':pessoa_pele_morena_clara_e_cabelo_vermelho:',
        'it': ':persona_carnagione_abbastanza_chiara_e_capelli_rossi:',
        'fa': u':بزرگسال_پوست_روشن_موقرمز:',
        'id': ':dewasa_warna_kulit_cerah-sedang_rambut_merah:',
        'zh': u':成人_中等浅肤色红发:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F9B3': { # 🧑🏼‍🦳
        'en' : ':person_medium-light_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':erwachsener_mittelhelle_hautfarbe,_weißes_haar:',
        'es': ':persona_adulta_tono_de_piel_claro_medio_y_pelo_blanco:',
        'fr': ':adulte_peau_moyennement_claire_et_cheveux_blancs:',
        'ja': u':大人_やや薄い肌色_白髪:',
        'ko': u':사람_연한_갈색_피부_백발:',
        'pt': ':pessoa_pele_morena_clara_e_cabelo_branco:',
        'it': ':persona_carnagione_abbastanza_chiara_e_capelli_bianchi:',
        'fa': u':بزرگسال_پوست_روشن_موسفید:',
        'id': ':dewasa_warna_kulit_cerah-sedang_rambut_putih:',
        'zh': u':成人_中等浅肤色白发:'
    },
    u'\U0001F9D1\U0001F3FD': { # 🧑🏽
        'en' : ':person_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':erwachsener_mittlere_hautfarbe:',
        'es': ':persona_adulta_tono_de_piel_medio:',
        'fr': u':adulte_peau_légèrement_mate:',
        'ja': u':大人_中間の肌色:',
        'ko': u':사람_갈색_피부:',
        'pt': ':pessoa_pele_morena:',
        'it': ':persona_carnagione_olivastra:',
        'fa': u':بزرگسال_پوست_طلایی:',
        'id': ':dewasa_warna_kulit_sedang:',
        'zh': u':成人_中等肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F9B2': { # 🧑🏽‍🦲
        'en' : ':person_medium_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mittlere_hautfarbe,_glatze:',
        'es': ':persona_adulta_tono_de_piel_medio_y_sin_pelo:',
        'fr': u':adulte_peau_légèrement_mate_et_chauve:',
        'ja': u':大人_中間の肌色_はげ頭:',
        'ko': u':사람_갈색_피부_대머리:',
        'pt': ':pessoa_pele_morena_e_careca:',
        'it': ':persona_carnagione_olivastra_e_calvo:',
        'fa': u':بزرگسال_پوست_طلایی_تاس:',
        'id': ':dewasa_warna_kulit_sedang_gundul:',
        'zh': u':成人_中等肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FD': { # 🧔🏽
        'en' : ':person_medium_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':person_mittlere_hautfarbe_bart:',
        'es': ':hombre_con_barba_tono_de_piel_medio:',
        'fr': u':personne_barbue__peau_légèrement_mate:',
        'ja': u':あごひげの人_中間の肌色:',
        'ko': u':수염_난_사람_갈색_피부:',
        'pt': ':homem_pele_morena_e_barba:',
        'it': ':persona_con_la_barba_carnagione_olivastra:',
        'fa': u':مرد_پوست_طلایی_ریش_دار:',
        'id': ':orang_warna_kulit_sedang_janggut:',
        'zh': u':有胡子的人_中等肤色:'
    },
    u'\U0001F471\U0001F3FD': { # 👱🏽
        'en' : ':person_medium_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mittlere_hautfarbe,_blondes_haar:',
        'es': ':persona_adulta_rubia_tono_de_piel_medio:',
        'fr': u':personne_blonde_peau_légèrement_mate:',
        'ja': u':金髪の人_中間の肌色:',
        'ko': u':금발인_사람_갈색_피부:',
        'pt': ':pessoa_pele_morena_e_cabelo_louro:',
        'it': ':persona_bionda_carnagione_olivastra:',
        'fa': u':آدم_پوست_طلایی_موبلوند:',
        'id': ':orang_warna_kulit_sedang_rambut_pirang:',
        'zh': u':金色头发的人_中等肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F9B1': { # 🧑🏽‍🦱
        'en' : ':person_medium_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mittlere_hautfarbe,_lockiges_haar:',
        'es': ':persona_adulta_tono_de_piel_medio_y_pelo_rizado:',
        'fr': u':adulte_peau_légèrement_mate_et_cheveux_bouclés:',
        'ja': u':大人_中間の肌色_巻き毛:',
        'ko': u':사람_갈색_피부_곱슬머리:',
        'pt': ':pessoa_pele_morena_e_cabelo_cacheado:',
        'it': ':persona_carnagione_olivastra_e_capelli_ricci:',
        'fa': u':بزرگسال_پوست_طلایی_موفرفری:',
        'id': ':dewasa_warna_kulit_sedang_rambut_keriting:',
        'zh': u':成人_中等肤色卷发:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F9B0': { # 🧑🏽‍🦰
        'en' : ':person_medium_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_mittlere_hautfarbe,_rotes_haar:',
        'es': ':persona_adulta_tono_de_piel_medio_y_pelo_pelirrojo:',
        'fr': u':adulte_peau_légèrement_mate_et_cheveux_roux:',
        'ja': u':大人_中間の肌色_赤毛:',
        'ko': u':사람_갈색_피부_빨간_머리:',
        'pt': ':pessoa_pele_morena_e_cabelo_vermelho:',
        'it': ':persona_carnagione_olivastra_e_capelli_rossi:',
        'fa': u':بزرگسال_پوست_طلایی_موقرمز:',
        'id': ':dewasa_warna_kulit_sedang_rambut_merah:',
        'zh': u':成人_中等肤色红发:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F9B3': { # 🧑🏽‍🦳
        'en' : ':person_medium_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':erwachsener_mittlere_hautfarbe,_weißes_haar:',
        'es': ':persona_adulta_tono_de_piel_medio_y_pelo_blanco:',
        'fr': u':adulte_peau_légèrement_mate_et_cheveux_blancs:',
        'ja': u':大人_中間の肌色_白髪:',
        'ko': u':사람_갈색_피부_백발:',
        'pt': ':pessoa_pele_morena_e_cabelo_branco:',
        'it': ':persona_carnagione_olivastra_e_capelli_bianchi:',
        'fa': u':بزرگسال_پوست_طلایی_موسفید:',
        'id': ':dewasa_warna_kulit_sedang_rambut_putih:',
        'zh': u':成人_中等肤色白发:'
    },
    u'\U0001F6B5': { # 🚵
        'en' : ':person_mountain_biking:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':mountain_bicyclist:'],
        'de': ':mountainbiker(in):',
        'es': u':persona_en_bicicleta_de_montaña:',
        'fr': ':personne_en_vtt:',
        'ja': u':マウンテンバイクに乗る人:',
        'ko': u':산악_자전거_타는_사람:',
        'pt': ':pessoa_fazendo_mountain_bike:',
        'it': ':ciclista_di_mountain_bike:',
        'fa': u':دوچرخه_کوهستان:',
        'id': ':orang_bersepeda_gunung:',
        'zh': u':骑山地车:'
    },
    u'\U0001F6B5\U0001F3FF': { # 🚵🏿
        'en' : ':person_mountain_biking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mountainbiker(in)_dunkle_hautfarbe:',
        'es': u':persona_en_bicicleta_de_montaña_tono_de_piel_oscuro:',
        'fr': u':personne_en_vtt_peau_foncée:',
        'ja': u':マウンテンバイクに乗る人_濃い肌色:',
        'ko': u':산악_자전거_타는_사람_검은색_피부:',
        'pt': ':pessoa_fazendo_mountain_bike_pele_escura:',
        'it': ':ciclista_di_mountain_bike_carnagione_scura:',
        'fa': u':دوچرخه_کوهستان_پوست_آبنوسی:',
        'id': ':orang_bersepeda_gunung_warna_kulit_gelap:',
        'zh': u':骑山地车_较深肤色:'
    },
    u'\U0001F6B5\U0001F3FB': { # 🚵🏻
        'en' : ':person_mountain_biking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mountainbiker(in)_helle_hautfarbe:',
        'es': u':persona_en_bicicleta_de_montaña_tono_de_piel_claro:',
        'fr': ':personne_en_vtt_peau_claire:',
        'ja': u':マウンテンバイクに乗る人_薄い肌色:',
        'ko': u':산악_자전거_타는_사람_하얀_피부:',
        'pt': ':pessoa_fazendo_mountain_bike_pele_clara:',
        'it': ':ciclista_di_mountain_bike_carnagione_chiara:',
        'fa': u':دوچرخه_کوهستان_پوست_سفید:',
        'id': ':orang_bersepeda_gunung_warna_kulit_cerah:',
        'zh': u':骑山地车_较浅肤色:'
    },
    u'\U0001F6B5\U0001F3FE': { # 🚵🏾
        'en' : ':person_mountain_biking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mountainbiker(in)_mitteldunkle_hautfarbe:',
        'es': u':persona_en_bicicleta_de_montaña_tono_de_piel_oscuro_medio:',
        'fr': ':personne_en_vtt_peau_mate:',
        'ja': u':マウンテンバイクに乗る人_やや濃い肌色:',
        'ko': u':산악_자전거_타는_사람_진한_갈색_피부:',
        'pt': ':pessoa_fazendo_mountain_bike_pele_morena_escura:',
        'it': ':ciclista_di_mountain_bike_carnagione_abbastanza_scura:',
        'fa': u':دوچرخه_کوهستان_پوست_گندمی:',
        'id': ':orang_bersepeda_gunung_warna_kulit_gelap-sedang:',
        'zh': u':骑山地车_中等深肤色:'
    },
    u'\U0001F6B5\U0001F3FC': { # 🚵🏼
        'en' : ':person_mountain_biking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mountainbiker(in)_mittelhelle_hautfarbe:',
        'es': u':persona_en_bicicleta_de_montaña_tono_de_piel_claro_medio:',
        'fr': ':personne_en_vtt_peau_moyennement_claire:',
        'ja': u':マウンテンバイクに乗る人_やや薄い肌色:',
        'ko': u':산악_자전거_타는_사람_연한_갈색_피부:',
        'pt': ':pessoa_fazendo_mountain_bike_pele_morena_clara:',
        'it': ':ciclista_di_mountain_bike_carnagione_abbastanza_chiara:',
        'fa': u':دوچرخه_کوهستان_پوست_روشن:',
        'id': ':orang_bersepeda_gunung_warna_kulit_cerah-sedang:',
        'zh': u':骑山地车_中等浅肤色:'
    },
    u'\U0001F6B5\U0001F3FD': { # 🚵🏽
        'en' : ':person_mountain_biking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mountainbiker(in)_mittlere_hautfarbe:',
        'es': u':persona_en_bicicleta_de_montaña_tono_de_piel_medio:',
        'fr': u':personne_en_vtt_peau_légèrement_mate:',
        'ja': u':マウンテンバイクに乗る人_中間の肌色:',
        'ko': u':산악_자전거_타는_사람_갈색_피부:',
        'pt': ':pessoa_fazendo_mountain_bike_pele_morena:',
        'it': ':ciclista_di_mountain_bike_carnagione_olivastra:',
        'fa': u':دوچرخه_کوهستان_پوست_طلایی:',
        'id': ':orang_bersepeda_gunung_warna_kulit_sedang:',
        'zh': u':骑山地车_中等肤色:'
    },
    u'\U0001F93E': { # 🤾
        'en' : ':person_playing_handball:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':handball_person:'],
        'de': ':handballspieler(in):',
        'es': ':persona_jugando_al_balonmano:',
        'fr': ':personne_jouant_au_handball:',
        'ja': u':ハンドボールをする人:',
        'ko': u':핸드볼하는_사람:',
        'pt': ':handebol:',
        'it': ':persona_che_gioca_a_pallamano:',
        'fa': u':هندبال:',
        'id': ':orang_bermain_bola_tangan:',
        'zh': u':手球:'
    },
    u'\U0001F93E\U0001F3FF': { # 🤾🏿
        'en' : ':person_playing_handball_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':handballspieler(in)_dunkle_hautfarbe:',
        'es': ':persona_jugando_al_balonmano_tono_de_piel_oscuro:',
        'fr': u':personne_jouant_au_handball_peau_foncée:',
        'ja': u':ハンドボールをする人_濃い肌色:',
        'ko': u':핸드볼하는_사람_검은색_피부:',
        'pt': ':handebol_pele_escura:',
        'it': ':persona_che_gioca_a_pallamano_carnagione_scura:',
        'fa': u':هندبال_پوست_آبنوسی:',
        'id': ':orang_bermain_bola_tangan_warna_kulit_gelap:',
        'zh': u':手球_较深肤色:'
    },
    u'\U0001F93E\U0001F3FB': { # 🤾🏻
        'en' : ':person_playing_handball_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':handballspieler(in)_helle_hautfarbe:',
        'es': ':persona_jugando_al_balonmano_tono_de_piel_claro:',
        'fr': ':personne_jouant_au_handball_peau_claire:',
        'ja': u':ハンドボールをする人_薄い肌色:',
        'ko': u':핸드볼하는_사람_하얀_피부:',
        'pt': ':handebol_pele_clara:',
        'it': ':persona_che_gioca_a_pallamano_carnagione_chiara:',
        'fa': u':هندبال_پوست_سفید:',
        'id': ':orang_bermain_bola_tangan_warna_kulit_cerah:',
        'zh': u':手球_较浅肤色:'
    },
    u'\U0001F93E\U0001F3FE': { # 🤾🏾
        'en' : ':person_playing_handball_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':handballspieler(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_jugando_al_balonmano_tono_de_piel_oscuro_medio:',
        'fr': ':personne_jouant_au_handball_peau_mate:',
        'ja': u':ハンドボールをする人_やや濃い肌色:',
        'ko': u':핸드볼하는_사람_진한_갈색_피부:',
        'pt': ':handebol_pele_morena_escura:',
        'it': ':persona_che_gioca_a_pallamano_carnagione_abbastanza_scura:',
        'fa': u':هندبال_پوست_گندمی:',
        'id': ':orang_bermain_bola_tangan_warna_kulit_gelap-sedang:',
        'zh': u':手球_中等深肤色:'
    },
    u'\U0001F93E\U0001F3FC': { # 🤾🏼
        'en' : ':person_playing_handball_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':handballspieler(in)_mittelhelle_hautfarbe:',
        'es': ':persona_jugando_al_balonmano_tono_de_piel_claro_medio:',
        'fr': ':personne_jouant_au_handball_peau_moyennement_claire:',
        'ja': u':ハンドボールをする人_やや薄い肌色:',
        'ko': u':핸드볼하는_사람_연한_갈색_피부:',
        'pt': ':handebol_pele_morena_clara:',
        'it': ':persona_che_gioca_a_pallamano_carnagione_abbastanza_chiara:',
        'fa': u':هندبال_پوست_روشن:',
        'id': ':orang_bermain_bola_tangan_warna_kulit_cerah-sedang:',
        'zh': u':手球_中等浅肤色:'
    },
    u'\U0001F93E\U0001F3FD': { # 🤾🏽
        'en' : ':person_playing_handball_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':handballspieler(in)_mittlere_hautfarbe:',
        'es': ':persona_jugando_al_balonmano_tono_de_piel_medio:',
        'fr': u':personne_jouant_au_handball_peau_légèrement_mate:',
        'ja': u':ハンドボールをする人_中間の肌色:',
        'ko': u':핸드볼하는_사람_갈색_피부:',
        'pt': ':handebol_pele_morena:',
        'it': ':persona_che_gioca_a_pallamano_carnagione_olivastra:',
        'fa': u':هندبال_پوست_طلایی:',
        'id': ':orang_bermain_bola_tangan_warna_kulit_sedang:',
        'zh': u':手球_中等肤色:'
    },
    u'\U0001F93D': { # 🤽
        'en' : ':person_playing_water_polo:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':water_polo:'],
        'de': ':wasserballspieler(in):',
        'es': ':persona_jugando_al_waterpolo:',
        'fr': ':personne_jouant_au_water-polo:',
        'ja': u':水球をする人:',
        'ko': u':수구하는_사람:',
        'pt': u':pessoa_jogando_polo_aquático:',
        'it': ':persona_che_gioca_a_pallanuoto:',
        'fa': u':واترپلو:',
        'id': ':orang_bermain_polo_air:',
        'zh': u':水球:'
    },
    u'\U0001F93D\U0001F3FF': { # 🤽🏿
        'en' : ':person_playing_water_polo_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':wasserballspieler(in)_dunkle_hautfarbe:',
        'es': ':persona_jugando_al_waterpolo_tono_de_piel_oscuro:',
        'fr': u':personne_jouant_au_water-polo_peau_foncée:',
        'ja': u':水球をする人_濃い肌色:',
        'ko': u':수구하는_사람_검은색_피부:',
        'pt': u':pessoa_jogando_polo_aquático_pele_escura:',
        'it': ':persona_che_gioca_a_pallanuoto_carnagione_scura:',
        'fa': u':واترپلو_پوست_آبنوسی:',
        'id': ':orang_bermain_polo_air_warna_kulit_gelap:',
        'zh': u':水球_较深肤色:'
    },
    u'\U0001F93D\U0001F3FB': { # 🤽🏻
        'en' : ':person_playing_water_polo_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':wasserballspieler(in)_helle_hautfarbe:',
        'es': ':persona_jugando_al_waterpolo_tono_de_piel_claro:',
        'fr': ':personne_jouant_au_water-polo_peau_claire:',
        'ja': u':水球をする人_薄い肌色:',
        'ko': u':수구하는_사람_하얀_피부:',
        'pt': u':pessoa_jogando_polo_aquático_pele_clara:',
        'it': ':persona_che_gioca_a_pallanuoto_carnagione_chiara:',
        'fa': u':واترپلو_پوست_سفید:',
        'id': ':orang_bermain_polo_air_warna_kulit_cerah:',
        'zh': u':水球_较浅肤色:'
    },
    u'\U0001F93D\U0001F3FE': { # 🤽🏾
        'en' : ':person_playing_water_polo_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':wasserballspieler(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_jugando_al_waterpolo_tono_de_piel_oscuro_medio:',
        'fr': ':personne_jouant_au_water-polo_peau_mate:',
        'ja': u':水球をする人_やや濃い肌色:',
        'ko': u':수구하는_사람_진한_갈색_피부:',
        'pt': u':pessoa_jogando_polo_aquático_pele_morena_escura:',
        'it': ':persona_che_gioca_a_pallanuoto_carnagione_abbastanza_scura:',
        'fa': u':واترپلو_پوست_گندمی:',
        'id': ':orang_bermain_polo_air_warna_kulit_gelap-sedang:',
        'zh': u':水球_中等深肤色:'
    },
    u'\U0001F93D\U0001F3FC': { # 🤽🏼
        'en' : ':person_playing_water_polo_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':wasserballspieler(in)_mittelhelle_hautfarbe:',
        'es': ':persona_jugando_al_waterpolo_tono_de_piel_claro_medio:',
        'fr': ':personne_jouant_au_water-polo_peau_moyennement_claire:',
        'ja': u':水球をする人_やや薄い肌色:',
        'ko': u':수구하는_사람_연한_갈색_피부:',
        'pt': u':pessoa_jogando_polo_aquático_pele_morena_clara:',
        'it': ':persona_che_gioca_a_pallanuoto_carnagione_abbastanza_chiara:',
        'fa': u':واترپلو_پوست_روشن:',
        'id': ':orang_bermain_polo_air_warna_kulit_cerah-sedang:',
        'zh': u':水球_中等浅肤色:'
    },
    u'\U0001F93D\U0001F3FD': { # 🤽🏽
        'en' : ':person_playing_water_polo_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':wasserballspieler(in)_mittlere_hautfarbe:',
        'es': ':persona_jugando_al_waterpolo_tono_de_piel_medio:',
        'fr': u':personne_jouant_au_water-polo_peau_légèrement_mate:',
        'ja': u':水球をする人_中間の肌色:',
        'ko': u':수구하는_사람_갈색_피부:',
        'pt': u':pessoa_jogando_polo_aquático_pele_morena:',
        'it': ':persona_che_gioca_a_pallanuoto_carnagione_olivastra:',
        'fa': u':واترپلو_پوست_طلایی:',
        'id': ':orang_bermain_polo_air_warna_kulit_sedang:',
        'zh': u':水球_中等肤色:'
    },
    u'\U0001F64E': { # 🙎
        'en' : ':person_pouting:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pouting_face:', ':person_with_pouting_face:'],
        'de': ':schmollende_person:',
        'es': ':persona_haciendo_pucheros:',
        'fr': ':personne_qui_boude:',
        'ja': u':不機嫌な人:',
        'ko': u':뾰로통한_사람:',
        'pt': ':pessoa_fazendo_bico:',
        'it': ':persona_imbronciata:',
        'fa': u':آدم_ناراضی:',
        'id': ':orang_tidak_senang:',
        'zh': u':撅嘴:'
    },
    u'\U0001F64E\U0001F3FF': { # 🙎🏿
        'en' : ':person_pouting_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schmollende_person_dunkle_hautfarbe:',
        'es': ':persona_haciendo_pucheros_tono_de_piel_oscuro:',
        'fr': u':personne_qui_boude_peau_foncée:',
        'ja': u':不機嫌な人_濃い肌色:',
        'ko': u':뾰로통한_사람_검은색_피부:',
        'pt': ':pessoa_fazendo_bico_pele_escura:',
        'it': ':persona_imbronciata_carnagione_scura:',
        'fa': u':آدم_ناراضی_پوست_آبنوسی:',
        'id': ':orang_tidak_senang_warna_kulit_gelap:',
        'zh': u':撅嘴_较深肤色:'
    },
    u'\U0001F64E\U0001F3FB': { # 🙎🏻
        'en' : ':person_pouting_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schmollende_person_helle_hautfarbe:',
        'es': ':persona_haciendo_pucheros_tono_de_piel_claro:',
        'fr': ':personne_qui_boude_peau_claire:',
        'ja': u':不機嫌な人_薄い肌色:',
        'ko': u':뾰로통한_사람_하얀_피부:',
        'pt': ':pessoa_fazendo_bico_pele_clara:',
        'it': ':persona_imbronciata_carnagione_chiara:',
        'fa': u':آدم_ناراضی_پوست_سفید:',
        'id': ':orang_tidak_senang_warna_kulit_cerah:',
        'zh': u':撅嘴_较浅肤色:'
    },
    u'\U0001F64E\U0001F3FE': { # 🙎🏾
        'en' : ':person_pouting_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schmollende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_haciendo_pucheros_tono_de_piel_oscuro_medio:',
        'fr': ':personne_qui_boude_peau_mate:',
        'ja': u':不機嫌な人_やや濃い肌色:',
        'ko': u':뾰로통한_사람_진한_갈색_피부:',
        'pt': ':pessoa_fazendo_bico_pele_morena_escura:',
        'it': ':persona_imbronciata_carnagione_abbastanza_scura:',
        'fa': u':آدم_ناراضی_پوست_گندمی:',
        'id': ':orang_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':撅嘴_中等深肤色:'
    },
    u'\U0001F64E\U0001F3FC': { # 🙎🏼
        'en' : ':person_pouting_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schmollende_person_mittelhelle_hautfarbe:',
        'es': ':persona_haciendo_pucheros_tono_de_piel_claro_medio:',
        'fr': ':personne_qui_boude_peau_moyennement_claire:',
        'ja': u':不機嫌な人_やや薄い肌色:',
        'ko': u':뾰로통한_사람_연한_갈색_피부:',
        'pt': ':pessoa_fazendo_bico_pele_morena_clara:',
        'it': ':persona_imbronciata_carnagione_abbastanza_chiara:',
        'fa': u':آدم_ناراضی_پوست_روشن:',
        'id': ':orang_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':撅嘴_中等浅肤色:'
    },
    u'\U0001F64E\U0001F3FD': { # 🙎🏽
        'en' : ':person_pouting_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schmollende_person_mittlere_hautfarbe:',
        'es': ':persona_haciendo_pucheros_tono_de_piel_medio:',
        'fr': u':personne_qui_boude_peau_légèrement_mate:',
        'ja': u':不機嫌な人_中間の肌色:',
        'ko': u':뾰로통한_사람_갈색_피부:',
        'pt': ':pessoa_fazendo_bico_pele_morena:',
        'it': ':persona_imbronciata_carnagione_olivastra:',
        'fa': u':آدم_ناراضی_پوست_طلایی:',
        'id': ':orang_tidak_senang_warna_kulit_sedang:',
        'zh': u':撅嘴_中等肤色:'
    },
    u'\U0001F64B': { # 🙋
        'en' : ':person_raising_hand:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':raising_hand:'],
        'de': ':person_mit_erhobenem_arm:',
        'es': ':persona_con_la_mano_levantada:',
        'fr': u':personne_qui_lève_la_main:',
        'ja': u':手を挙げる人:',
        'ko': u':한_손_든_사람:',
        'pt': u':pessoa_levantando_a_mão:',
        'it': ':persona_con_mano_alzata:',
        'fa': u':ای_ول:',
        'id': ':orang_mengangkat_tangan:',
        'zh': u':举手:'
    },
    u'\U0001F64B\U0001F3FF': { # 🙋🏿
        'en' : ':person_raising_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_erhobenem_arm_dunkle_hautfarbe:',
        'es': ':persona_con_la_mano_levantada_tono_de_piel_oscuro:',
        'fr': u':personne_qui_lève_la_main_peau_foncée:',
        'ja': u':手を挙げる人_濃い肌色:',
        'ko': u':한_손_든_사람_검은색_피부:',
        'pt': u':pessoa_levantando_a_mão_pele_escura:',
        'it': ':persona_con_mano_alzata_carnagione_scura:',
        'fa': u':ای_ول_پوست_آبنوسی:',
        'id': ':orang_mengangkat_tangan_warna_kulit_gelap:',
        'zh': u':举手_较深肤色:'
    },
    u'\U0001F64B\U0001F3FB': { # 🙋🏻
        'en' : ':person_raising_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_erhobenem_arm_helle_hautfarbe:',
        'es': ':persona_con_la_mano_levantada_tono_de_piel_claro:',
        'fr': u':personne_qui_lève_la_main_peau_claire:',
        'ja': u':手を挙げる人_薄い肌色:',
        'ko': u':한_손_든_사람_하얀_피부:',
        'pt': u':pessoa_levantando_a_mão_pele_clara:',
        'it': ':persona_con_mano_alzata_carnagione_chiara:',
        'fa': u':ای_ول_پوست_سفید:',
        'id': ':orang_mengangkat_tangan_warna_kulit_cerah:',
        'zh': u':举手_较浅肤色:'
    },
    u'\U0001F64B\U0001F3FE': { # 🙋🏾
        'en' : ':person_raising_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_erhobenem_arm_mitteldunkle_hautfarbe:',
        'es': ':persona_con_la_mano_levantada_tono_de_piel_oscuro_medio:',
        'fr': u':personne_qui_lève_la_main_peau_mate:',
        'ja': u':手を挙げる人_やや濃い肌色:',
        'ko': u':한_손_든_사람_진한_갈색_피부:',
        'pt': u':pessoa_levantando_a_mão_pele_morena_escura:',
        'it': ':persona_con_mano_alzata_carnagione_abbastanza_scura:',
        'fa': u':ای_ول_پوست_گندمی:',
        'id': ':orang_mengangkat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':举手_中等深肤色:'
    },
    u'\U0001F64B\U0001F3FC': { # 🙋🏼
        'en' : ':person_raising_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_erhobenem_arm_mittelhelle_hautfarbe:',
        'es': ':persona_con_la_mano_levantada_tono_de_piel_claro_medio:',
        'fr': u':personne_qui_lève_la_main_peau_moyennement_claire:',
        'ja': u':手を挙げる人_やや薄い肌色:',
        'ko': u':한_손_든_사람_연한_갈색_피부:',
        'pt': u':pessoa_levantando_a_mão_pele_morena_clara:',
        'it': ':persona_con_mano_alzata_carnagione_abbastanza_chiara:',
        'fa': u':ای_ول_پوست_روشن:',
        'id': ':orang_mengangkat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':举手_中等浅肤色:'
    },
    u'\U0001F64B\U0001F3FD': { # 🙋🏽
        'en' : ':person_raising_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_erhobenem_arm_mittlere_hautfarbe:',
        'es': ':persona_con_la_mano_levantada_tono_de_piel_medio:',
        'fr': u':personne_qui_lève_la_main_peau_légèrement_mate:',
        'ja': u':手を挙げる人_中間の肌色:',
        'ko': u':한_손_든_사람_갈색_피부:',
        'pt': u':pessoa_levantando_a_mão_pele_morena:',
        'it': ':persona_con_mano_alzata_carnagione_olivastra:',
        'fa': u':ای_ول_پوست_طلایی:',
        'id': ':orang_mengangkat_tangan_warna_kulit_sedang:',
        'zh': u':举手_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F9B0': { # 🧑‍🦰
        'en' : ':person_red_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':erwachsener_rotes_haar:',
        'es': ':persona_adulta_pelo_pelirrojo:',
        'fr': ':adulte_cheveux_roux:',
        'ja': u':大人_赤毛:',
        'ko': u':사람_빨간_머리:',
        'pt': ':pessoa_cabelo_vermelho:',
        'it': ':persona_capelli_rossi:',
        'fa': u':بزرگسال_موقرمز:',
        'id': ':dewasa_rambut_merah:',
        'zh': u':成人_红发:'
    },
    u'\U0001F6A3': { # 🚣
        'en' : ':person_rowing_boat:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':rowboat:'],
        'de': ':person_im_ruderboot:',
        'es': ':persona_remando_en_un_bote:',
        'fr': ':personne_ramant_dans_une_barque:',
        'ja': u':ボートをこぐ人:',
        'ko': u':노젓는_사람:',
        'pt': ':pessoa_remando:',
        'it': ':persona_in_barca_a_remi:',
        'fa': u':قایق_پارویی:',
        'id': ':orang_mendayung_perahu:',
        'zh': u':划艇:'
    },
    u'\U0001F6A3\U0001F3FF': { # 🚣🏿
        'en' : ':person_rowing_boat_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_im_ruderboot_dunkle_hautfarbe:',
        'es': ':persona_remando_en_un_bote_tono_de_piel_oscuro:',
        'fr': u':personne_ramant_dans_une_barque_peau_foncée:',
        'ja': u':ボートをこぐ人_濃い肌色:',
        'ko': u':노젓는_사람_검은색_피부:',
        'pt': ':pessoa_remando_pele_escura:',
        'it': ':persona_in_barca_a_remi_carnagione_scura:',
        'fa': u':قایق_پارویی_پوست_آبنوسی:',
        'id': ':orang_mendayung_perahu_warna_kulit_gelap:',
        'zh': u':划艇_较深肤色:'
    },
    u'\U0001F6A3\U0001F3FB': { # 🚣🏻
        'en' : ':person_rowing_boat_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_im_ruderboot_helle_hautfarbe:',
        'es': ':persona_remando_en_un_bote_tono_de_piel_claro:',
        'fr': ':personne_ramant_dans_une_barque_peau_claire:',
        'ja': u':ボートをこぐ人_薄い肌色:',
        'ko': u':노젓는_사람_하얀_피부:',
        'pt': ':pessoa_remando_pele_clara:',
        'it': ':persona_in_barca_a_remi_carnagione_chiara:',
        'fa': u':قایق_پارویی_پوست_سفید:',
        'id': ':orang_mendayung_perahu_warna_kulit_cerah:',
        'zh': u':划艇_较浅肤色:'
    },
    u'\U0001F6A3\U0001F3FE': { # 🚣🏾
        'en' : ':person_rowing_boat_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_im_ruderboot_mitteldunkle_hautfarbe:',
        'es': ':persona_remando_en_un_bote_tono_de_piel_oscuro_medio:',
        'fr': ':personne_ramant_dans_une_barque_peau_mate:',
        'ja': u':ボートをこぐ人_やや濃い肌色:',
        'ko': u':노젓는_사람_진한_갈색_피부:',
        'pt': ':pessoa_remando_pele_morena_escura:',
        'it': ':persona_in_barca_a_remi_carnagione_abbastanza_scura:',
        'fa': u':قایق_پارویی_پوست_گندمی:',
        'id': ':orang_mendayung_perahu_warna_kulit_gelap-sedang:',
        'zh': u':划艇_中等深肤色:'
    },
    u'\U0001F6A3\U0001F3FC': { # 🚣🏼
        'en' : ':person_rowing_boat_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_im_ruderboot_mittelhelle_hautfarbe:',
        'es': ':persona_remando_en_un_bote_tono_de_piel_claro_medio:',
        'fr': ':personne_ramant_dans_une_barque_peau_moyennement_claire:',
        'ja': u':ボートをこぐ人_やや薄い肌色:',
        'ko': u':노젓는_사람_연한_갈색_피부:',
        'pt': ':pessoa_remando_pele_morena_clara:',
        'it': ':persona_in_barca_a_remi_carnagione_abbastanza_chiara:',
        'fa': u':قایق_پارویی_پوست_روشن:',
        'id': ':orang_mendayung_perahu_warna_kulit_cerah-sedang:',
        'zh': u':划艇_中等浅肤色:'
    },
    u'\U0001F6A3\U0001F3FD': { # 🚣🏽
        'en' : ':person_rowing_boat_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_im_ruderboot_mittlere_hautfarbe:',
        'es': ':persona_remando_en_un_bote_tono_de_piel_medio:',
        'fr': u':personne_ramant_dans_une_barque_peau_légèrement_mate:',
        'ja': u':ボートをこぐ人_中間の肌色:',
        'ko': u':노젓는_사람_갈색_피부:',
        'pt': ':pessoa_remando_pele_morena:',
        'it': ':persona_in_barca_a_remi_carnagione_olivastra:',
        'fa': u':قایق_پارویی_پوست_طلایی:',
        'id': ':orang_mendayung_perahu_warna_kulit_sedang:',
        'zh': u':划艇_中等肤色:'
    },
    u'\U0001F3C3': { # 🏃
        'en' : ':person_running:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':runner:', ':running:'],
        'de': ':laufende_person:',
        'es': ':persona_corriendo:',
        'fr': ':personne_qui_court:',
        'ja': u':走る人:',
        'ko': u':뛰는_사람:',
        'pt': ':pessoa_correndo:',
        'it': ':persona_che_corre:',
        'fa': u':دونده:',
        'id': ':orang_berlari:',
        'zh': u':跑步者:'
    },
    u'\U0001F3C3\U0001F3FF': { # 🏃🏿
        'en' : ':person_running_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':laufende_person_dunkle_hautfarbe:',
        'es': ':persona_corriendo_tono_de_piel_oscuro:',
        'fr': u':personne_qui_court_peau_foncée:',
        'ja': u':走る人_濃い肌色:',
        'ko': u':뛰는_사람_검은색_피부:',
        'pt': ':pessoa_correndo_pele_escura:',
        'it': ':persona_che_corre_carnagione_scura:',
        'fa': u':دونده_پوست_آبنوسی:',
        'id': ':orang_berlari_warna_kulit_gelap:',
        'zh': u':跑步者_较深肤色:'
    },
    u'\U0001F3C3\U0001F3FB': { # 🏃🏻
        'en' : ':person_running_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':laufende_person_helle_hautfarbe:',
        'es': ':persona_corriendo_tono_de_piel_claro:',
        'fr': ':personne_qui_court_peau_claire:',
        'ja': u':走る人_薄い肌色:',
        'ko': u':뛰는_사람_하얀_피부:',
        'pt': ':pessoa_correndo_pele_clara:',
        'it': ':persona_che_corre_carnagione_chiara:',
        'fa': u':دونده_پوست_سفید:',
        'id': ':orang_berlari_warna_kulit_cerah:',
        'zh': u':跑步者_较浅肤色:'
    },
    u'\U0001F3C3\U0001F3FE': { # 🏃🏾
        'en' : ':person_running_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':laufende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_corriendo_tono_de_piel_oscuro_medio:',
        'fr': ':personne_qui_court_peau_mate:',
        'ja': u':走る人_やや濃い肌色:',
        'ko': u':뛰는_사람_진한_갈색_피부:',
        'pt': ':pessoa_correndo_pele_morena_escura:',
        'it': ':persona_che_corre_carnagione_abbastanza_scura:',
        'fa': u':دونده_پوست_گندمی:',
        'id': ':orang_berlari_warna_kulit_gelap-sedang:',
        'zh': u':跑步者_中等深肤色:'
    },
    u'\U0001F3C3\U0001F3FC': { # 🏃🏼
        'en' : ':person_running_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':laufende_person_mittelhelle_hautfarbe:',
        'es': ':persona_corriendo_tono_de_piel_claro_medio:',
        'fr': ':personne_qui_court_peau_moyennement_claire:',
        'ja': u':走る人_やや薄い肌色:',
        'ko': u':뛰는_사람_연한_갈색_피부:',
        'pt': ':pessoa_correndo_pele_morena_clara:',
        'it': ':persona_che_corre_carnagione_abbastanza_chiara:',
        'fa': u':دونده_پوست_روشن:',
        'id': ':orang_berlari_warna_kulit_cerah-sedang:',
        'zh': u':跑步者_中等浅肤色:'
    },
    u'\U0001F3C3\U0001F3FD': { # 🏃🏽
        'en' : ':person_running_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':laufende_person_mittlere_hautfarbe:',
        'es': ':persona_corriendo_tono_de_piel_medio:',
        'fr': u':personne_qui_court_peau_légèrement_mate:',
        'ja': u':走る人_中間の肌色:',
        'ko': u':뛰는_사람_갈색_피부:',
        'pt': ':pessoa_correndo_pele_morena:',
        'it': ':persona_che_corre_carnagione_olivastra:',
        'fa': u':دونده_پوست_طلایی:',
        'id': ':orang_berlari_warna_kulit_sedang:',
        'zh': u':跑步者_中等肤色:'
    },
    u'\U0001F937': { # 🤷
        'en' : ':person_shrugging:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':shrug:'],
        'de': ':schulterzuckende_person:',
        'es': ':persona_encogida_de_hombros:',
        'fr': u':personne_qui_hausse_les_épaules:',
        'ja': u':お手上げする人:',
        'ko': u':어깨를_으쓱하는_사람:',
        'pt': ':pessoa_dando_de_ombros:',
        'it': ':persona_che_scrolla_le_spalle:',
        'fa': u':شانه_بالا_انداختن:',
        'id': ':orang_mengangkat_bahu:',
        'zh': u':耸肩:'
    },
    u'\U0001F937\U0001F3FF': { # 🤷🏿
        'en' : ':person_shrugging_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schulterzuckende_person_dunkle_hautfarbe:',
        'es': ':persona_encogida_de_hombros_tono_de_piel_oscuro:',
        'fr': u':personne_qui_hausse_les_épaules_peau_foncée:',
        'ja': u':お手上げする人_濃い肌色:',
        'ko': u':어깨를_으쓱하는_사람_검은색_피부:',
        'pt': ':pessoa_dando_de_ombros_pele_escura:',
        'it': ':persona_che_scrolla_le_spalle_carnagione_scura:',
        'fa': u':شانه_بالا_انداختن_پوست_آبنوسی:',
        'id': ':orang_mengangkat_bahu_warna_kulit_gelap:',
        'zh': u':耸肩_较深肤色:'
    },
    u'\U0001F937\U0001F3FB': { # 🤷🏻
        'en' : ':person_shrugging_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schulterzuckende_person_helle_hautfarbe:',
        'es': ':persona_encogida_de_hombros_tono_de_piel_claro:',
        'fr': u':personne_qui_hausse_les_épaules_peau_claire:',
        'ja': u':お手上げする人_薄い肌色:',
        'ko': u':어깨를_으쓱하는_사람_하얀_피부:',
        'pt': ':pessoa_dando_de_ombros_pele_clara:',
        'it': ':persona_che_scrolla_le_spalle_carnagione_chiara:',
        'fa': u':شانه_بالا_انداختن_پوست_سفید:',
        'id': ':orang_mengangkat_bahu_warna_kulit_cerah:',
        'zh': u':耸肩_较浅肤色:'
    },
    u'\U0001F937\U0001F3FE': { # 🤷🏾
        'en' : ':person_shrugging_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schulterzuckende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_encogida_de_hombros_tono_de_piel_oscuro_medio:',
        'fr': u':personne_qui_hausse_les_épaules_peau_mate:',
        'ja': u':お手上げする人_やや濃い肌色:',
        'ko': u':어깨를_으쓱하는_사람_진한_갈색_피부:',
        'pt': ':pessoa_dando_de_ombros_pele_morena_escura:',
        'it': ':persona_che_scrolla_le_spalle_carnagione_abbastanza_scura:',
        'fa': u':شانه_بالا_انداختن_پوست_گندمی:',
        'id': ':orang_mengangkat_bahu_warna_kulit_gelap-sedang:',
        'zh': u':耸肩_中等深肤色:'
    },
    u'\U0001F937\U0001F3FC': { # 🤷🏼
        'en' : ':person_shrugging_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schulterzuckende_person_mittelhelle_hautfarbe:',
        'es': ':persona_encogida_de_hombros_tono_de_piel_claro_medio:',
        'fr': u':personne_qui_hausse_les_épaules_peau_moyennement_claire:',
        'ja': u':お手上げする人_やや薄い肌色:',
        'ko': u':어깨를_으쓱하는_사람_연한_갈색_피부:',
        'pt': ':pessoa_dando_de_ombros_pele_morena_clara:',
        'it': ':persona_che_scrolla_le_spalle_carnagione_abbastanza_chiara:',
        'fa': u':شانه_بالا_انداختن_پوست_روشن:',
        'id': ':orang_mengangkat_bahu_warna_kulit_cerah-sedang:',
        'zh': u':耸肩_中等浅肤色:'
    },
    u'\U0001F937\U0001F3FD': { # 🤷🏽
        'en' : ':person_shrugging_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schulterzuckende_person_mittlere_hautfarbe:',
        'es': ':persona_encogida_de_hombros_tono_de_piel_medio:',
        'fr': u':personne_qui_hausse_les_épaules_peau_légèrement_mate:',
        'ja': u':お手上げする人_中間の肌色:',
        'ko': u':어깨를_으쓱하는_사람_갈색_피부:',
        'pt': ':pessoa_dando_de_ombros_pele_morena:',
        'it': ':persona_che_scrolla_le_spalle_carnagione_olivastra:',
        'fa': u':شانه_بالا_انداختن_پوست_طلایی:',
        'id': ':orang_mengangkat_bahu_warna_kulit_sedang:',
        'zh': u':耸肩_中等肤色:'
    },
    u'\U0001F9CD': { # 🧍
        'en' : ':person_standing:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':standing_person:'],
        'de': ':stehende_person:',
        'es': ':persona_de_pie:',
        'fr': ':personne_debout:',
        'ja': u':立つ人:',
        'ko': u':서_있는_사람:',
        'pt': u':pessoa_em_pé:',
        'it': ':persona_in_piedi:',
        'fa': u':آدم_ایستاده:',
        'id': ':orang_berdiri:',
        'zh': u':站立者:'
    },
    u'\U0001F9CD\U0001F3FF': { # 🧍🏿
        'en' : ':person_standing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_person_dunkle_hautfarbe:',
        'es': ':persona_de_pie_tono_de_piel_oscuro:',
        'fr': u':personne_debout_peau_foncée:',
        'ja': u':立つ人_濃い肌色:',
        'ko': u':서_있는_사람_검은색_피부:',
        'pt': u':pessoa_em_pé_pele_escura:',
        'it': ':persona_in_piedi_carnagione_scura:',
        'fa': u':آدم_ایستاده_پوست_آبنوسی:',
        'id': ':orang_berdiri_warna_kulit_gelap:',
        'zh': u':站立者_较深肤色:'
    },
    u'\U0001F9CD\U0001F3FB': { # 🧍🏻
        'en' : ':person_standing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_person_helle_hautfarbe:',
        'es': ':persona_de_pie_tono_de_piel_claro:',
        'fr': ':personne_debout_peau_claire:',
        'ja': u':立つ人_薄い肌色:',
        'ko': u':서_있는_사람_하얀_피부:',
        'pt': u':pessoa_em_pé_pele_clara:',
        'it': ':persona_in_piedi_carnagione_chiara:',
        'fa': u':آدم_ایستاده_پوست_سفید:',
        'id': ':orang_berdiri_warna_kulit_cerah:',
        'zh': u':站立者_较浅肤色:'
    },
    u'\U0001F9CD\U0001F3FE': { # 🧍🏾
        'en' : ':person_standing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_person_mitteldunkle_hautfarbe:',
        'es': ':persona_de_pie_tono_de_piel_oscuro_medio:',
        'fr': ':personne_debout_peau_mate:',
        'ja': u':立つ人_やや濃い肌色:',
        'ko': u':서_있는_사람_진한_갈색_피부:',
        'pt': u':pessoa_em_pé_pele_morena_escura:',
        'it': ':persona_in_piedi_carnagione_abbastanza_scura:',
        'fa': u':آدم_ایستاده_پوست_گندمی:',
        'id': ':orang_berdiri_warna_kulit_gelap-sedang:',
        'zh': u':站立者_中等深肤色:'
    },
    u'\U0001F9CD\U0001F3FC': { # 🧍🏼
        'en' : ':person_standing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_person_mittelhelle_hautfarbe:',
        'es': ':persona_de_pie_tono_de_piel_claro_medio:',
        'fr': ':personne_debout_peau_moyennement_claire:',
        'ja': u':立つ人_やや薄い肌色:',
        'ko': u':서_있는_사람_연한_갈색_피부:',
        'pt': u':pessoa_em_pé_pele_morena_clara:',
        'it': ':persona_in_piedi_carnagione_abbastanza_chiara:',
        'fa': u':آدم_ایستاده_پوست_روشن:',
        'id': ':orang_berdiri_warna_kulit_cerah-sedang:',
        'zh': u':站立者_中等浅肤色:'
    },
    u'\U0001F9CD\U0001F3FD': { # 🧍🏽
        'en' : ':person_standing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_person_mittlere_hautfarbe:',
        'es': ':persona_de_pie_tono_de_piel_medio:',
        'fr': u':personne_debout_peau_légèrement_mate:',
        'ja': u':立つ人_中間の肌色:',
        'ko': u':서_있는_사람_갈색_피부:',
        'pt': u':pessoa_em_pé_pele_morena:',
        'it': ':persona_in_piedi_carnagione_olivastra:',
        'fa': u':آدم_ایستاده_پوست_طلایی:',
        'id': ':orang_berdiri_warna_kulit_sedang:',
        'zh': u':站立者_中等肤色:'
    },
    u'\U0001F3C4': { # 🏄
        'en' : ':person_surfing:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':surfer:'],
        'variant': True,
        'de': ':surfer(in):',
        'es': ':persona_haciendo_surf:',
        'fr': ':personne_faisant_du_surf:',
        'ja': u':サーフィンする人:',
        'ko': u':서핑하는_사람:',
        'pt': ':surfista:',
        'it': ':persona_che_fa_surf:',
        'fa': u':موج_سوار:',
        'id': ':orang_berselancar:',
        'zh': u':冲浪:'
    },
    u'\U0001F3C4\U0001F3FF': { # 🏄🏿
        'en' : ':person_surfing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':surfer(in)_dunkle_hautfarbe:',
        'es': ':persona_haciendo_surf_tono_de_piel_oscuro:',
        'fr': u':personne_faisant_du_surf_peau_foncée:',
        'ja': u':サーフィンする人_濃い肌色:',
        'ko': u':서핑하는_사람_검은색_피부:',
        'pt': ':surfista_pele_escura:',
        'it': ':persona_che_fa_surf_carnagione_scura:',
        'fa': u':موج_سوار_پوست_آبنوسی:',
        'id': ':orang_berselancar_warna_kulit_gelap:',
        'zh': u':冲浪_较深肤色:'
    },
    u'\U0001F3C4\U0001F3FB': { # 🏄🏻
        'en' : ':person_surfing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':surfer(in)_helle_hautfarbe:',
        'es': ':persona_haciendo_surf_tono_de_piel_claro:',
        'fr': ':personne_faisant_du_surf_peau_claire:',
        'ja': u':サーフィンする人_薄い肌色:',
        'ko': u':서핑하는_사람_하얀_피부:',
        'pt': ':surfista_pele_clara:',
        'it': ':persona_che_fa_surf_carnagione_chiara:',
        'fa': u':موج_سوار_پوست_سفید:',
        'id': ':orang_berselancar_warna_kulit_cerah:',
        'zh': u':冲浪_较浅肤色:'
    },
    u'\U0001F3C4\U0001F3FE': { # 🏄🏾
        'en' : ':person_surfing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':surfer(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_haciendo_surf_tono_de_piel_oscuro_medio:',
        'fr': ':personne_faisant_du_surf_peau_mate:',
        'ja': u':サーフィンする人_やや濃い肌色:',
        'ko': u':서핑하는_사람_진한_갈색_피부:',
        'pt': ':surfista_pele_morena_escura:',
        'it': ':persona_che_fa_surf_carnagione_abbastanza_scura:',
        'fa': u':موج_سوار_پوست_گندمی:',
        'id': ':orang_berselancar_warna_kulit_gelap-sedang:',
        'zh': u':冲浪_中等深肤色:'
    },
    u'\U0001F3C4\U0001F3FC': { # 🏄🏼
        'en' : ':person_surfing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':surfer(in)_mittelhelle_hautfarbe:',
        'es': ':persona_haciendo_surf_tono_de_piel_claro_medio:',
        'fr': ':personne_faisant_du_surf_peau_moyennement_claire:',
        'ja': u':サーフィンする人_やや薄い肌色:',
        'ko': u':서핑하는_사람_연한_갈색_피부:',
        'pt': ':surfista_pele_morena_clara:',
        'it': ':persona_che_fa_surf_carnagione_abbastanza_chiara:',
        'fa': u':موج_سوار_پوست_روشن:',
        'id': ':orang_berselancar_warna_kulit_cerah-sedang:',
        'zh': u':冲浪_中等浅肤色:'
    },
    u'\U0001F3C4\U0001F3FD': { # 🏄🏽
        'en' : ':person_surfing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':surfer(in)_mittlere_hautfarbe:',
        'es': ':persona_haciendo_surf_tono_de_piel_medio:',
        'fr': u':personne_faisant_du_surf_peau_légèrement_mate:',
        'ja': u':サーフィンする人_中間の肌色:',
        'ko': u':서핑하는_사람_갈색_피부:',
        'pt': ':surfista_pele_morena:',
        'it': ':persona_che_fa_surf_carnagione_olivastra:',
        'fa': u':موج_سوار_پوست_طلایی:',
        'id': ':orang_berselancar_warna_kulit_sedang:',
        'zh': u':冲浪_中等肤色:'
    },
    u'\U0001F3CA': { # 🏊
        'en' : ':person_swimming:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':swimmer:'],
        'variant': True,
        'de': ':schwimmer(in):',
        'es': ':persona_nadando:',
        'fr': ':personne_nageant:',
        'ja': u':泳ぐ人:',
        'ko': u':수영하는_사람:',
        'pt': ':pessoa_nadando:',
        'it': ':persona_che_nuota:',
        'fa': u':شناگر:',
        'id': ':orang_berenang:',
        'zh': u':游泳:'
    },
    u'\U0001F3CA\U0001F3FF': { # 🏊🏿
        'en' : ':person_swimming_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schwimmer(in)_dunkle_hautfarbe:',
        'es': ':persona_nadando_tono_de_piel_oscuro:',
        'fr': u':personne_nageant_peau_foncée:',
        'ja': u':泳ぐ人_濃い肌色:',
        'ko': u':수영하는_사람_검은색_피부:',
        'pt': ':pessoa_nadando_pele_escura:',
        'it': ':persona_che_nuota_carnagione_scura:',
        'fa': u':شناگر_پوست_آبنوسی:',
        'id': ':orang_berenang_warna_kulit_gelap:',
        'zh': u':游泳_较深肤色:'
    },
    u'\U0001F3CA\U0001F3FB': { # 🏊🏻
        'en' : ':person_swimming_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schwimmer(in)_helle_hautfarbe:',
        'es': ':persona_nadando_tono_de_piel_claro:',
        'fr': ':personne_nageant_peau_claire:',
        'ja': u':泳ぐ人_薄い肌色:',
        'ko': u':수영하는_사람_하얀_피부:',
        'pt': ':pessoa_nadando_pele_clara:',
        'it': ':persona_che_nuota_carnagione_chiara:',
        'fa': u':شناگر_پوست_سفید:',
        'id': ':orang_berenang_warna_kulit_cerah:',
        'zh': u':游泳_较浅肤色:'
    },
    u'\U0001F3CA\U0001F3FE': { # 🏊🏾
        'en' : ':person_swimming_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schwimmer(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_nadando_tono_de_piel_oscuro_medio:',
        'fr': ':personne_nageant_peau_mate:',
        'ja': u':泳ぐ人_やや濃い肌色:',
        'ko': u':수영하는_사람_진한_갈색_피부:',
        'pt': ':pessoa_nadando_pele_morena_escura:',
        'it': ':persona_che_nuota_carnagione_abbastanza_scura:',
        'fa': u':شناگر_پوست_گندمی:',
        'id': ':orang_berenang_warna_kulit_gelap-sedang:',
        'zh': u':游泳_中等深肤色:'
    },
    u'\U0001F3CA\U0001F3FC': { # 🏊🏼
        'en' : ':person_swimming_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schwimmer(in)_mittelhelle_hautfarbe:',
        'es': ':persona_nadando_tono_de_piel_claro_medio:',
        'fr': ':personne_nageant_peau_moyennement_claire:',
        'ja': u':泳ぐ人_やや薄い肌色:',
        'ko': u':수영하는_사람_연한_갈색_피부:',
        'pt': ':pessoa_nadando_pele_morena_clara:',
        'it': ':persona_che_nuota_carnagione_abbastanza_chiara:',
        'fa': u':شناگر_پوست_روشن:',
        'id': ':orang_berenang_warna_kulit_cerah-sedang:',
        'zh': u':游泳_中等浅肤色:'
    },
    u'\U0001F3CA\U0001F3FD': { # 🏊🏽
        'en' : ':person_swimming_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schwimmer(in)_mittlere_hautfarbe:',
        'es': ':persona_nadando_tono_de_piel_medio:',
        'fr': u':personne_nageant_peau_légèrement_mate:',
        'ja': u':泳ぐ人_中間の肌色:',
        'ko': u':수영하는_사람_갈색_피부:',
        'pt': ':pessoa_nadando_pele_morena:',
        'it': ':persona_che_nuota_carnagione_olivastra:',
        'fa': u':شناگر_پوست_طلایی:',
        'id': ':orang_berenang_warna_kulit_sedang:',
        'zh': u':游泳_中等肤色:'
    },
    u'\U0001F6C0': { # 🛀
        'en' : ':person_taking_bath:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bath:'],
        'de': ':badende_person:',
        'es': u':persona_en_la_bañera:',
        'fr': ':personne_prenant_un_bain:',
        'ja': u':風呂に入る人:',
        'ko': u':목욕하는_사람:',
        'pt': ':pessoa_tomando_banho:',
        'it': ':persona_che_fa_il_bagno:',
        'fa': u':فرد_در_وان:',
        'id': ':orang_di_bak_mandi:',
        'zh': u':洗澡的人:'
    },
    u'\U0001F6C0\U0001F3FF': { # 🛀🏿
        'en' : ':person_taking_bath_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':badende_person_dunkle_hautfarbe:',
        'es': u':persona_en_la_bañera_tono_de_piel_oscuro:',
        'fr': u':personne_prenant_un_bain_peau_foncée:',
        'ja': u':風呂に入る人_濃い肌色:',
        'ko': u':목욕하는_사람_검은색_피부:',
        'pt': ':pessoa_tomando_banho_pele_escura:',
        'it': ':persona_che_fa_il_bagno_carnagione_scura:',
        'fa': u':فرد_در_وان_پوست_آبنوسی:',
        'id': ':orang_di_bak_mandi_warna_kulit_gelap:',
        'zh': u':洗澡的人_较深肤色:'
    },
    u'\U0001F6C0\U0001F3FB': { # 🛀🏻
        'en' : ':person_taking_bath_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':badende_person_helle_hautfarbe:',
        'es': u':persona_en_la_bañera_tono_de_piel_claro:',
        'fr': ':personne_prenant_un_bain_peau_claire:',
        'ja': u':風呂に入る人_薄い肌色:',
        'ko': u':목욕하는_사람_하얀_피부:',
        'pt': ':pessoa_tomando_banho_pele_clara:',
        'it': ':persona_che_fa_il_bagno_carnagione_chiara:',
        'fa': u':فرد_در_وان_پوست_سفید:',
        'id': ':orang_di_bak_mandi_warna_kulit_cerah:',
        'zh': u':洗澡的人_较浅肤色:'
    },
    u'\U0001F6C0\U0001F3FE': { # 🛀🏾
        'en' : ':person_taking_bath_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':badende_person_mitteldunkle_hautfarbe:',
        'es': u':persona_en_la_bañera_tono_de_piel_oscuro_medio:',
        'fr': ':personne_prenant_un_bain_peau_mate:',
        'ja': u':風呂に入る人_やや濃い肌色:',
        'ko': u':목욕하는_사람_진한_갈색_피부:',
        'pt': ':pessoa_tomando_banho_pele_morena_escura:',
        'it': ':persona_che_fa_il_bagno_carnagione_abbastanza_scura:',
        'fa': u':فرد_در_وان_پوست_گندمی:',
        'id': ':orang_di_bak_mandi_warna_kulit_gelap-sedang:',
        'zh': u':洗澡的人_中等深肤色:'
    },
    u'\U0001F6C0\U0001F3FC': { # 🛀🏼
        'en' : ':person_taking_bath_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':badende_person_mittelhelle_hautfarbe:',
        'es': u':persona_en_la_bañera_tono_de_piel_claro_medio:',
        'fr': ':personne_prenant_un_bain_peau_moyennement_claire:',
        'ja': u':風呂に入る人_やや薄い肌色:',
        'ko': u':목욕하는_사람_연한_갈색_피부:',
        'pt': ':pessoa_tomando_banho_pele_morena_clara:',
        'it': ':persona_che_fa_il_bagno_carnagione_abbastanza_chiara:',
        'fa': u':فرد_در_وان_پوست_روشن:',
        'id': ':orang_di_bak_mandi_warna_kulit_cerah-sedang:',
        'zh': u':洗澡的人_中等浅肤色:'
    },
    u'\U0001F6C0\U0001F3FD': { # 🛀🏽
        'en' : ':person_taking_bath_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':badende_person_mittlere_hautfarbe:',
        'es': u':persona_en_la_bañera_tono_de_piel_medio:',
        'fr': u':personne_prenant_un_bain_peau_légèrement_mate:',
        'ja': u':風呂に入る人_中間の肌色:',
        'ko': u':목욕하는_사람_갈색_피부:',
        'pt': ':pessoa_tomando_banho_pele_morena:',
        'it': ':persona_che_fa_il_bagno_carnagione_olivastra:',
        'fa': u':فرد_در_وان_پوست_طلایی:',
        'id': ':orang_di_bak_mandi_warna_kulit_sedang:',
        'zh': u':洗澡的人_中等肤色:'
    },
    u'\U0001F481': { # 💁
        'en' : ':person_tipping_hand:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tipping_hand_person:', ':information_desk_person:'],
        'de': ':infoschalter-mitarbeiter(in):',
        'es': u':persona_de_mostrador_de_información:',
        'fr': ':personne_paume_vers_le_haut:',
        'ja': u':案内する人:',
        'ko': u':손바닥_꺾은_사람:',
        'pt': ':pessoa_com_a_palma_virada_para_cima:',
        'it': ':persona_al_punto_informazioni:',
        'fa': u':آماده_کمک:',
        'id': ':orang_menengadahkan_tangan:',
        'zh': u':前台:'
    },
    u'\U0001F481\U0001F3FF': { # 💁🏿
        'en' : ':person_tipping_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':infoschalter-mitarbeiter(in)_dunkle_hautfarbe:',
        'es': u':persona_de_mostrador_de_información_tono_de_piel_oscuro:',
        'fr': u':personne_paume_vers_le_haut_peau_foncée:',
        'ja': u':案内する人_濃い肌色:',
        'ko': u':손바닥_꺾은_사람_검은색_피부:',
        'pt': ':pessoa_com_a_palma_virada_para_cima_pele_escura:',
        'it': ':persona_al_punto_informazioni_carnagione_scura:',
        'fa': u':آماده_کمک_پوست_آبنوسی:',
        'id': ':orang_menengadahkan_tangan_warna_kulit_gelap:',
        'zh': u':前台_较深肤色:'
    },
    u'\U0001F481\U0001F3FB': { # 💁🏻
        'en' : ':person_tipping_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':infoschalter-mitarbeiter(in)_helle_hautfarbe:',
        'es': u':persona_de_mostrador_de_información_tono_de_piel_claro:',
        'fr': ':personne_paume_vers_le_haut_peau_claire:',
        'ja': u':案内する人_薄い肌色:',
        'ko': u':손바닥_꺾은_사람_하얀_피부:',
        'pt': ':pessoa_com_a_palma_virada_para_cima_pele_clara:',
        'it': ':persona_al_punto_informazioni_carnagione_chiara:',
        'fa': u':آماده_کمک_پوست_سفید:',
        'id': ':orang_menengadahkan_tangan_warna_kulit_cerah:',
        'zh': u':前台_较浅肤色:'
    },
    u'\U0001F481\U0001F3FE': { # 💁🏾
        'en' : ':person_tipping_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':infoschalter-mitarbeiter(in)_mitteldunkle_hautfarbe:',
        'es': u':persona_de_mostrador_de_información_tono_de_piel_oscuro_medio:',
        'fr': ':personne_paume_vers_le_haut_peau_mate:',
        'ja': u':案内する人_やや濃い肌色:',
        'ko': u':손바닥_꺾은_사람_진한_갈색_피부:',
        'pt': ':pessoa_com_a_palma_virada_para_cima_pele_morena_escura:',
        'it': ':persona_al_punto_informazioni_carnagione_abbastanza_scura:',
        'fa': u':آماده_کمک_پوست_گندمی:',
        'id': ':orang_menengadahkan_tangan_warna_kulit_gelap-sedang:',
        'zh': u':前台_中等深肤色:'
    },
    u'\U0001F481\U0001F3FC': { # 💁🏼
        'en' : ':person_tipping_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':infoschalter-mitarbeiter(in)_mittelhelle_hautfarbe:',
        'es': u':persona_de_mostrador_de_información_tono_de_piel_claro_medio:',
        'fr': ':personne_paume_vers_le_haut_peau_moyennement_claire:',
        'ja': u':案内する人_やや薄い肌色:',
        'ko': u':손바닥_꺾은_사람_연한_갈색_피부:',
        'pt': ':pessoa_com_a_palma_virada_para_cima_pele_morena_clara:',
        'it': ':persona_al_punto_informazioni_carnagione_abbastanza_chiara:',
        'fa': u':آماده_کمک_پوست_روشن:',
        'id': ':orang_menengadahkan_tangan_warna_kulit_cerah-sedang:',
        'zh': u':前台_中等浅肤色:'
    },
    u'\U0001F481\U0001F3FD': { # 💁🏽
        'en' : ':person_tipping_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':infoschalter-mitarbeiter(in)_mittlere_hautfarbe:',
        'es': u':persona_de_mostrador_de_información_tono_de_piel_medio:',
        'fr': u':personne_paume_vers_le_haut_peau_légèrement_mate:',
        'ja': u':案内する人_中間の肌色:',
        'ko': u':손바닥_꺾은_사람_갈색_피부:',
        'pt': ':pessoa_com_a_palma_virada_para_cima_pele_morena:',
        'it': ':persona_al_punto_informazioni_carnagione_olivastra:',
        'fa': u':آماده_کمک_پوست_طلایی:',
        'id': ':orang_menengadahkan_tangan_warna_kulit_sedang:',
        'zh': u':前台_中等肤色:'
    },
    u'\U0001F6B6': { # 🚶
        'en' : ':person_walking:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':walking:'],
        'de': u':fußgänger(in):',
        'es': ':persona_caminando:',
        'fr': ':personne_qui_marche:',
        'ja': u':歩く人:',
        'ko': u':보행자:',
        'pt': ':pessoa_andando:',
        'it': ':pedone:',
        'fa': u':عابر_پیاده:',
        'id': ':orang_berjalan_kaki:',
        'zh': u':行人:'
    },
    u'\U0001F6B6\U0001F3FF': { # 🚶🏿
        'en' : ':person_walking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':fußgänger(in)_dunkle_hautfarbe:',
        'es': ':persona_caminando_tono_de_piel_oscuro:',
        'fr': u':personne_qui_marche_peau_foncée:',
        'ja': u':歩く人_濃い肌色:',
        'ko': u':보행자_검은색_피부:',
        'pt': ':pessoa_andando_pele_escura:',
        'it': ':pedone_carnagione_scura:',
        'fa': u':عابر_پیاده_پوست_آبنوسی:',
        'id': ':orang_berjalan_kaki_warna_kulit_gelap:',
        'zh': u':行人_较深肤色:'
    },
    u'\U0001F6B6\U0001F3FB': { # 🚶🏻
        'en' : ':person_walking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':fußgänger(in)_helle_hautfarbe:',
        'es': ':persona_caminando_tono_de_piel_claro:',
        'fr': ':personne_qui_marche_peau_claire:',
        'ja': u':歩く人_薄い肌色:',
        'ko': u':보행자_하얀_피부:',
        'pt': ':pessoa_andando_pele_clara:',
        'it': ':pedone_carnagione_chiara:',
        'fa': u':عابر_پیاده_پوست_سفید:',
        'id': ':orang_berjalan_kaki_warna_kulit_cerah:',
        'zh': u':行人_较浅肤色:'
    },
    u'\U0001F6B6\U0001F3FE': { # 🚶🏾
        'en' : ':person_walking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':fußgänger(in)_mitteldunkle_hautfarbe:',
        'es': ':persona_caminando_tono_de_piel_oscuro_medio:',
        'fr': ':personne_qui_marche_peau_mate:',
        'ja': u':歩く人_やや濃い肌色:',
        'ko': u':보행자_진한_갈색_피부:',
        'pt': ':pessoa_andando_pele_morena_escura:',
        'it': ':pedone_carnagione_abbastanza_scura:',
        'fa': u':عابر_پیاده_پوست_گندمی:',
        'id': ':orang_berjalan_kaki_warna_kulit_gelap-sedang:',
        'zh': u':行人_中等深肤色:'
    },
    u'\U0001F6B6\U0001F3FC': { # 🚶🏼
        'en' : ':person_walking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':fußgänger(in)_mittelhelle_hautfarbe:',
        'es': ':persona_caminando_tono_de_piel_claro_medio:',
        'fr': ':personne_qui_marche_peau_moyennement_claire:',
        'ja': u':歩く人_やや薄い肌色:',
        'ko': u':보행자_연한_갈색_피부:',
        'pt': ':pessoa_andando_pele_morena_clara:',
        'it': ':pedone_carnagione_abbastanza_chiara:',
        'fa': u':عابر_پیاده_پوست_روشن:',
        'id': ':orang_berjalan_kaki_warna_kulit_cerah-sedang:',
        'zh': u':行人_中等浅肤色:'
    },
    u'\U0001F6B6\U0001F3FD': { # 🚶🏽
        'en' : ':person_walking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':fußgänger(in)_mittlere_hautfarbe:',
        'es': ':persona_caminando_tono_de_piel_medio:',
        'fr': u':personne_qui_marche_peau_légèrement_mate:',
        'ja': u':歩く人_中間の肌色:',
        'ko': u':보행자_갈색_피부:',
        'pt': ':pessoa_andando_pele_morena:',
        'it': ':pedone_carnagione_olivastra:',
        'fa': u':عابر_پیاده_پوست_طلایی:',
        'id': ':orang_berjalan_kaki_warna_kulit_sedang:',
        'zh': u':行人_中等肤色:'
    },
    u'\U0001F473': { # 👳
        'en' : ':person_wearing_turban:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':person_with_turban:'],
        'de': ':person_mit_turban:',
        'es': ':persona_con_turbante:',
        'fr': ':personne_en_turban:',
        'ja': u':ターバンの人:',
        'ko': u':터번을_쓰고_있는_사람:',
        'pt': ':pessoa_com_turbante:',
        'it': ':persona_con_turbante:',
        'fa': u':مرد_عمامه_دار:',
        'id': ':orang_mengenakan_serban:',
        'zh': u':戴头巾的人:'
    },
    u'\U0001F473\U0001F3FF': { # 👳🏿
        'en' : ':person_wearing_turban_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_turban_dunkle_hautfarbe:',
        'es': ':persona_con_turbante_tono_de_piel_oscuro:',
        'fr': u':personne_en_turban_peau_foncée:',
        'ja': u':ターバンの人_濃い肌色:',
        'ko': u':터번을_쓰고_있는_사람_검은색_피부:',
        'pt': ':pessoa_com_turbante_pele_escura:',
        'it': ':persona_con_turbante_carnagione_scura:',
        'fa': u':مرد_عمامه_دار_پوست_آبنوسی:',
        'id': ':orang_mengenakan_serban_warna_kulit_gelap:',
        'zh': u':戴头巾的人_较深肤色:'
    },
    u'\U0001F473\U0001F3FB': { # 👳🏻
        'en' : ':person_wearing_turban_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_turban_helle_hautfarbe:',
        'es': ':persona_con_turbante_tono_de_piel_claro:',
        'fr': ':personne_en_turban_peau_claire:',
        'ja': u':ターバンの人_薄い肌色:',
        'ko': u':터번을_쓰고_있는_사람_하얀_피부:',
        'pt': ':pessoa_com_turbante_pele_clara:',
        'it': ':persona_con_turbante_carnagione_chiara:',
        'fa': u':مرد_عمامه_دار_پوست_سفید:',
        'id': ':orang_mengenakan_serban_warna_kulit_cerah:',
        'zh': u':戴头巾的人_较浅肤色:'
    },
    u'\U0001F473\U0001F3FE': { # 👳🏾
        'en' : ':person_wearing_turban_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_turban_mitteldunkle_hautfarbe:',
        'es': ':persona_con_turbante_tono_de_piel_oscuro_medio:',
        'fr': ':personne_en_turban_peau_mate:',
        'ja': u':ターバンの人_やや濃い肌色:',
        'ko': u':터번을_쓰고_있는_사람_진한_갈색_피부:',
        'pt': ':pessoa_com_turbante_pele_morena_escura:',
        'it': ':persona_con_turbante_carnagione_abbastanza_scura:',
        'fa': u':مرد_عمامه_دار_پوست_گندمی:',
        'id': ':orang_mengenakan_serban_warna_kulit_gelap-sedang:',
        'zh': u':戴头巾的人_中等深肤色:'
    },
    u'\U0001F473\U0001F3FC': { # 👳🏼
        'en' : ':person_wearing_turban_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_turban_mittelhelle_hautfarbe:',
        'es': ':persona_con_turbante_tono_de_piel_claro_medio:',
        'fr': ':personne_en_turban_peau_moyennement_claire:',
        'ja': u':ターバンの人_やや薄い肌色:',
        'ko': u':터번을_쓰고_있는_사람_연한_갈색_피부:',
        'pt': ':pessoa_com_turbante_pele_morena_clara:',
        'it': ':persona_con_turbante_carnagione_abbastanza_chiara:',
        'fa': u':مرد_عمامه_دار_پوست_روشن:',
        'id': ':orang_mengenakan_serban_warna_kulit_cerah-sedang:',
        'zh': u':戴头巾的人_中等浅肤色:'
    },
    u'\U0001F473\U0001F3FD': { # 👳🏽
        'en' : ':person_wearing_turban_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_turban_mittlere_hautfarbe:',
        'es': ':persona_con_turbante_tono_de_piel_medio:',
        'fr': u':personne_en_turban_peau_légèrement_mate:',
        'ja': u':ターバンの人_中間の肌色:',
        'ko': u':터번을_쓰고_있는_사람_갈색_피부:',
        'pt': ':pessoa_com_turbante_pele_morena:',
        'it': ':persona_con_turbante_carnagione_olivastra:',
        'fa': u':مرد_عمامه_دار_پوست_طلایی:',
        'id': ':orang_mengenakan_serban_warna_kulit_sedang:',
        'zh': u':戴头巾的人_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F9B3': { # 🧑‍🦳
        'en' : ':person_white_hair:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':erwachsener_weißes_haar:',
        'es': ':persona_adulta_pelo_blanco:',
        'fr': ':adulte_cheveux_blancs:',
        'ja': u':大人_白髪:',
        'ko': u':사람_백발:',
        'pt': ':pessoa_cabelo_branco:',
        'it': ':persona_capelli_bianchi:',
        'fa': u':بزرگسال_موسفید:',
        'id': ':dewasa_rambut_putih:',
        'zh': u':成人_白发:'
    },
    u'\U0001FAC5': { # 🫅
        'en' : ':person_with_crown:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':person_mit_krone:',
        'es': ':persona_con_corona:',
        'fr': ':personne_avec_une_couronne:',
        'ja': u':王冠をかぶった人:',
        'ko': u':왕관을_쓴_사람:',
        'pt': ':pessoa_com_coroa:',
        'it': ':persona_con_corona:',
        'fa': u':آدم_تاج_دار:',
        'id': ':orang_mengenakan_mahkota:',
        'zh': u':戴王冠的人:'
    },
    u'\U0001FAC5\U0001F3FF': { # 🫅🏿
        'en' : ':person_with_crown_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC5\U0001F3FB': { # 🫅🏻
        'en' : ':person_with_crown_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC5\U0001F3FE': { # 🫅🏾
        'en' : ':person_with_crown_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC5\U0001F3FC': { # 🫅🏼
        'en' : ':person_with_crown_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC5\U0001F3FD': { # 🫅🏽
        'en' : ':person_with_crown_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F472': { # 👲
        'en' : ':person_with_skullcap:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':man_with_gua_pi_mao:'],
        'de': ':mann_mit_chinesischem_hut:',
        'es': ':persona_con_gorro_chino:',
        'fr': ':homme_avec_casquette_chinoise:',
        'ja': u':中華帽の男性:',
        'ko': u':중국_전통_모자를_쓰고_있는_남자:',
        'pt': u':homem_de_boné:',
        'it': ':uomo_con_zucchetto_cinese:',
        'fa': u':مرد_با_کلاه_چینی:',
        'id': ':orang_dengan_topi_tionghoa:',
        'zh': u':戴瓜皮帽的人:'
    },
    u'\U0001F472\U0001F3FF': { # 👲🏿
        'en' : ':person_with_skullcap_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mit_chinesischem_hut_dunkle_hautfarbe:',
        'es': ':hombre_con_gorro_chino_tono_de_piel_oscuro:',
        'fr': u':homme_avec_casquette_chinoise__peau_foncée:',
        'ja': u':中華帽の男性_濃い肌色:',
        'ko': u':중국_전통_모자를_쓰고_있는_남자_검은색_피부:',
        'pt': u':homem_de_boné_pele_escura:',
        'it': ':uomo_con_zucchetto_cinese_carnagione_scura:',
        'fa': u':مرد_با_کلاه_چینی_پوست_آبنوسی:',
        'id': ':orang_dengan_topi_tionghoa_warna_kulit_gelap:',
        'zh': u':戴瓜皮帽的人_较深肤色:'
    },
    u'\U0001F472\U0001F3FB': { # 👲🏻
        'en' : ':person_with_skullcap_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mit_chinesischem_hut_helle_hautfarbe:',
        'es': ':hombre_con_gorro_chino_tono_de_piel_claro:',
        'fr': ':homme_avec_casquette_chinoise__peau_claire:',
        'ja': u':中華帽の男性_薄い肌色:',
        'ko': u':중국_전통_모자를_쓰고_있는_남자_하얀_피부:',
        'pt': u':homem_de_boné_pele_clara:',
        'it': ':uomo_con_zucchetto_cinese_carnagione_chiara:',
        'fa': u':مرد_با_کلاه_چینی_پوست_سفید:',
        'id': ':orang_dengan_topi_tionghoa_warna_kulit_cerah:',
        'zh': u':戴瓜皮帽的人_较浅肤色:'
    },
    u'\U0001F472\U0001F3FE': { # 👲🏾
        'en' : ':person_with_skullcap_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mit_chinesischem_hut_mitteldunkle_hautfarbe:',
        'es': ':hombre_con_gorro_chino_tono_de_piel_oscuro_medio:',
        'fr': ':homme_avec_casquette_chinoise__peau_mate:',
        'ja': u':中華帽の男性_やや濃い肌色:',
        'ko': u':중국_전통_모자를_쓰고_있는_남자_진한_갈색_피부:',
        'pt': u':homem_de_boné_pele_morena_escura:',
        'it': ':uomo_con_zucchetto_cinese_carnagione_abbastanza_scura:',
        'fa': u':مرد_با_کلاه_چینی_پوست_گندمی:',
        'id': ':orang_dengan_topi_tionghoa_warna_kulit_gelap-sedang:',
        'zh': u':戴瓜皮帽的人_中等深肤色:'
    },
    u'\U0001F472\U0001F3FC': { # 👲🏼
        'en' : ':person_with_skullcap_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mit_chinesischem_hut_mittelhelle_hautfarbe:',
        'es': ':hombre_con_gorro_chino_tono_de_piel_claro_medio:',
        'fr': ':homme_avec_casquette_chinoise__peau_moyennement_claire:',
        'ja': u':中華帽の男性_やや薄い肌色:',
        'ko': u':중국_전통_모자를_쓰고_있는_남자_연한_갈색_피부:',
        'pt': u':homem_de_boné_pele_morena_clara:',
        'it': ':uomo_con_zucchetto_cinese_carnagione_abbastanza_chiara:',
        'fa': u':مرد_با_کلاه_چینی_پوست_روشن:',
        'id': ':orang_dengan_topi_tionghoa_warna_kulit_cerah-sedang:',
        'zh': u':戴瓜皮帽的人_中等浅肤色:'
    },
    u'\U0001F472\U0001F3FD': { # 👲🏽
        'en' : ':person_with_skullcap_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':mann_mit_chinesischem_hut_mittlere_hautfarbe:',
        'es': ':hombre_con_gorro_chino_tono_de_piel_medio:',
        'fr': u':homme_avec_casquette_chinoise__peau_légèrement_mate:',
        'ja': u':中華帽の男性_中間の肌色:',
        'ko': u':중국_전통_모자를_쓰고_있는_남자_갈색_피부:',
        'pt': u':homem_de_boné_pele_morena:',
        'it': ':uomo_con_zucchetto_cinese_carnagione_olivastra:',
        'fa': u':مرد_با_کلاه_چینی_پوست_طلایی:',
        'id': ':orang_dengan_topi_tionghoa_warna_kulit_sedang:',
        'zh': u':戴瓜皮帽的人_中等肤色:'
    },
    u'\U0001F470': { # 👰
        'en' : ':person_with_veil:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':person_mit_schleier:',
        'es': ':persona_con_velo:',
        'fr': u':personne_mariée_avec_voile:',
        'ja': u':ベールの人:',
        'ko': u':면사포를_쓴_사람:',
        'pt': u':pessoa_com_véu:',
        'it': ':persona_con_velo:',
        'fa': u':شخص_با_تور_عروس:',
        'id': ':orang_berpenutup_kepala:',
        'zh': u':戴头纱的人:'
    },
    u'\U0001F470\U0001F3FF': { # 👰🏿
        'en' : ':person_with_veil_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_schleier_dunkle_hautfarbe:',
        'es': ':persona_con_velo_tono_de_piel_oscuro:',
        'fr': u':personne_mariée_avec_voile_peau_foncée:',
        'ja': u':ベールの人_濃い肌色:',
        'ko': u':면사포를_쓴_사람_검은색_피부:',
        'pt': ':noiva_pele_escura:',
        'it': ':persona_con_velo_carnagione_scura:',
        'fa': u':شخص_با_تور_عروس_پوست_آبنوسی:',
        'id': ':orang_berpenutup_kepala_warna_kulit_gelap:',
        'zh': u':戴头纱的人_较深肤色:'
    },
    u'\U0001F470\U0001F3FB': { # 👰🏻
        'en' : ':person_with_veil_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_schleier_helle_hautfarbe:',
        'es': ':persona_con_velo_tono_de_piel_claro:',
        'fr': u':personne_mariée_avec_voile_peau_claire:',
        'ja': u':ベールの人_薄い肌色:',
        'ko': u':면사포를_쓴_사람_하얀_피부:',
        'pt': ':noiva_pele_clara:',
        'it': ':persona_con_velo_carnagione_chiara:',
        'fa': u':شخص_با_تور_عروس_پوست_سفید:',
        'id': ':orang_berpenutup_kepala_warna_kulit_cerah:',
        'zh': u':戴头纱的人_较浅肤色:'
    },
    u'\U0001F470\U0001F3FE': { # 👰🏾
        'en' : ':person_with_veil_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_schleier_mitteldunkle_hautfarbe:',
        'es': ':persona_con_velo_tono_de_piel_oscuro_medio:',
        'fr': u':personne_mariée_avec_voile_peau_mate:',
        'ja': u':ベールの人_やや濃い肌色:',
        'ko': u':면사포를_쓴_사람_진한_갈색_피부:',
        'pt': ':noiva_pele_morena_escura:',
        'it': ':persona_con_velo_carnagione_abbastanza_scura:',
        'fa': u':شخص_با_تور_عروس_پوست_گندمی:',
        'id': ':orang_berpenutup_kepala_warna_kulit_gelap-sedang:',
        'zh': u':戴头纱的人_中等深肤色:'
    },
    u'\U0001F470\U0001F3FC': { # 👰🏼
        'en' : ':person_with_veil_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_schleier_mittelhelle_hautfarbe:',
        'es': ':persona_con_velo_tono_de_piel_claro_medio:',
        'fr': u':personne_mariée_avec_voile_peau_moyennement_claire:',
        'ja': u':ベールの人_やや薄い肌色:',
        'ko': u':면사포를_쓴_사람_연한_갈색_피부:',
        'pt': ':noiva_pele_morena_clara:',
        'it': ':persona_con_velo_carnagione_abbastanza_chiara:',
        'fa': u':شخص_با_تور_عروس_پوست_روشن:',
        'id': ':orang_berpenutup_kepala_warna_kulit_cerah-sedang:',
        'zh': u':戴头纱的人_中等浅肤色:'
    },
    u'\U0001F470\U0001F3FD': { # 👰🏽
        'en' : ':person_with_veil_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':person_mit_schleier_mittlere_hautfarbe:',
        'es': ':persona_con_velo_tono_de_piel_medio:',
        'fr': u':personne_mariée_avec_voile_peau_légèrement_mate:',
        'ja': u':ベールの人_中間の肌色:',
        'ko': u':면사포를_쓴_사람_갈색_피부:',
        'pt': ':noiva_pele_morena:',
        'it': ':persona_con_velo_carnagione_olivastra:',
        'fa': u':شخص_با_تور_عروس_پوست_طلایی:',
        'id': ':orang_berpenutup_kepala_warna_kulit_sedang:',
        'zh': u':戴头纱的人_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F9AF': { # 🧑‍🦯
        'en' : ':person_with_white_cane:',
        'status' : fully_qualified,
        'E' : 12.1,
        'alias' : [':person_with_probing_cane:'],
        'de': ':person_mit_gehstock:',
        'es': u':persona_con_bastón:',
        'fr': ':personne_avec_une_canne_blanche:',
        'ja': u':杖をついた人:',
        'ko': u':지팡이를_든_사람:',
        'pt': ':pessoa_com_bengala_para_cego:',
        'it': ':persona_con_bastone_di_orientamento:',
        'fa': u':شخصی_با_عصای_راهنما:',
        'id': ':orang_dengan_tongkat:',
        'zh': u':拄盲杖的人:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F9AF': { # 🧑🏿‍🦯
        'en' : ':person_with_white_cane_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_mit_gehstock_dunkle_hautfarbe:',
        'es': u':persona_con_bastón_tono_de_piel_oscuro:',
        'fr': u':personne_avec_une_canne_blanche_peau_foncée:',
        'ja': u':杖をついた人_濃い肌色:',
        'ko': u':지팡이를_든_사람_검은색_피부:',
        'pt': ':pessoa_com_bengala_para_cego_pele_escura:',
        'it': ':persona_con_bastone_di_orientamento_carnagione_scura:',
        'fa': u':شخصی_با_عصای_راهنما_پوست_آبنوسی:',
        'id': ':orang_dengan_tongkat_warna_kulit_gelap:',
        'zh': u':拄盲杖的人_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F9AF': { # 🧑🏻‍🦯
        'en' : ':person_with_white_cane_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_mit_gehstock_helle_hautfarbe:',
        'es': u':persona_con_bastón_tono_de_piel_claro:',
        'fr': ':personne_avec_une_canne_blanche_peau_claire:',
        'ja': u':杖をついた人_薄い肌色:',
        'ko': u':지팡이를_든_사람_하얀_피부:',
        'pt': ':pessoa_com_bengala_para_cego_pele_clara:',
        'it': ':persona_con_bastone_di_orientamento_carnagione_chiara:',
        'fa': u':شخصی_با_عصای_راهنما_پوست_سفید:',
        'id': ':orang_dengan_tongkat_warna_kulit_cerah:',
        'zh': u':拄盲杖的人_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F9AF': { # 🧑🏾‍🦯
        'en' : ':person_with_white_cane_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_mit_gehstock_mitteldunkle_hautfarbe:',
        'es': u':persona_con_bastón_tono_de_piel_oscuro_medio:',
        'fr': ':personne_avec_une_canne_blanche_peau_mate:',
        'ja': u':杖をついた人_やや濃い肌色:',
        'ko': u':지팡이를_든_사람_진한_갈색_피부:',
        'pt': ':pessoa_com_bengala_para_cego_pele_morena_escura:',
        'it': ':persona_con_bastone_di_orientamento_carnagione_abbastanza_scura:',
        'fa': u':شخصی_با_عصای_راهنما_پوست_گندمی:',
        'id': ':orang_dengan_tongkat_warna_kulit_gelap-sedang:',
        'zh': u':拄盲杖的人_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F9AF': { # 🧑🏼‍🦯
        'en' : ':person_with_white_cane_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_mit_gehstock_mittelhelle_hautfarbe:',
        'es': u':persona_con_bastón_tono_de_piel_claro_medio:',
        'fr': ':personne_avec_une_canne_blanche_peau_moyennement_claire:',
        'ja': u':杖をついた人_やや薄い肌色:',
        'ko': u':지팡이를_든_사람_연한_갈색_피부:',
        'pt': ':pessoa_com_bengala_para_cego_pele_morena_clara:',
        'it': ':persona_con_bastone_di_orientamento_carnagione_abbastanza_chiara:',
        'fa': u':شخصی_با_عصای_راهنما_پوست_روشن:',
        'id': ':orang_dengan_tongkat_warna_kulit_cerah-sedang:',
        'zh': u':拄盲杖的人_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F9AF': { # 🧑🏽‍🦯
        'en' : ':person_with_white_cane_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':person_mit_gehstock_mittlere_hautfarbe:',
        'es': u':persona_con_bastón_tono_de_piel_medio:',
        'fr': u':personne_avec_une_canne_blanche_peau_légèrement_mate:',
        'ja': u':杖をついた人_中間の肌色:',
        'ko': u':지팡이를_든_사람_갈색_피부:',
        'pt': ':pessoa_com_bengala_para_cego_pele_morena:',
        'it': ':persona_con_bastone_di_orientamento_carnagione_olivastra:',
        'fa': u':شخصی_با_عصای_راهنما_پوست_طلایی:',
        'id': ':orang_dengan_tongkat_warna_kulit_sedang:',
        'zh': u':拄盲杖的人_中等肤色:'
    },
    u'\U0001F9EB': { # 🧫
        'en' : ':petri_dish:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':petrischale:',
        'es': ':placa_de_petri:',
        'fr': u':boîte_de_pétri:',
        'ja': u':ペトリ皿:',
        'ko': u':페트리_접시:',
        'pt': ':placa_de_petri:',
        'it': ':piastra_di_petri:',
        'fa': u':ظرف_کشت:',
        'id': ':cawan_petri:',
        'zh': u':培养皿:'
    },
    u'\U000026CF\U0000FE0F': { # ⛏️
        'en' : ':pick:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':pickel:',
        'es': ':pico:',
        'fr': ':pioche:',
        'ja': u':つるはし:',
        'ko': u':곡괭이:',
        'pt': ':picareta:',
        'it': ':piccone:',
        'fa': u':کلنگ:',
        'id': ':beliung:',
        'zh': u':铁镐:'
    },
    u'\U000026CF': { # ⛏
        'en' : ':pick:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':pickel:',
        'es': ':pico:',
        'fr': ':pioche:',
        'ja': u':つるはし:',
        'ko': u':곡괭이:',
        'pt': ':picareta:',
        'it': ':piccone:',
        'fa': u':کلنگ:',
        'id': ':beliung:',
        'zh': u':铁镐:'
    },
    u'\U0001F6FB': { # 🛻
        'en' : ':pickup_truck:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':pick-up:',
        'es': ':camioneta:',
        'fr': ':pick-up:',
        'ja': u':軽トラック:',
        'ko': u':픽업트럭:',
        'pt': ':caminhonete:',
        'it': ':pickup:',
        'fa': u':وانت:',
        'id': ':truk_pikap:',
        'zh': u':敞蓬小型载货卡车:'
    },
    u'\U0001F967': { # 🥧
        'en' : ':pie:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':kuchen:',
        'es': ':pastel:',
        'fr': ':tarte:',
        'ja': u':パイ:',
        'ko': u':파이:',
        'pt': ':torta:',
        'it': ':torta:',
        'fa': u':پای:',
        'id': ':pai:',
        'zh': u':派:'
    },
    u'\U0001F416': { # 🐖
        'en' : ':pig:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':pig2:'],
        'de': ':schwein:',
        'es': ':cerdo:',
        'fr': ':cochon:',
        'ja': u':ブタ:',
        'ko': u':돼지:',
        'pt': ':porco:',
        'it': ':maiale:',
        'fa': u':خوک:',
        'id': ':babi:',
        'zh': u':猪:'
    },
    u'\U0001F437': { # 🐷
        'en' : ':pig_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':pig:'],
        'de': ':schweinegesicht:',
        'es': ':cara_de_cerdo:',
        'fr': u':tête_de_cochon:',
        'ja': u':ブタの顔:',
        'ko': u':돼지_얼굴:',
        'pt': ':rosto_de_porco:',
        'it': ':muso_di_maiale:',
        'fa': u':صورت_خوک:',
        'id': ':wajah_babi:',
        'zh': u':猪头:'
    },
    u'\U0001F43D': { # 🐽
        'en' : ':pig_nose:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':schweinerüssel:',
        'es': ':nariz_de_cerdo:',
        'fr': ':groin:',
        'ja': u':ブタ鼻:',
        'ko': u':돼지코:',
        'pt': ':nariz_de_porco:',
        'it': ':naso_da_maiale:',
        'fa': u':دماغ_خوک:',
        'id': ':hidung_babi:',
        'zh': u':猪鼻子:'
    },
    u'\U0001F4A9': { # 💩
        'en' : ':pile_of_poo:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':poop:', ':hankey:', ':shit:'],
        'de': ':kothaufen:',
        'es': ':caca_con_ojos:',
        'fr': ':tas_de_crotte:',
        'ja': u':うんち:',
        'ko': u':똥:',
        'pt': u':cocô:',
        'it': ':cacca:',
        'fa': u':یه_تپهٔ_گه:',
        'id': ':kotoran:',
        'zh': u':大便:'
    },
    u'\U0001F48A': { # 💊
        'en' : ':pill:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kapsel:',
        'es': u':píldora:',
        'fr': ':pilule:',
        'ja': u':薬:',
        'ko': u':알약:',
        'pt': ':comprimido:',
        'it': ':pillola:',
        'fa': u':قرص:',
        'id': ':pil:',
        'zh': u':药丸:'
    },
    u'\U0001F9D1\U0000200D\U00002708\U0000FE0F': { # 🧑‍✈️
        'en' : ':pilot:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':pilot(in):',
        'es': ':piloto:',
        'fr': ':pilote:',
        'ja': u':パイロット:',
        'ko': u':기장:',
        'pt': ':piloto:',
        'it': ':pilota:',
        'fa': u':خلبان:',
        'id': ':pilot:',
        'zh': u':飞行员:'
    },
    u'\U0001F9D1\U0000200D\U00002708': { # 🧑‍✈
        'en' : ':pilot:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':pilot(in):',
        'es': ':piloto:',
        'fr': ':pilote:',
        'ja': u':パイロット:',
        'ko': u':기장:',
        'pt': ':piloto:',
        'it': ':pilota:',
        'fa': u':خلبان:',
        'id': ':pilot:',
        'zh': u':飞行员:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002708\U0000FE0F': { # 🧑🏿‍✈️
        'en' : ':pilot_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_dunkle_hautfarbe:',
        'es': ':piloto_tono_de_piel_oscuro:',
        'fr': u':pilote_peau_foncée:',
        'ja': u':パイロット_濃い肌色:',
        'ko': u':기장_검은색_피부:',
        'pt': ':piloto_pele_escura:',
        'it': ':pilota_carnagione_scura:',
        'fa': u':خلبان_پوست_آبنوسی:',
        'id': ':pilot_warna_kulit_gelap:',
        'zh': u':飞行员_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U00002708': { # 🧑🏿‍✈
        'en' : ':pilot_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_dunkle_hautfarbe:',
        'es': ':piloto_tono_de_piel_oscuro:',
        'fr': u':pilote_peau_foncée:',
        'ja': u':パイロット_濃い肌色:',
        'ko': u':기장_검은색_피부:',
        'pt': ':piloto_pele_escura:',
        'it': ':pilota_carnagione_scura:',
        'fa': u':خلبان_پوست_آبنوسی:',
        'id': ':pilot_warna_kulit_gelap:',
        'zh': u':飞行员_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002708\U0000FE0F': { # 🧑🏻‍✈️
        'en' : ':pilot_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_helle_hautfarbe:',
        'es': ':piloto_tono_de_piel_claro:',
        'fr': ':pilote_peau_claire:',
        'ja': u':パイロット_薄い肌色:',
        'ko': u':기장_하얀_피부:',
        'pt': ':piloto_pele_clara:',
        'it': ':pilota_carnagione_chiara:',
        'fa': u':خلبان_پوست_سفید:',
        'id': ':pilot_warna_kulit_cerah:',
        'zh': u':飞行员_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U00002708': { # 🧑🏻‍✈
        'en' : ':pilot_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_helle_hautfarbe:',
        'es': ':piloto_tono_de_piel_claro:',
        'fr': ':pilote_peau_claire:',
        'ja': u':パイロット_薄い肌色:',
        'ko': u':기장_하얀_피부:',
        'pt': ':piloto_pele_clara:',
        'it': ':pilota_carnagione_chiara:',
        'fa': u':خلبان_پوست_سفید:',
        'id': ':pilot_warna_kulit_cerah:',
        'zh': u':飞行员_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002708\U0000FE0F': { # 🧑🏾‍✈️
        'en' : ':pilot_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_mitteldunkle_hautfarbe:',
        'es': ':piloto_tono_de_piel_oscuro_medio:',
        'fr': ':pilote_peau_mate:',
        'ja': u':パイロット_やや濃い肌色:',
        'ko': u':기장_진한_갈색_피부:',
        'pt': ':piloto_pele_morena_escura:',
        'it': ':pilota_carnagione_abbastanza_scura:',
        'fa': u':خلبان_پوست_گندمی:',
        'id': ':pilot_warna_kulit_gelap-sedang:',
        'zh': u':飞行员_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U00002708': { # 🧑🏾‍✈
        'en' : ':pilot_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_mitteldunkle_hautfarbe:',
        'es': ':piloto_tono_de_piel_oscuro_medio:',
        'fr': ':pilote_peau_mate:',
        'ja': u':パイロット_やや濃い肌色:',
        'ko': u':기장_진한_갈색_피부:',
        'pt': ':piloto_pele_morena_escura:',
        'it': ':pilota_carnagione_abbastanza_scura:',
        'fa': u':خلبان_پوست_گندمی:',
        'id': ':pilot_warna_kulit_gelap-sedang:',
        'zh': u':飞行员_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002708\U0000FE0F': { # 🧑🏼‍✈️
        'en' : ':pilot_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_mittelhelle_hautfarbe:',
        'es': ':piloto_tono_de_piel_claro_medio:',
        'fr': ':pilote_peau_moyennement_claire:',
        'ja': u':パイロット_やや薄い肌色:',
        'ko': u':기장_연한_갈색_피부:',
        'pt': ':piloto_pele_morena_clara:',
        'it': ':pilota_carnagione_abbastanza_chiara:',
        'fa': u':خلبان_پوست_روشن:',
        'id': ':pilot_warna_kulit_cerah-sedang:',
        'zh': u':飞行员_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U00002708': { # 🧑🏼‍✈
        'en' : ':pilot_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_mittelhelle_hautfarbe:',
        'es': ':piloto_tono_de_piel_claro_medio:',
        'fr': ':pilote_peau_moyennement_claire:',
        'ja': u':パイロット_やや薄い肌色:',
        'ko': u':기장_연한_갈색_피부:',
        'pt': ':piloto_pele_morena_clara:',
        'it': ':pilota_carnagione_abbastanza_chiara:',
        'fa': u':خلبان_پوست_روشن:',
        'id': ':pilot_warna_kulit_cerah-sedang:',
        'zh': u':飞行员_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002708\U0000FE0F': { # 🧑🏽‍✈️
        'en' : ':pilot_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_mittlere_hautfarbe:',
        'es': ':piloto_tono_de_piel_medio:',
        'fr': u':pilote_peau_légèrement_mate:',
        'ja': u':パイロット_中間の肌色:',
        'ko': u':기장_갈색_피부:',
        'pt': ':piloto_pele_morena:',
        'it': ':pilota_carnagione_olivastra:',
        'fa': u':خلبان_پوست_طلایی:',
        'id': ':pilot_warna_kulit_sedang:',
        'zh': u':飞行员_中等肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U00002708': { # 🧑🏽‍✈
        'en' : ':pilot_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12.1,
        'de': ':pilot(in)_mittlere_hautfarbe:',
        'es': ':piloto_tono_de_piel_medio:',
        'fr': u':pilote_peau_légèrement_mate:',
        'ja': u':パイロット_中間の肌色:',
        'ko': u':기장_갈색_피부:',
        'pt': ':piloto_pele_morena:',
        'it': ':pilota_carnagione_olivastra:',
        'fa': u':خلبان_پوست_طلایی:',
        'id': ':pilot_warna_kulit_sedang:',
        'zh': u':飞行员_中等肤色:'
    },
    u'\U0001F90C': { # 🤌
        'en' : ':pinched_fingers:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':zusammengedrückte_finger:',
        'es': ':dedos_juntos_apuntando_hacia_arriba:',
        'fr': ':bout_des_doigts_joints:',
        'ja': u':上向きにすぼめた手:',
        'ko': u':꼬집는_손가락:',
        'pt': ':dedos_comprimidos:',
        'it': ':mano_a_pigna:',
        'fa': u':انگشتان_جمع_شده:',
        'id': ':jari_terkuncup:',
        'zh': u':捏手指:'
    },
    u'\U0001F90C\U0001F3FF': { # 🤌🏿
        'en' : ':pinched_fingers_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':zusammengedrückte_finger_dunkle_hautfarbe:',
        'es': ':dedos_juntos_apuntando_hacia_arriba_tono_de_piel_oscuro:',
        'fr': u':bout_des_doigts_joints_peau_foncée:',
        'ja': u':上向きにすぼめた手_濃い肌色:',
        'ko': u':꼬집는_손가락_검은색_피부:',
        'pt': ':dedos_comprimidos_pele_escura:',
        'it': ':mano_a_pigna_carnagione_scura:',
        'fa': u':انگشتان_جمع_شده_پوست_آبنوسی:',
        'id': ':jari_terkuncup_warna_kulit_gelap:',
        'zh': u':捏手指_较深肤色:'
    },
    u'\U0001F90C\U0001F3FB': { # 🤌🏻
        'en' : ':pinched_fingers_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':zusammengedrückte_finger_helle_hautfarbe:',
        'es': ':dedos_juntos_apuntando_hacia_arriba_tono_de_piel_claro:',
        'fr': ':bout_des_doigts_joints_peau_claire:',
        'ja': u':上向きにすぼめた手_薄い肌色:',
        'ko': u':꼬집는_손가락_하얀_피부:',
        'pt': ':dedos_comprimidos_pele_clara:',
        'it': ':mano_a_pigna_carnagione_chiara:',
        'fa': u':انگشتان_جمع_شده_پوست_سفید:',
        'id': ':jari_terkuncup_warna_kulit_cerah:',
        'zh': u':捏手指_较浅肤色:'
    },
    u'\U0001F90C\U0001F3FE': { # 🤌🏾
        'en' : ':pinched_fingers_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':zusammengedrückte_finger_mitteldunkle_hautfarbe:',
        'es': ':dedos_juntos_apuntando_hacia_arriba_tono_de_piel_oscuro_medio:',
        'fr': ':bout_des_doigts_joints_peau_mate:',
        'ja': u':上向きにすぼめた手_やや濃い肌色:',
        'ko': u':꼬집는_손가락_진한_갈색_피부:',
        'pt': ':dedos_comprimidos_pele_morena_escura:',
        'it': ':mano_a_pigna_carnagione_abbastanza_scura:',
        'fa': u':انگشتان_جمع_شده_پوست_گندمی:',
        'id': ':jari_terkuncup_warna_kulit_gelap-sedang:',
        'zh': u':捏手指_中等深肤色:'
    },
    u'\U0001F90C\U0001F3FC': { # 🤌🏼
        'en' : ':pinched_fingers_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':zusammengedrückte_finger_mittelhelle_hautfarbe:',
        'es': ':dedos_juntos_apuntando_hacia_arriba_tono_de_piel_claro_medio:',
        'fr': ':bout_des_doigts_joints_peau_moyennement_claire:',
        'ja': u':上向きにすぼめた手_やや薄い肌色:',
        'ko': u':꼬집는_손가락_연한_갈색_피부:',
        'pt': ':dedos_comprimidos_pele_morena_clara:',
        'it': ':mano_a_pigna_carnagione_abbastanza_chiara:',
        'fa': u':انگشتان_جمع_شده_پوست_روشن:',
        'id': ':jari_terkuncup_warna_kulit_cerah-sedang:',
        'zh': u':捏手指_中等浅肤色:'
    },
    u'\U0001F90C\U0001F3FD': { # 🤌🏽
        'en' : ':pinched_fingers_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':zusammengedrückte_finger_mittlere_hautfarbe:',
        'es': ':dedos_juntos_apuntando_hacia_arriba_tono_de_piel_medio:',
        'fr': u':bout_des_doigts_joints_peau_légèrement_mate:',
        'ja': u':上向きにすぼめた手_中間の肌色:',
        'ko': u':꼬집는_손가락_갈색_피부:',
        'pt': ':dedos_comprimidos_pele_morena:',
        'it': ':mano_a_pigna_carnagione_olivastra:',
        'fa': u':انگشتان_جمع_شده_پوست_طلایی:',
        'id': ':jari_terkuncup_warna_kulit_sedang:',
        'zh': u':捏手指_中等肤色:'
    },
    u'\U0001F90F': { # 🤏
        'en' : ':pinching_hand:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':wenig-geste:',
        'es': ':mano_pellizcando:',
        'fr': u':pouce_et_index_rapprochés:',
        'ja': u':つまんでいる指:',
        'ko': u':꼬집는_손:',
        'pt': u':mão_beliscando:',
        'it': ':mano_che_fa_il_gesto_del_pizzico:',
        'fa': u':دست_در_حال_نیشگون_گرفتن:',
        'id': ':tangan_menjepit:',
        'zh': u':捏合的手势:'
    },
    u'\U0001F90F\U0001F3FF': { # 🤏🏿
        'en' : ':pinching_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':wenig-geste_dunkle_hautfarbe:',
        'es': ':mano_pellizcando_tono_de_piel_oscuro:',
        'fr': u':pouce_et_index_rapprochés_peau_foncée:',
        'ja': u':つまんでいる指_濃い肌色:',
        'ko': u':꼬집는_손_검은색_피부:',
        'pt': u':mão_beliscando_pele_escura:',
        'it': ':mano_che_fa_il_gesto_del_pizzico_carnagione_scura:',
        'fa': u':دست_در_حال_نیشگون_گرفتن_پوست_آبنوسی:',
        'id': ':tangan_menjepit_warna_kulit_gelap:',
        'zh': u':捏合的手势_较深肤色:'
    },
    u'\U0001F90F\U0001F3FB': { # 🤏🏻
        'en' : ':pinching_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':wenig-geste_helle_hautfarbe:',
        'es': ':mano_pellizcando_tono_de_piel_claro:',
        'fr': u':pouce_et_index_rapprochés_peau_claire:',
        'ja': u':つまんでいる指_薄い肌色:',
        'ko': u':꼬집는_손_하얀_피부:',
        'pt': u':mão_beliscando_pele_clara:',
        'it': ':mano_che_fa_il_gesto_del_pizzico_carnagione_chiara:',
        'fa': u':دست_در_حال_نیشگون_گرفتن_پوست_سفید:',
        'id': ':tangan_menjepit_warna_kulit_cerah:',
        'zh': u':捏合的手势_较浅肤色:'
    },
    u'\U0001F90F\U0001F3FE': { # 🤏🏾
        'en' : ':pinching_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':wenig-geste_mitteldunkle_hautfarbe:',
        'es': ':mano_pellizcando_tono_de_piel_oscuro_medio:',
        'fr': u':pouce_et_index_rapprochés_peau_mate:',
        'ja': u':つまんでいる指_やや濃い肌色:',
        'ko': u':꼬집는_손_진한_갈색_피부:',
        'pt': u':mão_beliscando_pele_morena_escura:',
        'it': ':mano_che_fa_il_gesto_del_pizzico_carnagione_abbastanza_scura:',
        'fa': u':دست_در_حال_نیشگون_گرفتن_پوست_گندمی:',
        'id': ':tangan_menjepit_warna_kulit_gelap-sedang:',
        'zh': u':捏合的手势_中等深肤色:'
    },
    u'\U0001F90F\U0001F3FC': { # 🤏🏼
        'en' : ':pinching_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':wenig-geste_mittelhelle_hautfarbe:',
        'es': ':mano_pellizcando_tono_de_piel_claro_medio:',
        'fr': u':pouce_et_index_rapprochés_peau_moyennement_claire:',
        'ja': u':つまんでいる指_やや薄い肌色:',
        'ko': u':꼬집는_손_연한_갈색_피부:',
        'pt': u':mão_beliscando_pele_morena_clara:',
        'it': ':mano_che_fa_il_gesto_del_pizzico_carnagione_abbastanza_chiara:',
        'fa': u':دست_در_حال_نیشگون_گرفتن_پوست_روشن:',
        'id': ':tangan_menjepit_warna_kulit_cerah-sedang:',
        'zh': u':捏合的手势_中等浅肤色:'
    },
    u'\U0001F90F\U0001F3FD': { # 🤏🏽
        'en' : ':pinching_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':wenig-geste_mittlere_hautfarbe:',
        'es': ':mano_pellizcando_tono_de_piel_medio:',
        'fr': u':pouce_et_index_rapprochés_peau_légèrement_mate:',
        'ja': u':つまんでいる指_中間の肌色:',
        'ko': u':꼬집는_손_갈색_피부:',
        'pt': u':mão_beliscando_pele_morena:',
        'it': ':mano_che_fa_il_gesto_del_pizzico_carnagione_olivastra:',
        'fa': u':دست_در_حال_نیشگون_گرفتن_پوست_طلایی:',
        'id': ':tangan_menjepit_warna_kulit_sedang:',
        'zh': u':捏合的手势_中等肤色:'
    },
    u'\U0001F38D': { # 🎍
        'en' : ':pine_decoration:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':bamboo:'],
        'de': ':piniendekoration:',
        'es': u':decoración_de_pino:',
        'fr': u':bambou_décoratif:',
        'ja': u':門松:',
        'ko': u':일본_장식:',
        'pt': u':decoração_de_pinhos:',
        'it': u':bambù_decorato:',
        'fa': u':تزئین_کاج:',
        'id': ':dekorasi_pinus:',
        'zh': u':门松:'
    },
    u'\U0001F34D': { # 🍍
        'en' : ':pineapple:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':ananas:',
        'es': u':piña:',
        'fr': ':ananas:',
        'ja': u':パイナップル:',
        'ko': u':파인애플:',
        'pt': ':abacaxi:',
        'it': ':ananas:',
        'fa': u':آناناس:',
        'id': ':nanas:',
        'zh': u':菠萝:'
    },
    u'\U0001F3D3': { # 🏓
        'en' : ':ping_pong:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':table_tennis_paddle_and_ball:'],
        'de': ':tischtennis:',
        'es': ':tenis_de_mesa:',
        'fr': ':ping-pong:',
        'ja': u':卓球:',
        'ko': u':탁구:',
        'pt': ':pingue-pongue:',
        'it': ':ping_pong:',
        'fa': u':پینگ_پونگ:',
        'id': ':ping_pong:',
        'zh': u':乒乓球:'
    },
    u'\U0001FA77': { # 🩷
        'en' : ':pink_heart:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':pinkes_herz:',
        'es': u':corazón_rosa:',
        'fr': u':cœur_rose:',
        'ja': u':ピンクのハート:',
        'ko': u':분홍색_하트:',
        'pt': u':coração_rosa:',
        'it': ':cuore_rosa:',
        'fa': u':قلب_صورتی:',
        'id': ':hati_merah_muda:',
        'zh': u':粉红色的心:'
    },
    u'\U0001F3F4\U0000200D\U00002620\U0000FE0F': { # 🏴‍☠️
        'en' : ':pirate_flag:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':piratenflagge:',
        'es': ':bandera_pirata:',
        'fr': ':drapeau_de_pirate:',
        'ja': u':海賊旗:',
        'ko': u':해적_깃발:',
        'pt': ':bandeira_de_pirata:',
        'it': ':bandiera_dei_pirati:',
        'fa': u':پرچم_دزدان_دریایی:',
        'id': ':bendera_bajak_laut:',
        'zh': u':海盗旗:'
    },
    u'\U0001F3F4\U0000200D\U00002620': { # 🏴‍☠
        'en' : ':pirate_flag:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':piratenflagge:',
        'es': ':bandera_pirata:',
        'fr': ':drapeau_de_pirate:',
        'ja': u':海賊旗:',
        'ko': u':해적_깃발:',
        'pt': ':bandeira_de_pirata:',
        'it': ':bandiera_dei_pirati:',
        'fa': u':پرچم_دزدان_دریایی:',
        'id': ':bendera_bajak_laut:',
        'zh': u':海盗旗:'
    },
    u'\U0001F355': { # 🍕
        'en' : ':pizza:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':pizza:',
        'es': ':pizza:',
        'fr': ':pizza:',
        'ja': u':ピザ:',
        'ko': u':피자:',
        'pt': ':pizza:',
        'it': ':pizza:',
        'fa': u':پیتزا:',
        'id': ':pizza:',
        'zh': u':披萨:'
    },
    u'\U0001FA85': { # 🪅
        'en' : u':piñata:',
        'status' : fully_qualified,
        'E' : 13,
        'alias' : [':pinata:'],
        'de': u':piñata:',
        'es': u':piñata:',
        'fr': u':piñata:',
        'ja': u':ピニャータ:',
        'ko': u':피냐타:',
        'pt': ':pinhata:',
        'it': ':pentolaccia:',
        'fa': u':پینیاتا:',
        'id': ':pinata:',
        'zh': u':彩罐:'
    },
    u'\U0001FAA7': { # 🪧
        'en' : ':placard:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':protestschild:',
        'es': ':letrero:',
        'fr': ':pancarte:',
        'ja': u':プラカード:',
        'ko': u':플래카드:',
        'pt': ':placa:',
        'it': ':cartello:',
        'fa': u':پلاکارد:',
        'id': ':plakat:',
        'zh': u':标语牌:'
    },
    u'\U0001F6D0': { # 🛐
        'en' : ':place_of_worship:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':religiöse_stätte:',
        'es': ':lugar_de_culto:',
        'fr': ':lieu_de_culte:',
        'ja': u':礼拝所:',
        'ko': u':예배공간:',
        'pt': ':local_de_culto:',
        'it': ':luogo_di_culto:',
        'fa': u':محل_عبادت:',
        'id': ':tempat_ibadah:',
        'zh': u':宗教场所:'
    },
    u'\U000025B6\U0000FE0F': { # ▶️
        'en' : ':play_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_forward:'],
        'variant': True,
        'de': ':wiedergabe:',
        'es': ':reproducir:',
        'fr': ':bouton_lecture:',
        'ja': u':再生ボタン:',
        'ko': u':재생_버튼:',
        'pt': u':botão_reproduzir:',
        'it': ':pulsante_di_riproduzione:',
        'fa': u':دکمه_پخش:',
        'id': ':tombol_putar:',
        'zh': u':播放按钮:'
    },
    u'\U000025B6': { # ▶
        'en' : ':play_button:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_forward:'],
        'variant': True,
        'de': ':wiedergabe:',
        'es': ':reproducir:',
        'fr': ':bouton_lecture:',
        'ja': u':再生ボタン:',
        'ko': u':재생_버튼:',
        'pt': u':botão_reproduzir:',
        'it': ':pulsante_di_riproduzione:',
        'fa': u':دکمهٔ_پخش:',
        'id': ':tombol_putar:',
        'zh': u':播放按钮:'
    },
    u'\U000023EF\U0000FE0F': { # ⏯️
        'en' : ':play_or_pause_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':black_right__pointing_triangle_with_double_vertical_bar:'],
        'variant': True,
        'de': ':wiedergabe_oder_pause:',
        'es': ':reproducir_o_pausa:',
        'fr': ':bouton_lecture/pause:',
        'ja': u':再生/一時停止ボタン:',
        'ko': u':재생_또는_일시_정지_버튼:',
        'pt': u':botão_de_reproduzir_ou_pausar:',
        'it': ':pulsante_riproduci_pausa:',
        'fa': u':دکمه_پخش_یا_مکث:',
        'id': ':tombol_putar_atau_jeda:',
        'zh': u':播放或暂停按钮:'
    },
    u'\U000023EF': { # ⏯
        'en' : ':play_or_pause_button:',
        'status' : unqualified,
        'E' : 1,
        'alias' : [':black_right__pointing_triangle_with_double_vertical_bar:'],
        'variant': True,
        'de': ':wiedergabe_oder_pause:',
        'es': ':reproducir_o_pausa:',
        'fr': ':bouton_lecture/pause:',
        'ja': u':再生/一時停止ボタン:',
        'ko': u':재생_또는_일시_정지_버튼:',
        'pt': u':botão_de_reproduzir_ou_pausar:',
        'it': ':pulsante_riproduci/pausa:',
        'fa': u':دکمهٔ_پخش_یا_مکث:',
        'id': ':tombol_putar_atau_jeda:',
        'zh': u':播放或暂停按钮:'
    },
    u'\U0001F6DD': { # 🛝
        'en' : ':playground_slide:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':spielplatzrutsche:',
        'es': u':tobogán:',
        'fr': ':toboggan:',
        'ja': u':すべり台:',
        'ko': u':미끄럼틀:',
        'pt': ':escorregador:',
        'it': ':scivolo:',
        'fa': u':سرسره:',
        'id': ':perosotan:',
        'zh': u':游乐场滑梯:'
    },
    u'\U0001F97A': { # 🥺
        'en' : ':pleading_face:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':bettelndes_gesicht:',
        'es': ':cara_suplicante:',
        'fr': ':visage_implorant:',
        'ja': u':訴えるような顔:',
        'ko': u':애원하는_얼굴:',
        'pt': ':rosto_implorando:',
        'it': ':faccina_supplichevole:',
        'fa': u':التماس_کنان:',
        'id': ':wajah_memelas:',
        'zh': u':恳求的脸:'
    },
    u'\U0001FAA0': { # 🪠
        'en' : ':plunger:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':saugglocke:',
        'es': ':desatascador:',
        'fr': ':ventouse:',
        'ja': u':ラバーカップ:',
        'ko': u':뚫어뻥:',
        'pt': ':desentupidor:',
        'it': ':sturalavandini:',
        'fa': u':لوله_بازکن:',
        'id': ':penyedot_wc:',
        'zh': u':活塞:'
    },
    u'\U00002795': { # ➕
        'en' : ':plus:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heavy_plus_sign:'],
        'de': ':plus:',
        'es': u':más:',
        'fr': ':plus:',
        'ja': u':プラス:',
        'ko': u':더하기:',
        'pt': u':símbolo_de_adição:',
        'it': ':addizione:',
        'fa': u':بعلاوه:',
        'id': ':tambah:',
        'zh': u':加:'
    },
    u'\U0001F43B\U0000200D\U00002744\U0000FE0F': { # 🐻‍❄️
        'en' : ':polar_bear:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':eisbär:',
        'es': ':oso_polar:',
        'fr': ':ours_polaire:',
        'ja': u':シロクマ:',
        'ko': u':북극곰:',
        'pt': ':urso_polar:',
        'it': ':orso_polare:',
        'fa': u':خرس_قطبی:',
        'id': ':beruang_kutub:',
        'zh': u':北极熊:'
    },
    u'\U0001F43B\U0000200D\U00002744': { # 🐻‍❄
        'en' : ':polar_bear:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': u':eisbär:',
        'es': ':oso_polar:',
        'fr': ':ours_polaire:',
        'ja': u':シロクマ:',
        'ko': u':북극곰:',
        'pt': ':urso_polar:',
        'it': ':orso_polare:',
        'fa': u':خرس_قطبی:',
        'id': ':beruang_kutub:',
        'zh': u':北极熊:'
    },
    u'\U0001F693': { # 🚓
        'en' : ':police_car:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':polizeiwagen:',
        'es': u':coche_de_policía:',
        'fr': ':voiture_de_police:',
        'ja': u':パトカー:',
        'ko': u':경찰차:',
        'pt': ':viatura_policial:',
        'it': ':macchina_della_polizia:',
        'fa': u':ماشین_پلیس:',
        'id': ':mobil_polisi:',
        'zh': u':警车:'
    },
    u'\U0001F6A8': { # 🚨
        'en' : ':police_car_light:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':rotating_light:'],
        'de': ':polizeilicht:',
        'es': u':luces_de_policía:',
        'fr': ':gyrophare:',
        'ja': u':パトランプ:',
        'ko': u':사이렌:',
        'pt': ':sirene:',
        'it': ':lampeggiante:',
        'fa': u':چراغ_ماشین_پلیس:',
        'id': ':lampu_mobil_polisi:',
        'zh': u':警车灯:'
    },
    u'\U0001F46E': { # 👮
        'en' : ':police_officer:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cop:'],
        'de': ':polizist(in):',
        'es': u':agente_de_policía:',
        'fr': ':officier_de_police:',
        'ja': u':警察官:',
        'ko': u':경찰관:',
        'pt': ':policial:',
        'it': ':agente_di_polizia:',
        'fa': u':پلیس:',
        'id': ':polisi:',
        'zh': u':警察:'
    },
    u'\U0001F46E\U0001F3FF': { # 👮🏿
        'en' : ':police_officer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':polizist(in)_dunkle_hautfarbe:',
        'es': u':agente_de_policía_tono_de_piel_oscuro:',
        'fr': u':officier_de_police_peau_foncée:',
        'ja': u':警察官_濃い肌色:',
        'ko': u':경찰관_검은색_피부:',
        'pt': ':policial_pele_escura:',
        'it': ':agente_di_polizia_carnagione_scura:',
        'fa': u':پلیس_پوست_آبنوسی:',
        'id': ':polisi_warna_kulit_gelap:',
        'zh': u':警察_较深肤色:'
    },
    u'\U0001F46E\U0001F3FB': { # 👮🏻
        'en' : ':police_officer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':polizist(in)_helle_hautfarbe:',
        'es': u':agente_de_policía_tono_de_piel_claro:',
        'fr': ':officier_de_police_peau_claire:',
        'ja': u':警察官_薄い肌色:',
        'ko': u':경찰관_하얀_피부:',
        'pt': ':policial_pele_clara:',
        'it': ':agente_di_polizia_carnagione_chiara:',
        'fa': u':پلیس_پوست_سفید:',
        'id': ':polisi_warna_kulit_cerah:',
        'zh': u':警察_较浅肤色:'
    },
    u'\U0001F46E\U0001F3FE': { # 👮🏾
        'en' : ':police_officer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':polizist(in)_mitteldunkle_hautfarbe:',
        'es': u':agente_de_policía_tono_de_piel_oscuro_medio:',
        'fr': ':officier_de_police_peau_mate:',
        'ja': u':警察官_やや濃い肌色:',
        'ko': u':경찰관_진한_갈색_피부:',
        'pt': ':policial_pele_morena_escura:',
        'it': ':agente_di_polizia_carnagione_abbastanza_scura:',
        'fa': u':پلیس_پوست_گندمی:',
        'id': ':polisi_warna_kulit_gelap-sedang:',
        'zh': u':警察_中等深肤色:'
    },
    u'\U0001F46E\U0001F3FC': { # 👮🏼
        'en' : ':police_officer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':polizist(in)_mittelhelle_hautfarbe:',
        'es': u':agente_de_policía_tono_de_piel_claro_medio:',
        'fr': ':officier_de_police_peau_moyennement_claire:',
        'ja': u':警察官_やや薄い肌色:',
        'ko': u':경찰관_연한_갈색_피부:',
        'pt': ':policial_pele_morena_clara:',
        'it': ':agente_di_polizia_carnagione_abbastanza_chiara:',
        'fa': u':پلیس_پوست_روشن:',
        'id': ':polisi_warna_kulit_cerah-sedang:',
        'zh': u':警察_中等浅肤色:'
    },
    u'\U0001F46E\U0001F3FD': { # 👮🏽
        'en' : ':police_officer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':polizist(in)_mittlere_hautfarbe:',
        'es': u':agente_de_policía_tono_de_piel_medio:',
        'fr': u':officier_de_police_peau_légèrement_mate:',
        'ja': u':警察官_中間の肌色:',
        'ko': u':경찰관_갈색_피부:',
        'pt': ':policial_pele_morena:',
        'it': ':agente_di_polizia_carnagione_olivastra:',
        'fa': u':پلیس_پوست_طلایی:',
        'id': ':polisi_warna_kulit_sedang:',
        'zh': u':警察_中等肤色:'
    },
    u'\U0001F429': { # 🐩
        'en' : ':poodle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':pudel:',
        'es': ':caniche:',
        'fr': ':caniche:',
        'ja': u':プードル:',
        'ko': u':푸들:',
        'pt': ':poodle:',
        'it': ':barboncino:',
        'fa': u':پودل:',
        'id': ':pudel:',
        'zh': u':贵宾犬:'
    },
    u'\U0001F3B1': { # 🎱
        'en' : ':pool_8_ball:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':8ball:'],
        'de': ':billardkugel:',
        'es': ':bola_negra_de_billar:',
        'fr': ':boule_de_billard:',
        'ja': u':ビリヤード:',
        'ko': u':당구:',
        'pt': ':bilhar:',
        'it': ':palla_da_biliardo:',
        'fa': u':بیلیارد:',
        'id': ':biliar_8_bola:',
        'zh': u':台球:'
    },
    u'\U0001F37F': { # 🍿
        'en' : ':popcorn:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':popcorn:',
        'es': ':palomitas:',
        'fr': ':pop-corn:',
        'ja': u':ポップコーン:',
        'ko': u':팝콘:',
        'pt': ':pipoca:',
        'it': ':popcorn:',
        'fa': u':ذرت_بوداده:',
        'id': ':popcorn:',
        'zh': u':爆米花:'
    },
    u'\U0001F3E4': { # 🏤
        'en' : ':post_office:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':european_post_office:'],
        'de': u':postgebäude:',
        'es': ':oficina_de_correos_europea:',
        'fr': ':bureau_de_poste:',
        'ja': u':西洋の郵便局:',
        'ko': u':우체국:',
        'pt': ':correio:',
        'it': ':ufficio_postale:',
        'fa': u':ادارهٔ_پست:',
        'id': ':kantor_pos:',
        'zh': u':邮局:'
    },
    u'\U0001F4EF': { # 📯
        'en' : ':postal_horn:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':posthorn:',
        'es': ':corneta_de_posta:',
        'fr': ':cor_postal:',
        'ja': u':郵便ラッパ:',
        'ko': u':호른:',
        'pt': ':corneta_postal:',
        'it': ':corno_postale:',
        'fa': u':شیپور_پست:',
        'id': ':trompet_pos:',
        'zh': u':邮号:'
    },
    u'\U0001F4EE': { # 📮
        'en' : ':postbox:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':briefkasten:',
        'es': u':buzón:',
        'fr': u':boîte_aux_lettres:',
        'ja': u':郵便ポスト:',
        'ko': u':우편함:',
        'pt': ':caixa_de_correio:',
        'it': ':cassetta_delle_lettere:',
        'fa': u':صندوق_پست:',
        'id': ':kotak_pos:',
        'zh': u':邮筒:'
    },
    u'\U0001F372': { # 🍲
        'en' : ':pot_of_food:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':stew:'],
        'de': ':topf_mit_essen:',
        'es': ':olla_de_comida:',
        'fr': ':marmite:',
        'ja': u':なべ:',
        'ko': u':국:',
        'pt': ':panela:',
        'it': ':pentola_di_cibo:',
        'fa': u':ظرف_غذا:',
        'id': ':panci_makanan:',
        'zh': u':一锅食物:'
    },
    u'\U0001F6B0': { # 🚰
        'en' : ':potable_water:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':trinkwasser:',
        'es': ':agua_potable:',
        'fr': ':eau_potable:',
        'ja': u':飲料水:',
        'ko': u':음수대:',
        'pt': u':água_potável:',
        'it': ':acqua_potabile:',
        'fa': u':آب_آشامیدنی:',
        'id': ':air_dapat_diminum:',
        'zh': u':饮用水:'
    },
    u'\U0001F954': { # 🥔
        'en' : ':potato:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':kartoffel:',
        'es': ':patata:',
        'fr': ':pomme_de_terre:',
        'ja': u':ジャガイモ:',
        'ko': u':감자:',
        'pt': ':batata:',
        'it': ':patata:',
        'fa': u':سیب_زمینی:',
        'id': ':kentang:',
        'zh': u':土豆:'
    },
    u'\U0001FAB4': { # 🪴
        'en' : ':potted_plant:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':topfpflanze:',
        'es': ':planta_de_maceta:',
        'fr': ':plante_en_pot:',
        'ja': u':鉢植え:',
        'ko': u':분재:',
        'pt': ':vaso_com_planta:',
        'it': ':pianta_in_vaso:',
        'fa': u':گیاه_گلدانی:',
        'id': ':tanaman_pot:',
        'zh': u':盆栽植物:'
    },
    u'\U0001F357': { # 🍗
        'en' : ':poultry_leg:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':hähnchenschenkel:',
        'es': ':muslo_de_pollo:',
        'fr': ':cuisse_de_poulet:',
        'ja': u':鶏もも肉:',
        'ko': u':닭다리:',
        'pt': ':coxa_de_frango:',
        'it': ':coscia_di_pollo:',
        'fa': u':ران_ماکیان:',
        'id': ':kaki_ayam:',
        'zh': u':家禽的腿:'
    },
    u'\U0001F4B7': { # 💷
        'en' : ':pound_banknote:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':pound:'],
        'de': ':pfund-banknote:',
        'es': ':billete_de_libra:',
        'fr': ':billet_en_livres:',
        'ja': u':ポンド札:',
        'ko': u':파운드:',
        'pt': ':nota_de_libra:',
        'it': ':banconota_sterlina:',
        'fa': u':اسکناس_پوند:',
        'id': ':uang_kertas_pound:',
        'zh': u':英镑:'
    },
    u'\U0001FAD7': { # 🫗
        'en' : ':pouring_liquid:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':flüssigkeit_ausgießen:',
        'es': u':líquido_derramándose:',
        'fr': ':verser_un_liquide:',
        'ja': u':コップから注ぐ:',
        'ko': u':쏟아져_나오는_액체:',
        'pt': u':derramando_líquido:',
        'it': ':liquido_versato:',
        'fa': u':ریختن_مایع:',
        'id': ':menuang_cairan:',
        'zh': u':倾倒液体:'
    },
    u'\U0001F63E': { # 😾
        'en' : ':pouting_cat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schmollende_katze:',
        'es': ':gato_enfadado:',
        'fr': ':chat_qui_boude:',
        'ja': u':不機嫌な猫:',
        'ko': u':뾰로통한_고양이_얼굴:',
        'pt': ':rosto_de_gato_mal-humorado:',
        'it': ':gatto_imbronciato:',
        'fa': u':گربهٔ_اخمو:',
        'id': ':wajah_kucing_marah:',
        'zh': u':生气的猫:'
    },
    u'\U0001F4FF': { # 📿
        'en' : ':prayer_beads:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':gebetskette:',
        'es': ':rosario:',
        'fr': ':chapelet:',
        'ja': u':数珠:',
        'ko': u':묵주:',
        'pt': u':rosário_de_oração:',
        'it': ':rosario:',
        'fa': u':تسبیح:',
        'id': ':tasbih:',
        'zh': u':念珠:'
    },
    u'\U0001FAC3': { # 🫃
        'en' : ':pregnant_man:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':schwangerer_mann:',
        'es': ':hombre_embarazado:',
        'fr': ':homme_enceint:',
        'ja': u':妊夫:',
        'ko': u':임신한_남자:',
        'pt': u':homem_grávido:',
        'it': ':uomo_incinto:',
        'fa': u':مرد_باردار:',
        'id': ':pria_hamil:',
        'zh': u':怀孕的男人:'
    },
    u'\U0001FAC3\U0001F3FF': { # 🫃🏿
        'en' : ':pregnant_man_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC3\U0001F3FB': { # 🫃🏻
        'en' : ':pregnant_man_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC3\U0001F3FE': { # 🫃🏾
        'en' : ':pregnant_man_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC3\U0001F3FC': { # 🫃🏼
        'en' : ':pregnant_man_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC3\U0001F3FD': { # 🫃🏽
        'en' : ':pregnant_man_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC4': { # 🫄
        'en' : ':pregnant_person:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':schwangere_person:',
        'es': ':persona_embarazada:',
        'fr': ':personne_enceinte:',
        'ja': u':妊娠した人:',
        'ko': u':임신한_사람:',
        'pt': u':pessoa_grávida:',
        'it': ':persona_incinta:',
        'fa': u':آدم_باردار:',
        'id': ':orang_hamil:',
        'zh': u':怀孕的人:'
    },
    u'\U0001FAC4\U0001F3FF': { # 🫄🏿
        'en' : ':pregnant_person_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC4\U0001F3FB': { # 🫄🏻
        'en' : ':pregnant_person_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC4\U0001F3FE': { # 🫄🏾
        'en' : ':pregnant_person_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC4\U0001F3FC': { # 🫄🏼
        'en' : ':pregnant_person_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAC4\U0001F3FD': { # 🫄🏽
        'en' : ':pregnant_person_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001F930': { # 🤰
        'en' : ':pregnant_woman:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schwangere_frau:',
        'es': ':mujer_embarazada:',
        'fr': ':femme_enceinte:',
        'ja': u':妊婦:',
        'ko': u':임산부:',
        'pt': u':grávida:',
        'it': ':donna_incinta:',
        'fa': u':زن_باردار:',
        'id': ':wanita_hamil:',
        'zh': u':孕妇:'
    },
    u'\U0001F930\U0001F3FF': { # 🤰🏿
        'en' : ':pregnant_woman_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schwangere_frau_dunkle_hautfarbe:',
        'es': ':mujer_embarazada_tono_de_piel_oscuro:',
        'fr': u':femme_enceinte_peau_foncée:',
        'ja': u':妊婦_濃い肌色:',
        'ko': u':임산부_검은색_피부:',
        'pt': u':grávida_pele_escura:',
        'it': ':donna_incinta_carnagione_scura:',
        'fa': u':زن_باردار_پوست_آبنوسی:',
        'id': ':wanita_hamil_warna_kulit_gelap:',
        'zh': u':孕妇_较深肤色:'
    },
    u'\U0001F930\U0001F3FB': { # 🤰🏻
        'en' : ':pregnant_woman_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schwangere_frau_helle_hautfarbe:',
        'es': ':mujer_embarazada_tono_de_piel_claro:',
        'fr': ':femme_enceinte_peau_claire:',
        'ja': u':妊婦_薄い肌色:',
        'ko': u':임산부_하얀_피부:',
        'pt': u':grávida_pele_clara:',
        'it': ':donna_incinta_carnagione_chiara:',
        'fa': u':زن_باردار_پوست_سفید:',
        'id': ':wanita_hamil_warna_kulit_cerah:',
        'zh': u':孕妇_较浅肤色:'
    },
    u'\U0001F930\U0001F3FE': { # 🤰🏾
        'en' : ':pregnant_woman_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schwangere_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_embarazada_tono_de_piel_oscuro_medio:',
        'fr': ':femme_enceinte_peau_mate:',
        'ja': u':妊婦_やや濃い肌色:',
        'ko': u':임산부_진한_갈색_피부:',
        'pt': u':grávida_pele_morena_escura:',
        'it': ':donna_incinta_carnagione_abbastanza_scura:',
        'fa': u':زن_باردار_پوست_گندمی:',
        'id': ':wanita_hamil_warna_kulit_gelap-sedang:',
        'zh': u':孕妇_中等深肤色:'
    },
    u'\U0001F930\U0001F3FC': { # 🤰🏼
        'en' : ':pregnant_woman_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schwangere_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_embarazada_tono_de_piel_claro_medio:',
        'fr': ':femme_enceinte_peau_moyennement_claire:',
        'ja': u':妊婦_やや薄い肌色:',
        'ko': u':임산부_연한_갈색_피부:',
        'pt': u':grávida_pele_morena_clara:',
        'it': ':donna_incinta_carnagione_abbastanza_chiara:',
        'fa': u':زن_باردار_پوست_روشن:',
        'id': ':wanita_hamil_warna_kulit_cerah-sedang:',
        'zh': u':孕妇_中等浅肤色:'
    },
    u'\U0001F930\U0001F3FD': { # 🤰🏽
        'en' : ':pregnant_woman_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':schwangere_frau_mittlere_hautfarbe:',
        'es': ':mujer_embarazada_tono_de_piel_medio:',
        'fr': u':femme_enceinte_peau_légèrement_mate:',
        'ja': u':妊婦_中間の肌色:',
        'ko': u':임산부_갈색_피부:',
        'pt': u':grávida_pele_morena:',
        'it': ':donna_incinta_carnagione_olivastra:',
        'fa': u':زن_باردار_پوست_طلایی:',
        'id': ':wanita_hamil_warna_kulit_sedang:',
        'zh': u':孕妇_中等肤色:'
    },
    u'\U0001F968': { # 🥨
        'en' : ':pretzel:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':brezel:',
        'es': ':bretzel:',
        'fr': ':bretzel:',
        'ja': u':プレッツェル:',
        'ko': u':프레첼:',
        'pt': ':pretzel:',
        'it': ':pretzel:',
        'fa': u':چوب_شور:',
        'id': ':pretzel:',
        'zh': u':椒盐卷饼:'
    },
    u'\U0001F934': { # 🤴
        'en' : ':prince:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':prinz:',
        'es': u':príncipe:',
        'fr': ':prince:',
        'ja': u':プリンス:',
        'ko': u':왕자:',
        'pt': u':príncipe:',
        'it': ':principe:',
        'fa': u':شاهزاده:',
        'id': ':pangeran:',
        'zh': u':王子:'
    },
    u'\U0001F934\U0001F3FF': { # 🤴🏿
        'en' : ':prince_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':prinz_dunkle_hautfarbe:',
        'es': u':príncipe_tono_de_piel_oscuro:',
        'fr': u':prince_peau_foncée:',
        'ja': u':プリンス_濃い肌色:',
        'ko': u':왕자_검은색_피부:',
        'pt': u':príncipe_pele_escura:',
        'it': ':principe_carnagione_scura:',
        'fa': u':شاهزاده_پوست_آبنوسی:',
        'id': ':pangeran_warna_kulit_gelap:',
        'zh': u':王子_较深肤色:'
    },
    u'\U0001F934\U0001F3FB': { # 🤴🏻
        'en' : ':prince_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':prinz_helle_hautfarbe:',
        'es': u':príncipe_tono_de_piel_claro:',
        'fr': ':prince_peau_claire:',
        'ja': u':プリンス_薄い肌色:',
        'ko': u':왕자_하얀_피부:',
        'pt': u':príncipe_pele_clara:',
        'it': ':principe_carnagione_chiara:',
        'fa': u':شاهزاده_پوست_سفید:',
        'id': ':pangeran_warna_kulit_cerah:',
        'zh': u':王子_较浅肤色:'
    },
    u'\U0001F934\U0001F3FE': { # 🤴🏾
        'en' : ':prince_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':prinz_mitteldunkle_hautfarbe:',
        'es': u':príncipe_tono_de_piel_oscuro_medio:',
        'fr': ':prince_peau_mate:',
        'ja': u':プリンス_やや濃い肌色:',
        'ko': u':왕자_진한_갈색_피부:',
        'pt': u':príncipe_pele_morena_escura:',
        'it': ':principe_carnagione_abbastanza_scura:',
        'fa': u':شاهزاده_پوست_گندمی:',
        'id': ':pangeran_warna_kulit_gelap-sedang:',
        'zh': u':王子_中等深肤色:'
    },
    u'\U0001F934\U0001F3FC': { # 🤴🏼
        'en' : ':prince_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':prinz_mittelhelle_hautfarbe:',
        'es': u':príncipe_tono_de_piel_claro_medio:',
        'fr': ':prince_peau_moyennement_claire:',
        'ja': u':プリンス_やや薄い肌色:',
        'ko': u':왕자_연한_갈색_피부:',
        'pt': u':príncipe_pele_morena_clara:',
        'it': ':principe_carnagione_abbastanza_chiara:',
        'fa': u':شاهزاده_پوست_روشن:',
        'id': ':pangeran_warna_kulit_cerah-sedang:',
        'zh': u':王子_中等浅肤色:'
    },
    u'\U0001F934\U0001F3FD': { # 🤴🏽
        'en' : ':prince_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':prinz_mittlere_hautfarbe:',
        'es': u':príncipe_tono_de_piel_medio:',
        'fr': u':prince_peau_légèrement_mate:',
        'ja': u':プリンス_中間の肌色:',
        'ko': u':왕자_갈색_피부:',
        'pt': u':príncipe_pele_morena:',
        'it': ':principe_carnagione_olivastra:',
        'fa': u':شاهزاده_پوست_طلایی:',
        'id': ':pangeran_warna_kulit_sedang:',
        'zh': u':王子_中等肤色:'
    },
    u'\U0001F478': { # 👸
        'en' : ':princess:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':prinzessin:',
        'es': ':princesa:',
        'fr': ':princesse:',
        'ja': u':プリンセス:',
        'ko': u':공주:',
        'pt': ':princesa:',
        'it': ':principessa:',
        'fa': u':شاهزاده_خانم:',
        'id': ':putri:',
        'zh': u':公主:'
    },
    u'\U0001F478\U0001F3FF': { # 👸🏿
        'en' : ':princess_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':prinzessin_dunkle_hautfarbe:',
        'es': ':princesa_tono_de_piel_oscuro:',
        'fr': u':princesse_peau_foncée:',
        'ja': u':プリンセス_濃い肌色:',
        'ko': u':공주_검은색_피부:',
        'pt': ':princesa_pele_escura:',
        'it': ':principessa_carnagione_scura:',
        'fa': u':شاهزاده_خانم_پوست_آبنوسی:',
        'id': ':putri_warna_kulit_gelap:',
        'zh': u':公主_较深肤色:'
    },
    u'\U0001F478\U0001F3FB': { # 👸🏻
        'en' : ':princess_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':prinzessin_helle_hautfarbe:',
        'es': ':princesa_tono_de_piel_claro:',
        'fr': ':princesse_peau_claire:',
        'ja': u':プリンセス_薄い肌色:',
        'ko': u':공주_하얀_피부:',
        'pt': ':princesa_pele_clara:',
        'it': ':principessa_carnagione_chiara:',
        'fa': u':شاهزاده_خانم_پوست_سفید:',
        'id': ':putri_warna_kulit_cerah:',
        'zh': u':公主_较浅肤色:'
    },
    u'\U0001F478\U0001F3FE': { # 👸🏾
        'en' : ':princess_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':prinzessin_mitteldunkle_hautfarbe:',
        'es': ':princesa_tono_de_piel_oscuro_medio:',
        'fr': ':princesse_peau_mate:',
        'ja': u':プリンセス_やや濃い肌色:',
        'ko': u':공주_진한_갈색_피부:',
        'pt': ':princesa_pele_morena_escura:',
        'it': ':principessa_carnagione_abbastanza_scura:',
        'fa': u':شاهزاده_خانم_پوست_گندمی:',
        'id': ':putri_warna_kulit_gelap-sedang:',
        'zh': u':公主_中等深肤色:'
    },
    u'\U0001F478\U0001F3FC': { # 👸🏼
        'en' : ':princess_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':prinzessin_mittelhelle_hautfarbe:',
        'es': ':princesa_tono_de_piel_claro_medio:',
        'fr': ':princesse_peau_moyennement_claire:',
        'ja': u':プリンセス_やや薄い肌色:',
        'ko': u':공주_연한_갈색_피부:',
        'pt': ':princesa_pele_morena_clara:',
        'it': ':principessa_carnagione_abbastanza_chiara:',
        'fa': u':شاهزاده_خانم_پوست_روشن:',
        'id': ':putri_warna_kulit_cerah-sedang:',
        'zh': u':公主_中等浅肤色:'
    },
    u'\U0001F478\U0001F3FD': { # 👸🏽
        'en' : ':princess_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':prinzessin_mittlere_hautfarbe:',
        'es': ':princesa_tono_de_piel_medio:',
        'fr': u':princesse_peau_légèrement_mate:',
        'ja': u':プリンセス_中間の肌色:',
        'ko': u':공주_갈색_피부:',
        'pt': ':princesa_pele_morena:',
        'it': ':principessa_carnagione_olivastra:',
        'fa': u':شاهزاده_خانم_پوست_طلایی:',
        'id': ':putri_warna_kulit_sedang:',
        'zh': u':公主_中等肤色:'
    },
    u'\U0001F5A8\U0000FE0F': { # 🖨️
        'en' : ':printer:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':drucker:',
        'es': ':impresora:',
        'fr': ':imprimante:',
        'ja': u':プリンタ:',
        'ko': u':프린터:',
        'pt': ':impressora:',
        'it': ':stampante:',
        'fa': u':چاپگر:',
        'id': ':printer:',
        'zh': u':打印机:'
    },
    u'\U0001F5A8': { # 🖨
        'en' : ':printer:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':drucker:',
        'es': ':impresora:',
        'fr': ':imprimante:',
        'ja': u':プリンタ:',
        'ko': u':프린터:',
        'pt': ':impressora:',
        'it': ':stampante:',
        'fa': u':چاپگر:',
        'id': ':printer:',
        'zh': u':打印机:'
    },
    u'\U0001F6AB': { # 🚫
        'en' : ':prohibited:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':no_entry_sign:'],
        'de': ':verboten:',
        'es': ':prohibido:',
        'fr': u':symbole_d’interdiction:',
        'ja': u':車両通行止め:',
        'ko': u':금지:',
        'pt': ':proibido:',
        'it': ':segnale_di_divieto:',
        'fa': u':ممنوع:',
        'id': ':dilarang:',
        'zh': u':禁止:'
    },
    u'\U0001F7E3': { # 🟣
        'en' : ':purple_circle:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':lila_punkt:',
        'es': u':círculo_morado:',
        'fr': ':disque_violet:',
        'ja': u':紫の丸:',
        'ko': u':보라색_원:',
        'pt': u':círculo_roxo:',
        'it': ':cerchio_viola:',
        'fa': u':دایره_بنفش:',
        'id': ':lingkaran_ungu:',
        'zh': u':紫色圆:'
    },
    u'\U0001F49C': { # 💜
        'en' : ':purple_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':lila_herz:',
        'es': u':corazón_morado:',
        'fr': u':cœur_violet:',
        'ja': u':紫のハート:',
        'ko': u':보라색_하트:',
        'pt': u':coração_roxo:',
        'it': ':cuore_viola:',
        'fa': u':قلب_بنفش:',
        'id': ':hati_ungu:',
        'zh': u':紫心:'
    },
    u'\U0001F7EA': { # 🟪
        'en' : ':purple_square:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':lila_quadrat:',
        'es': ':cuadrado_morado:',
        'fr': u':carré_violet:',
        'ja': u':紫の四角:',
        'ko': u':보라색_사각형:',
        'pt': ':quadrado_roxo:',
        'it': ':quadrato_viola:',
        'fa': u':مربع_بنفش:',
        'id': ':persegi_ungu:',
        'zh': u':紫色方块:'
    },
    u'\U0001F45B': { # 👛
        'en' : ':purse:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':geldbörse:',
        'es': ':monedero:',
        'fr': ':porte-monnaie:',
        'ja': u':がま口:',
        'ko': u':지갑:',
        'pt': ':bolsinha:',
        'it': ':borsellino:',
        'fa': u':کیف_دستی:',
        'id': ':dompet:',
        'zh': u':钱包:'
    },
    u'\U0001F4CC': { # 📌
        'en' : ':pushpin:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':reißzwecke:',
        'es': ':chincheta:',
        'fr': ':punaise:',
        'ja': u':押しピン:',
        'ko': u':압정:',
        'pt': ':tacha:',
        'it': ':puntina:',
        'fa': u':سنجاق:',
        'id': ':paku_penanda:',
        'zh': u':图钉:'
    },
    u'\U0001F9E9': { # 🧩
        'en' : ':puzzle_piece:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':jigsaw:'],
        'de': ':puzzleteil:',
        'es': ':pieza_de_puzle:',
        'fr': u':pièce_de_puzzle:',
        'ja': u':ジグソーパズル:',
        'ko': u':퍼즐:',
        'pt': u':quebra-cabeça:',
        'it': ':pezzo_di_puzzle:',
        'fa': u':قطعه_پازل:',
        'id': ':keping_puzzle:',
        'zh': u':拼图:'
    },
    u'\U0001F407': { # 🐇
        'en' : ':rabbit:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':rabbit2:'],
        'de': ':hase:',
        'es': ':conejo:',
        'fr': ':lapin:',
        'ja': u':ウサギ:',
        'ko': u':토끼:',
        'pt': ':coelho:',
        'it': ':coniglio:',
        'fa': u':خرگوش:',
        'id': ':kelinci:',
        'zh': u':兔子:'
    },
    u'\U0001F430': { # 🐰
        'en' : ':rabbit_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':rabbit:'],
        'de': ':hasengesicht:',
        'es': ':cara_de_conejo:',
        'fr': u':tête_de_lapin:',
        'ja': u':ウサギの顔:',
        'ko': u':토끼_얼굴:',
        'pt': ':rosto_de_coelho:',
        'it': ':muso_di_coniglio:',
        'fa': u':صورت_خرگوش:',
        'id': ':wajah_kelinci:',
        'zh': u':兔子头:'
    },
    u'\U0001F99D': { # 🦝
        'en' : ':raccoon:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':waschbär:',
        'es': ':mapache:',
        'fr': ':raton_laveur:',
        'ja': u':アライグマ:',
        'ko': u':너구리:',
        'pt': ':guaxinim:',
        'it': ':procione:',
        'fa': u':راکون:',
        'id': ':rakun:',
        'zh': u':浣熊:'
    },
    u'\U0001F3CE\U0000FE0F': { # 🏎️
        'en' : ':racing_car:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':rennauto:',
        'es': ':coche_de_carreras:',
        'fr': ':voiture_de_course:',
        'ja': u':レーシングカー:',
        'ko': u':경주용_자동차:',
        'pt': ':carro_de_corrida:',
        'it': ':auto_da_corsa:',
        'fa': u':ماشین_مسابقه:',
        'id': ':mobil_balap:',
        'zh': u':赛车:'
    },
    u'\U0001F3CE': { # 🏎
        'en' : ':racing_car:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':rennauto:',
        'es': ':coche_de_carreras:',
        'fr': ':voiture_de_course:',
        'ja': u':レーシングカー:',
        'ko': u':경주용_자동차:',
        'pt': ':carro_de_corrida:',
        'it': ':auto_da_corsa:',
        'fa': u':ماشین_مسابقه:',
        'id': ':mobil_balap:',
        'zh': u':赛车:'
    },
    u'\U0001F4FB': { # 📻
        'en' : ':radio:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':radio:',
        'es': ':radio:',
        'fr': ':radio:',
        'ja': u':ラジオ:',
        'ko': u':라디오:',
        'pt': u':rádio:',
        'it': ':radio:',
        'fa': u':رادیو:',
        'id': ':radio:',
        'zh': u':收音机:'
    },
    u'\U0001F518': { # 🔘
        'en' : ':radio_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':optionsfeld:',
        'es': u':botón_de_opción:',
        'fr': ':bouton_radio:',
        'ja': u':ラジオボタン:',
        'ko': u':라디오_버튼:',
        'pt': u':botão_de_opção:',
        'it': ':pulsante_rotondo:',
        'fa': u':دکمهٔ_رادیویی:',
        'id': ':tombol_radio:',
        'zh': u':单选按钮:'
    },
    u'\U00002622\U0000FE0F': { # ☢️
        'en' : ':radioactive:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':radioactive_sign:'],
        'variant': True,
        'de': ':radioaktiv:',
        'es': ':radiactivo:',
        'fr': ':radioactif:',
        'ja': u':放射能:',
        'ko': u':방사능:',
        'pt': ':radioativo:',
        'it': u':simbolo_della_radioattività:',
        'fa': u':رادیواکتیو:',
        'id': ':radioaktif:',
        'zh': u':辐射:'
    },
    u'\U00002622': { # ☢
        'en' : ':radioactive:',
        'status' : unqualified,
        'E' : 1,
        'alias' : [':radioactive_sign:'],
        'variant': True,
        'de': ':radioaktiv:',
        'es': ':radiactivo:',
        'fr': ':radioactif:',
        'ja': u':放射能:',
        'ko': u':방사능:',
        'pt': ':radioativo:',
        'it': u':simbolo_della_radioattività:',
        'fa': u':رادیواکتیو:',
        'id': ':radioaktif:',
        'zh': u':辐射:'
    },
    u'\U0001F683': { # 🚃
        'en' : ':railway_car:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':eisenbahnwagen:',
        'es': u':vagón:',
        'fr': ':wagon:',
        'ja': u':電車:',
        'ko': u':전철:',
        'pt': u':vagão_de_trem:',
        'it': ':vagone:',
        'fa': u':واگن_ریلی:',
        'id': ':gerbong:',
        'zh': u':轨道车:'
    },
    u'\U0001F6E4\U0000FE0F': { # 🛤️
        'en' : ':railway_track:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':bahngleis:',
        'es': u':vía_de_tren:',
        'fr': u':voie_ferrée:',
        'ja': u':線路:',
        'ko': u':철도_선로:',
        'pt': ':trilhos:',
        'it': ':binari:',
        'fa': u':ریل_قطار:',
        'id': ':rel_kereta:',
        'zh': u':铁轨:'
    },
    u'\U0001F6E4': { # 🛤
        'en' : ':railway_track:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':bahngleis:',
        'es': u':vía_de_tren:',
        'fr': u':voie_ferrée:',
        'ja': u':線路:',
        'ko': u':철도_선로:',
        'pt': ':trilhos:',
        'it': ':binari:',
        'fa': u':ریل_قطار:',
        'id': ':rel_kereta:',
        'zh': u':铁轨:'
    },
    u'\U0001F308': { # 🌈
        'en' : ':rainbow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':regenbogen:',
        'es': u':arcoíris:',
        'fr': ':arc-en-ciel:',
        'ja': u':虹:',
        'ko': u':무지개:',
        'pt': u':arco-íris:',
        'it': ':arcobaleno:',
        'fa': u':رنگین_کمان:',
        'id': ':pelangi:',
        'zh': u':彩虹:'
    },
    u'\U0001F3F3\U0000FE0F\U0000200D\U0001F308': { # 🏳️‍🌈
        'en' : ':rainbow_flag:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':regenbogenflagge:',
        'es': u':bandera_del_arcoíris:',
        'fr': ':drapeau_arc-en-ciel:',
        'ja': u':レインボーフラッグ:',
        'ko': u':무지개_깃발:',
        'pt': u':bandeira_do_arco-íris:',
        'it': ':bandiera_arcobaleno:',
        'fa': u':پرچم_رنگین_کمان:',
        'id': ':bendera_pelangi:',
        'zh': u':彩虹旗:'
    },
    u'\U0001F3F3\U0000200D\U0001F308': { # 🏳‍🌈
        'en' : ':rainbow_flag:',
        'status' : unqualified,
        'E' : 4,
        'de': ':regenbogenflagge:',
        'es': u':bandera_del_arcoíris:',
        'fr': ':drapeau_arc-en-ciel:',
        'ja': u':レインボーフラッグ:',
        'ko': u':무지개_깃발:',
        'pt': u':bandeira_do_arco-íris:',
        'it': ':bandiera_arcobaleno:',
        'fa': u':پرچم_رنگین_کمان:',
        'id': ':bendera_pelangi:',
        'zh': u':彩虹旗:'
    },
    u'\U0001F91A': { # 🤚
        'en' : ':raised_back_of_hand:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':erhobene_hand_von_hinten:',
        'es': ':dorso_de_la_mano:',
        'fr': u':dos_de_main_levée:',
        'ja': u':手の甲:',
        'ko': u':손등:',
        'pt': u':dorso_da_mão_levantado:',
        'it': ':dorso_mano_alzata:',
        'fa': u':پشت_دست:',
        'id': ':angkat_tangan:',
        'zh': u':立起的手背:'
    },
    u'\U0001F91A\U0001F3FF': { # 🤚🏿
        'en' : ':raised_back_of_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':erhobene_hand_von_hinten_dunkle_hautfarbe:',
        'es': ':dorso_de_la_mano_tono_de_piel_oscuro:',
        'fr': u':dos_de_main_levée_peau_foncée:',
        'ja': u':手の甲_濃い肌色:',
        'ko': u':손등_검은색_피부:',
        'pt': u':dorso_da_mão_levantado_pele_escura:',
        'it': ':dorso_mano_alzata_carnagione_scura:',
        'fa': u':پشت_دست_پوست_آبنوسی:',
        'id': ':angkat_tangan_warna_kulit_gelap:',
        'zh': u':立起的手背_较深肤色:'
    },
    u'\U0001F91A\U0001F3FB': { # 🤚🏻
        'en' : ':raised_back_of_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':erhobene_hand_von_hinten_helle_hautfarbe:',
        'es': ':dorso_de_la_mano_tono_de_piel_claro:',
        'fr': u':dos_de_main_levée_peau_claire:',
        'ja': u':手の甲_薄い肌色:',
        'ko': u':손등_하얀_피부:',
        'pt': u':dorso_da_mão_levantado_pele_clara:',
        'it': ':dorso_mano_alzata_carnagione_chiara:',
        'fa': u':پشت_دست_پوست_سفید:',
        'id': ':angkat_tangan_warna_kulit_cerah:',
        'zh': u':立起的手背_较浅肤色:'
    },
    u'\U0001F91A\U0001F3FE': { # 🤚🏾
        'en' : ':raised_back_of_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':erhobene_hand_von_hinten_mitteldunkle_hautfarbe:',
        'es': ':dorso_de_la_mano_tono_de_piel_oscuro_medio:',
        'fr': u':dos_de_main_levée_peau_mate:',
        'ja': u':手の甲_やや濃い肌色:',
        'ko': u':손등_진한_갈색_피부:',
        'pt': u':dorso_da_mão_levantado_pele_morena_escura:',
        'it': ':dorso_mano_alzata_carnagione_abbastanza_scura:',
        'fa': u':پشت_دست_پوست_گندمی:',
        'id': ':angkat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':立起的手背_中等深肤色:'
    },
    u'\U0001F91A\U0001F3FC': { # 🤚🏼
        'en' : ':raised_back_of_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':erhobene_hand_von_hinten_mittelhelle_hautfarbe:',
        'es': ':dorso_de_la_mano_tono_de_piel_claro_medio:',
        'fr': u':dos_de_main_levée_peau_moyennement_claire:',
        'ja': u':手の甲_やや薄い肌色:',
        'ko': u':손등_연한_갈색_피부:',
        'pt': u':dorso_da_mão_levantado_pele_morena_clara:',
        'it': ':dorso_mano_alzata_carnagione_abbastanza_chiara:',
        'fa': u':پشت_دست_پوست_روشن:',
        'id': ':angkat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':立起的手背_中等浅肤色:'
    },
    u'\U0001F91A\U0001F3FD': { # 🤚🏽
        'en' : ':raised_back_of_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':erhobene_hand_von_hinten_mittlere_hautfarbe:',
        'es': ':dorso_de_la_mano_tono_de_piel_medio:',
        'fr': u':dos_de_main_levée_peau_légèrement_mate:',
        'ja': u':手の甲_中間の肌色:',
        'ko': u':손등_갈색_피부:',
        'pt': u':dorso_da_mão_levantado_pele_morena:',
        'it': ':dorso_mano_alzata_carnagione_olivastra:',
        'fa': u':پشت_دست_پوست_طلایی:',
        'id': ':angkat_tangan_warna_kulit_sedang:',
        'zh': u':立起的手背_中等肤色:'
    },
    u'\U0000270A': { # ✊
        'en' : ':raised_fist:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':fist:', ':fist_raised:'],
        'de': ':erhobene_faust:',
        'es': u':puño_en_alto:',
        'fr': u':poing_levé:',
        'ja': u':げんこつ:',
        'ko': u':주먹:',
        'pt': ':punho_levantado:',
        'it': ':pugno:',
        'fa': u':مشت_کردن:',
        'id': ':tangan_terkepal_ke_atas:',
        'zh': u':举起拳头:'
    },
    u'\U0000270A\U0001F3FF': { # ✊🏿
        'en' : ':raised_fist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_faust_dunkle_hautfarbe:',
        'es': u':puño_en_alto_tono_de_piel_oscuro:',
        'fr': u':poing_levé_peau_foncée:',
        'ja': u':げんこつ_濃い肌色:',
        'ko': u':주먹_검은색_피부:',
        'pt': ':punho_levantado_pele_escura:',
        'it': ':pugno_carnagione_scura:',
        'fa': u':مشت_کردن_پوست_آبنوسی:',
        'id': ':tangan_terkepal_ke_atas_warna_kulit_gelap:',
        'zh': u':举起拳头_较深肤色:'
    },
    u'\U0000270A\U0001F3FB': { # ✊🏻
        'en' : ':raised_fist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_faust_helle_hautfarbe:',
        'es': u':puño_en_alto_tono_de_piel_claro:',
        'fr': u':poing_levé_peau_claire:',
        'ja': u':げんこつ_薄い肌色:',
        'ko': u':주먹_하얀_피부:',
        'pt': ':punho_levantado_pele_clara:',
        'it': ':pugno_carnagione_chiara:',
        'fa': u':مشت_کردن_پوست_سفید:',
        'id': ':tangan_terkepal_ke_atas_warna_kulit_cerah:',
        'zh': u':举起拳头_较浅肤色:'
    },
    u'\U0000270A\U0001F3FE': { # ✊🏾
        'en' : ':raised_fist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_faust_mitteldunkle_hautfarbe:',
        'es': u':puño_en_alto_tono_de_piel_oscuro_medio:',
        'fr': u':poing_levé_peau_mate:',
        'ja': u':げんこつ_やや濃い肌色:',
        'ko': u':주먹_진한_갈색_피부:',
        'pt': ':punho_levantado_pele_morena_escura:',
        'it': ':pugno_carnagione_abbastanza_scura:',
        'fa': u':مشت_کردن_پوست_گندمی:',
        'id': ':tangan_terkepal_ke_atas_warna_kulit_gelap-sedang:',
        'zh': u':举起拳头_中等深肤色:'
    },
    u'\U0000270A\U0001F3FC': { # ✊🏼
        'en' : ':raised_fist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_faust_mittelhelle_hautfarbe:',
        'es': u':puño_en_alto_tono_de_piel_claro_medio:',
        'fr': u':poing_levé_peau_moyennement_claire:',
        'ja': u':げんこつ_やや薄い肌色:',
        'ko': u':주먹_연한_갈색_피부:',
        'pt': ':punho_levantado_pele_morena_clara:',
        'it': ':pugno_carnagione_abbastanza_chiara:',
        'fa': u':مشت_کردن_پوست_روشن:',
        'id': ':tangan_terkepal_ke_atas_warna_kulit_cerah-sedang:',
        'zh': u':举起拳头_中等浅肤色:'
    },
    u'\U0000270A\U0001F3FD': { # ✊🏽
        'en' : ':raised_fist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_faust_mittlere_hautfarbe:',
        'es': u':puño_en_alto_tono_de_piel_medio:',
        'fr': u':poing_levé_peau_légèrement_mate:',
        'ja': u':げんこつ_中間の肌色:',
        'ko': u':주먹_갈색_피부:',
        'pt': ':punho_levantado_pele_morena:',
        'it': ':pugno_carnagione_olivastra:',
        'fa': u':مشت_کردن_پوست_طلایی:',
        'id': ':tangan_terkepal_ke_atas_warna_kulit_sedang:',
        'zh': u':举起拳头_中等肤色:'
    },
    u'\U0000270B': { # ✋
        'en' : ':raised_hand:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':hand:'],
        'de': ':erhobene_hand:',
        'es': ':mano_levantada:',
        'fr': u':main_levée:',
        'ja': u':挙手:',
        'ko': u':손바닥:',
        'pt': u':mão_levantada:',
        'it': ':mano_alzata:',
        'fa': u':دست_بالابرده:',
        'id': ':telapak_tangan_terbuka_dengan_jari_rapat:',
        'zh': u':举起手:'
    },
    u'\U0000270B\U0001F3FF': { # ✋🏿
        'en' : ':raised_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_hand_dunkle_hautfarbe:',
        'es': ':mano_levantada_tono_de_piel_oscuro:',
        'fr': u':main_levée_peau_foncée:',
        'ja': u':挙手_濃い肌色:',
        'ko': u':손바닥_검은색_피부:',
        'pt': u':mão_levantada_pele_escura:',
        'it': ':mano_alzata_carnagione_scura:',
        'fa': u':دست_بالابرده_پوست_آبنوسی:',
        'id': ':telapak_tangan_terbuka_dengan_jari_rapat_warna_kulit_gelap:',
        'zh': u':举起手_较深肤色:'
    },
    u'\U0000270B\U0001F3FB': { # ✋🏻
        'en' : ':raised_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_hand_helle_hautfarbe:',
        'es': ':mano_levantada_tono_de_piel_claro:',
        'fr': u':main_levée_peau_claire:',
        'ja': u':挙手_薄い肌色:',
        'ko': u':손바닥_하얀_피부:',
        'pt': u':mão_levantada_pele_clara:',
        'it': ':mano_alzata_carnagione_chiara:',
        'fa': u':دست_بالابرده_پوست_سفید:',
        'id': ':telapak_tangan_terbuka_dengan_jari_rapat_warna_kulit_cerah:',
        'zh': u':举起手_较浅肤色:'
    },
    u'\U0000270B\U0001F3FE': { # ✋🏾
        'en' : ':raised_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_hand_mitteldunkle_hautfarbe:',
        'es': ':mano_levantada_tono_de_piel_oscuro_medio:',
        'fr': u':main_levée_peau_mate:',
        'ja': u':挙手_やや濃い肌色:',
        'ko': u':손바닥_진한_갈색_피부:',
        'pt': u':mão_levantada_pele_morena_escura:',
        'it': ':mano_alzata_carnagione_abbastanza_scura:',
        'fa': u':دست_بالابرده_پوست_گندمی:',
        'id': ':telapak_tangan_terbuka_dengan_jari_rapat_warna_kulit_gelap-sedang:',
        'zh': u':举起手_中等深肤色:'
    },
    u'\U0000270B\U0001F3FC': { # ✋🏼
        'en' : ':raised_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_hand_mittelhelle_hautfarbe:',
        'es': ':mano_levantada_tono_de_piel_claro_medio:',
        'fr': u':main_levée_peau_moyennement_claire:',
        'ja': u':挙手_やや薄い肌色:',
        'ko': u':손바닥_연한_갈색_피부:',
        'pt': u':mão_levantada_pele_morena_clara:',
        'it': ':mano_alzata_carnagione_abbastanza_chiara:',
        'fa': u':دست_بالابرده_پوست_روشن:',
        'id': ':telapak_tangan_terbuka_dengan_jari_rapat_warna_kulit_cerah-sedang:',
        'zh': u':举起手_中等浅肤色:'
    },
    u'\U0000270B\U0001F3FD': { # ✋🏽
        'en' : ':raised_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erhobene_hand_mittlere_hautfarbe:',
        'es': ':mano_levantada_tono_de_piel_medio:',
        'fr': u':main_levée_peau_légèrement_mate:',
        'ja': u':挙手_中間の肌色:',
        'ko': u':손바닥_갈색_피부:',
        'pt': u':mão_levantada_pele_morena:',
        'it': ':mano_alzata_carnagione_olivastra:',
        'fa': u':دست_بالابرده_پوست_طلایی:',
        'id': ':telapak_tangan_terbuka_dengan_jari_rapat_warna_kulit_sedang:',
        'zh': u':举起手_中等肤色:'
    },
    u'\U0001F64C': { # 🙌
        'en' : ':raising_hands:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':raised_hands:'],
        'de': u':zwei_erhobene_handflächen:',
        'es': ':manos_levantadas_celebrando:',
        'fr': u':mains_levées:',
        'ja': u':バンザイ:',
        'ko': u':만세:',
        'pt': u':mãos_para_cima:',
        'it': ':mani_alzate:',
        'fa': u':دست_های_بالا_آورده:',
        'id': ':mengangkat_tangan:',
        'zh': u':举双手:'
    },
    u'\U0001F64C\U0001F3FF': { # 🙌🏿
        'en' : ':raising_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':zwei_erhobene_handflächen_dunkle_hautfarbe:',
        'es': ':manos_levantadas_celebrando_tono_de_piel_oscuro:',
        'fr': u':mains_levées_peau_foncée:',
        'ja': u':バンザイ_濃い肌色:',
        'ko': u':만세_검은색_피부:',
        'pt': u':mãos_para_cima_pele_escura:',
        'it': ':mani_alzate_carnagione_scura:',
        'fa': u':تمجید_پوست_آبنوسی:',
        'id': ':mengangkat_tangan_warna_kulit_gelap:',
        'zh': u':举双手_较深肤色:'
    },
    u'\U0001F64C\U0001F3FB': { # 🙌🏻
        'en' : ':raising_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':zwei_erhobene_handflächen_helle_hautfarbe:',
        'es': ':manos_levantadas_celebrando_tono_de_piel_claro:',
        'fr': u':mains_levées_peau_claire:',
        'ja': u':バンザイ_薄い肌色:',
        'ko': u':만세_하얀_피부:',
        'pt': u':mãos_para_cima_pele_clara:',
        'it': ':mani_alzate_carnagione_chiara:',
        'fa': u':تمجید_پوست_سفید:',
        'id': ':mengangkat_tangan_warna_kulit_cerah:',
        'zh': u':举双手_较浅肤色:'
    },
    u'\U0001F64C\U0001F3FE': { # 🙌🏾
        'en' : ':raising_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':zwei_erhobene_handflächen_mitteldunkle_hautfarbe:',
        'es': ':manos_levantadas_celebrando_tono_de_piel_oscuro_medio:',
        'fr': u':mains_levées_peau_mate:',
        'ja': u':バンザイ_やや濃い肌色:',
        'ko': u':만세_진한_갈색_피부:',
        'pt': u':mãos_para_cima_pele_morena_escura:',
        'it': ':mani_alzate_carnagione_abbastanza_scura:',
        'fa': u':تمجید_پوست_گندمی:',
        'id': ':mengangkat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':举双手_中等深肤色:'
    },
    u'\U0001F64C\U0001F3FC': { # 🙌🏼
        'en' : ':raising_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':zwei_erhobene_handflächen_mittelhelle_hautfarbe:',
        'es': ':manos_levantadas_celebrando_tono_de_piel_claro_medio:',
        'fr': u':mains_levées_peau_moyennement_claire:',
        'ja': u':バンザイ_やや薄い肌色:',
        'ko': u':만세_연한_갈색_피부:',
        'pt': u':mãos_para_cima_pele_morena_clara:',
        'it': ':mani_alzate_carnagione_abbastanza_chiara:',
        'fa': u':تمجید_پوست_روشن:',
        'id': ':mengangkat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':举双手_中等浅肤色:'
    },
    u'\U0001F64C\U0001F3FD': { # 🙌🏽
        'en' : ':raising_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':zwei_erhobene_handflächen_mittlere_hautfarbe:',
        'es': ':manos_levantadas_celebrando_tono_de_piel_medio:',
        'fr': u':mains_levées_peau_légèrement_mate:',
        'ja': u':バンザイ_中間の肌色:',
        'ko': u':만세_갈색_피부:',
        'pt': u':mãos_para_cima_pele_morena:',
        'it': ':mani_alzate_carnagione_olivastra:',
        'fa': u':تمجید_پوست_طلایی:',
        'id': ':mengangkat_tangan_warna_kulit_sedang:',
        'zh': u':举双手_中等肤色:'
    },
    u'\U0001F40F': { # 🐏
        'en' : ':ram:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':widder:',
        'es': ':carnero:',
        'fr': u':bélier:',
        'ja': u':牡羊:',
        'ko': u':숫양:',
        'pt': ':carneiro:',
        'it': ':montone:',
        'fa': u':قوچ:',
        'id': ':domba_jantan:',
        'zh': u':公羊:'
    },
    u'\U0001F400': { # 🐀
        'en' : ':rat:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':ratte:',
        'es': ':rata:',
        'fr': ':rat:',
        'ja': u':ネズミ:',
        'ko': u':쥐:',
        'pt': ':rato:',
        'it': ':ratto:',
        'fa': u':موش_صحرایی:',
        'id': ':tikus:',
        'zh': u':耗子:'
    },
    u'\U0001FA92': { # 🪒
        'en' : ':razor:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':rasierer:',
        'es': ':cuchilla_de_afeitar:',
        'fr': ':rasoir:',
        'ja': u':剃刀:',
        'ko': u':면도칼:',
        'pt': u':lâmina:',
        'it': ':rasoio:',
        'fa': u':ریش_تراش:',
        'id': ':pisau_cukur:',
        'zh': u':剃须刀:'
    },
    u'\U0001F9FE': { # 🧾
        'en' : ':receipt:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':beleg:',
        'es': ':recibo:',
        'fr': u':reçu:',
        'ja': u':レシート:',
        'ko': u':영수증:',
        'pt': ':recibo:',
        'it': ':scontrino:',
        'fa': u':رسید:',
        'id': ':kuitansi:',
        'zh': u':收据:'
    },
    u'\U000023FA\U0000FE0F': { # ⏺️
        'en' : ':record_button:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':black_circle_for_record:'],
        'variant': True,
        'de': ':aufnehmen:',
        'es': ':grabar:',
        'fr': ':bouton_enregistrer:',
        'ja': u':録音録画ボタン:',
        'ko': u':녹음_버튼:',
        'pt': u':botão_gravar:',
        'it': ':pulsante_di_registrazione:',
        'fa': u':دکمه_ضبط:',
        'id': ':tombol_rekam:',
        'zh': u':录制按钮:'
    },
    u'\U000023FA': { # ⏺
        'en' : ':record_button:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':black_circle_for_record:'],
        'variant': True,
        'de': ':aufnehmen:',
        'es': ':grabar:',
        'fr': ':bouton_enregistrer:',
        'ja': u':録音録画ボタン:',
        'ko': u':녹음_버튼:',
        'pt': u':botão_gravar:',
        'it': ':pulsante_di_registrazione:',
        'fa': u':دکمهٔ_ضبط:',
        'id': ':tombol_rekam:',
        'zh': u':录制按钮:'
    },
    u'\U0000267B\U0000FE0F': { # ♻️
        'en' : ':recycling_symbol:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':recycle:'],
        'variant': True,
        'de': ':recycling-symbol:',
        'es': u':símbolo_de_reciclaje:',
        'fr': ':symbole_recyclage:',
        'ja': u':リサイクルマーク:',
        'ko': u':재활용_표시:',
        'pt': u':símbolo_de_reciclagem:',
        'it': ':simbolo_del_riciclaggio:',
        'fa': u':نماد_بازیافت:',
        'id': ':simbol_daur_ulang:',
        'zh': u':回收标志:'
    },
    u'\U0000267B': { # ♻
        'en' : ':recycling_symbol:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':recycle:'],
        'variant': True,
        'de': ':recycling-symbol:',
        'es': u':símbolo_de_reciclaje:',
        'fr': ':symbole_recyclage:',
        'ja': u':リサイクルマーク:',
        'ko': u':재활용_표시:',
        'pt': u':símbolo_de_reciclagem:',
        'it': ':simbolo_del_riciclaggio:',
        'fa': u':نماد_بازیافت:',
        'id': ':simbol_daur_ulang:',
        'zh': u':回收标志:'
    },
    u'\U0001F34E': { # 🍎
        'en' : ':red_apple:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':apple:'],
        'de': ':roter_apfel:',
        'es': ':manzana_roja:',
        'fr': ':pomme_rouge:',
        'ja': u':赤リンゴ:',
        'ko': u':빨간_사과:',
        'pt': u':maçã_vermelha:',
        'it': ':mela_rossa:',
        'fa': u':سیب_سرخ:',
        'id': ':apel_merah:',
        'zh': u':红苹果:'
    },
    u'\U0001F534': { # 🔴
        'en' : ':red_circle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':roter_punkt:',
        'es': u':círculo_rojo:',
        'fr': ':disque_rouge:',
        'ja': u':赤い丸:',
        'ko': u':빨간_원:',
        'pt': u':círculo_vermelho:',
        'it': ':cerchio_rosso:',
        'fa': u':دایره_قرمز:',
        'id': ':lingkaran_merah:',
        'zh': u':红色圆:'
    },
    u'\U0001F9E7': { # 🧧
        'en' : ':red_envelope:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':roter_umschlag:',
        'es': ':sobre_rojo:',
        'fr': ':enveloppe_rouge:',
        'ja': u':赤い封筒:',
        'ko': u':세뱃돈:',
        'pt': ':envelope_vermelho:',
        'it': ':busta_hongbao:',
        'fa': u':پاکت_سرخ:',
        'id': ':amplop_merah:',
        'zh': u':红包:'
    },
    u'\U00002757': { # ❗
        'en' : ':red_exclamation_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heavy_exclamation_mark:', ':exclamation:'],
        'variant': True,
        'de': ':rotes_ausrufezeichen:',
        'es': u':exclamación_roja:',
        'fr': u':point_d’exclamation_rouge:',
        'ja': u':赤い感嘆符:',
        'ko': u':빨간색_느낌표:',
        'pt': u':ponto_de_exclamação_vermelho:',
        'it': ':punto_esclamativo_rosso:',
        'fa': u':علامت_تعجب_قرمز:',
        'id': ':tanda_seru_merah:',
        'zh': u':红色感叹号:'
    },
    u'\U0001F9B0': { # 🦰
        'en' : ':red_hair:',
        'status' : component,
        'E' : 11,
        'de': ':rotes_haar:',
        'es': ':pelo_pelirrojo:',
        'fr': ':cheveux_roux:',
        'ja': u':赤毛:',
        'ko': u':빨간_머리:',
        'pt': ':cabelo_vermelho:',
        'it': ':capelli_rossi:',
        'fa': u':موقرمز:',
        'id': ':rambut_merah:',
        'zh': u':红发:'
    },
    u'\U00002764\U0000FE0F': { # ❤️
        'en' : ':red_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heart:'],
        'variant': True,
        'de': ':rotes_herz:',
        'es': u':corazón_rojo:',
        'fr': u':cœur_rouge:',
        'ja': u':赤いハート:',
        'ko': u':빨간색_하트:',
        'pt': u':coração_vermelho:',
        'it': ':cuore_rosso:',
        'fa': u':قلب_قرمز:',
        'id': ':hati_merah:',
        'zh': u':红心:'
    },
    u'\U00002764': { # ❤
        'en' : ':red_heart:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':heart:'],
        'variant': True,
        'de': ':rotes_herz:',
        'es': u':corazón_rojo:',
        'fr': u':cœur_rouge:',
        'ja': u':赤いハート:',
        'ko': u':빨간색_하트:',
        'pt': u':coração_vermelho:',
        'it': ':cuore_rosso:',
        'fa': u':قلب_قرمز:',
        'id': ':hati_merah:',
        'zh': u':红心:'
    },
    u'\U0001F3EE': { # 🏮
        'en' : ':red_paper_lantern:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':izakaya_lantern:', ':lantern:'],
        'de': ':rote_papierlaterne:',
        'es': u':lámpara_japonesa:',
        'fr': ':lampion_rouge:',
        'ja': u':赤ちょうちん:',
        'ko': u':일본식_등:',
        'pt': ':lanterna_vermelha_de_papel:',
        'it': ':lanterna_rossa:',
        'fa': u':فانوس_کاغذی_قرمز:',
        'id': ':lampion_merah:',
        'zh': u':红灯笼:'
    },
    u'\U00002753': { # ❓
        'en' : ':red_question_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':question:'],
        'variant': True,
        'de': ':rotes_fragezeichen:',
        'es': u':interrogación_roja:',
        'fr': u':point_d’interrogation_rouge:',
        'ja': u':赤い疑問符:',
        'ko': u':빨간색_물음표:',
        'pt': u':ponto_de_interrogação_vermelho:',
        'it': ':punto_interrogativo_rosso:',
        'fa': u':علامت_سؤال_قرمز:',
        'id': ':tanda_tanya_merah:',
        'zh': u':红色问号:'
    },
    u'\U0001F7E5': { # 🟥
        'en' : ':red_square:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':rotes_quadrat:',
        'es': ':cuadrado_rojo:',
        'fr': u':carré_rouge:',
        'ja': u':赤い四角:',
        'ko': u':빨간색_사각형:',
        'pt': ':quadrado_vermelho:',
        'it': ':quadrato_rosso:',
        'fa': u':مربع_سرخ:',
        'id': ':persegi_merah:',
        'zh': u':红色方块:'
    },
    u'\U0001F53B': { # 🔻
        'en' : ':red_triangle_pointed_down:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':small_red_triangle_down:'],
        'de': ':rotes_dreieck_mit_der_spitze_nach_unten:',
        'es': u':triángulo_rojo_hacia_abajo:',
        'fr': ':triangle_rouge_pointant_vers_le_bas:',
        'ja': u':赤い下三角:',
        'ko': u':빨간색_아래쪽_삼각형:',
        'pt': u':triângulo_vermelho_para_baixo:',
        'it': ':triangolo_rosso_con_punta_verso_il_basso:',
        'fa': u':مثلث_با_رأس_پایین:',
        'id': ':segitiga_merah_mengarah_ke_bawah:',
        'zh': u':红色倒三角:'
    },
    u'\U0001F53A': { # 🔺
        'en' : ':red_triangle_pointed_up:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':small_red_triangle:'],
        'de': ':rotes_dreieck_mit_der_spitze_nach_oben:',
        'es': u':triángulo_rojo_hacia_arriba:',
        'fr': ':triangle_rouge_pointant_vers_le_haut:',
        'ja': u':赤い上三角:',
        'ko': u':빨간색_위쪽_삼각형:',
        'pt': u':triângulo_vermelho_para_cima:',
        'it': u':triangolo_rosso_con_punta_verso_l’alto:',
        'fa': u':مثلث_با_رأس_بالا:',
        'id': ':segitiga_merah_mengarah_ke_atas:',
        'zh': u':红色正三角:'
    },
    u'\U000000AE\U0000FE0F': { # ®️
        'en' : ':registered:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':registered-trademark:',
        'es': ':marca_registrada:',
        'fr': u':marque_déposée:',
        'ja': u':登録商標マーク:',
        'ko': u':등록상표:',
        'pt': u':símbolo_de_registrado:',
        'it': ':marchio_registrato:',
        'fa': u':نشان_تجاری_ثبت_شده:',
        'id': ':terdaftar:',
        'zh': u':注册:'
    },
    u'\U000000AE': { # ®
        'en' : ':registered:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':registered-trademark:',
        'es': ':marca_registrada:',
        'fr': u':marque_déposée:',
        'ja': u':登録商標マーク:',
        'ko': u':등록상표:',
        'pt': u':símbolo_de_registrado:',
        'it': ':marchio_registrato:',
        'fa': u':نشان_تجاری_ثبت_شده:',
        'id': ':terdaftar:',
        'zh': u':注册:'
    },
    u'\U0001F60C': { # 😌
        'en' : ':relieved_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':relieved:'],
        'de': ':erleichtertes_gesicht:',
        'es': ':cara_de_alivio:',
        'fr': u':visage_soulagé:',
        'ja': u':ほっとした顔:',
        'ko': u':안심한_얼굴:',
        'pt': ':rosto_aliviado:',
        'it': ':faccina_sollevata:',
        'fa': u':آسوده_خاطر:',
        'id': ':wajah_lega:',
        'zh': u':松了口气:'
    },
    u'\U0001F397\U0000FE0F': { # 🎗️
        'en' : ':reminder_ribbon:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':gedenkschleife:',
        'es': ':lazo_conmemorativo:',
        'fr': u':ruban_de_mémoire:',
        'ja': u':リマインダーリボン:',
        'ko': u':추모_리본:',
        'pt': ':fita_de_lembrete:',
        'it': ':nastro:',
        'fa': u':روبان_یادآوری:',
        'id': ':pita_pengingat:',
        'zh': u':提示丝带:'
    },
    u'\U0001F397': { # 🎗
        'en' : ':reminder_ribbon:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':gedenkschleife:',
        'es': ':lazo_conmemorativo:',
        'fr': u':ruban_de_mémoire:',
        'ja': u':リマインダーリボン:',
        'ko': u':추모_리본:',
        'pt': ':fita_de_lembrete:',
        'it': ':nastro:',
        'fa': u':روبان_یادآوری:',
        'id': ':pita_pengingat:',
        'zh': u':提示丝带:'
    },
    u'\U0001F501': { # 🔁
        'en' : ':repeat_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':repeat:'],
        'de': ':wiederholen:',
        'es': ':repetir:',
        'fr': u':bouton_répétition:',
        'ja': u':リピートボタン:',
        'ko': u':전곡_반복_재생:',
        'pt': u':botão_de_repetir:',
        'it': ':pulsante_di_ripetizione_della_riproduzione:',
        'fa': u':دکمهٔ_تکرار:',
        'id': ':tombol_ulangi:',
        'zh': u':重复按钮:'
    },
    u'\U0001F502': { # 🔂
        'en' : ':repeat_single_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':repeat_one:'],
        'de': ':titel_wiederholen:',
        'es': ':repetir_una_vez:',
        'fr': u':bouton_répétition_de_la_piste:',
        'ja': u':1曲リピートボタン:',
        'ko': u':한_곡_반복_재생:',
        'pt': u':botão_de_repetir_uma_única_faixa:',
        'it': ':pulsante_di_ripetizione_della_riproduzione_di_una_traccia:',
        'fa': u':دکمهٔ_یک_بار_تکرار:',
        'id': ':tombol_ulangi_satu_lagu:',
        'zh': u':重复一次按钮:'
    },
    u'\U000026D1\U0000FE0F': { # ⛑️
        'en' : u':rescue_worker’s_helmet:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':helmet_with_white_cross:', ':rescue_worker_helmet:'],
        'variant': True,
        'de': ':rettungshelm:',
        'es': ':casco_con_una_cruz_blanca:',
        'fr': ':casque_de_secouriste:',
        'ja': u':白十字ヘルメット:',
        'ko': u':흰_십자가가_있는_헬멧:',
        'pt': ':capacacete_de_socorrista:',
        'it': ':elmetto_con_croce_bianca:',
        'fa': u':کلاه_صلیب_سرخ:',
        'id': ':helm_dengan_palang_putih:',
        'zh': u':白十字头盔:'
    },
    u'\U000026D1': { # ⛑
        'en' : u':rescue_worker’s_helmet:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':helmet_with_white_cross:', ':rescue_worker_helmet:'],
        'variant': True,
        'de': ':rettungshelm:',
        'es': ':casco_con_una_cruz_blanca:',
        'fr': ':casque_de_secouriste:',
        'ja': u':白十字ヘルメット:',
        'ko': u':흰_십자가가_있는_헬멧:',
        'pt': ':capacacete_de_socorrista:',
        'it': ':elmetto_con_croce_bianca:',
        'fa': u':کلاه_صلیب_سرخ:',
        'id': ':helm_dengan_palang_putih:',
        'zh': u':白十字头盔:'
    },
    u'\U0001F6BB': { # 🚻
        'en' : ':restroom:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':toiletten:',
        'es': u':señal_de_aseos:',
        'fr': ':panneau_toilettes:',
        'ja': u':トイレ:',
        'ko': u':화장실:',
        'pt': ':banheiro:',
        'it': ':simbolo_dei_servizi_igienici:',
        'fa': u':توالت_عمومی:',
        'id': ':kamar_kecil:',
        'zh': u':卫生间:'
    },
    u'\U000025C0\U0000FE0F': { # ◀️
        'en' : ':reverse_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_backward:'],
        'variant': True,
        'de': u':pfeil_zurück:',
        'es': ':retroceso:',
        'fr': ':bouton_retour:',
        'ja': u':逆再生ボタン:',
        'ko': u':반대로_버튼:',
        'pt': u':botão_de_voltar:',
        'it': ':pulsante_di_riavvolgimento:',
        'fa': u':دکمه_برگرداندن:',
        'id': ':tombol_mundur:',
        'zh': u':倒退按钮:'
    },
    u'\U000025C0': { # ◀
        'en' : ':reverse_button:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_backward:'],
        'variant': True,
        'de': u':pfeil_zurück:',
        'es': ':retroceso:',
        'fr': ':bouton_retour:',
        'ja': u':逆再生ボタン:',
        'ko': u':반대로_버튼:',
        'pt': u':botão_de_voltar:',
        'it': ':pulsante_di_riavvolgimento:',
        'fa': u':دکمهٔ_برگرداندن:',
        'id': ':tombol_mundur:',
        'zh': u':倒退按钮:'
    },
    u'\U0001F49E': { # 💞
        'en' : ':revolving_hearts:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kreisende_herzen:',
        'es': ':corazones_giratorios:',
        'fr': u':cœurs_qui_tournent:',
        'ja': u':回転するハート:',
        'ko': u':회전하는_하트:',
        'pt': u':corações_girando:',
        'it': ':cuori_che_girano:',
        'fa': u':قلب_چرخان:',
        'id': ':hati_berputar:',
        'zh': u':舞动的心:'
    },
    u'\U0001F98F': { # 🦏
        'en' : ':rhinoceros:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':nashorn:',
        'es': ':rinoceronte:',
        'fr': u':rhinocéros:',
        'ja': u':サイ:',
        'ko': u':코뿔소:',
        'pt': ':rinoceronte:',
        'it': ':rinoceronte:',
        'fa': u':کرگدن:',
        'id': ':badak:',
        'zh': u':犀牛:'
    },
    u'\U0001F380': { # 🎀
        'en' : ':ribbon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':pinke_schleife:',
        'es': ':lazo:',
        'fr': ':ruban:',
        'ja': u':リボン:',
        'ko': u':리본:',
        'pt': u':laço_de_fita:',
        'it': ':fiocco:',
        'fa': u':روبان:',
        'id': ':pita:',
        'zh': u':蝴蝶结:'
    },
    u'\U0001F359': { # 🍙
        'en' : ':rice_ball:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':reisbällchen:',
        'es': ':bola_de_arroz:',
        'fr': ':boulette_de_riz:',
        'ja': u':おにぎり:',
        'ko': u':삼각_김밥:',
        'pt': u':arroz_japonês:',
        'it': ':onigiri:',
        'fa': u':کوفته_برنجی:',
        'id': ':nasi_kepal:',
        'zh': u':饭团:'
    },
    u'\U0001F358': { # 🍘
        'en' : ':rice_cracker:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':reiscracker:',
        'es': ':galleta_de_arroz:',
        'fr': ':galette_de_riz:',
        'ja': u':せんべい:',
        'ko': u':주먹밥:',
        'pt': ':biscoito_de_arroz:',
        'it': ':galletta_di_riso:',
        'fa': u':تردک_برنجی:',
        'id': ':kerupuk_beras:',
        'zh': u':米饼:'
    },
    u'\U0001F91C': { # 🤜
        'en' : ':right-facing_fist:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':fist_right:'],
        'de': ':faust_nach_rechts:',
        'es': u':puño_hacia_la_derecha:',
        'fr': u':poing_à_droite:',
        'ja': u':右向きのこぶし:',
        'ko': u':오른쪽을_향하는_주먹:',
        'pt': ':punho_direito:',
        'it': ':pugno_a_destra:',
        'fa': u':مشت_به_راست:',
        'id': ':tinju_kanan:',
        'zh': u':朝右的拳头:'
    },
    u'\U0001F91C\U0001F3FF': { # 🤜🏿
        'en' : ':right-facing_fist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_rechts_dunkle_hautfarbe:',
        'es': u':puño_hacia_la_derecha_tono_de_piel_oscuro:',
        'fr': u':poing_à_droite_peau_foncée:',
        'ja': u':右向きのこぶし_濃い肌色:',
        'ko': u':오른쪽을_향하는_주먹_검은색_피부:',
        'pt': ':punho_direito_pele_escura:',
        'it': ':pugno_a_destra_carnagione_scura:',
        'fa': u':مشت_به_راست_پوست_آبنوسی:',
        'id': ':tinju_kanan_warna_kulit_gelap:',
        'zh': u':朝右的拳头_较深肤色:'
    },
    u'\U0001F91C\U0001F3FB': { # 🤜🏻
        'en' : ':right-facing_fist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_rechts_helle_hautfarbe:',
        'es': u':puño_hacia_la_derecha_tono_de_piel_claro:',
        'fr': u':poing_à_droite_peau_claire:',
        'ja': u':右向きのこぶし_薄い肌色:',
        'ko': u':오른쪽을_향하는_주먹_하얀_피부:',
        'pt': ':punho_direito_pele_clara:',
        'it': ':pugno_a_destra_carnagione_chiara:',
        'fa': u':مشت_به_راست_پوست_سفید:',
        'id': ':tinju_kanan_warna_kulit_cerah:',
        'zh': u':朝右的拳头_较浅肤色:'
    },
    u'\U0001F91C\U0001F3FE': { # 🤜🏾
        'en' : ':right-facing_fist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_rechts_mitteldunkle_hautfarbe:',
        'es': u':puño_hacia_la_derecha_tono_de_piel_oscuro_medio:',
        'fr': u':poing_à_droite_peau_mate:',
        'ja': u':右向きのこぶし_やや濃い肌色:',
        'ko': u':오른쪽을_향하는_주먹_진한_갈색_피부:',
        'pt': ':punho_direito_pele_morena_escura:',
        'it': ':pugno_a_destra_carnagione_abbastanza_scura:',
        'fa': u':مشت_به_راست_پوست_گندمی:',
        'id': ':tinju_kanan_warna_kulit_gelap-sedang:',
        'zh': u':朝右的拳头_中等深肤色:'
    },
    u'\U0001F91C\U0001F3FC': { # 🤜🏼
        'en' : ':right-facing_fist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_rechts_mittelhelle_hautfarbe:',
        'es': u':puño_hacia_la_derecha_tono_de_piel_claro_medio:',
        'fr': u':poing_à_droite_peau_moyennement_claire:',
        'ja': u':右向きのこぶし_やや薄い肌色:',
        'ko': u':오른쪽을_향하는_주먹_연한_갈색_피부:',
        'pt': ':punho_direito_pele_morena_clara:',
        'it': ':pugno_a_destra_carnagione_abbastanza_chiara:',
        'fa': u':مشت_به_راست_پوست_روشن:',
        'id': ':tinju_kanan_warna_kulit_cerah-sedang:',
        'zh': u':朝右的拳头_中等浅肤色:'
    },
    u'\U0001F91C\U0001F3FD': { # 🤜🏽
        'en' : ':right-facing_fist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':faust_nach_rechts_mittlere_hautfarbe:',
        'es': u':puño_hacia_la_derecha_tono_de_piel_medio:',
        'fr': u':poing_à_droite_peau_légèrement_mate:',
        'ja': u':右向きのこぶし_中間の肌色:',
        'ko': u':오른쪽을_향하는_주먹_갈색_피부:',
        'pt': ':punho_direito_pele_morena:',
        'it': ':pugno_a_destra_carnagione_olivastra:',
        'fa': u':مشت_به_راست_پوست_طلایی:',
        'id': ':tinju_kanan_warna_kulit_sedang:',
        'zh': u':朝右的拳头_中等肤色:'
    },
    u'\U0001F5EF\U0000FE0F': { # 🗯️
        'en' : ':right_anger_bubble:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': u':sprechblase_für_wütende_aussage_rechts:',
        'es': ':bocadillo_de_enfado_por_la_derecha:',
        'fr': u':bulle_colère_droite:',
        'ja': u':怒りの吹き出し:',
        'ko': u':화난_표현의_오른쪽_말풍선:',
        'pt': u':balão_de_raiva_à_direita:',
        'it': ':nuvoletta_rabbia:',
        'fa': u':حباب_خشم_راست:',
        'id': ':gelembung_marah_kanan:',
        'zh': u':愤怒话语气泡:'
    },
    u'\U0001F5EF': { # 🗯
        'en' : ':right_anger_bubble:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': u':sprechblase_für_wütende_aussage_rechts:',
        'es': ':bocadillo_de_enfado_por_la_derecha:',
        'fr': u':bulle_colère_droite:',
        'ja': u':怒りの吹き出し:',
        'ko': u':화난_표현의_오른쪽_말풍선:',
        'pt': u':balão_de_raiva_à_direita:',
        'it': ':nuvoletta_rabbia:',
        'fa': u':حباب_خشم_راست:',
        'id': ':gelembung_marah_kanan:',
        'zh': u':愤怒话语气泡:'
    },
    u'\U000027A1\U0000FE0F': { # ➡️
        'en' : ':right_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_right:'],
        'variant': True,
        'de': ':pfeil_nach_rechts:',
        'es': ':flecha_hacia_la_derecha:',
        'fr': u':flèche_droite:',
        'ja': u':右矢印:',
        'ko': u':우향_화살표:',
        'pt': ':seta_para_a_direita:',
        'it': ':freccia_rivolta_verso_destra:',
        'fa': u':پیکان_راست:',
        'id': ':tanda_panah_kanan:',
        'zh': u':向右箭头:'
    },
    u'\U000027A1': { # ➡
        'en' : ':right_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_right:'],
        'variant': True,
        'de': ':pfeil_nach_rechts:',
        'es': ':flecha_hacia_la_derecha:',
        'fr': u':flèche_droite:',
        'ja': u':右矢印:',
        'ko': u':우향_화살표:',
        'pt': ':seta_para_a_direita:',
        'it': ':freccia_rivolta_verso_destra:',
        'fa': u':پیکان_راست:',
        'id': ':tanda_panah_kanan:',
        'zh': u':向右箭头:'
    },
    u'\U00002935\U0000FE0F': { # ⤵️
        'en' : ':right_arrow_curving_down:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_heading_down:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_unten:',
        'es': u':flecha_derecha_curvándose_hacia_abajo:',
        'fr': u':flèche_courbe_bas:',
        'ja': u':下カーブ矢印:',
        'ko': u':아래쪽으로_꺾어지는_우향_화살표:',
        'pt': ':seta_para_a_direita_curvada_para_baixo:',
        'it': ':freccia_curva_in_basso:',
        'fa': u':پیکان_خمیده_پایین_راست:',
        'id': ':tanda_panah_kanan_melengkung_ke_bawah:',
        'zh': u':右下弯箭头:'
    },
    u'\U00002935': { # ⤵
        'en' : ':right_arrow_curving_down:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_heading_down:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_unten:',
        'es': u':flecha_derecha_curvándose_hacia_abajo:',
        'fr': u':flèche_courbe_bas:',
        'ja': u':下カーブ矢印:',
        'ko': u':아래쪽으로_꺾어지는_우향_화살표:',
        'pt': ':seta_para_a_direita_curvada_para_baixo:',
        'it': ':freccia_curva_in_basso:',
        'fa': u':پیکان_خمیده_پایین_راست:',
        'id': ':tanda_panah_kanan_melengkung_ke_bawah:',
        'zh': u':右下弯箭头:'
    },
    u'\U000021A9\U0000FE0F': { # ↩️
        'en' : ':right_arrow_curving_left:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':leftwards_arrow_with_hook:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_links:',
        'es': u':flecha_derecha_curvándose_a_la_izquierda:',
        'fr': u':flèche_courbe_gauche:',
        'ja': u':右カーブ矢印:',
        'ko': u':왼쪽으로_꺾어지는_우향_화살표:',
        'pt': ':seta_curva_da_direita_para_a_esquerda:',
        'it': ':freccia_curva_a_sinistra:',
        'fa': u':پیکان_خمیده_راست:',
        'id': ':tanda_panah_kanan_melengkung_ke_kiri:',
        'zh': u':右转弯箭头:'
    },
    u'\U000021A9': { # ↩
        'en' : ':right_arrow_curving_left:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':leftwards_arrow_with_hook:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_links:',
        'es': u':flecha_derecha_curvándose_a_la_izquierda:',
        'fr': u':flèche_courbe_gauche:',
        'ja': u':右カーブ矢印:',
        'ko': u':왼쪽으로_꺾어지는_우향_화살표:',
        'pt': ':seta_curva_da_direita_para_a_esquerda:',
        'it': ':freccia_curva_a_sinistra:',
        'fa': u':پیکان_خمیده_راست:',
        'id': ':tanda_panah_kanan_melengkung_ke_kiri:',
        'zh': u':右转弯箭头:'
    },
    u'\U00002934\U0000FE0F': { # ⤴️
        'en' : ':right_arrow_curving_up:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_heading_up:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_oben:',
        'es': u':flecha_derecha_curvándose_hacia_arriba:',
        'fr': u':flèche_courbe_haut:',
        'ja': u':上カーブ矢印:',
        'ko': u':위쪽으로_꺾어지는_우향_화살표:',
        'pt': ':seta_para_a_direita_curvada_para_cima:',
        'it': ':freccia_curva_in_alto:',
        'fa': u':پیکان_خمیده_بالا_راست:',
        'id': ':tanda_panah_kanan_melengkung_ke_atas:',
        'zh': u':右上弯箭头:'
    },
    u'\U00002934': { # ⤴
        'en' : ':right_arrow_curving_up:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_heading_up:'],
        'variant': True,
        'de': ':geschwungener_pfeil_nach_oben:',
        'es': u':flecha_derecha_curvándose_hacia_arriba:',
        'fr': u':flèche_courbe_haut:',
        'ja': u':上カーブ矢印:',
        'ko': u':위쪽으로_꺾어지는_우향_화살표:',
        'pt': ':seta_para_a_direita_curvada_para_cima:',
        'it': ':freccia_curva_in_alto:',
        'fa': u':پیکان_خمیده_بالا_راست:',
        'id': ':tanda_panah_kanan_melengkung_ke_atas:',
        'zh': u':右上弯箭头:'
    },
    u'\U0001FAF1': { # 🫱
        'en' : ':rightwards_hand:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':nach_rechts_weisende_hand:',
        'es': ':mano_hacia_la_derecha:',
        'fr': ':main_vers_la_droite:',
        'ja': u':右に向けた手:',
        'ko': u':오른쪽으로_향하는_손등:',
        'pt': u':mão_para_a_direita:',
        'it': ':mano_rivolta_a_destra:',
        'fa': u':دست_به_سمت_راست:',
        'id': ':tangan_menghadap_kanan:',
        'zh': u':向右的手:'
    },
    u'\U0001FAF1\U0001F3FF': { # 🫱🏿
        'en' : ':rightwards_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FB': { # 🫱🏻
        'en' : ':rightwards_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FE': { # 🫱🏾
        'en' : ':rightwards_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FC': { # 🫱🏼
        'en' : ':rightwards_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF1\U0001F3FD': { # 🫱🏽
        'en' : ':rightwards_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 14
    },
    u'\U0001FAF8': { # 🫸
        'en' : ':rightwards_pushing_hand:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':nach_rechts_schiebende_hand:',
        'es': ':mano_empujando_hacia_la_derecha:',
        'fr': ':main_qui_pousse_vers_la_droite:',
        'ja': u':右向きに押している手:',
        'ko': u':오른쪽으로_밀치는_손:',
        'pt': u':mão_empurrando_para_a_direita:',
        'it': ':mano_che_spinge_a_destra:',
        'fa': u':دست_فشاردهنده_به_سمت_راست:',
        'id': ':tangan_mendorong_ke_kanan:',
        'zh': u':向右推:'
    },
    u'\U0001FAF8\U0001F3FF': { # 🫸🏿
        'en' : ':rightwards_pushing_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF8\U0001F3FB': { # 🫸🏻
        'en' : ':rightwards_pushing_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF8\U0001F3FE': { # 🫸🏾
        'en' : ':rightwards_pushing_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF8\U0001F3FC': { # 🫸🏼
        'en' : ':rightwards_pushing_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001FAF8\U0001F3FD': { # 🫸🏽
        'en' : ':rightwards_pushing_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 15
    },
    u'\U0001F48D': { # 💍
        'en' : ':ring:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':ring:',
        'es': ':anillo:',
        'fr': ':bague:',
        'ja': u':指輪:',
        'ko': u':반지:',
        'pt': ':anel:',
        'it': ':anello:',
        'fa': u':حلقه:',
        'id': ':cincin:',
        'zh': u':戒指:'
    },
    u'\U0001F6DF': { # 🛟
        'en' : ':ring_buoy:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':rettungsring:',
        'es': ':salvavidas:',
        'fr': u':bouée_de_sauvetage:',
        'ja': u':救命浮環:',
        'ko': u':구명부환:',
        'pt': ':boia:',
        'it': ':salvagente:',
        'fa': u':حلقه_نجات:',
        'id': ':ban_pelampung:',
        'zh': u':救生圈:'
    },
    u'\U0001FA90': { # 🪐
        'en' : ':ringed_planet:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':ringplanet:',
        'es': ':planeta_con_anillos:',
        'fr': u':planète_à_anneaux:',
        'ja': u':環のある惑星:',
        'ko': u':고리가_있는_행성:',
        'pt': u':planeta_com_anéis:',
        'it': ':pianeta_con_satellite:',
        'fa': u':سیاره_حلقه_دار:',
        'id': ':planet_bercincin:',
        'zh': u':有环行星:'
    },
    u'\U0001F360': { # 🍠
        'en' : ':roasted_sweet_potato:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sweet_potato:'],
        'de': u':geröstete_süßkartoffel:',
        'es': ':patata_asada:',
        'fr': ':patate_douce:',
        'ja': u':焼き芋:',
        'ko': u':고구마:',
        'pt': ':batata_assada:',
        'it': ':patata_dolce_arrosto:',
        'fa': u':سیب_زمینی_شیرین_کباب_شده:',
        'id': ':ubi_panggang:',
        'zh': u':烤红薯:'
    },
    u'\U0001F916': { # 🤖
        'en' : ':robot:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':robot_face:'],
        'de': ':roboter:',
        'es': ':robot:',
        'fr': ':robot:',
        'ja': u':ロボット:',
        'ko': u':로봇_얼굴:',
        'pt': u':rosto_de_robô:',
        'it': ':faccina_di_robot:',
        'fa': u':روبات:',
        'id': ':robot:',
        'zh': u':机器人:'
    },
    u'\U0001FAA8': { # 🪨
        'en' : ':rock:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':felsen:',
        'es': ':piedra:',
        'fr': ':rocher:',
        'ja': u':岩石:',
        'ko': u':바위:',
        'pt': ':pedra:',
        'it': ':roccia:',
        'fa': u':صخره:',
        'id': ':batu:',
        'zh': u':岩石:'
    },
    u'\U0001F680': { # 🚀
        'en' : ':rocket:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':rakete:',
        'es': ':cohete:',
        'fr': u':fusée:',
        'ja': u':ロケット:',
        'ko': u':로켓:',
        'pt': ':foguete:',
        'it': ':razzo:',
        'fa': u':موشک:',
        'id': ':roket:',
        'zh': u':火箭:'
    },
    u'\U0001F9FB': { # 🧻
        'en' : ':roll_of_paper:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':küchenrolle:',
        'es': ':rollo_de_papel:',
        'fr': ':rouleau_de_papier:',
        'ja': u':トイレットペーパー:',
        'ko': u':두루마리:',
        'pt': ':rolo_de_papel:',
        'it': ':rotolo_di_carta_igienica:',
        'fa': u':رول_کاغذ:',
        'id': ':gulungan_kertas:',
        'zh': u':卷纸:'
    },
    u'\U0001F5DE\U0000FE0F': { # 🗞️
        'en' : ':rolled-up_newspaper:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':rolled__up_newspaper:', ':newspaper_roll:'],
        'variant': True,
        'de': ':zusammengerollte_zeitung:',
        'es': u':periódico_enrollado:',
        'fr': u':journal_roulé:',
        'ja': u':丸めた新聞:',
        'ko': u':돌돌_말린_신문:',
        'pt': ':jornal_enrolado:',
        'it': ':quotidiano_arrotolato:',
        'fa': u':رول_روزنامه:',
        'id': ':gulungan_koran:',
        'zh': u':报纸卷:'
    },
    u'\U0001F5DE': { # 🗞
        'en' : ':rolled-up_newspaper:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':rolled__up_newspaper:', ':newspaper_roll:'],
        'variant': True,
        'de': ':zusammengerollte_zeitung:',
        'es': u':periódico_enrollado:',
        'fr': u':journal_roulé:',
        'ja': u':丸めた新聞:',
        'ko': u':돌돌_말린_신문:',
        'pt': ':jornal_enrolado:',
        'it': ':quotidiano_arrotolato:',
        'fa': u':رول_روزنامه:',
        'id': ':gulungan_koran:',
        'zh': u':报纸卷:'
    },
    u'\U0001F3A2': { # 🎢
        'en' : ':roller_coaster:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':achterbahn:',
        'es': u':montaña_rusa:',
        'fr': ':montagnes_russes:',
        'ja': u':ジェットコースター:',
        'ko': u':롤러코스터:',
        'pt': ':montanha_russa:',
        'it': ':montagne_russe:',
        'fa': u':ترن_هوایی:',
        'id': ':roller_coaster:',
        'zh': u':过山车:'
    },
    u'\U0001F6FC': { # 🛼
        'en' : ':roller_skate:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':rollschuh:',
        'es': ':patines:',
        'fr': u':patin_à_roulettes:',
        'ja': u':ローラースケート:',
        'ko': u':롤러스케이트:',
        'pt': ':patins_de_rodas:',
        'it': ':pattini_a_rotelle:',
        'fa': u':کفش_اسکیت:',
        'id': ':sepatu_roda:',
        'zh': u':四轮滑冰鞋:'
    },
    u'\U0001F923': { # 🤣
        'en' : ':rolling_on_the_floor_laughing:',
        'status' : fully_qualified,
        'E' : 3,
        'alias' : [':rofl:'],
        'de': u':sich_vor_lachen_auf_dem_boden_wälzen:',
        'es': u':cara_revolviéndose_de_la_risa:',
        'fr': ':se_rouler_par_terre_de_rire:',
        'ja': u':笑い転げる:',
        'ko': u':바닥을_구르며_웃는_얼굴:',
        'pt': u':rolando_no_chão_de_rir:',
        'it': ':ridere_a_crepapelle:',
        'fa': u':از_خنده_غش_کردن:',
        'id': ':tertawa_terbahak-bahak:',
        'zh': u':笑得满地打滚:'
    },
    u'\U0001F413': { # 🐓
        'en' : ':rooster:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':hahn:',
        'es': ':gallo:',
        'fr': ':coq:',
        'ja': u':おんどり:',
        'ko': u':수탉:',
        'pt': ':galo:',
        'it': ':gallo:',
        'fa': u':خروس:',
        'id': ':ayam_jago:',
        'zh': u':公鸡:'
    },
    u'\U0001F339': { # 🌹
        'en' : ':rose:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':rose:',
        'es': ':rosa:',
        'fr': ':rose:',
        'ja': u':バラ:',
        'ko': u':장미꽃:',
        'pt': ':rosa:',
        'it': ':rosa:',
        'fa': u':رز:',
        'id': ':mawar:',
        'zh': u':玫瑰:'
    },
    u'\U0001F3F5\U0000FE0F': { # 🏵️
        'en' : ':rosette:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':rosette:',
        'es': ':roseta:',
        'fr': ':rosette:',
        'ja': u':花飾り:',
        'ko': u':장미:',
        'pt': ':roseta:',
        'it': ':rosetta:',
        'fa': u':گل_رزت:',
        'id': ':hiasan_mawar:',
        'zh': u':圆形花饰:'
    },
    u'\U0001F3F5': { # 🏵
        'en' : ':rosette:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':rosette:',
        'es': ':roseta:',
        'fr': ':rosette:',
        'ja': u':花飾り:',
        'ko': u':장미:',
        'pt': ':roseta:',
        'it': ':rosetta:',
        'fa': u':گل_رزت:',
        'id': ':hiasan_mawar:',
        'zh': u':圆形花饰:'
    },
    u'\U0001F4CD': { # 📍
        'en' : ':round_pushpin:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':stecknadel:',
        'es': ':chincheta_redonda:',
        'fr': u':épingle:',
        'ja': u':丸い押しピン:',
        'ko': u':둥근_머리_핀:',
        'pt': ':tacha_redonda:',
        'it': ':puntina_arrotondata:',
        'fa': u':سنجاق_ته_گرد:',
        'id': ':paku_penanda_bulat:',
        'zh': u':圆图钉:'
    },
    u'\U0001F3C9': { # 🏉
        'en' : ':rugby_football:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':rugbyball:',
        'es': u':balón_de_rugby:',
        'fr': ':rugby:',
        'ja': u':ラグビー:',
        'ko': u':럭비공:',
        'pt': ':bola_de_rugby:',
        'it': ':pallone_da_rugby:',
        'fa': u':راگبی:',
        'id': ':sepak_bola_rugbi:',
        'zh': u':英式橄榄球:'
    },
    u'\U0001F3BD': { # 🎽
        'en' : ':running_shirt:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':running_shirt_with_sash:'],
        'de': ':laufshirt:',
        'es': ':camiseta_sin_mangas:',
        'fr': ':maillot_de_course:',
        'ja': u':長距離走:',
        'ko': u':러닝_셔츠:',
        'pt': ':camiseta_de_corrida:',
        'it': ':maglia_da_corsa:',
        'fa': u':لباس_دو:',
        'id': ':kaos_lari:',
        'zh': u':运动背心:'
    },
    u'\U0001F45F': { # 👟
        'en' : ':running_shoe:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':athletic_shoe:'],
        'de': ':sportschuh:',
        'es': ':zapatilla_deportiva:',
        'fr': ':chaussure_de_sport:',
        'ja': u':スニーカー:',
        'ko': u':운동화:',
        'pt': u':tênis_de_corrida:',
        'it': ':scarpa_sportiva:',
        'fa': u':کفش_دویدن:',
        'id': ':sepatu_lari:',
        'zh': u':跑鞋:'
    },
    u'\U0001F625': { # 😥
        'en' : ':sad_but_relieved_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':disappointed_relieved:'],
        'de': ':trauriges_aber_erleichtertes_gesicht:',
        'es': ':cara_triste_pero_aliviada:',
        'fr': u':visage_triste_mais_soulagé:',
        'ja': u':どうしよう:',
        'ko': u':실망했지만_안도하는_얼굴:',
        'pt': ':rosto_triste_mas_aliviado:',
        'it': ':faccina_delusa_ma_sollevata:',
        'fa': u':ناامید_اما_تسکین_یافته:',
        'id': ':wajah_kecewa_namun_lega:',
        'zh': u':失望但如释重负:'
    },
    u'\U0001F9F7': { # 🧷
        'en' : ':safety_pin:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':sicherheitsnadel:',
        'es': ':imperdible:',
        'fr': u':épingle_de_sûreté:',
        'ja': u':安全ピン:',
        'ko': u':옷핀:',
        'pt': u':alfinete_de_segurança:',
        'it': ':spilla_da_balia:',
        'fa': u':سنجاق_قفلی:',
        'id': ':peniti:',
        'zh': u':安全别针:'
    },
    u'\U0001F9BA': { # 🦺
        'en' : ':safety_vest:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':sicherheitsweste:',
        'es': ':chaleco_de_seguridad:',
        'fr': u':gilet_de_sécurité:',
        'ja': u':安全ベスト:',
        'ko': u':구명조끼:',
        'pt': ':colete_salva-vidas:',
        'it': ':gilet_di_sicurezza:',
        'fa': u':جلیقه_ایمنی:',
        'id': ':rompi_pengaman:',
        'zh': u':救生衣:'
    },
    u'\U000026F5': { # ⛵
        'en' : ':sailboat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':boat:'],
        'variant': True,
        'de': ':segelboot:',
        'es': ':velero:',
        'fr': ':voilier:',
        'ja': u':ヨット:',
        'ko': u':돛단배:',
        'pt': ':barco_a_vela:',
        'it': ':barca_a_vela:',
        'fa': u':قایق_بادبانی:',
        'id': ':perahu_layar:',
        'zh': u':帆船:'
    },
    u'\U0001F376': { # 🍶
        'en' : ':sake:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':sake-flasche_mit_tasse:',
        'es': ':sake:',
        'fr': u':saké:',
        'ja': u':徳利:',
        'ko': u':사케:',
        'pt': u':saquê:',
        'it': u':sakè:',
        'fa': u':ساکی:',
        'id': ':sake:',
        'zh': u':清酒:'
    },
    u'\U0001F9C2': { # 🧂
        'en' : ':salt:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':salz:',
        'es': ':sal:',
        'fr': ':sel:',
        'ja': u':塩:',
        'ko': u':소금:',
        'pt': ':sal:',
        'it': ':sale:',
        'fa': u':نمک:',
        'id': ':garam:',
        'zh': u':盐:'
    },
    u'\U0001FAE1': { # 🫡
        'en' : ':saluting_face:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':salutierendes_gesicht:',
        'es': ':cara_saludando:',
        'fr': ':visage_qui_fait_un_salut_militaire:',
        'ja': u':敬礼する顔:',
        'ko': u':경례하는_얼굴:',
        'pt': ':rosto_saudando:',
        'it': ':faccina_che_fa_il_saluto:',
        'fa': u':چهره_سلام_کنان:',
        'id': ':wajah_memberi_hormat:',
        'zh': u':致敬:'
    },
    u'\U0001F96A': { # 🥪
        'en' : ':sandwich:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':sandwich:',
        'es': u':sándwich:',
        'fr': ':sandwich:',
        'ja': u':サンドイッチ:',
        'ko': u':샌드위치:',
        'pt': u':sanduíche:',
        'it': ':sandwich:',
        'fa': u':ساندویچ:',
        'id': ':roti_lapis:',
        'zh': u':三明治:'
    },
    u'\U0001F97B': { # 🥻
        'en' : ':sari:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':sari:',
        'es': ':sari:',
        'fr': ':sari:',
        'ja': u':サリー:',
        'ko': u':사리:',
        'pt': ':sari:',
        'it': ':sari:',
        'fa': u':ساری:',
        'id': ':sari:',
        'zh': u':纱丽:'
    },
    u'\U0001F6F0\U0000FE0F': { # 🛰️
        'en' : ':satellite:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':artificial_satellite:'],
        'variant': True,
        'de': ':satellit:',
        'es': u':satélite:',
        'fr': ':satellite:',
        'ja': u':人工衛星:',
        'ko': u':인공위성:',
        'pt': u':satélite:',
        'it': ':satellite:',
        'fa': u':ماهواره:',
        'id': ':satelit:',
        'zh': u':卫星:'
    },
    u'\U0001F6F0': { # 🛰
        'en' : ':satellite:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':artificial_satellite:'],
        'variant': True,
        'de': ':satellit:',
        'es': u':satélite:',
        'fr': ':satellite:',
        'ja': u':人工衛星:',
        'ko': u':인공위성:',
        'pt': u':satélite:',
        'it': ':satellite:',
        'fa': u':ماهواره:',
        'id': ':satelit:',
        'zh': u':卫星:'
    },
    u'\U0001F4E1': { # 📡
        'en' : ':satellite_antenna:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':satellite:'],
        'de': u':satellitenschüssel:',
        'es': u':antena_de_satélite:',
        'fr': ':antenne_satellite:',
        'ja': u':パラボラアンテナ:',
        'ko': u':위성_안테나:',
        'pt': u':antena_parabólica:',
        'it': ':antenna_satellitare:',
        'fa': u':آنتن_ماهواره:',
        'id': ':antena_satelit:',
        'zh': u':卫星天线:'
    },
    u'\U0001F995': { # 🦕
        'en' : ':sauropod:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':sauropode:',
        'es': u':saurópodo:',
        'fr': ':sauropode:',
        'ja': u':草食恐竜:',
        'ko': u':초식_공룡:',
        'pt': u':saurópode:',
        'it': ':sauropode:',
        'fa': u':سوسمار:',
        'id': ':sauropod:',
        'zh': u':蜥蜴类:'
    },
    u'\U0001F3B7': { # 🎷
        'en' : ':saxophone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':saxofon:',
        'es': u':saxofón:',
        'fr': ':saxophone:',
        'ja': u':サックス:',
        'ko': u':색소폰:',
        'pt': ':saxofone:',
        'it': ':sassofono:',
        'fa': u':ساکسیفون:',
        'id': ':saksofon:',
        'zh': u':萨克斯管:'
    },
    u'\U0001F9E3': { # 🧣
        'en' : ':scarf:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':schal:',
        'es': ':bufanda:',
        'fr': ':foulard:',
        'ja': u':マフラー:',
        'ko': u':스카프:',
        'pt': ':cachecol:',
        'it': ':sciarpa:',
        'fa': u':روسری:',
        'id': ':syal:',
        'zh': u':围巾:'
    },
    u'\U0001F3EB': { # 🏫
        'en' : ':school:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schule:',
        'es': ':colegio:',
        'fr': u':école:',
        'ja': u':学校:',
        'ko': u':학교:',
        'pt': ':escola:',
        'it': ':scuola:',
        'fa': u':مدرسه:',
        'id': ':sekolah:',
        'zh': u':学校:'
    },
    u'\U0001F9D1\U0000200D\U0001F52C': { # 🧑‍🔬
        'en' : ':scientist:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':wissenschaftler(in):',
        'es': ':profesional_de_la_ciencia:',
        'fr': ':scientifique:',
        'ja': u':科学者:',
        'ko': u':과학자:',
        'pt': ':cientista:',
        'it': ':persona_che_lavora_in_campo_scientifico:',
        'fa': u':دانشمند:',
        'id': ':ilmuwan:',
        'zh': u':科学家:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F52C': { # 🧑🏿‍🔬
        'en' : ':scientist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':wissenschaftler(in)_dunkle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_tono_de_piel_oscuro:',
        'fr': u':scientifique_peau_foncée:',
        'ja': u':科学者_濃い肌色:',
        'ko': u':과학자_검은색_피부:',
        'pt': ':cientista_pele_escura:',
        'it': ':persona_che_lavora_in_campo_scientifico_carnagione_scura:',
        'fa': u':دانشمند_پوست_آبنوسی:',
        'id': ':ilmuwan_warna_kulit_gelap:',
        'zh': u':科学家_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F52C': { # 🧑🏻‍🔬
        'en' : ':scientist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':wissenschaftler(in)_helle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_tono_de_piel_claro:',
        'fr': ':scientifique_peau_claire:',
        'ja': u':科学者_薄い肌色:',
        'ko': u':과학자_하얀_피부:',
        'pt': ':cientista_pele_clara:',
        'it': ':persona_che_lavora_in_campo_scientifico_carnagione_chiara:',
        'fa': u':دانشمند_پوست_سفید:',
        'id': ':ilmuwan_warna_kulit_cerah:',
        'zh': u':科学家_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F52C': { # 🧑🏾‍🔬
        'en' : ':scientist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':wissenschaftler(in)_mitteldunkle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_tono_de_piel_oscuro_medio:',
        'fr': ':scientifique_peau_mate:',
        'ja': u':科学者_やや濃い肌色:',
        'ko': u':과학자_진한_갈색_피부:',
        'pt': ':cientista_pele_morena_escura:',
        'it': ':persona_che_lavora_in_campo_scientifico_carnagione_abbastanza_scura:',
        'fa': u':دانشمند_پوست_گندمی:',
        'id': ':ilmuwan_warna_kulit_gelap-sedang:',
        'zh': u':科学家_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F52C': { # 🧑🏼‍🔬
        'en' : ':scientist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':wissenschaftler(in)_mittelhelle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_tono_de_piel_claro_medio:',
        'fr': ':scientifique_peau_moyennement_claire:',
        'ja': u':科学者_やや薄い肌色:',
        'ko': u':과학자_연한_갈색_피부:',
        'pt': ':cientista_pele_morena_clara:',
        'it': ':persona_che_lavora_in_campo_scientifico_carnagione_abbastanza_chiara:',
        'fa': u':دانشمند_پوست_روشن:',
        'id': ':ilmuwan_warna_kulit_cerah-sedang:',
        'zh': u':科学家_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F52C': { # 🧑🏽‍🔬
        'en' : ':scientist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':wissenschaftler(in)_mittlere_hautfarbe:',
        'es': ':profesional_de_la_ciencia_tono_de_piel_medio:',
        'fr': u':scientifique_peau_légèrement_mate:',
        'ja': u':科学者_中間の肌色:',
        'ko': u':과학자_갈색_피부:',
        'pt': ':cientista_pele_morena:',
        'it': ':persona_che_lavora_in_campo_scientifico_carnagione_olivastra:',
        'fa': u':دانشمند_پوست_طلایی:',
        'id': ':ilmuwan_warna_kulit_sedang:',
        'zh': u':科学家_中等肤色:'
    },
    u'\U00002702\U0000FE0F': { # ✂️
        'en' : ':scissors:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':schere:',
        'es': ':tijeras:',
        'fr': ':ciseaux:',
        'ja': u':はさみ:',
        'ko': u':가위:',
        'pt': ':tesoura:',
        'it': ':forbici:',
        'fa': u':قیچی:',
        'id': ':gunting:',
        'zh': u':剪刀:'
    },
    u'\U00002702': { # ✂
        'en' : ':scissors:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':schere:',
        'es': ':tijeras:',
        'fr': ':ciseaux:',
        'ja': u':はさみ:',
        'ko': u':가위:',
        'pt': ':tesoura:',
        'it': ':forbici:',
        'fa': u':قیچی:',
        'id': ':gunting:',
        'zh': u':剪刀:'
    },
    u'\U0001F982': { # 🦂
        'en' : ':scorpion:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':skorpion:',
        'es': u':escorpión:',
        'fr': ':scorpion:',
        'ja': u':サソリ:',
        'ko': u':전갈:',
        'pt': u':escorpião:',
        'it': ':scorpione:',
        'fa': u':عقرب:',
        'id': ':kalajengking:',
        'zh': u':蝎子:'
    },
    u'\U0001FA9B': { # 🪛
        'en' : ':screwdriver:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':schraubenzieher:',
        'es': ':destornillador:',
        'fr': ':tournevis:',
        'ja': u':ねじ回し:',
        'ko': u':드라이버:',
        'pt': ':chave_de_fenda:',
        'it': ':cacciavite:',
        'fa': u':پیچ_گوشتی:',
        'id': ':obeng:',
        'zh': u':螺丝刀:'
    },
    u'\U0001F4DC': { # 📜
        'en' : ':scroll:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schriftrolle:',
        'es': ':pergamino:',
        'fr': ':parchemin:',
        'ja': u':巻き物:',
        'ko': u':문서:',
        'pt': ':pergaminho:',
        'it': ':pergamena:',
        'fa': u':طومار:',
        'id': ':gulungan:',
        'zh': u':卷轴:'
    },
    u'\U0001F9AD': { # 🦭
        'en' : ':seal:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':seehund:',
        'es': ':foca:',
        'fr': ':phoque:',
        'ja': u':アザラシ:',
        'ko': u':물개:',
        'pt': ':foca:',
        'it': ':foca:',
        'fa': u':فُک:',
        'id': ':anjing_laut:',
        'zh': u':海豹:'
    },
    u'\U0001F4BA': { # 💺
        'en' : ':seat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':sitzplatz:',
        'es': ':asiento_de_transporte:',
        'fr': u':siège:',
        'ja': u':座席:',
        'ko': u':좌석:',
        'pt': ':assento:',
        'it': ':sedile:',
        'fa': u':جایگاه:',
        'id': ':kursi:',
        'zh': u':座位:'
    },
    u'\U0001F648': { # 🙈
        'en' : ':see-no-evil_monkey:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':see_no_evil:'],
        'de': ':sich_die_augen_zuhaltendes_affengesicht:',
        'es': ':mono_con_los_ojos_tapados:',
        'fr': ':singe_ne_rien_voir:',
        'ja': u':見ざる:',
        'ko': u':눈을_가리고_있는_원숭이:',
        'pt': u':macaco_que_não_vê_nada:',
        'it': ':non_vedo:',
        'fa': u':میمون_شرنبین:',
        'id': ':tidak_melihat:',
        'zh': u':非礼勿视:'
    },
    u'\U0001F331': { # 🌱
        'en' : ':seedling:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':spross:',
        'es': ':planta_joven:',
        'fr': ':jeune_pousse:',
        'ja': u':新芽:',
        'ko': u':새싹:',
        'pt': ':muda_de_planta:',
        'it': ':germoglio:',
        'fa': u':جوانه:',
        'id': ':semai:',
        'zh': u':幼苗:'
    },
    u'\U0001F933': { # 🤳
        'en' : ':selfie:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':selfie:',
        'es': ':selfi:',
        'fr': ':selfie:',
        'ja': u':セルフィー:',
        'ko': u':셀카:',
        'pt': ':selfie:',
        'it': ':selfie:',
        'fa': u':خودگرفت:',
        'id': ':selfie:',
        'zh': u':自拍:'
    },
    u'\U0001F933\U0001F3FF': { # 🤳🏿
        'en' : ':selfie_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':selfie_dunkle_hautfarbe:',
        'es': ':selfi_tono_de_piel_oscuro:',
        'fr': u':selfie_peau_foncée:',
        'ja': u':セルフィー_濃い肌色:',
        'ko': u':셀카_검은색_피부:',
        'pt': ':selfie_pele_escura:',
        'it': ':selfie_carnagione_scura:',
        'fa': u':خودگرفت_پوست_آبنوسی:',
        'id': ':selfie_warna_kulit_gelap:',
        'zh': u':自拍_较深肤色:'
    },
    u'\U0001F933\U0001F3FB': { # 🤳🏻
        'en' : ':selfie_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':selfie_helle_hautfarbe:',
        'es': ':selfi_tono_de_piel_claro:',
        'fr': ':selfie_peau_claire:',
        'ja': u':セルフィー_薄い肌色:',
        'ko': u':셀카_하얀_피부:',
        'pt': ':selfie_pele_clara:',
        'it': ':selfie_carnagione_chiara:',
        'fa': u':خودگرفت_پوست_سفید:',
        'id': ':selfie_warna_kulit_cerah:',
        'zh': u':自拍_较浅肤色:'
    },
    u'\U0001F933\U0001F3FE': { # 🤳🏾
        'en' : ':selfie_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':selfie_mitteldunkle_hautfarbe:',
        'es': ':selfi_tono_de_piel_oscuro_medio:',
        'fr': ':selfie_peau_mate:',
        'ja': u':セルフィー_やや濃い肌色:',
        'ko': u':셀카_진한_갈색_피부:',
        'pt': ':selfie_pele_morena_escura:',
        'it': ':selfie_carnagione_abbastanza_scura:',
        'fa': u':خودگرفت_پوست_گندمی:',
        'id': ':selfie_warna_kulit_gelap-sedang:',
        'zh': u':自拍_中等深肤色:'
    },
    u'\U0001F933\U0001F3FC': { # 🤳🏼
        'en' : ':selfie_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':selfie_mittelhelle_hautfarbe:',
        'es': ':selfi_tono_de_piel_claro_medio:',
        'fr': ':selfie_peau_moyennement_claire:',
        'ja': u':セルフィー_やや薄い肌色:',
        'ko': u':셀카_연한_갈색_피부:',
        'pt': ':selfie_pele_morena_clara:',
        'it': ':selfie_carnagione_abbastanza_chiara:',
        'fa': u':خودگرفت_پوست_روشن:',
        'id': ':selfie_warna_kulit_cerah-sedang:',
        'zh': u':自拍_中等浅肤色:'
    },
    u'\U0001F933\U0001F3FD': { # 🤳🏽
        'en' : ':selfie_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':selfie_mittlere_hautfarbe:',
        'es': ':selfi_tono_de_piel_medio:',
        'fr': u':selfie_peau_légèrement_mate:',
        'ja': u':セルフィー_中間の肌色:',
        'ko': u':셀카_갈색_피부:',
        'pt': ':selfie_pele_morena:',
        'it': ':selfie_carnagione_olivastra:',
        'fa': u':خودگرفت_پوست_طلایی:',
        'id': ':selfie_warna_kulit_sedang:',
        'zh': u':自拍_中等肤色:'
    },
    u'\U0001F415\U0000200D\U0001F9BA': { # 🐕‍🦺
        'en' : ':service_dog:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':assistenzhund:',
        'es': ':perro_de_servicio:',
        'fr': u':chien_d’assistance:',
        'ja': u':介助犬:',
        'ko': u':보조견:',
        'pt': u':cão_de_serviço:',
        'it': ':cane_da_assistenza:',
        'fa': u':سگ_کمکی:',
        'id': ':anjing_pembimbing:',
        'zh': u':服务犬:'
    },
    u'\U0001F562': { # 🕢
        'en' : ':seven-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock730:'],
        'variant': True,
        'de': ':7.30_uhr:',
        'es': ':siete_y_media:',
        'fr': ':sept_heures_et_demie:',
        'ja': u':7時半:',
        'ko': u':일곱_시_반:',
        'pt': ':sete_e_meia:',
        'it': ':ore_sette_e_mezza:',
        'fa': u':ساعت_هفت_و_نیم:',
        'id': ':jam_setengah_delapan:',
        'zh': u':七点半:'
    },
    u'\U0001F556': { # 🕖
        'en' : u':seven_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock7:'],
        'variant': True,
        'de': ':7.00_uhr:',
        'es': ':7_en_punto:',
        'fr': ':sept_heures:',
        'ja': u':7時:',
        'ko': u':일곱_시:',
        'pt': ':7_horas:',
        'it': ':ore_sette:',
        'fa': u':ساعت_هفت:',
        'id': ':jam_tujuh_tepat:',
        'zh': u':七点:'
    },
    u'\U0001FAA1': { # 🪡
        'en' : ':sewing_needle:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':nähnadel:',
        'es': ':aguja_de_coser:',
        'fr': u':aiguille_à_coudre:',
        'ja': u':縫い針:',
        'ko': u':바늘:',
        'pt': ':agulha_de_costura:',
        'it': ':ago_da_cucito:',
        'fa': u':سوزن_خیاطی:',
        'id': ':jarum_jahit:',
        'zh': u':缝合针:'
    },
    u'\U0001FAE8': { # 🫨
        'en' : ':shaking_face:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':zitterndes_doppelgesicht:',
        'es': ':cara_temblorosa:',
        'fr': u':visage_secoué:',
        'ja': u':震えている顔:',
        'ko': u':요동치는_얼굴:',
        'pt': ':rosto_tremendo:',
        'it': ':faccina_tremante:',
        'fa': u':چهره_لرزان:',
        'id': ':wajah_gemetar:',
        'zh': u':颤抖:'
    },
    u'\U0001F958': { # 🥘
        'en' : ':shallow_pan_of_food:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':pfannengericht:',
        'es': ':paella:',
        'fr': u':plat_mitonné:',
        'ja': u':パエリア:',
        'ko': u':납작한_냄비:',
        'pt': u':caçarola_com_comida:',
        'it': ':padella_con_cibo:',
        'fa': u':ماهیتابه_غذا:',
        'id': ':wajan_dangkal:',
        'zh': u':装有食物的浅底锅:'
    },
    u'\U00002618\U0000FE0F': { # ☘️
        'en' : ':shamrock:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':kleeblatt:',
        'es': u':trébol:',
        'fr': u':trèfle:',
        'ja': u':クローバー:',
        'ko': u':토끼풀:',
        'pt': ':trevo:',
        'it': ':trifoglio:',
        'fa': u':برگ_شبدر:',
        'id': ':shamrock:',
        'zh': u':三叶草:'
    },
    u'\U00002618': { # ☘
        'en' : ':shamrock:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':kleeblatt:',
        'es': u':trébol:',
        'fr': u':trèfle:',
        'ja': u':クローバー:',
        'ko': u':토끼풀:',
        'pt': ':trevo:',
        'it': ':trifoglio:',
        'fa': u':برگ_شبدر:',
        'id': ':shamrock:',
        'zh': u':三叶草:'
    },
    u'\U0001F988': { # 🦈
        'en' : ':shark:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':hai:',
        'es': u':tiburón:',
        'fr': ':requin:',
        'ja': u':サメ:',
        'ko': u':상어:',
        'pt': u':tubarão:',
        'it': ':squalo:',
        'fa': u':کوسه:',
        'id': ':hiu:',
        'zh': u':鲨鱼:'
    },
    u'\U0001F367': { # 🍧
        'en' : ':shaved_ice:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wassereis:',
        'es': ':granizado_hawaiano:',
        'fr': u':granité:',
        'ja': u':かき氷:',
        'ko': u':샤베트_아이스크림:',
        'pt': ':raspadinha_de_gelo:',
        'it': ':granita:',
        'fa': u':یخ_در_بهشت:',
        'id': ':es_serut:',
        'zh': u':刨冰:'
    },
    u'\U0001F33E': { # 🌾
        'en' : ':sheaf_of_rice:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ear_of_rice:'],
        'de': u':reisähre:',
        'es': ':espiga_de_arroz:',
        'fr': ':plant_de_riz:',
        'ja': u':稲:',
        'ko': u':벼:',
        'pt': ':planta_de_arroz:',
        'it': ':pianta_di_riso:',
        'fa': u':خوشه_برنج:',
        'id': ':seikat_padi:',
        'zh': u':稻子:'
    },
    u'\U0001F6E1\U0000FE0F': { # 🛡️
        'en' : ':shield:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schutzschild:',
        'es': ':escudo:',
        'fr': ':bouclier:',
        'ja': u':盾:',
        'ko': u':방패:',
        'pt': ':escudo:',
        'it': ':scudo:',
        'fa': u':سپر:',
        'id': ':perisai:',
        'zh': u':盾牌:'
    },
    u'\U0001F6E1': { # 🛡
        'en' : ':shield:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schutzschild:',
        'es': ':escudo:',
        'fr': ':bouclier:',
        'ja': u':盾:',
        'ko': u':방패:',
        'pt': ':escudo:',
        'it': ':scudo:',
        'fa': u':سپر:',
        'id': ':perisai:',
        'zh': u':盾牌:'
    },
    u'\U000026E9\U0000FE0F': { # ⛩️
        'en' : ':shinto_shrine:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':shinto-schrein:',
        'es': u':santuario_sintoísta:',
        'fr': ':sanctuaire_shinto:',
        'ja': u':鳥居:',
        'ko': u':신토_신사:',
        'pt': u':santuário_japonês:',
        'it': ':santuario_shintoista:',
        'fa': u':معبد_شینتو:',
        'id': ':kuil_shinto:',
        'zh': u':神社:'
    },
    u'\U000026E9': { # ⛩
        'en' : ':shinto_shrine:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':shinto-schrein:',
        'es': u':santuario_sintoísta:',
        'fr': ':sanctuaire_shinto:',
        'ja': u':鳥居:',
        'ko': u':신토_신사:',
        'pt': u':santuário_japonês:',
        'it': ':santuario_shintoista:',
        'fa': u':معبد_شینتو:',
        'id': ':kuil_shinto:',
        'zh': u':神社:'
    },
    u'\U0001F6A2': { # 🚢
        'en' : ':ship:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schiff:',
        'es': ':barco:',
        'fr': ':navire:',
        'ja': u':船:',
        'ko': u':선박:',
        'pt': ':navio:',
        'it': ':nave:',
        'fa': u':کشتی:',
        'id': ':kapal:',
        'zh': u':船:'
    },
    u'\U0001F320': { # 🌠
        'en' : ':shooting_star:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':stars:'],
        'de': ':sternschnuppe:',
        'es': ':estrella_fugaz:',
        'fr': u':étoile_filante:',
        'ja': u':流れ星:',
        'ko': u':별똥별:',
        'pt': ':estrela_cadente:',
        'it': ':stella_cadente:',
        'fa': u':ستاره_ثاقب:',
        'id': ':bintang_jatuh:',
        'zh': u':流星:'
    },
    u'\U0001F6CD\U0000FE0F': { # 🛍️
        'en' : ':shopping_bags:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':shopping:'],
        'variant': True,
        'de': u':einkaufstüten:',
        'es': ':bolsas_de_compras:',
        'fr': ':sacs_de_shopping:',
        'ja': u':紙袋:',
        'ko': u':쇼핑백:',
        'pt': ':sacolas_de_compras:',
        'it': ':borse_della_spesa:',
        'fa': u':کیف_خرید:',
        'id': ':tas_belanja:',
        'zh': u':购物袋:'
    },
    u'\U0001F6CD': { # 🛍
        'en' : ':shopping_bags:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':shopping:'],
        'variant': True,
        'de': u':einkaufstüten:',
        'es': ':bolsas_de_compras:',
        'fr': ':sacs_de_shopping:',
        'ja': u':紙袋:',
        'ko': u':쇼핑백:',
        'pt': ':sacolas_de_compras:',
        'it': ':borse_della_spesa:',
        'fa': u':کیف_خرید:',
        'id': ':tas_belanja:',
        'zh': u':购物袋:'
    },
    u'\U0001F6D2': { # 🛒
        'en' : ':shopping_cart:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':einkaufswagen:',
        'es': ':carrito_de_la_compra:',
        'fr': ':chariot:',
        'ja': u':ショッピングカート:',
        'ko': u':쇼핑카트:',
        'pt': ':carrinho_de_compras:',
        'it': ':carrello:',
        'fa': u':گاری_خرید:',
        'id': ':troli_belanja:',
        'zh': u':购物车:'
    },
    u'\U0001F370': { # 🍰
        'en' : ':shortcake:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':cake:'],
        'de': ':torte:',
        'es': ':trozo_de_tarta:',
        'fr': u':gâteau_sablé:',
        'ja': u':ショートケーキ:',
        'ko': u':조각_케익:',
        'pt': u':pão_de_ló_de_morango:',
        'it': ':fetta_di_torta:',
        'fa': u':شُرت_کیک:',
        'id': ':kue:',
        'zh': u':水果蛋糕:'
    },
    u'\U0001FA73': { # 🩳
        'en' : ':shorts:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':shorts:',
        'es': ':pantalones_cortos:',
        'fr': ':short:',
        'ja': u':ショーツ:',
        'ko': u':반바지:',
        'pt': ':shorts:',
        'it': ':pantaloncini:',
        'fa': u':شلوارک:',
        'id': ':celana_pendek:',
        'zh': u':短裤:'
    },
    u'\U0001F6BF': { # 🚿
        'en' : ':shower:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':dusche:',
        'es': ':ducha:',
        'fr': ':douche:',
        'ja': u':シャワー:',
        'ko': u':샤워:',
        'pt': ':chuveiro:',
        'it': ':doccia:',
        'fa': u':دوش:',
        'id': ':shower:',
        'zh': u':淋浴:'
    },
    u'\U0001F990': { # 🦐
        'en' : ':shrimp:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':garnele:',
        'es': ':gamba:',
        'fr': ':crevette:',
        'ja': u':エビ:',
        'ko': u':새우:',
        'pt': u':camarão:',
        'it': ':gamberetto:',
        'fa': u':میگو:',
        'id': ':udang:',
        'zh': u':虾:'
    },
    u'\U0001F500': { # 🔀
        'en' : ':shuffle_tracks_button:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':twisted_rightwards_arrows:'],
        'de': ':zufallsmodus:',
        'es': u':reproducción_aleatoria:',
        'fr': u':bouton_lecture_aléatoire:',
        'ja': u':シャッフルボタン:',
        'ko': u':랜덤_재생:',
        'pt': u':botão_de_músicas_aleatórias:',
        'it': ':pulsante_di_riproduzione_casuale:',
        'fa': u':دکمهٔ_پخش_تصادفی:',
        'id': ':tombol_acak_lagu:',
        'zh': u':随机播放音轨按钮:'
    },
    u'\U0001F92B': { # 🤫
        'en' : ':shushing_face:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':ermahnendes_gesicht:',
        'es': ':cara_pidiendo_silencio:',
        'fr': ':visage_avec_un_doigt_sur_la_bouche:',
        'ja': u':しーっ:',
        'ko': u':쉿_하는_얼굴:',
        'pt': u':rosto_fazendo_sinal_de_silêncio:',
        'it': ':faccina_che_zittisce:',
        'fa': u':هیس:',
        'id': ':wajah_menyuruh_diam:',
        'zh': u':安静的脸:'
    },
    u'\U0001F918': { # 🤘
        'en' : ':sign_of_the_horns:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':metal:'],
        'de': u':teufelsgruß:',
        'es': ':mano_haciendo_el_signo_de_cuernos:',
        'fr': ':cornes_avec_les_doigts:',
        'ja': u':角の指サイン:',
        'ko': u':뿔_모양_손짓:',
        'pt': u':saudação_do_rock:',
        'it': ':segno_delle_corna:',
        'fa': u':نماد_شاخ:',
        'id': ':lambang_tanduk:',
        'zh': u':摇滚:'
    },
    u'\U0001F918\U0001F3FF': { # 🤘🏿
        'en' : ':sign_of_the_horns_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':teufelsgruß_dunkle_hautfarbe:',
        'es': ':mano_haciendo_el_signo_de_cuernos_tono_de_piel_oscuro:',
        'fr': u':cornes_avec_les_doigts_peau_foncée:',
        'ja': u':角の指サイン_濃い肌色:',
        'ko': u':뿔_모양_손짓_검은색_피부:',
        'pt': u':saudação_do_rock_pele_escura:',
        'it': ':segno_delle_corna_carnagione_scura:',
        'fa': u':نماد_شاخ_پوست_آبنوسی:',
        'id': ':lambang_tanduk_warna_kulit_gelap:',
        'zh': u':摇滚_较深肤色:'
    },
    u'\U0001F918\U0001F3FB': { # 🤘🏻
        'en' : ':sign_of_the_horns_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':teufelsgruß_helle_hautfarbe:',
        'es': ':mano_haciendo_el_signo_de_cuernos_tono_de_piel_claro:',
        'fr': ':cornes_avec_les_doigts_peau_claire:',
        'ja': u':角の指サイン_薄い肌色:',
        'ko': u':뿔_모양_손짓_하얀_피부:',
        'pt': u':saudação_do_rock_pele_clara:',
        'it': ':segno_delle_corna_carnagione_chiara:',
        'fa': u':نماد_شاخ_پوست_سفید:',
        'id': ':lambang_tanduk_warna_kulit_cerah:',
        'zh': u':摇滚_较浅肤色:'
    },
    u'\U0001F918\U0001F3FE': { # 🤘🏾
        'en' : ':sign_of_the_horns_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':teufelsgruß_mitteldunkle_hautfarbe:',
        'es': ':mano_haciendo_el_signo_de_cuernos_tono_de_piel_oscuro_medio:',
        'fr': ':cornes_avec_les_doigts_peau_mate:',
        'ja': u':角の指サイン_やや濃い肌色:',
        'ko': u':뿔_모양_손짓_진한_갈색_피부:',
        'pt': u':saudação_do_rock_pele_morena_escura:',
        'it': ':segno_delle_corna_carnagione_abbastanza_scura:',
        'fa': u':نماد_شاخ_پوست_گندمی:',
        'id': ':lambang_tanduk_warna_kulit_gelap-sedang:',
        'zh': u':摇滚_中等深肤色:'
    },
    u'\U0001F918\U0001F3FC': { # 🤘🏼
        'en' : ':sign_of_the_horns_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':teufelsgruß_mittelhelle_hautfarbe:',
        'es': ':mano_haciendo_el_signo_de_cuernos_tono_de_piel_claro_medio:',
        'fr': ':cornes_avec_les_doigts_peau_moyennement_claire:',
        'ja': u':角の指サイン_やや薄い肌色:',
        'ko': u':뿔_모양_손짓_연한_갈색_피부:',
        'pt': u':saudação_do_rock_pele_morena_clara:',
        'it': ':segno_delle_corna_carnagione_abbastanza_chiara:',
        'fa': u':نماد_شاخ_پوست_روشن:',
        'id': ':lambang_tanduk_warna_kulit_cerah-sedang:',
        'zh': u':摇滚_中等浅肤色:'
    },
    u'\U0001F918\U0001F3FD': { # 🤘🏽
        'en' : ':sign_of_the_horns_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':teufelsgruß_mittlere_hautfarbe:',
        'es': ':mano_haciendo_el_signo_de_cuernos_tono_de_piel_medio:',
        'fr': u':cornes_avec_les_doigts_peau_légèrement_mate:',
        'ja': u':角の指サイン_中間の肌色:',
        'ko': u':뿔_모양_손짓_갈색_피부:',
        'pt': u':saudação_do_rock_pele_morena:',
        'it': ':segno_delle_corna_carnagione_olivastra:',
        'fa': u':نماد_شاخ_پوست_طلایی:',
        'id': ':lambang_tanduk_warna_kulit_sedang:',
        'zh': u':摇滚_中等肤色:'
    },
    u'\U0001F9D1\U0000200D\U0001F3A4': { # 🧑‍🎤
        'en' : ':singer:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sänger(in):',
        'es': ':cantante:',
        'fr': ':chanteur_(tous_genres):',
        'ja': u':歌手:',
        'ko': u':가수:',
        'pt': ':cantor:',
        'it': ':cantante:',
        'fa': u':خواننده:',
        'id': ':penyanyi:',
        'zh': u':歌手:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F3A4': { # 🧑🏿‍🎤
        'en' : ':singer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sänger(in)_dunkle_hautfarbe:',
        'es': ':cantante_tono_de_piel_oscuro:',
        'fr': u':chanteur_(tous_genres)_peau_foncée:',
        'ja': u':歌手_濃い肌色:',
        'ko': u':가수_검은색_피부:',
        'pt': ':cantor_pele_escura:',
        'it': ':cantante_carnagione_scura:',
        'fa': u':خواننده_پوست_آبنوسی:',
        'id': ':penyanyi_warna_kulit_gelap:',
        'zh': u':歌手_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F3A4': { # 🧑🏻‍🎤
        'en' : ':singer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sänger(in)_helle_hautfarbe:',
        'es': ':cantante_tono_de_piel_claro:',
        'fr': ':chanteur_(tous_genres)_peau_claire:',
        'ja': u':歌手_薄い肌色:',
        'ko': u':가수_하얀_피부:',
        'pt': ':cantor_pele_clara:',
        'it': ':cantante_carnagione_chiara:',
        'fa': u':خواننده_پوست_سفید:',
        'id': ':penyanyi_warna_kulit_cerah:',
        'zh': u':歌手_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F3A4': { # 🧑🏾‍🎤
        'en' : ':singer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sänger(in)_mitteldunkle_hautfarbe:',
        'es': ':cantante_tono_de_piel_oscuro_medio:',
        'fr': ':chanteur_(tous_genres)_peau_mate:',
        'ja': u':歌手_やや濃い肌色:',
        'ko': u':가수_진한_갈색_피부:',
        'pt': ':cantor_pele_morena_escura:',
        'it': ':cantante_carnagione_abbastanza_scura:',
        'fa': u':خواننده_پوست_گندمی:',
        'id': ':penyanyi_warna_kulit_gelap-sedang:',
        'zh': u':歌手_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F3A4': { # 🧑🏼‍🎤
        'en' : ':singer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sänger(in)_mittelhelle_hautfarbe:',
        'es': ':cantante_tono_de_piel_claro_medio:',
        'fr': ':chanteur_(tous_genres)_peau_moyennement_claire:',
        'ja': u':歌手_やや薄い肌色:',
        'ko': u':가수_연한_갈색_피부:',
        'pt': ':cantor_pele_morena_clara:',
        'it': ':cantante_carnagione_abbastanza_chiara:',
        'fa': u':خواننده_پوست_روشن:',
        'id': ':penyanyi_warna_kulit_cerah-sedang:',
        'zh': u':歌手_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F3A4': { # 🧑🏽‍🎤
        'en' : ':singer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':sänger(in)_mittlere_hautfarbe:',
        'es': ':cantante_tono_de_piel_medio:',
        'fr': u':chanteur_(tous_genres)_peau_légèrement_mate:',
        'ja': u':歌手_中間の肌色:',
        'ko': u':가수_갈색_피부:',
        'pt': ':cantor_pele_morena:',
        'it': ':cantante_carnagione_olivastra:',
        'fa': u':خواننده_پوست_طلایی:',
        'id': ':penyanyi_warna_kulit_sedang:',
        'zh': u':歌手_中等肤色:'
    },
    u'\U0001F561': { # 🕡
        'en' : ':six-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock630:'],
        'variant': True,
        'de': ':6.30_uhr:',
        'es': ':seis_y_media:',
        'fr': ':six_heures_et_demie:',
        'ja': u':6時半:',
        'ko': u':여섯_시_반:',
        'pt': ':seis_e_meia:',
        'it': ':ore_sei_e_mezza:',
        'fa': u':ساعت_شش_و_نیم:',
        'id': ':jam_setengah_tujuh:',
        'zh': u':六点半:'
    },
    u'\U0001F555': { # 🕕
        'en' : u':six_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock6:'],
        'variant': True,
        'de': ':6.00_uhr:',
        'es': ':6_en_punto:',
        'fr': ':six_heures:',
        'ja': u':6時:',
        'ko': u':여섯_시:',
        'pt': ':6_horas:',
        'it': ':ore_sei:',
        'fa': u':ساعت_شش:',
        'id': ':jam_enam_tepat:',
        'zh': u':六点:'
    },
    u'\U0001F6F9': { # 🛹
        'en' : ':skateboard:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':skateboard:',
        'es': u':monopatín:',
        'fr': u':planche_à_roulettes:',
        'ja': u':スケートボード:',
        'ko': u':스케이트보드:',
        'pt': ':skate:',
        'it': ':skateboard:',
        'fa': u':تختهٔ_اسکیت:',
        'id': ':papan_luncur:',
        'zh': u':滑板:'
    },
    u'\U000026F7\U0000FE0F': { # ⛷️
        'en' : ':skier:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':skifahrer(in):',
        'es': ':esquiador:',
        'fr': ':skieur:',
        'ja': u':スキーヤー:',
        'ko': u':스키_타는_사람:',
        'pt': ':esquiador:',
        'it': ':sciatore:',
        'fa': u':اسکی_سوار:',
        'id': ':pemain_ski:',
        'zh': u':滑雪的人:'
    },
    u'\U000026F7': { # ⛷
        'en' : ':skier:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':skifahrer(in):',
        'es': ':persona_esquiando:',
        'fr': ':skieur:',
        'ja': u':スキーヤー:',
        'ko': u':스키_타는_사람:',
        'pt': ':esquiador:',
        'it': ':sciatore:',
        'fa': u':اسکی_سوار:',
        'id': ':pemain_ski:',
        'zh': u':滑雪的人:'
    },
    u'\U0001F3BF': { # 🎿
        'en' : ':skis:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ski:'],
        'de': ':ski:',
        'es': u':esquís:',
        'fr': ':ski:',
        'ja': u':スキー:',
        'ko': u':스키:',
        'pt': ':esqui:',
        'it': ':sci:',
        'fa': u':چوب_اسکی:',
        'id': ':ski:',
        'zh': u':滑雪:'
    },
    u'\U0001F480': { # 💀
        'en' : ':skull:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':totenkopf:',
        'es': ':calavera:',
        'fr': u':crâne:',
        'ja': u':ドクロ:',
        'ko': u':해골:',
        'pt': ':caveira:',
        'it': ':teschio:',
        'fa': u':جمجمه:',
        'id': ':tengkorak:',
        'zh': u':头骨:'
    },
    u'\U00002620\U0000FE0F': { # ☠️
        'en' : ':skull_and_crossbones:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':totenkopf_mit_gekreuzten_knochen:',
        'es': ':calavera_y_huesos_cruzados:',
        'fr': u':tête_de_mort:',
        'ja': u':ドクロと骨:',
        'ko': u':해골과_뼈다귀:',
        'pt': ':caveira_e_ossos_cruzados:',
        'it': ':teschio_con_ossa_incrociate:',
        'fa': u':جمجمه_و_استخوان_صلیبی:',
        'id': ':tengkorak_dan_tulang:',
        'zh': u':骷髅:'
    },
    u'\U00002620': { # ☠
        'en' : ':skull_and_crossbones:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':totenkopf_mit_gekreuzten_knochen:',
        'es': ':calavera_y_huesos_cruzados:',
        'fr': u':tête_de_mort:',
        'ja': u':ドクロと骨:',
        'ko': u':해골과_뼈다귀:',
        'pt': ':caveira_e_ossos_cruzados:',
        'it': ':teschio_con_ossa_incrociate:',
        'fa': u':جمجمه_و_استخوان_صلیبی:',
        'id': ':tengkorak_dan_tulang:',
        'zh': u':骷髅:'
    },
    u'\U0001F9A8': { # 🦨
        'en' : ':skunk:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stinktier:',
        'es': ':mofeta:',
        'fr': ':mouffette:',
        'ja': u':スカンク:',
        'ko': u':스컹크:',
        'pt': u':gambá:',
        'it': ':puzzola:',
        'fa': u':راسو:',
        'id': ':sigung:',
        'zh': u':臭鼬:'
    },
    u'\U0001F6F7': { # 🛷
        'en' : ':sled:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':schlitten:',
        'es': ':trineo:',
        'fr': ':luge:',
        'ja': u':そり競技:',
        'ko': u':썰매:',
        'pt': u':trenó:',
        'it': ':slitta:',
        'fa': u':سورتمه:',
        'id': ':kereta_luncur:',
        'zh': u':雪橇:'
    },
    u'\U0001F634': { # 😴
        'en' : ':sleeping_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':sleeping:'],
        'de': ':schlafendes_gesicht:',
        'es': ':cara_durmiendo:',
        'fr': ':visage_somnolent:',
        'ja': u':寝る:',
        'ko': u':졸고_있는_얼굴:',
        'pt': ':rosto_dormindo:',
        'it': ':faccina_che_dorme:',
        'fa': u':خوابیده:',
        'id': ':wajah_tidur:',
        'zh': u':睡着了:'
    },
    u'\U0001F62A': { # 😪
        'en' : ':sleepy_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sleepy:'],
        'de': u':schläfriges_gesicht:',
        'es': u':cara_de_sueño:',
        'fr': ':visage_endormi:',
        'ja': u':眠い:',
        'ko': u':졸린_얼굴:',
        'pt': ':rosto_sonolento:',
        'it': ':faccina_assonnata:',
        'fa': u':خواب_آلود:',
        'id': ':wajah_mengantuk:',
        'zh': u':困:'
    },
    u'\U0001F641': { # 🙁
        'en' : ':slightly_frowning_face:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':betrübtes_gesicht:',
        'es': u':cara_con_el_ceño_ligeramente_fruncido:',
        'fr': u':visage_légèrement_mécontent:',
        'ja': u':少し困った顔:',
        'ko': u':살짝_찡그린_얼굴:',
        'pt': ':rosto_meio_triste:',
        'it': ':faccina_leggermente_imbronciata:',
        'fa': u':دلخور:',
        'id': ':wajah_agak_cemberut:',
        'zh': u':微微不满:'
    },
    u'\U0001F642': { # 🙂
        'en' : ':slightly_smiling_face:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':leicht_lächelndes_gesicht:',
        'es': ':cara_sonriendo_ligeramente:',
        'fr': u':visage_avec_un_léger_sourire:',
        'ja': u':微笑む:',
        'ko': u':살짝_미소_짓는_얼굴:',
        'pt': ':rosto_levemente_sorridente:',
        'it': ':faccina_con_sorriso_accennato:',
        'fa': u':لبخند_ملایم:',
        'id': ':wajah_agak_tersenyum:',
        'zh': u':呵呵:'
    },
    u'\U0001F3B0': { # 🎰
        'en' : ':slot_machine:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':spielautomat:',
        'es': u':máquina_tragaperras:',
        'fr': u':machine_à_sous:',
        'ja': u':スロットマシン:',
        'ko': u':슬롯_머신:',
        'pt': u':caça-níquel:',
        'it': ':slot_machine:',
        'fa': u':ماشین_پولی:',
        'id': ':mesin_slot:',
        'zh': u':老虎机:'
    },
    u'\U0001F9A5': { # 🦥
        'en' : ':sloth:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':faultier:',
        'es': ':perezoso:',
        'fr': ':paresseux:',
        'ja': u':ナマケモノ:',
        'ko': u':나무늘보:',
        'pt': u':preguiça:',
        'it': ':bradipo:',
        'fa': u':تنبل:',
        'id': ':kungkang:',
        'zh': u':树懒:'
    },
    u'\U0001F6E9\U0000FE0F': { # 🛩️
        'en' : ':small_airplane:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kleines_flugzeug:',
        'es': ':avioneta:',
        'fr': ':petit_avion:',
        'ja': u':小型飛行機:',
        'ko': u':경비행기:',
        'pt': u':avião_pequeno:',
        'it': ':aereo_turistico:',
        'fa': u':هواپیمای_کوچک:',
        'id': ':pesawat_kecil:',
        'zh': u':小型飞机:'
    },
    u'\U0001F6E9': { # 🛩
        'en' : ':small_airplane:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':kleines_flugzeug:',
        'es': ':avioneta:',
        'fr': ':petit_avion:',
        'ja': u':小型飛行機:',
        'ko': u':경비행기:',
        'pt': u':avião_pequeno:',
        'it': ':aereo_turistico:',
        'fa': u':هواپیمای_کوچک:',
        'id': ':pesawat_kecil:',
        'zh': u':小型飞机:'
    },
    u'\U0001F539': { # 🔹
        'en' : ':small_blue_diamond:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kleine_blaue_raute:',
        'es': u':rombo_azul_pequeño:',
        'fr': ':petit_losange_bleu:',
        'ja': u':小さい青のひし形:',
        'ko': u':작은_파란색_마름모:',
        'pt': ':losango_azul_pequeno:',
        'it': ':rombo_blu_piccolo:',
        'fa': u':لوزی_آبی_کوچک:',
        'id': ':wajik_biru_kecil:',
        'zh': u':蓝色小菱形:'
    },
    u'\U0001F538': { # 🔸
        'en' : ':small_orange_diamond:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':kleine_orangefarbene_raute:',
        'es': u':rombo_naranja_pequeño:',
        'fr': ':petit_losange_orange:',
        'ja': u':小さいオレンジのひし形:',
        'ko': u':작은_주황색_마름모:',
        'pt': ':losango_laranja_pequeno:',
        'it': ':rombo_arancione_piccolo:',
        'fa': u':لوزی_نارنجی_کوچک:',
        'id': ':wajik_oranye_kecil:',
        'zh': u':橙色小菱形:'
    },
    u'\U0001F63B': { # 😻
        'en' : ':smiling_cat_with_heart-eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heart_eyes_cat:'],
        'de': ':lachende_katze_mit_herzen_als_augen:',
        'es': u':gato_sonriendo_con_ojos_de_corazón:',
        'fr': u':chat_souriant_aux_yeux_en_cœurs:',
        'ja': u':目がハートの猫:',
        'ko': u':하트_눈_고양이_얼굴:',
        'pt': u':rosto_de_gato_sorridente_com_olhos_de_coração:',
        'it': ':gatto_innamorato:',
        'fa': u':گربهٔ_خندان_عاشق:',
        'id': ':wajah_kucing_gembira_bermata_hati:',
        'zh': u':花痴的猫:'
    },
    u'\U0000263A\U0000FE0F': { # ☺️
        'en' : ':smiling_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':relaxed:'],
        'variant': True,
        'de': u':lächelndes_gesicht:',
        'es': ':cara_sonriente:',
        'fr': ':visage_souriant:',
        'ja': u':スマイリー:',
        'ko': u':웃는_얼굴:',
        'pt': ':rosto_sorridente:',
        'it': ':faccina_sorridente:',
        'fa': u':لبخند:',
        'id': ':wajah_tersenyum:',
        'zh': u':微笑:'
    },
    u'\U0000263A': { # ☺
        'en' : ':smiling_face:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':relaxed:'],
        'variant': True,
        'de': u':lächelndes_gesicht:',
        'es': ':cara_sonriente:',
        'fr': ':visage_souriant:',
        'ja': u':スマイリー:',
        'ko': u':웃는_얼굴:',
        'pt': ':rosto_sorridente:',
        'it': ':faccina_sorridente:',
        'fa': u':لبخند:',
        'id': ':wajah_tersenyum:',
        'zh': u':微笑:'
    },
    u'\U0001F607': { # 😇
        'en' : ':smiling_face_with_halo:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':innocent:'],
        'de': u':lächelndes_gesicht_mit_heiligenschein:',
        'es': ':cara_sonriendo_con_aureola:',
        'fr': u':visage_souriant_avec_auréole:',
        'ja': u':天使の輪がついた笑顔:',
        'ko': u':후광이_비치는_웃는_얼굴:',
        'pt': u':rosto_sorridente_com_auréola:',
        'it': ':faccina_con_sorriso_e_aureola:',
        'fa': u':هاله_دار:',
        'id': ':wajah_malaikat:',
        'zh': u':微笑天使:'
    },
    u'\U0001F60D': { # 😍
        'en' : ':smiling_face_with_heart-eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':heart_eyes:'],
        'de': u':lächelndes_gesicht_mit_herzförmigen_augen:',
        'es': u':cara_sonriendo_con_ojos_de_corazón:',
        'fr': u':visage_souriant_avec_yeux_en_forme_de_cœur:',
        'ja': u':目がハートの笑顔:',
        'ko': u':하트_눈_얼굴:',
        'pt': u':rosto_sorridente_com_olhos_de_coração:',
        'it': ':faccina_con_sorriso_e_occhi_a_cuore:',
        'fa': u':چشم_های_عاشق:',
        'id': ':wajah_tersenyum_lebar_bermata_hati:',
        'zh': u':花痴:'
    },
    u'\U0001F970': { # 🥰
        'en' : ':smiling_face_with_hearts:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':smiling_face_with_three_hearts:'],
        'de': u':lächelndes_gesicht_mit_herzen:',
        'es': ':cara_sonriendo_con_corazones:',
        'fr': u':visage_souriant_avec_cœurs:',
        'ja': u':ハートの笑顔:',
        'ko': u':하트와_함께_웃는_얼굴:',
        'pt': u':rosto_sorridente_com_3_corações:',
        'it': ':faccina_con_cuoricini:',
        'fa': u':صورت_خندان_و_عاشق:',
        'id': ':wajah_tersenyum_dengan_3_hati:',
        'zh': u':喜笑颜开:'
    },
    u'\U0001F608': { # 😈
        'en' : ':smiling_face_with_horns:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':smiling_imp:'],
        'de': u':grinsendes_gesicht_mit_hörnern:',
        'es': ':cara_sonriendo_con_cuernos:',
        'fr': ':visage_souriant_avec_des_cornes:',
        'ja': u':笑った悪魔:',
        'ko': u':머리에_뿔이_달린_웃는_얼굴:',
        'pt': ':rosto_sorridente_com_chifres:',
        'it': ':faccina_con_sorriso_e_corna:',
        'fa': u':صورت_لبخندزنان_با_دوشاخ:',
        'id': ':wajah_tersenyum_bertanduk:',
        'zh': u':恶魔微笑:'
    },
    u'\U0001F917': { # 🤗
        'en' : ':smiling_face_with_open_hands:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':hugging_face:', ':hugs:'],
        'de': u':gesicht_mit_umarmenden_händen:',
        'es': ':cara_con_manos_abrazando:',
        'fr': u':visage_qui_fait_un_câlin:',
        'ja': u':ハグ:',
        'ko': u':포옹하고_있는_얼굴:',
        'pt': u':rosto_abraçando:',
        'it': ':faccina_che_abbraccia:',
        'fa': u':بغل_کردن:',
        'id': ':wajah_memeluk:',
        'zh': u':抱抱:'
    },
    u'\U0001F60A': { # 😊
        'en' : ':smiling_face_with_smiling_eyes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':blush:'],
        'de': u':lächelndes_gesicht_mit_lachenden_augen:',
        'es': ':cara_feliz_con_ojos_sonrientes:',
        'fr': ':visage_souriant_avec_yeux_rieurs:',
        'ja': u':にこにこ:',
        'ko': u':미소_짓는_눈으로_살짝_웃는_얼굴:',
        'pt': ':rosto_sorridente_com_olhos_sorridentes:',
        'it': ':faccina_con_occhi_sorridenti:',
        'fa': u':لبخند_خجالتی:',
        'id': ':wajah_tersenyum_dengan_mata_bahagia:',
        'zh': u':羞涩微笑:'
    },
    u'\U0001F60E': { # 😎
        'en' : ':smiling_face_with_sunglasses:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':sunglasses:'],
        'de': u':lächelndes_gesicht_mit_sonnenbrille:',
        'es': ':cara_sonriendo_con_gafas_de_sol:',
        'fr': ':visage_avec_lunettes_de_soleil:',
        'ja': u':サングラスで笑顔:',
        'ko': u':선글라스_낀_얼굴:',
        'pt': u':rosto_sorridente_com_óculos_escuros:',
        'it': ':faccina_con_sorriso_e_occhiali_da_sole:',
        'fa': u':باحال:',
        'id': ':wajah_berkacamata_hitam:',
        'zh': u':墨镜笑脸:'
    },
    u'\U0001F972': { # 🥲
        'en' : ':smiling_face_with_tear:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':lachendes_gesicht_mit_träne:',
        'es': u':cara_sonriente_con_lágrima:',
        'fr': ':visage_souriant_avec_une_larme:',
        'ja': u':嬉し涙の顔:',
        'ko': u':눈물_흘리며_웃는_얼굴:',
        'pt': u':rosto_sorridente_com_lágrima:',
        'it': ':faccina_sorridente_con_lacrima:',
        'fa': u':چهرهٔ_خندان_با_اشک:',
        'id': ':wajah_tersenyum_dengan_air_mata:',
        'zh': u':含泪的笑脸:'
    },
    u'\U0001F60F': { # 😏
        'en' : ':smirking_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':smirk:'],
        'de': u':süffisant_lächelndes_gesicht:',
        'es': ':cara_sonriendo_con_superioridad:',
        'fr': ':visage_avec_un_sourire_malin:',
        'ja': u':薄笑いをする顔:',
        'ko': u':히죽거리는_얼굴:',
        'pt': ':rosto_com_sorriso_maroto:',
        'it': ':faccina_con_sorrisetto:',
        'fa': u':پوزخند:',
        'id': ':wajah_tersenyum_sombong:',
        'zh': u':得意:'
    },
    u'\U0001F40C': { # 🐌
        'en' : ':snail:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schnecke:',
        'es': ':caracol:',
        'fr': ':escargot:',
        'ja': u':かたつむり:',
        'ko': u':달팽이:',
        'pt': ':caracol:',
        'it': ':lumaca:',
        'fa': u':حلزون:',
        'id': ':siput:',
        'zh': u':蜗牛:'
    },
    u'\U0001F40D': { # 🐍
        'en' : ':snake:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schlange:',
        'es': ':serpiente:',
        'fr': ':serpent:',
        'ja': u':ヘビ:',
        'ko': u':뱀:',
        'pt': ':cobra:',
        'it': ':serpente:',
        'fa': u':مار:',
        'id': ':ular:',
        'zh': u':蛇:'
    },
    u'\U0001F927': { # 🤧
        'en' : ':sneezing_face:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':niesendes_gesicht:',
        'es': ':cara_estornudando:',
        'fr': u':visage_qui_éternue:',
        'ja': u':くしゃみする顔:',
        'ko': u':재채기하는_얼굴:',
        'pt': ':rosto_espirrando:',
        'it': ':faccina_che_starnutisce:',
        'fa': u':عطسه:',
        'id': ':bersin:',
        'zh': u':打喷嚏:'
    },
    u'\U0001F3D4\U0000FE0F': { # 🏔️
        'en' : ':snow-capped_mountain:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':mountain_snow:', ':snow_capped_mountain:'],
        'variant': True,
        'de': ':schneebedeckter_berg:',
        'es': u':montaña_con_nieve:',
        'fr': u':montagne_enneigée:',
        'ja': u':雪山:',
        'ko': u':눈_덮인_산:',
        'pt': ':montanha_com_neve:',
        'it': ':montagna_innevata:',
        'fa': u':قله_برفی:',
        'id': ':gunung_dengan_puncak_bersalju:',
        'zh': u':雪山:'
    },
    u'\U0001F3D4': { # 🏔
        'en' : ':snow-capped_mountain:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':mountain_snow:', ':snow_capped_mountain:'],
        'variant': True,
        'de': ':schneebedeckter_berg:',
        'es': u':montaña_con_nieve:',
        'fr': u':montagne_enneigée:',
        'ja': u':雪山:',
        'ko': u':눈_덮인_산:',
        'pt': ':montanha_com_neve:',
        'it': ':montagna_innevata:',
        'fa': u':قلهٔ_برفی:',
        'id': ':gunung_dengan_puncak_bersalju:',
        'zh': u':雪山:'
    },
    u'\U0001F3C2': { # 🏂
        'en' : ':snowboarder:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':snowboarder(in):',
        'es': ':practicante_de_snowboard:',
        'fr': ':snowboardeur:',
        'ja': u':スノーボーダー:',
        'ko': u':스노보드_타는_사람:',
        'pt': ':praticante_de_snowboard:',
        'it': ':persona_sullo_snowboard:',
        'fa': u':اسنوبرد:',
        'id': ':peselancar_salju:',
        'zh': u':滑雪板:'
    },
    u'\U0001F3C2\U0001F3FF': { # 🏂🏿
        'en' : ':snowboarder_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':snowboarder(in)_dunkle_hautfarbe:',
        'es': ':practicante_de_snowboard_tono_de_piel_oscuro:',
        'fr': u':snowboardeur_peau_foncée:',
        'ja': u':スノーボーダー_濃い肌色:',
        'ko': u':스노보드_타는_사람_검은색_피부:',
        'pt': ':praticante_de_snowboard_pele_escura:',
        'it': ':persona_sullo_snowboard_carnagione_scura:',
        'fa': u':اسنوبرد_پوست_آبنوسی:',
        'id': ':peselancar_salju_warna_kulit_gelap:',
        'zh': u':滑雪板_较深肤色:'
    },
    u'\U0001F3C2\U0001F3FB': { # 🏂🏻
        'en' : ':snowboarder_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':snowboarder(in)_helle_hautfarbe:',
        'es': ':practicante_de_snowboard_tono_de_piel_claro:',
        'fr': ':snowboardeur_peau_claire:',
        'ja': u':スノーボーダー_薄い肌色:',
        'ko': u':스노보드_타는_사람_하얀_피부:',
        'pt': ':praticante_de_snowboard_pele_clara:',
        'it': ':persona_sullo_snowboard_carnagione_chiara:',
        'fa': u':اسنوبرد_پوست_سفید:',
        'id': ':peselancar_salju_warna_kulit_cerah:',
        'zh': u':滑雪板_较浅肤色:'
    },
    u'\U0001F3C2\U0001F3FE': { # 🏂🏾
        'en' : ':snowboarder_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':snowboarder(in)_mitteldunkle_hautfarbe:',
        'es': ':practicante_de_snowboard_tono_de_piel_oscuro_medio:',
        'fr': ':snowboardeur_peau_mate:',
        'ja': u':スノーボーダー_やや濃い肌色:',
        'ko': u':스노보드_타는_사람_진한_갈색_피부:',
        'pt': ':praticante_de_snowboard_pele_morena_escura:',
        'it': ':persona_sullo_snowboard_carnagione_abbastanza_scura:',
        'fa': u':اسنوبرد_پوست_گندمی:',
        'id': ':peselancar_salju_warna_kulit_gelap-sedang:',
        'zh': u':滑雪板_中等深肤色:'
    },
    u'\U0001F3C2\U0001F3FC': { # 🏂🏼
        'en' : ':snowboarder_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':snowboarder(in)_mittelhelle_hautfarbe:',
        'es': ':practicante_de_snowboard_tono_de_piel_claro_medio:',
        'fr': ':snowboardeur_peau_moyennement_claire:',
        'ja': u':スノーボーダー_やや薄い肌色:',
        'ko': u':스노보드_타는_사람_연한_갈색_피부:',
        'pt': ':praticante_de_snowboard_pele_morena_clara:',
        'it': ':persona_sullo_snowboard_carnagione_abbastanza_chiara:',
        'fa': u':اسنوبرد_پوست_روشن:',
        'id': ':peselancar_salju_warna_kulit_cerah-sedang:',
        'zh': u':滑雪板_中等浅肤色:'
    },
    u'\U0001F3C2\U0001F3FD': { # 🏂🏽
        'en' : ':snowboarder_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':snowboarder(in)_mittlere_hautfarbe:',
        'es': ':practicante_de_snowboard_tono_de_piel_medio:',
        'fr': u':snowboardeur_peau_légèrement_mate:',
        'ja': u':スノーボーダー_中間の肌色:',
        'ko': u':스노보드_타는_사람_갈색_피부:',
        'pt': ':praticante_de_snowboard_pele_morena:',
        'it': ':persona_sullo_snowboard_carnagione_olivastra:',
        'fa': u':اسنوبرد_پوست_طلایی:',
        'id': ':peselancar_salju_warna_kulit_sedang:',
        'zh': u':滑雪板_中等肤色:'
    },
    u'\U00002744\U0000FE0F': { # ❄️
        'en' : ':snowflake:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':schneeflocke:',
        'es': ':copo_de_nieve:',
        'fr': ':flocon:',
        'ja': u':雪の結晶:',
        'ko': u':눈송이:',
        'pt': ':floco_de_neve:',
        'it': ':fiocco_di_neve:',
        'fa': u':برف_دانه:',
        'id': ':serpihan_salju:',
        'zh': u':雪花:'
    },
    u'\U00002744': { # ❄
        'en' : ':snowflake:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':schneeflocke:',
        'es': ':copo_de_nieve:',
        'fr': ':flocon:',
        'ja': u':雪の結晶:',
        'ko': u':눈송이:',
        'pt': ':floco_de_neve:',
        'it': ':fiocco_di_neve:',
        'fa': u':برف_دانه:',
        'id': ':serpihan_salju:',
        'zh': u':雪花:'
    },
    u'\U00002603\U0000FE0F': { # ☃️
        'en' : ':snowman:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':snowman_with_snow:'],
        'variant': True,
        'de': ':schneemann_im_schnee:',
        'es': u':muñeco_de_nieve_con_nieve:',
        'fr': ':bonhomme_de_neige:',
        'ja': u':雪だるまと雪:',
        'ko': u':눈사람:',
        'pt': ':boneco_de_neve:',
        'it': ':pupazzo_di_neve:',
        'fa': u':آدم_برفی:',
        'id': ':boneka_salju_dengan_hujan_salju:',
        'zh': u':雪与雪人:'
    },
    u'\U00002603': { # ☃
        'en' : ':snowman:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':snowman_with_snow:'],
        'variant': True,
        'de': ':schneemann_im_schnee:',
        'es': u':muñeco_de_nieve_con_nieve:',
        'fr': ':bonhomme_de_neige:',
        'ja': u':雪だるまと雪:',
        'ko': u':눈사람:',
        'pt': ':boneco_de_neve:',
        'it': ':pupazzo_di_neve:',
        'fa': u':آدم_برفی:',
        'id': ':boneka_salju_dengan_hujan_salju:',
        'zh': u':雪与雪人:'
    },
    u'\U000026C4': { # ⛄
        'en' : ':snowman_without_snow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':snowman:'],
        'variant': True,
        'de': ':schneemann_ohne_schneeflocken:',
        'es': u':muñeco_de_nieve:',
        'fr': ':bonhomme_de_neige_sans_neige:',
        'ja': u':雪だるま:',
        'ko': u':스노우맨:',
        'pt': ':boneco_de_neve_sem_neve:',
        'it': ':pupazzo_di_neve_senza_neve:',
        'fa': u':آدم_برفی_بدون_برف:',
        'id': ':boneka_salju_tanpa_salju:',
        'zh': u':雪人:'
    },
    u'\U0001F9FC': { # 🧼
        'en' : ':soap:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':seife:',
        'es': u':jabón:',
        'fr': ':savon:',
        'ja': u':石けん:',
        'ko': u':비누:',
        'pt': ':sabonete:',
        'it': ':sapone:',
        'fa': u':صابون:',
        'id': ':sabun:',
        'zh': u':皂:'
    },
    u'\U000026BD': { # ⚽
        'en' : ':soccer_ball:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':soccer:'],
        'variant': True,
        'de': u':fußball:',
        'es': u':balón_de_fútbol:',
        'fr': ':ballon_de_football:',
        'ja': u':サッカー:',
        'ko': u':축구공:',
        'pt': ':bola_de_futebol:',
        'it': ':pallone_da_calcio:',
        'fa': u':توپ_فوتبال:',
        'id': ':bola_sepak:',
        'zh': u':足球:'
    },
    u'\U0001F9E6': { # 🧦
        'en' : ':socks:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':socken:',
        'es': ':calcetines:',
        'fr': ':chaussettes:',
        'ja': u':ソックス:',
        'ko': u':양말:',
        'pt': ':meias:',
        'it': ':calzini:',
        'fa': u':جوراب:',
        'id': ':kaus_kaki:',
        'zh': u':袜子:'
    },
    u'\U0001F366': { # 🍦
        'en' : ':soft_ice_cream:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':icecream:'],
        'de': ':softeis:',
        'es': ':cucurucho_de_helado:',
        'fr': ':glace_italienne:',
        'ja': u':ソフトクリーム:',
        'ko': u':소프트_아이스크림:',
        'pt': ':sorvete_italiano:',
        'it': ':cono_gelato:',
        'fa': u':بستنی_قیفی:',
        'id': ':es_krim_lembut:',
        'zh': u':圆筒冰激凌:'
    },
    u'\U0001F94E': { # 🥎
        'en' : ':softball:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':softball:',
        'es': ':pelota_de_softball:',
        'fr': ':softball:',
        'ja': u':ソフトボール:',
        'ko': u':소프트볼:',
        'pt': ':softbol:',
        'it': ':palla_da_softball:',
        'fa': u':سافت_بال:',
        'id': ':sofbol:',
        'zh': u':垒球:'
    },
    u'\U00002660\U0000FE0F': { # ♠️
        'en' : ':spade_suit:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':spades:'],
        'variant': True,
        'de': ':pik:',
        'es': ':palo_de_picas:',
        'fr': ':pique:',
        'ja': u':スペード:',
        'ko': u':스페이드:',
        'pt': ':naipe_de_espadas:',
        'it': ':picche:',
        'fa': u':خال_پیک:',
        'id': ':sekop:',
        'zh': u':黑桃:'
    },
    u'\U00002660': { # ♠
        'en' : ':spade_suit:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':spades:'],
        'variant': True,
        'de': ':pik:',
        'es': ':palo_de_picas:',
        'fr': ':pique:',
        'ja': u':スペード:',
        'ko': u':스페이드:',
        'pt': ':naipe_de_espadas:',
        'it': ':picche:',
        'fa': u':خال_پیک:',
        'id': ':sekop:',
        'zh': u':黑桃:'
    },
    u'\U0001F35D': { # 🍝
        'en' : ':spaghetti:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':spaghetti:',
        'es': ':espagueti:',
        'fr': ':spaghetti:',
        'ja': u':スパゲッティ:',
        'ko': u':스파게티:',
        'pt': ':espaguete:',
        'it': ':spaghetti:',
        'fa': u':اسپاگتی:',
        'id': ':spageti:',
        'zh': u':意粉:'
    },
    u'\U00002747\U0000FE0F': { # ❇️
        'en' : ':sparkle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':funkeln:',
        'es': ':chispa:',
        'fr': u':éclat:',
        'ja': u':スパークル:',
        'ko': u':반짝임:',
        'pt': u':faísca:',
        'it': ':scintilla_stilizzata:',
        'fa': u':جرقه:',
        'id': ':kilauan:',
        'zh': u':火花:'
    },
    u'\U00002747': { # ❇
        'en' : ':sparkle:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':funkeln:',
        'es': ':chispa:',
        'fr': u':éclat:',
        'ja': u':スパークル:',
        'ko': u':반짝임:',
        'pt': u':faísca:',
        'it': ':scintilla_stilizzata:',
        'fa': u':جرقه:',
        'id': ':kilauan:',
        'zh': u':火花:'
    },
    u'\U0001F387': { # 🎇
        'en' : ':sparkler:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wunderkerze:',
        'es': ':bengala:',
        'fr': ':cierge_magique:',
        'ja': u':線香花火:',
        'ko': u':불꽃:',
        'pt': ':vela_estrela:',
        'it': ':stellina_scintillante:',
        'fa': u':فشفشه:',
        'id': ':kembang_api_batang:',
        'zh': u':烟花:'
    },
    u'\U00002728': { # ✨
        'en' : ':sparkles:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':funkelnde_sterne:',
        'es': ':chispas:',
        'fr': u':étincelles:',
        'ja': u':きらきら:',
        'ko': u':블링블링:',
        'pt': ':brilhos:',
        'it': ':stelline:',
        'fa': u':درخشش:',
        'id': ':berkilau:',
        'zh': u':闪亮:'
    },
    u'\U0001F496': { # 💖
        'en' : ':sparkling_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':funkelndes_herz:',
        'es': u':corazón_brillante:',
        'fr': u':cœur_étincelant:',
        'ja': u':きらきらハート:',
        'ko': u':빛나는_하트:',
        'pt': u':coração_brilhante:',
        'it': ':cuore_che_luccica:',
        'fa': u':قلب_درخشان:',
        'id': ':hati_bersinar:',
        'zh': u':闪亮的心:'
    },
    u'\U0001F64A': { # 🙊
        'en' : ':speak-no-evil_monkey:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':speak_no_evil:'],
        'de': ':sich_den_mund_zuhaltendes_affengesicht:',
        'es': ':mono_con_la_boca_tapada:',
        'fr': ':singe_ne_rien_dire:',
        'ja': u':言わざる:',
        'ko': u':입을_막고_있는_원숭이:',
        'pt': u':macaco_que_não_fala_nada:',
        'it': ':non_parlo:',
        'fa': u':میمون_شرنگو:',
        'id': ':tidak_bicara:',
        'zh': u':非礼勿言:'
    },
    u'\U0001F50A': { # 🔊
        'en' : ':speaker_high_volume:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':loud_sound:'],
        'de': u':lautsprecher_mit_hoher_lautstärke:',
        'es': ':altavoz_a_volumen_alto:',
        'fr': u':volume_des_enceintes_élevé:',
        'ja': u':スピーカー音量大:',
        'ko': u':스피커_소리_크게:',
        'pt': ':alto-falante_com_volume_alto:',
        'it': ':altoparlante_a_volume_alto:',
        'fa': u':بلندگو_با_صدای_بلند:',
        'id': ':volume_speaker_tinggi:',
        'zh': u':高音量的扬声器:'
    },
    u'\U0001F508': { # 🔈
        'en' : ':speaker_low_volume:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':speaker:'],
        'variant': True,
        'de': u':lautsprecher_mit_geringer_lautstärke:',
        'es': ':altavoz_a_volumen_bajo:',
        'fr': ':volume_des_enceintes_faible:',
        'ja': u':スピーカー:',
        'ko': u':스피커:',
        'pt': ':alto-falante_com_volume_baixo:',
        'it': ':altoparlante_a_volume_basso:',
        'fa': u':بلندگو_با_صدای_کم:',
        'id': ':volume_speaker_rendah:',
        'zh': u':低音量的扬声器:'
    },
    u'\U0001F509': { # 🔉
        'en' : ':speaker_medium_volume:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':sound:'],
        'de': u':lautsprecher_mit_mittlerer_lautstärke:',
        'es': ':altavoz_a_volumen_medio:',
        'fr': ':volume_des_enceintes_moyen:',
        'ja': u':スピーカー音量小:',
        'ko': u':스피커_소리_작게:',
        'pt': u':alto-falante_com_volume_médio:',
        'it': ':altoparlante_a_volume_intermedio:',
        'fa': u':بلندگو_با_صدای_متعادل:',
        'id': ':volume_speaker_medium:',
        'zh': u':中等音量的扬声器:'
    },
    u'\U0001F5E3\U0000FE0F': { # 🗣️
        'en' : ':speaking_head:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':speaking_head_in_silhouette:'],
        'variant': True,
        'de': ':sprechender_kopf:',
        'es': ':cabeza_parlante:',
        'fr': u':tête_qui_parle:',
        'ja': u':話す人のシルエット:',
        'ko': u':말하고_있는_옆얼굴:',
        'pt': ':silhueta_falando:',
        'it': ':persona_che_parla:',
        'fa': u':درحال_صحبت_کردن:',
        'id': ':kepala_berbicara:',
        'zh': u':说话:'
    },
    u'\U0001F5E3': { # 🗣
        'en' : ':speaking_head:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':speaking_head_in_silhouette:'],
        'variant': True,
        'de': ':sprechender_kopf:',
        'es': ':cabeza_parlante:',
        'fr': u':tête_qui_parle:',
        'ja': u':話す人のシルエット:',
        'ko': u':말하고_있는_옆얼굴:',
        'pt': ':silhueta_falando:',
        'it': ':persona_che_parla:',
        'fa': u':درحال_صحبت_کردن:',
        'id': ':kepala_berbicara:',
        'zh': u':说话:'
    },
    u'\U0001F4AC': { # 💬
        'en' : ':speech_balloon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':sprechblase_mit_drei_punkten:',
        'es': u':bocadillo_de_diálogo:',
        'fr': ':bulle_de_parole:',
        'ja': u':会話の吹き出し:',
        'ko': u':말풍선:',
        'pt': u':balão_de_diálogo:',
        'it': ':fumetto:',
        'fa': u':بالن_گفتار:',
        'id': ':balon_ucapan:',
        'zh': u':话语气泡:'
    },
    u'\U0001F6A4': { # 🚤
        'en' : ':speedboat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':schnellboot:',
        'es': ':lancha_motora:',
        'fr': ':hors-bord:',
        'ja': u':スピードボート:',
        'ko': u':쾌속정:',
        'pt': ':lancha:',
        'it': ':motoscafo:',
        'fa': u':قایق_تندرو:',
        'id': ':perahu_cepat:',
        'zh': u':快艇:'
    },
    u'\U0001F577\U0000FE0F': { # 🕷️
        'en' : ':spider:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':spinne:',
        'es': u':araña:',
        'fr': u':araignée:',
        'ja': u':クモ:',
        'ko': u':거미:',
        'pt': ':aranha:',
        'it': ':ragno:',
        'fa': u':عنکبوت:',
        'id': ':laba-laba:',
        'zh': u':蜘蛛:'
    },
    u'\U0001F577': { # 🕷
        'en' : ':spider:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':spinne:',
        'es': u':araña:',
        'fr': u':araignée:',
        'ja': u':クモ:',
        'ko': u':거미:',
        'pt': ':aranha:',
        'it': ':ragno:',
        'fa': u':عنکبوت:',
        'id': ':laba-laba:',
        'zh': u':蜘蛛:'
    },
    u'\U0001F578\U0000FE0F': { # 🕸️
        'en' : ':spider_web:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':spinnennetz:',
        'es': u':tela_de_araña:',
        'fr': u':toile_d’araignée:',
        'ja': u':クモの巣:',
        'ko': u':거미줄:',
        'pt': ':teia_de_aranha:',
        'it': ':ragnatela:',
        'fa': u':تار_عنکبوت:',
        'id': ':jaring_laba-laba:',
        'zh': u':蜘蛛网:'
    },
    u'\U0001F578': { # 🕸
        'en' : ':spider_web:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':spinnennetz:',
        'es': u':tela_de_araña:',
        'fr': u':toile_d’araignée:',
        'ja': u':クモの巣:',
        'ko': u':거미줄:',
        'pt': ':teia_de_aranha:',
        'it': ':ragnatela:',
        'fa': u':تار_عنکبوت:',
        'id': ':jaring_laba-laba:',
        'zh': u':蜘蛛网:'
    },
    u'\U0001F5D3\U0000FE0F': { # 🗓️
        'en' : ':spiral_calendar:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':spiral_calendar_pad:'],
        'variant': True,
        'de': ':spiralkalender:',
        'es': ':calendario_de_espiral:',
        'fr': u':calendrier_à_spirale:',
        'ja': u':月めくりカレンダー:',
        'ko': u':스프링_달력:',
        'pt': u':calendário_espiral:',
        'it': ':calendario_a_spirale:',
        'fa': u':تقویم_سیمی:',
        'id': ':kalender_spiral:',
        'zh': u':线圈日历:'
    },
    u'\U0001F5D3': { # 🗓
        'en' : ':spiral_calendar:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':spiral_calendar_pad:'],
        'variant': True,
        'de': ':spiralkalender:',
        'es': ':calendario_de_espiral:',
        'fr': u':calendrier_à_spirale:',
        'ja': u':月めくりカレンダー:',
        'ko': u':스프링_달력:',
        'pt': u':calendário_espiral:',
        'it': ':calendario_a_spirale:',
        'fa': u':تقویم_سیمی:',
        'id': ':kalender_spiral:',
        'zh': u':线圈日历:'
    },
    u'\U0001F5D2\U0000FE0F': { # 🗒️
        'en' : ':spiral_notepad:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':spiral_note_pad:'],
        'variant': True,
        'de': ':notizblock:',
        'es': ':bloc_de_notas_de_espiral:',
        'fr': u':bloc-notes_à_spirale:',
        'ja': u':メモ帳:',
        'ko': u':스프링_노트:',
        'pt': ':bloco_espiral:',
        'it': ':blocco_per_appunti_con_spirale:',
        'fa': u':دفترچه_یادداشت_سیمی:',
        'id': ':catatan_spiral:',
        'zh': u':线圈本:'
    },
    u'\U0001F5D2': { # 🗒
        'en' : ':spiral_notepad:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':spiral_note_pad:'],
        'variant': True,
        'de': ':notizblock:',
        'es': ':bloc_de_notas_de_espiral:',
        'fr': u':bloc-notes_à_spirale:',
        'ja': u':メモ帳:',
        'ko': u':스프링_노트:',
        'pt': ':bloco_espiral:',
        'it': ':blocco_per_appunti_con_spirale:',
        'fa': u':دفترچهٔ_یادداشت_سیمی:',
        'id': ':catatan_spiral:',
        'zh': u':线圈本:'
    },
    u'\U0001F41A': { # 🐚
        'en' : ':spiral_shell:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':shell:'],
        'de': ':schneckenhaus:',
        'es': ':concha_de_mar:',
        'fr': ':coquille_en_spirale:',
        'ja': u':巻き貝:',
        'ko': u':달팽이집:',
        'pt': ':caramujo:',
        'it': ':conchiglia:',
        'fa': u':صدف_مارپیچی:',
        'id': ':cangkang_spiral:',
        'zh': u':海螺:'
    },
    u'\U0001F9FD': { # 🧽
        'en' : ':sponge:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':schwamm:',
        'es': ':esponja:',
        'fr': u':éponge:',
        'ja': u':スポンジ:',
        'ko': u':스펀지:',
        'pt': ':esponja:',
        'it': ':spugna:',
        'fa': u':لیف_حمام:',
        'id': ':spons:',
        'zh': u':海绵:'
    },
    u'\U0001F944': { # 🥄
        'en' : ':spoon:',
        'status' : fully_qualified,
        'E' : 3,
        'de': u':löffel:',
        'es': ':cuchara:',
        'fr': u':cuillère:',
        'ja': u':スプーン:',
        'ko': u':숟가락:',
        'pt': ':colher:',
        'it': ':cucchiaio:',
        'fa': u':قاشق:',
        'id': ':sendok:',
        'zh': u':匙:'
    },
    u'\U0001F699': { # 🚙
        'en' : ':sport_utility_vehicle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':blue_car:'],
        'de': ':wohnmobil:',
        'es': u':vehículo_deportivo_utilitario:',
        'fr': u':véhicule_utilitaire_sport:',
        'ja': u':アールブイ車:',
        'ko': u':지프:',
        'pt': ':suv:',
        'it': ':suv:',
        'fa': u':خودروی_شاسی_بلند:',
        'id': ':kendaraan_rekreasi:',
        'zh': u':运动型多用途车:'
    },
    u'\U0001F3C5': { # 🏅
        'en' : ':sports_medal:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':medal_sports:'],
        'de': ':sportmedaille:',
        'es': ':medalla_deportiva:',
        'fr': u':médaille_sportive:',
        'ja': u':メダル:',
        'ko': u':스포츠_메달:',
        'pt': ':medalha_esportiva:',
        'it': ':medaglia_sportiva:',
        'fa': u':مدال_ورزشی:',
        'id': ':medali_olahraga:',
        'zh': u':奖牌:'
    },
    u'\U0001F433': { # 🐳
        'en' : ':spouting_whale:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':whale:'],
        'de': ':blasender_wal:',
        'es': ':ballena_soltando_un_chorro:',
        'fr': u':baleine_soufflant_par_son_évent:',
        'ja': u':潮吹きクジラ:',
        'ko': u':물_뿜는_고래:',
        'pt': u':baleia_esguichando_água:',
        'it': ':balena_che_spruzza_acqua:',
        'fa': u':نهنگ_در_حال_آب_فشانی:',
        'id': ':ikan_paus_menyembur:',
        'zh': u':喷水的鲸:'
    },
    u'\U0001F991': { # 🦑
        'en' : ':squid:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':tintenfisch:',
        'es': ':calamar:',
        'fr': ':calamar:',
        'ja': u':イカ:',
        'ko': u':오징어:',
        'pt': ':lula:',
        'it': ':calamaro:',
        'fa': u':ماهی_مرکب:',
        'id': ':cumi-cumi:',
        'zh': u':乌贼:'
    },
    u'\U0001F61D': { # 😝
        'en' : ':squinting_face_with_tongue:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':stuck_out_tongue_closed_eyes:'],
        'de': ':gesicht_mit_herausgestreckter_zunge_und_zusammengekniffenen_augen:',
        'es': ':cara_con_ojos_cerrados_y_lengua_fuera:',
        'fr': u':visage_qui_tire_la_langue_les_yeux_plissés:',
        'ja': u':目を閉じてべー:',
        'ko': u':눈을_감고_메롱하는_얼굴:',
        'pt': u':rosto_com_olhos_semicerrados_e_língua_para_fora:',
        'it': ':faccina_con_un_gran_sorriso_che_mostra_la_lingua:',
        'fa': u':زبونک_با_چشم_بسته:',
        'id': ':wajah_menjulurkan_lidah_dan_memejamkan_mata:',
        'zh': u':眯眼吐舌:'
    },
    u'\U0001F3DF\U0000FE0F': { # 🏟️
        'en' : ':stadium:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':stadion:',
        'es': ':estadio:',
        'fr': ':stade:',
        'ja': u':競技場:',
        'ko': u':경기장:',
        'pt': u':estádio:',
        'it': ':stadio:',
        'fa': u':ورزشگاه:',
        'id': ':stadion:',
        'zh': u':体育馆:'
    },
    u'\U0001F3DF': { # 🏟
        'en' : ':stadium:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':stadion:',
        'es': ':estadio:',
        'fr': ':stade:',
        'ja': u':競技場:',
        'ko': u':경기장:',
        'pt': u':estádio:',
        'it': ':stadio:',
        'fa': u':ورزشگاه:',
        'id': ':stadion:',
        'zh': u':体育馆:'
    },
    u'\U00002B50': { # ⭐
        'en' : ':star:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':weißer_mittelgroßer_stern:',
        'es': ':estrella:',
        'fr': u':étoile:',
        'ja': u':スター:',
        'ko': u':별:',
        'pt': u':estrela_branca_média:',
        'it': ':stella:',
        'fa': u':ستاره_سفید:',
        'id': ':bintang_medium_putih:',
        'zh': u':星星:'
    },
    u'\U0001F929': { # 🤩
        'en' : ':star-struck:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':star_struck:'],
        'de': u':überwältigt:',
        'es': ':cara_sonriendo_con_estrellas:',
        'fr': u':visage_avec_des_étoiles_à_la_place_des_yeux:',
        'ja': u':目が星の笑顔:',
        'ko': u':반한_얼굴:',
        'pt': ':rosto_com_olhar_maravilhado:',
        'it': ':colpo_di_fulmine:',
        'fa': u':آدم_مشهور_دیده:',
        'id': ':wajah_dengan_mata_berbentuk_bintang:',
        'zh': u':好崇拜哦:'
    },
    u'\U0000262A\U0000FE0F': { # ☪️
        'en' : ':star_and_crescent:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':hilal_und_stern:',
        'es': ':media_luna_y_estrella:',
        'fr': u':lune_et_étoile:',
        'ja': u':星と三日月:',
        'ko': u':초승달과_별:',
        'pt': ':estrela_e_lua_crescente:',
        'it': ':mezzaluna_e_stella:',
        'fa': u':هلال_و_ستاره:',
        'id': ':bintang_dan_bulan:',
        'zh': u':星月:'
    },
    u'\U0000262A': { # ☪
        'en' : ':star_and_crescent:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':hilal_und_stern:',
        'es': ':media_luna_y_estrella:',
        'fr': u':lune_et_étoile:',
        'ja': u':星と三日月:',
        'ko': u':초승달과_별:',
        'pt': ':estrela_e_lua_crescente:',
        'it': ':mezzaluna_e_stella:',
        'fa': u':هلال_و_ستاره:',
        'id': ':bintang_dan_bulan:',
        'zh': u':星月:'
    },
    u'\U00002721\U0000FE0F': { # ✡️
        'en' : ':star_of_David:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':star_of_david:'],
        'variant': True,
        'de': ':davidstern:',
        'es': ':estrella_de_david:',
        'fr': u':étoile_de_david:',
        'ja': u':ダビデの星:',
        'ko': u':다비드별:',
        'pt': ':estrela_de_davi:',
        'it': ':stella_di_david:',
        'fa': u':ستاره_داود:',
        'id': ':bintang_daud:',
        'zh': u':六芒星:'
    },
    u'\U00002721': { # ✡
        'en' : ':star_of_David:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':star_of_david:'],
        'variant': True,
        'de': ':davidstern:',
        'es': ':estrella_de_david:',
        'fr': u':étoile_de_david:',
        'ja': u':ダビデの星:',
        'ko': u':다비드별:',
        'pt': ':estrela_de_davi:',
        'it': ':stella_di_david:',
        'fa': u':ستارهٔ_داود:',
        'id': ':bintang_daud:',
        'zh': u':六芒星:'
    },
    u'\U0001F689': { # 🚉
        'en' : ':station:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':bahnhof:',
        'es': u':estación_de_tren:',
        'fr': ':gare:',
        'ja': u':駅:',
        'ko': u':기차역:',
        'pt': u':estação:',
        'it': ':stazione:',
        'fa': u':ایستگاه_قطار:',
        'id': ':stasiun:',
        'zh': u':车站:'
    },
    u'\U0001F35C': { # 🍜
        'en' : ':steaming_bowl:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ramen:'],
        'de': u':schüssel_und_essstäbchen:',
        'es': u':tazón_de_fideos:',
        'fr': ':bol_fumant:',
        'ja': u':ラーメン:',
        'ko': u':국수:',
        'pt': u':lámen:',
        'it': ':ciotola_fumante:',
        'fa': u':کاسه_نودل:',
        'id': ':mangkuk_mengepul:',
        'zh': u':面条:'
    },
    u'\U0001FA7A': { # 🩺
        'en' : ':stethoscope:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stethoskop:',
        'es': ':estetoscopio:',
        'fr': u':stéthoscope:',
        'ja': u':聴診器:',
        'ko': u':청진기:',
        'pt': u':estetoscópio:',
        'it': ':stetoscopio:',
        'fa': u':گوشی_پزشکی:',
        'id': ':stetoskop:',
        'zh': u':听诊器:'
    },
    u'\U000023F9\U0000FE0F': { # ⏹️
        'en' : ':stop_button:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':black_square_for_stop:'],
        'variant': True,
        'de': ':stopp:',
        'es': ':detener:',
        'fr': ':bouton_stop:',
        'ja': u':停止ボタン:',
        'ko': u':정지_버튼:',
        'pt': u':botão_parar:',
        'it': ':pulsante_stop:',
        'fa': u':دکمه_توقف:',
        'id': ':tombol_berhenti:',
        'zh': u':停止按钮:'
    },
    u'\U000023F9': { # ⏹
        'en' : ':stop_button:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':black_square_for_stop:'],
        'variant': True,
        'de': ':stopp:',
        'es': ':detener:',
        'fr': ':bouton_stop:',
        'ja': u':停止ボタン:',
        'ko': u':정지_버튼:',
        'pt': u':botão_parar:',
        'it': ':pulsante_stop:',
        'fa': u':دکمهٔ_توقف:',
        'id': ':tombol_berhenti:',
        'zh': u':停止按钮:'
    },
    u'\U0001F6D1': { # 🛑
        'en' : ':stop_sign:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':stoppschild:',
        'es': u':señal_de_stop:',
        'fr': ':stop:',
        'ja': u':止まれの標識:',
        'ko': u':멈춤_표시:',
        'pt': ':sinal_de_pare:',
        'it': ':segnale_di_stop:',
        'fa': u':علامت_ایست:',
        'id': ':rambu_stop:',
        'zh': u':停止标志:'
    },
    u'\U000023F1\U0000FE0F': { # ⏱️
        'en' : ':stopwatch:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':stoppuhr:',
        'es': u':cronómetro:',
        'fr': u':chronomètre:',
        'ja': u':ストップウォッチ:',
        'ko': u':스톱워치:',
        'pt': u':cronômetro:',
        'it': ':cronometro:',
        'fa': u':کرنومتر:',
        'id': ':stopwatch:',
        'zh': u':秒表:'
    },
    u'\U000023F1': { # ⏱
        'en' : ':stopwatch:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':stoppuhr:',
        'es': u':cronómetro:',
        'fr': u':chronomètre:',
        'ja': u':ストップウォッチ:',
        'ko': u':스톱워치:',
        'pt': u':cronômetro:',
        'it': ':cronometro:',
        'fa': u':کرنومتر:',
        'id': ':stopwatch:',
        'zh': u':秒表:'
    },
    u'\U0001F4CF': { # 📏
        'en' : ':straight_ruler:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':lineal:',
        'es': ':regla:',
        'fr': u':règle:',
        'ja': u':定規:',
        'ko': u':자:',
        'pt': u':régua_reta:',
        'it': ':righello:',
        'fa': u':خط_کش:',
        'id': ':penggaris_lurus:',
        'zh': u':直尺:'
    },
    u'\U0001F353': { # 🍓
        'en' : ':strawberry:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':erdbeere:',
        'es': ':fresa:',
        'fr': ':fraise:',
        'ja': u':いちご:',
        'ko': u':딸기:',
        'pt': ':morango:',
        'it': ':fragola:',
        'fa': u':توت_فرنگی:',
        'id': ':stroberi:',
        'zh': u':草莓:'
    },
    u'\U0001F9D1\U0000200D\U0001F393': { # 🧑‍🎓
        'en' : ':student:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':student(in):',
        'es': ':estudiante:',
        'fr': u':étudiant_(tous_genres):',
        'ja': u':学生:',
        'ko': u':학생:',
        'pt': ':aluno:',
        'it': ':studente:',
        'fa': u':دانش_آموز:',
        'id': ':murid:',
        'zh': u':学生:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F393': { # 🧑🏿‍🎓
        'en' : ':student_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':student(in)_dunkle_hautfarbe:',
        'es': ':estudiante_tono_de_piel_oscuro:',
        'fr': u':étudiant_(tous_genres)_peau_foncée:',
        'ja': u':学生_濃い肌色:',
        'ko': u':학생_검은색_피부:',
        'pt': ':aluno_pele_escura:',
        'it': ':studente_carnagione_scura:',
        'fa': u':دانش_آموز_پوست_آبنوسی:',
        'id': ':murid_warna_kulit_gelap:',
        'zh': u':学生_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F393': { # 🧑🏻‍🎓
        'en' : ':student_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':student(in)_helle_hautfarbe:',
        'es': ':estudiante_tono_de_piel_claro:',
        'fr': u':étudiant_(tous_genres)_peau_claire:',
        'ja': u':学生_薄い肌色:',
        'ko': u':학생_하얀_피부:',
        'pt': ':aluno_pele_clara:',
        'it': ':studente_carnagione_chiara:',
        'fa': u':دانش_آموز_پوست_سفید:',
        'id': ':murid_warna_kulit_cerah:',
        'zh': u':学生_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F393': { # 🧑🏾‍🎓
        'en' : ':student_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':student(in)_mitteldunkle_hautfarbe:',
        'es': ':estudiante_tono_de_piel_oscuro_medio:',
        'fr': u':étudiant_(tous_genres)_peau_mate:',
        'ja': u':学生_やや濃い肌色:',
        'ko': u':학생_진한_갈색_피부:',
        'pt': ':aluno_pele_morena_escura:',
        'it': ':studente_carnagione_abbastanza_scura:',
        'fa': u':دانش_آموز_پوست_گندمی:',
        'id': ':murid_warna_kulit_gelap-sedang:',
        'zh': u':学生_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F393': { # 🧑🏼‍🎓
        'en' : ':student_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':student(in)_mittelhelle_hautfarbe:',
        'es': ':estudiante_tono_de_piel_claro_medio:',
        'fr': u':étudiant_(tous_genres)_peau_moyennement_claire:',
        'ja': u':学生_やや薄い肌色:',
        'ko': u':학생_연한_갈색_피부:',
        'pt': ':aluno_pele_morena_clara:',
        'it': ':studente_carnagione_abbastanza_chiara:',
        'fa': u':دانش_آموز_پوست_روشن:',
        'id': ':murid_warna_kulit_cerah-sedang:',
        'zh': u':学生_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F393': { # 🧑🏽‍🎓
        'en' : ':student_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':student(in)_mittlere_hautfarbe:',
        'es': ':estudiante_tono_de_piel_medio:',
        'fr': u':étudiant_(tous_genres)_peau_légèrement_mate:',
        'ja': u':学生_中間の肌色:',
        'ko': u':학생_갈색_피부:',
        'pt': ':aluno_pele_morena:',
        'it': ':studente_carnagione_olivastra:',
        'fa': u':دانش_آموز_پوست_طلایی:',
        'id': ':murid_warna_kulit_sedang:',
        'zh': u':学生_中等肤色:'
    },
    u'\U0001F399\U0000FE0F': { # 🎙️
        'en' : ':studio_microphone:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':studiomikrofon:',
        'es': u':micrófono_de_estudio:',
        'fr': ':micro_de_studio:',
        'ja': u':スタジオマイク:',
        'ko': u':스튜디오_마이크:',
        'pt': u':microfone_de_estúdio:',
        'it': ':microfono_radiofonico:',
        'fa': u':میکروفون_استودیویی:',
        'id': ':mikrofon_studio:',
        'zh': u':录音室麦克风:'
    },
    u'\U0001F399': { # 🎙
        'en' : ':studio_microphone:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':studiomikrofon:',
        'es': u':micrófono_de_estudio:',
        'fr': ':micro_de_studio:',
        'ja': u':スタジオマイク:',
        'ko': u':스튜디오_마이크:',
        'pt': u':microfone_de_estúdio:',
        'it': ':microfono_radiofonico:',
        'fa': u':میکروفون_استودیویی:',
        'id': ':mikrofon_studio:',
        'zh': u':录音室麦克风:'
    },
    u'\U0001F959': { # 🥙
        'en' : ':stuffed_flatbread:',
        'status' : fully_qualified,
        'E' : 3,
        'de': u':döner:',
        'es': ':pan_relleno:',
        'fr': ':kebab:',
        'ja': u':ケバブサンド:',
        'ko': u':밀전병에_싼_요리:',
        'pt': u':pão_recheado:',
        'it': ':pita_farcita:',
        'fa': u':لقمه:',
        'id': ':roti_tawar_isi:',
        'zh': u':夹心饼:'
    },
    u'\U00002600\U0000FE0F': { # ☀️
        'en' : ':sun:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sunny:'],
        'variant': True,
        'de': ':sonne:',
        'es': ':sol:',
        'fr': ':soleil:',
        'ja': u':太陽:',
        'ko': u':태양:',
        'pt': ':sol:',
        'it': ':sole:',
        'fa': u':خورشید:',
        'id': ':matahari:',
        'zh': u':太阳:'
    },
    u'\U00002600': { # ☀
        'en' : ':sun:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':sunny:'],
        'variant': True,
        'de': ':sonne:',
        'es': ':sol:',
        'fr': ':soleil:',
        'ja': u':太陽:',
        'ko': u':태양:',
        'pt': ':sol:',
        'it': ':sole:',
        'fa': u':خورشید:',
        'id': ':matahari:',
        'zh': u':太阳:'
    },
    u'\U000026C5': { # ⛅
        'en' : ':sun_behind_cloud:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':partly_sunny:'],
        'variant': True,
        'de': ':sonne_hinter_wolke:',
        'es': u':sol_detrás_de_una_nube:',
        'fr': u':soleil_derrière_les_nuages:',
        'ja': u':曇り時々晴れ:',
        'ko': u':구름_뒤의_해:',
        'pt': u':sol_por_trás_das_nuvens:',
        'it': ':sole_coperto:',
        'fa': u':خورشید_پشت_ابر:',
        'id': ':matahari_di_balik_awan:',
        'zh': u':阴:'
    },
    u'\U0001F325\U0000FE0F': { # 🌥️
        'en' : ':sun_behind_large_cloud:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':white_sun_behind_cloud:'],
        'variant': True,
        'de': u':sonne_hinter_großer_wolke:',
        'es': u':sol_detrás_de_una_nube_grande:',
        'fr': u':soleil_derrière_un_gros_nuage:',
        'ja': u':曇り一時晴れ:',
        'ko': u':큰_구름_뒤의_태양:',
        'pt': ':nublado:',
        'it': ':molto_nuvoloso:',
        'fa': u':خورشید_پشت_ابر_بزرگ:',
        'id': ':matahari_di_balik_awan_besar:',
        'zh': u':多云:'
    },
    u'\U0001F325': { # 🌥
        'en' : ':sun_behind_large_cloud:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':white_sun_behind_cloud:'],
        'variant': True,
        'de': u':sonne_hinter_großer_wolke:',
        'es': u':sol_detrás_de_una_nube_grande:',
        'fr': u':soleil_derrière_un_gros_nuage:',
        'ja': u':曇り一時晴れ:',
        'ko': u':큰_구름_뒤의_태양:',
        'pt': ':nublado:',
        'it': ':molto_nuvoloso:',
        'fa': u':خورشید_پشت_ابر_بزرگ:',
        'id': ':matahari_di_balik_awan_besar:',
        'zh': u':多云:'
    },
    u'\U0001F326\U0000FE0F': { # 🌦️
        'en' : ':sun_behind_rain_cloud:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':white_sun_behind_cloud_with_rain:'],
        'variant': True,
        'de': ':sonne_hinter_regenwolke:',
        'es': u':sol_detrás_de_una_nube_con_lluvia:',
        'fr': u':soleil_derrière_un_nuage_de_pluie:',
        'ja': u':雨時々晴れ:',
        'ko': u':비구름_뒤의_태양:',
        'pt': ':sol_com_chuva:',
        'it': ':sole_coperto_e_pioggia:',
        'fa': u':خورشید_پشت_ابر_بارانی:',
        'id': ':matahari_di_balik_awan_hujan:',
        'zh': u':晴转雨:'
    },
    u'\U0001F326': { # 🌦
        'en' : ':sun_behind_rain_cloud:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':white_sun_behind_cloud_with_rain:'],
        'variant': True,
        'de': ':sonne_hinter_regenwolke:',
        'es': u':sol_detrás_de_una_nube_con_lluvia:',
        'fr': u':soleil_derrière_un_nuage_de_pluie:',
        'ja': u':雨時々晴れ:',
        'ko': u':비구름_뒤의_태양:',
        'pt': ':sol_com_chuva:',
        'it': ':sole_coperto_e_pioggia:',
        'fa': u':خورشید_پشت_ابر_بارانی:',
        'id': ':matahari_di_balik_awan_hujan:',
        'zh': u':晴转雨:'
    },
    u'\U0001F324\U0000FE0F': { # 🌤️
        'en' : ':sun_behind_small_cloud:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':white_sun_with_small_cloud:'],
        'variant': True,
        'de': ':sonne_hinter_kleiner_wolke:',
        'es': u':sol_detrás_de_una_nube_pequeña:',
        'fr': u':soleil_derrière_un_petit_nuage:',
        'ja': u':晴れ時々曇り:',
        'ko': u':작은_구름_뒤의_태양:',
        'pt': ':sol_com_nuvens:',
        'it': ':parzialmente_nuvoloso:',
        'fa': u':خورشید_پشت_ابر_کوچک:',
        'id': ':matahari_di_balik_awan_kecil:',
        'zh': u':晴偶有云:'
    },
    u'\U0001F324': { # 🌤
        'en' : ':sun_behind_small_cloud:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':white_sun_with_small_cloud:'],
        'variant': True,
        'de': ':sonne_hinter_kleiner_wolke:',
        'es': u':sol_detrás_de_una_nube_pequeña:',
        'fr': u':soleil_derrière_un_petit_nuage:',
        'ja': u':晴れ時々曇り:',
        'ko': u':작은_구름_뒤의_태양:',
        'pt': ':sol_com_nuvens:',
        'it': ':parzialmente_nuvoloso:',
        'fa': u':خورشید_پشت_ابر_کوچک:',
        'id': ':matahari_di_balik_awan_kecil:',
        'zh': u':晴偶有云:'
    },
    u'\U0001F31E': { # 🌞
        'en' : ':sun_with_face:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':sonne_mit_gesicht:',
        'es': ':sol_con_cara:',
        'fr': ':soleil_avec_visage:',
        'ja': u':顔のある太陽:',
        'ko': u':얼굴이_있는_해:',
        'pt': ':rosto_do_sol:',
        'it': ':faccina_sole:',
        'fa': u':صورت_خورشید:',
        'id': ':wajah_matahari:',
        'zh': u':微笑的太阳:'
    },
    u'\U0001F33B': { # 🌻
        'en' : ':sunflower:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':sonnenblume:',
        'es': ':girasol:',
        'fr': ':tournesol:',
        'ja': u':ヒマワリ:',
        'ko': u':해바라기:',
        'pt': ':girassol:',
        'it': ':girasole:',
        'fa': u':گل_آفتابگردان:',
        'id': ':bunga_matahari:',
        'zh': u':向日葵:'
    },
    u'\U0001F576\U0000FE0F': { # 🕶️
        'en' : ':sunglasses:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':dark_sunglasses:'],
        'variant': True,
        'de': ':sonnenbrille:',
        'es': ':gafas_de_sol:',
        'fr': ':lunettes_de_soleil:',
        'ja': u':サングラス:',
        'ko': u':선글라스:',
        'pt': u':óculos_escuros:',
        'it': ':occhiali_da_sole:',
        'fa': u':عینک_آفتابی:',
        'id': ':kacamata_hitam:',
        'zh': u':墨镜:'
    },
    u'\U0001F576': { # 🕶
        'en' : ':sunglasses:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':dark_sunglasses:'],
        'variant': True,
        'de': ':sonnenbrille:',
        'es': ':gafas_de_sol:',
        'fr': ':lunettes_de_soleil:',
        'ja': u':サングラス:',
        'ko': u':선글라스:',
        'pt': u':óculos_escuros:',
        'it': ':occhiali_da_sole:',
        'fa': u':عینک_آفتابی:',
        'id': ':kacamata_hitam:',
        'zh': u':墨镜:'
    },
    u'\U0001F305': { # 🌅
        'en' : ':sunrise:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':sonnenaufgang_über_dem_meer:',
        'es': ':amanecer:',
        'fr': ':soleil_levant:',
        'ja': u':日の出:',
        'ko': u':일출:',
        'pt': u':aurora_sobre_água:',
        'it': ':alba:',
        'fa': u':طلوع:',
        'id': ':matahari_terbit:',
        'zh': u':日出:'
    },
    u'\U0001F304': { # 🌄
        'en' : ':sunrise_over_mountains:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':sonnenaufgang_über_bergen:',
        'es': u':amanecer_sobre_montañas:',
        'fr': u':soleil_levant_derrière_les_montagnes:',
        'ja': u':山から日の出:',
        'ko': u':산에서_떠오르는_해:',
        'pt': ':aurora_sobre_montanhas:',
        'it': ':alba_sulle_montagne:',
        'fa': u':طلوع_در_کوهستان:',
        'id': ':matahari_terbit_di_antara_gunung:',
        'zh': u':山顶日出:'
    },
    u'\U0001F307': { # 🌇
        'en' : ':sunset:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':city_sunrise:'],
        'de': ':sonnenuntergang_in_der_stadt:',
        'es': ':puesta_del_sol:',
        'fr': ':coucher_de_soleil:',
        'ja': u':夕日:',
        'ko': u':일몰:',
        'pt': u':pôr_do_sol:',
        'it': ':tramonto:',
        'fa': u':غروب:',
        'id': ':matahari_terbenam:',
        'zh': u':日落:'
    },
    u'\U0001F9B8': { # 🦸
        'en' : ':superhero:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':superheld(in):',
        'es': u':personaje_de_superhéroe:',
        'fr': u':super-héros:',
        'ja': u':スーパーヒーロー:',
        'ko': u':히로인:',
        'pt': u':super-herói:',
        'it': ':supereroe:',
        'fa': u':ابرقهرمان:',
        'id': ':pahlawan_super:',
        'zh': u':超级英雄:'
    },
    u'\U0001F9B8\U0001F3FF': { # 🦸🏿
        'en' : ':superhero_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':held_dunkle_hautfarbe:',
        'es': u':personaje_de_superhéroe_tono_de_piel_oscuro:',
        'fr': u':super-héros_peau_foncée:',
        'ja': u':スーパーヒーロー_濃い肌色:',
        'ko': u':히로인_검은색_피부:',
        'pt': u':super-herói_pele_escura:',
        'it': ':supereroe_carnagione_scura:',
        'fa': u':ابرقهرمان_پوست_آبنوسی:',
        'id': ':pahlawan_super_warna_kulit_gelap:',
        'zh': u':超级英雄_较深肤色:'
    },
    u'\U0001F9B8\U0001F3FB': { # 🦸🏻
        'en' : ':superhero_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':held_helle_hautfarbe:',
        'es': u':personaje_de_superhéroe_tono_de_piel_claro:',
        'fr': u':super-héros_peau_claire:',
        'ja': u':スーパーヒーロー_薄い肌色:',
        'ko': u':히로인_하얀_피부:',
        'pt': u':super-herói_pele_clara:',
        'it': ':supereroe_carnagione_chiara:',
        'fa': u':ابرقهرمان_پوست_سفید:',
        'id': ':pahlawan_super_warna_kulit_cerah:',
        'zh': u':超级英雄_较浅肤色:'
    },
    u'\U0001F9B8\U0001F3FE': { # 🦸🏾
        'en' : ':superhero_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':held_mitteldunkle_hautfarbe:',
        'es': u':personaje_de_superhéroe_tono_de_piel_oscuro_medio:',
        'fr': u':super-héros_peau_mate:',
        'ja': u':スーパーヒーロー_やや濃い肌色:',
        'ko': u':히로인_진한_갈색_피부:',
        'pt': u':super-herói_pele_morena_escura:',
        'it': ':supereroe_carnagione_abbastanza_scura:',
        'fa': u':ابرقهرمان_پوست_گندمی:',
        'id': ':pahlawan_super_warna_kulit_gelap-sedang:',
        'zh': u':超级英雄_中等深肤色:'
    },
    u'\U0001F9B8\U0001F3FC': { # 🦸🏼
        'en' : ':superhero_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':held_mittelhelle_hautfarbe:',
        'es': u':personaje_de_superhéroe_tono_de_piel_claro_medio:',
        'fr': u':super-héros_peau_moyennement_claire:',
        'ja': u':スーパーヒーロー_やや薄い肌色:',
        'ko': u':히로인_연한_갈색_피부:',
        'pt': u':super-herói_pele_morena_clara:',
        'it': ':supereroe_carnagione_abbastanza_chiara:',
        'fa': u':ابرقهرمان_پوست_روشن:',
        'id': ':pahlawan_super_warna_kulit_cerah-sedang:',
        'zh': u':超级英雄_中等浅肤色:'
    },
    u'\U0001F9B8\U0001F3FD': { # 🦸🏽
        'en' : ':superhero_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':held_mittlere_hautfarbe:',
        'es': u':personaje_de_superhéroe_tono_de_piel_medio:',
        'fr': u':super-héros_peau_légèrement_mate:',
        'ja': u':スーパーヒーロー_中間の肌色:',
        'ko': u':히로인_갈색_피부:',
        'pt': u':super-herói_pele_morena:',
        'it': ':supereroe_carnagione_olivastra:',
        'fa': u':ابرقهرمان_پوست_طلایی:',
        'id': ':pahlawan_super_warna_kulit_sedang:',
        'zh': u':超级英雄_中等肤色:'
    },
    u'\U0001F9B9': { # 🦹
        'en' : ':supervillain:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':bösewicht:',
        'es': ':personaje_de_supervillano:',
        'fr': ':super-vilain:',
        'ja': u':悪役:',
        'ko': u':슈퍼_악당:',
        'pt': u':supervilão:',
        'it': ':supercattivo:',
        'fa': u':ابرشرور:',
        'id': ':penjahat_super:',
        'zh': u':超级大坏蛋:'
    },
    u'\U0001F9B9\U0001F3FF': { # 🦹🏿
        'en' : ':supervillain_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':bösewicht_dunkle_hautfarbe:',
        'es': ':personaje_de_supervillano_tono_de_piel_oscuro:',
        'fr': u':super-vilain_peau_foncée:',
        'ja': u':悪役_濃い肌色:',
        'ko': u':슈퍼_악당_검은색_피부:',
        'pt': u':supervilão_pele_escura:',
        'it': ':supercattivo_carnagione_scura:',
        'fa': u':ابرشرور_پوست_آبنوسی:',
        'id': ':penjahat_super_warna_kulit_gelap:',
        'zh': u':超级大坏蛋_较深肤色:'
    },
    u'\U0001F9B9\U0001F3FB': { # 🦹🏻
        'en' : ':supervillain_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':bösewicht_helle_hautfarbe:',
        'es': ':personaje_de_supervillano_tono_de_piel_claro:',
        'fr': ':super-vilain_peau_claire:',
        'ja': u':悪役_薄い肌色:',
        'ko': u':슈퍼_악당_하얀_피부:',
        'pt': u':supervilão_pele_clara:',
        'it': ':supercattivo_carnagione_chiara:',
        'fa': u':ابرشرور_پوست_سفید:',
        'id': ':penjahat_super_warna_kulit_cerah:',
        'zh': u':超级大坏蛋_较浅肤色:'
    },
    u'\U0001F9B9\U0001F3FE': { # 🦹🏾
        'en' : ':supervillain_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':bösewicht_mitteldunkle_hautfarbe:',
        'es': ':personaje_de_supervillano_tono_de_piel_oscuro_medio:',
        'fr': ':super-vilain_peau_mate:',
        'ja': u':悪役_やや濃い肌色:',
        'ko': u':슈퍼_악당_진한_갈색_피부:',
        'pt': u':supervilão_pele_morena_escura:',
        'it': ':supercattivo_carnagione_abbastanza_scura:',
        'fa': u':ابرشرور_پوست_گندمی:',
        'id': ':penjahat_super_warna_kulit_gelap-sedang:',
        'zh': u':超级大坏蛋_中等深肤色:'
    },
    u'\U0001F9B9\U0001F3FC': { # 🦹🏼
        'en' : ':supervillain_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':bösewicht_mittelhelle_hautfarbe:',
        'es': ':personaje_de_supervillano_tono_de_piel_claro_medio:',
        'fr': ':super-vilain_peau_moyennement_claire:',
        'ja': u':悪役_やや薄い肌色:',
        'ko': u':슈퍼_악당_연한_갈색_피부:',
        'pt': u':supervilão_pele_morena_clara:',
        'it': ':supercattivo_carnagione_abbastanza_chiara:',
        'fa': u':ابرشرور_پوست_روشن:',
        'id': ':penjahat_super_warna_kulit_cerah-sedang:',
        'zh': u':超级大坏蛋_中等浅肤色:'
    },
    u'\U0001F9B9\U0001F3FD': { # 🦹🏽
        'en' : ':supervillain_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':bösewicht_mittlere_hautfarbe:',
        'es': ':personaje_de_supervillano_tono_de_piel_medio:',
        'fr': u':super-vilain_peau_légèrement_mate:',
        'ja': u':悪役_中間の肌色:',
        'ko': u':슈퍼_악당_갈색_피부:',
        'pt': u':supervilão_pele_morena:',
        'it': ':supercattivo_carnagione_olivastra:',
        'fa': u':ابرشرور_پوست_طلایی:',
        'id': ':penjahat_super_warna_kulit_sedang:',
        'zh': u':超级大坏蛋_中等肤色:'
    },
    u'\U0001F363': { # 🍣
        'en' : ':sushi:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':sushi:',
        'es': ':sushi:',
        'fr': ':sushi:',
        'ja': u':すし:',
        'ko': u':초밥:',
        'pt': ':sushi:',
        'it': ':sushi:',
        'fa': u':سوشی:',
        'id': ':sushi:',
        'zh': u':寿司:'
    },
    u'\U0001F69F': { # 🚟
        'en' : ':suspension_railway:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schwebebahn:',
        'es': u':ferrocarril_de_suspensión:',
        'fr': ':train_suspendu:',
        'ja': u':懸垂式モノレール:',
        'ko': u':매달린_케이블카:',
        'pt': ':estrada_de_ferro_suspensa:',
        'it': ':ferrovia_sospesa:',
        'fa': u':قطار_معلق:',
        'id': ':kereta_suspensi:',
        'zh': u':空轨:'
    },
    u'\U0001F9A2': { # 🦢
        'en' : ':swan:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':schwan:',
        'es': ':cisne:',
        'fr': ':cygne:',
        'ja': u':白鳥:',
        'ko': u':백조:',
        'pt': ':cisne:',
        'it': ':cigno:',
        'fa': u':قو:',
        'id': ':angsa_leher_panjang:',
        'zh': u':天鹅:'
    },
    u'\U0001F4A6': { # 💦
        'en' : ':sweat_droplets:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sweat_drops:'],
        'de': u':schweißtropfen:',
        'es': ':gotas_de_sudor:',
        'fr': ':gouttes_de_sueur:',
        'ja': u':あせあせ:',
        'ko': u':땀:',
        'pt': ':pingos_de_suor:',
        'it': ':gocce_di_sudore:',
        'fa': u':قطره_های_عرق:',
        'id': ':keringat:',
        'zh': u':汗滴:'
    },
    u'\U0001F54D': { # 🕍
        'en' : ':synagogue:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':synagoge:',
        'es': ':sinagoga:',
        'fr': ':synagogue:',
        'ja': u':シナゴーグ:',
        'ko': u':시나고그:',
        'pt': ':sinagoga:',
        'it': ':sinagoga:',
        'fa': u':کنیسه:',
        'id': ':sinagog:',
        'zh': u':犹太教堂:'
    },
    u'\U0001F489': { # 💉
        'en' : ':syringe:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':spritze:',
        'es': ':jeringuilla:',
        'fr': ':seringue:',
        'ja': u':注射器:',
        'ko': u':주사기:',
        'pt': ':seringa:',
        'it': ':siringa:',
        'fa': u':سرنگ:',
        'id': ':suntikan:',
        'zh': u':注射器:'
    },
    u'\U0001F455': { # 👕
        'en' : ':t-shirt:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tshirt:', ':shirt:'],
        'de': ':t-shirt:',
        'es': ':camiseta:',
        'fr': ':t-shirt:',
        'ja': u':tシャツ:',
        'ko': u':티셔츠:',
        'pt': ':camiseta:',
        'it': ':t-shirt:',
        'fa': u':تی_شرت:',
        'id': ':kaos:',
        'zh': u':T恤:'
    },
    u'\U0001F32E': { # 🌮
        'en' : ':taco:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':taco:',
        'es': ':taco:',
        'fr': ':taco:',
        'ja': u':タコス:',
        'ko': u':타코:',
        'pt': ':taco:',
        'it': ':taco:',
        'fa': u':تاکو:',
        'id': ':taco:',
        'zh': u':墨西哥卷饼:'
    },
    u'\U0001F961': { # 🥡
        'en' : ':takeout_box:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':takeaway-schachtel:',
        'es': ':caja_para_llevar:',
        'fr': u':boîte_à_emporter:',
        'ja': u':テイクアウト弁当:',
        'ko': u':테이크아웃_상자:',
        'pt': ':caixa_para_viagem:',
        'it': ':confezione_da_asporto:',
        'fa': u':جعبه_بردنی:',
        'id': ':kotak_makanan:',
        'zh': u':外卖盒:'
    },
    u'\U0001FAD4': { # 🫔
        'en' : ':tamale:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':tamale:',
        'es': ':tamal:',
        'fr': ':tamal:',
        'ja': u':タマル:',
        'ko': u':타말레:',
        'pt': ':tamale:',
        'it': ':tamale:',
        'fa': u':تامال:',
        'id': ':tamale:',
        'zh': u':墨西哥粽子:'
    },
    u'\U0001F38B': { # 🎋
        'en' : ':tanabata_tree:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':tanabata-baum:',
        'es': u':árbol_de_tanabata:',
        'fr': u':arbre_à_vœux:',
        'ja': u':七夕:',
        'ko': u':소원을_건_나무:',
        'pt': u':árvore_de_tanabata:',
        'it': ':albero_di_tanabata:',
        'fa': u':درخت_تاناباتا:',
        'id': ':pohon_tanabata:',
        'zh': u':七夕树:'
    },
    u'\U0001F34A': { # 🍊
        'en' : ':tangerine:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':orange:', ':mandarin:'],
        'de': ':mandarine:',
        'es': ':mandarina:',
        'fr': ':mandarine:',
        'ja': u':みかん:',
        'ko': u':귤:',
        'pt': ':tangerina:',
        'it': ':mandarino:',
        'fa': u':نارنگی:',
        'id': ':buah_jeruk:',
        'zh': u':橘子:'
    },
    u'\U0001F695': { # 🚕
        'en' : ':taxi:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':taxi:',
        'es': ':taxi:',
        'fr': ':taxi:',
        'ja': u':タクシー:',
        'ko': u':택시:',
        'pt': u':táxi:',
        'it': ':taxi:',
        'fa': u':تاکسی:',
        'id': ':taksi:',
        'zh': u':出租车:'
    },
    u'\U0001F9D1\U0000200D\U0001F3EB': { # 🧑‍🏫
        'en' : ':teacher:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':lehrer(in):',
        'es': ':docente:',
        'fr': ':personnel_enseignant:',
        'ja': u':教師:',
        'ko': u':교사:',
        'pt': ':professora_na_escola:',
        'it': ':insegnante:',
        'fa': u':معلم:',
        'id': ':guru:',
        'zh': u':老师:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F3EB': { # 🧑🏿‍🏫
        'en' : ':teacher_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':lehrer(in)_dunkle_hautfarbe:',
        'es': ':docente_tono_de_piel_oscuro:',
        'fr': u':personnel_enseignant_peau_foncée:',
        'ja': u':教師_濃い肌色:',
        'ko': u':교사_검은색_피부:',
        'pt': ':professora_na_escola_pele_escura:',
        'it': ':insegnante_carnagione_scura:',
        'fa': u':معلم_پوست_آبنوسی:',
        'id': ':guru_warna_kulit_gelap:',
        'zh': u':老师_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F3EB': { # 🧑🏻‍🏫
        'en' : ':teacher_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':lehrer(in)_helle_hautfarbe:',
        'es': ':docente_tono_de_piel_claro:',
        'fr': ':personnel_enseignant_peau_claire:',
        'ja': u':教師_薄い肌色:',
        'ko': u':교사_하얀_피부:',
        'pt': ':professora_na_escola_pele_clara:',
        'it': ':insegnante_carnagione_chiara:',
        'fa': u':معلم_پوست_سفید:',
        'id': ':guru_warna_kulit_cerah:',
        'zh': u':老师_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F3EB': { # 🧑🏾‍🏫
        'en' : ':teacher_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':lehrer(in)_mitteldunkle_hautfarbe:',
        'es': ':docente_tono_de_piel_oscuro_medio:',
        'fr': ':personnel_enseignant_peau_mate:',
        'ja': u':教師_やや濃い肌色:',
        'ko': u':교사_진한_갈색_피부:',
        'pt': ':professora_na_escola_pele_morena_escura:',
        'it': ':insegnante_carnagione_abbastanza_scura:',
        'fa': u':معلم_پوست_گندمی:',
        'id': ':guru_warna_kulit_gelap-sedang:',
        'zh': u':老师_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F3EB': { # 🧑🏼‍🏫
        'en' : ':teacher_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':lehrer(in)_mittelhelle_hautfarbe:',
        'es': ':docente_tono_de_piel_claro_medio:',
        'fr': ':personnel_enseignant_peau_moyennement_claire:',
        'ja': u':教師_やや薄い肌色:',
        'ko': u':교사_연한_갈색_피부:',
        'pt': ':professora_na_escola_pele_morena_clara:',
        'it': ':insegnante_carnagione_abbastanza_chiara:',
        'fa': u':معلم_پوست_روشن:',
        'id': ':guru_warna_kulit_cerah-sedang:',
        'zh': u':老师_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F3EB': { # 🧑🏽‍🏫
        'en' : ':teacher_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':lehrer(in)_mittlere_hautfarbe:',
        'es': ':docente_tono_de_piel_medio:',
        'fr': u':personnel_enseignant_peau_légèrement_mate:',
        'ja': u':教師_中間の肌色:',
        'ko': u':교사_갈색_피부:',
        'pt': ':professora_na_escola_pele_morena:',
        'it': ':insegnante_carnagione_olivastra:',
        'fa': u':معلم_پوست_طلایی:',
        'id': ':guru_warna_kulit_sedang:',
        'zh': u':老师_中等肤色:'
    },
    u'\U0001F375': { # 🍵
        'en' : ':teacup_without_handle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tea:'],
        'de': ':teetasse_ohne_henkel:',
        'es': u':tazón_de_té:',
        'fr': ':tasse:',
        'ja': u':湯飲み:',
        'ko': u':차:',
        'pt': u':xícara_de_chá_sem_alça:',
        'it': u':tazza_da_tè_senza_manico:',
        'fa': u':فنجان_چای_بدون_دسته:',
        'id': ':cangkir_teh_tanpa_gagang:',
        'zh': u':热茶:'
    },
    u'\U0001FAD6': { # 🫖
        'en' : ':teapot:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':teekanne:',
        'es': ':tetera:',
        'fr': u':théière:',
        'ja': u':ティーポット:',
        'ko': u':찻주전자:',
        'pt': ':bule:',
        'it': ':teiera:',
        'fa': u':قوری:',
        'id': ':teko:',
        'zh': u':茶壶:'
    },
    u'\U0001F4C6': { # 📆
        'en' : ':tear-off_calendar:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':calendar:'],
        'de': u':abreißkalender:',
        'es': ':calendario_recortable:',
        'fr': u':éphéméride:',
        'ja': u':日めくりカレンダー:',
        'ko': u':뜯어진_달력:',
        'pt': u':calendário_com_folhas_destacáveis:',
        'it': ':calendario_a_strappo:',
        'fa': u':تقویم_رومیزی:',
        'id': ':kalender_sobek:',
        'zh': u':手撕日历:'
    },
    u'\U0001F9D1\U0000200D\U0001F4BB': { # 🧑‍💻
        'en' : ':technologist:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':it-experte/it-expertin:',
        'es': u':profesional_de_la_tecnología:',
        'fr': ':informaticien_(tous_genres):',
        'ja': u':技術者:',
        'ko': u':기술_전문가:',
        'pt': ':programador:',
        'it': ':persona_esperta_di_tecnologia:',
        'fa': u':متخصص:',
        'id': ':ahli_teknologi:',
        'zh': u':程序员:'
    },
    u'\U0001F9D1\U0001F3FF\U0000200D\U0001F4BB': { # 🧑🏿‍💻
        'en' : ':technologist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':it-experte/it-expertin_dunkle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_tono_de_piel_oscuro:',
        'fr': u':informaticien_(tous_genres)_peau_foncée:',
        'ja': u':技術者_濃い肌色:',
        'ko': u':기술_전문가_검은색_피부:',
        'pt': ':programador_pele_escura:',
        'it': ':persona_esperta_di_tecnologia_carnagione_scura:',
        'fa': u':متخصص_پوست_آبنوسی:',
        'id': ':ahli_teknologi_warna_kulit_gelap:',
        'zh': u':程序员_较深肤色:'
    },
    u'\U0001F9D1\U0001F3FB\U0000200D\U0001F4BB': { # 🧑🏻‍💻
        'en' : ':technologist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':it-experte/it-expertin_helle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_tono_de_piel_claro:',
        'fr': ':informaticien_(tous_genres)_peau_claire:',
        'ja': u':技術者_薄い肌色:',
        'ko': u':기술_전문가_하얀_피부:',
        'pt': ':programador_pele_clara:',
        'it': ':persona_esperta_di_tecnologia_carnagione_chiara:',
        'fa': u':متخصص_پوست_سفید:',
        'id': ':ahli_teknologi_warna_kulit_cerah:',
        'zh': u':程序员_较浅肤色:'
    },
    u'\U0001F9D1\U0001F3FE\U0000200D\U0001F4BB': { # 🧑🏾‍💻
        'en' : ':technologist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':it-experte/it-expertin_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_tono_de_piel_oscuro_medio:',
        'fr': ':informaticien_(tous_genres)_peau_mate:',
        'ja': u':技術者_やや濃い肌色:',
        'ko': u':기술_전문가_진한_갈색_피부:',
        'pt': ':programador_pele_morena_escura:',
        'it': ':persona_esperta_di_tecnologia_carnagione_abbastanza_scura:',
        'fa': u':متخصص_پوست_گندمی:',
        'id': ':ahli_teknologi_warna_kulit_gelap-sedang:',
        'zh': u':程序员_中等深肤色:'
    },
    u'\U0001F9D1\U0001F3FC\U0000200D\U0001F4BB': { # 🧑🏼‍💻
        'en' : ':technologist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':it-experte/it-expertin_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_tono_de_piel_claro_medio:',
        'fr': ':informaticien_(tous_genres)_peau_moyennement_claire:',
        'ja': u':技術者_やや薄い肌色:',
        'ko': u':기술_전문가_연한_갈색_피부:',
        'pt': ':programador_pele_morena_clara:',
        'it': ':persona_esperta_di_tecnologia_carnagione_abbastanza_chiara:',
        'fa': u':متخصص_پوست_روشن:',
        'id': ':ahli_teknologi_warna_kulit_cerah-sedang:',
        'zh': u':程序员_中等浅肤色:'
    },
    u'\U0001F9D1\U0001F3FD\U0000200D\U0001F4BB': { # 🧑🏽‍💻
        'en' : ':technologist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': ':it-experte/it-expertin_mittlere_hautfarbe:',
        'es': u':profesional_de_la_tecnología_tono_de_piel_medio:',
        'fr': u':informaticien_(tous_genres)_peau_légèrement_mate:',
        'ja': u':技術者_中間の肌色:',
        'ko': u':기술_전문가_갈색_피부:',
        'pt': ':programador_pele_morena:',
        'it': ':persona_esperta_di_tecnologia_carnagione_olivastra:',
        'fa': u':متخصص_پوست_طلایی:',
        'id': ':ahli_teknologi_warna_kulit_sedang:',
        'zh': u':程序员_中等肤色:'
    },
    u'\U0001F9F8': { # 🧸
        'en' : ':teddy_bear:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':teddybär:',
        'es': ':osito_de_peluche:',
        'fr': ':ours_en_peluche:',
        'ja': u':テディベア:',
        'ko': u':테디_베어:',
        'pt': u':ursinho_de_pelúcia:',
        'it': ':orsetto:',
        'fa': u':تدی_خرسه:',
        'id': ':boneka_beruang:',
        'zh': u':泰迪熊:'
    },
    u'\U0000260E\U0000FE0F': { # ☎️
        'en' : ':telephone:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':phone:'],
        'variant': True,
        'de': ':telefon:',
        'es': u':teléfono:',
        'fr': u':téléphone:',
        'ja': u':固定電話:',
        'ko': u':전화기:',
        'pt': ':telefone_no_gancho:',
        'it': ':telefono_fisso:',
        'fa': u':تلفن:',
        'id': ':telepon:',
        'zh': u':电话:'
    },
    u'\U0000260E': { # ☎
        'en' : ':telephone:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':phone:'],
        'variant': True,
        'de': ':telefon:',
        'es': u':teléfono:',
        'fr': u':téléphone:',
        'ja': u':固定電話:',
        'ko': u':전화기:',
        'pt': ':telefone_no_gancho:',
        'it': ':telefono_fisso:',
        'fa': u':تلفن:',
        'id': ':telepon:',
        'zh': u':电话:'
    },
    u'\U0001F4DE': { # 📞
        'en' : ':telephone_receiver:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':telefonhörer:',
        'es': u':auricular_de_teléfono:',
        'fr': u':combiné_téléphonique:',
        'ja': u':受話器:',
        'ko': u':수화기:',
        'pt': ':telefone:',
        'it': ':cornetta:',
        'fa': u':گوشی_تلفن:',
        'id': ':gagang_telepon:',
        'zh': u':电话听筒:'
    },
    u'\U0001F52D': { # 🔭
        'en' : ':telescope:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':teleskop:',
        'es': ':telescopio:',
        'fr': u':télescope:',
        'ja': u':望遠鏡:',
        'ko': u':망원경:',
        'pt': u':telescópio:',
        'it': ':telescopio:',
        'fa': u':تلسکوپ:',
        'id': ':teleskop:',
        'zh': u':望远镜:'
    },
    u'\U0001F4FA': { # 📺
        'en' : ':television:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tv:'],
        'variant': True,
        'de': ':fernseher:',
        'es': u':televisión:',
        'fr': u':téléviseur:',
        'ja': u':テレビ:',
        'ko': u':텔레비전:',
        'pt': u':televisão:',
        'it': ':televisore:',
        'fa': u':تلویزیون:',
        'id': ':televisi:',
        'zh': u':电视机:'
    },
    u'\U0001F565': { # 🕥
        'en' : ':ten-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock1030:'],
        'variant': True,
        'de': ':10.30_uhr:',
        'es': ':diez_y_media:',
        'fr': ':dix_heures_et_demie:',
        'ja': u':10時半:',
        'ko': u':열_시_반:',
        'pt': ':dez_e_meia:',
        'it': ':ore_dieci_e_mezza:',
        'fa': u':ساعت_ده_و_نیم:',
        'id': ':jam_setengah_sebelas:',
        'zh': u':十点半:'
    },
    u'\U0001F559': { # 🕙
        'en' : u':ten_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock10:'],
        'variant': True,
        'de': ':10.00_uhr:',
        'es': ':10_en_punto:',
        'fr': ':dix_heures:',
        'ja': u':10時:',
        'ko': u':열_시:',
        'pt': ':10_horas:',
        'it': ':ore_dieci:',
        'fa': u':ساعت_ده:',
        'id': ':jam_sepuluh_tepat:',
        'zh': u':十点:'
    },
    u'\U0001F3BE': { # 🎾
        'en' : ':tennis:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':tennisball:',
        'es': ':pelota_de_tenis:',
        'fr': ':tennis:',
        'ja': u':テニス:',
        'ko': u':테니스:',
        'pt': u':tênis:',
        'it': ':tennis:',
        'fa': u':تنیس:',
        'id': ':tenis:',
        'zh': u':网球:'
    },
    u'\U000026FA': { # ⛺
        'en' : ':tent:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':zelt:',
        'es': u':tienda_de_campaña:',
        'fr': ':tente:',
        'ja': u':テント:',
        'ko': u':텐트:',
        'pt': ':barraca:',
        'it': ':tenda:',
        'fa': u':چادر:',
        'id': ':tenda:',
        'zh': u':帐篷:'
    },
    u'\U0001F9EA': { # 🧪
        'en' : ':test_tube:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':reagenzglas:',
        'es': ':tubo_de_ensayo:',
        'fr': u':tube_à_essai:',
        'ja': u':試験管:',
        'ko': u':시험관:',
        'pt': ':tubo_de_ensaio:',
        'it': ':provetta:',
        'fa': u':لولهٔ_آزمایشگاه:',
        'id': ':tabung_uji:',
        'zh': u':试管:'
    },
    u'\U0001F321\U0000FE0F': { # 🌡️
        'en' : ':thermometer:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':thermometer:',
        'es': u':termómetro:',
        'fr': u':thermomètre:',
        'ja': u':温度計:',
        'ko': u':온도계:',
        'pt': u':termômetro:',
        'it': ':termometro:',
        'fa': u':دماسنج:',
        'id': ':termometer:',
        'zh': u':温度计:'
    },
    u'\U0001F321': { # 🌡
        'en' : ':thermometer:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':thermometer:',
        'es': u':termómetro:',
        'fr': u':thermomètre:',
        'ja': u':温度計:',
        'ko': u':온도계:',
        'pt': u':termômetro:',
        'it': ':termometro:',
        'fa': u':دماسنج:',
        'id': ':termometer:',
        'zh': u':温度计:'
    },
    u'\U0001F914': { # 🤔
        'en' : ':thinking_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':thinking:'],
        'de': ':nachdenkendes_gesicht:',
        'es': ':cara_pensativa:',
        'fr': u':visage_en_pleine_réflexion:',
        'ja': u':考える顔:',
        'ko': u':생각하는_얼굴:',
        'pt': ':rosto_pensativo:',
        'it': ':faccina_concentrata:',
        'fa': u':درحال_تفکر:',
        'id': ':wajah_berpikir:',
        'zh': u':想一想:'
    },
    u'\U0001FA74': { # 🩴
        'en' : ':thong_sandal:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':zehensandale:',
        'es': ':chancla:',
        'fr': ':tong:',
        'ja': u':ビーチサンダル:',
        'ko': u':가락신:',
        'pt': ':chinelo:',
        'it': ':infradito:',
        'fa': u':دمپایی_لاانگشتی:',
        'id': ':sandal_jepit:',
        'zh': u':夹趾凉鞋:'
    },
    u'\U0001F4AD': { # 💭
        'en' : ':thought_balloon:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':gedankenblase:',
        'es': ':bocadillo_de_pensamiento:',
        'fr': u':bulle_de_pensée:',
        'ja': u':雲形の吹き出し:',
        'ko': u':생각_풍선:',
        'pt': u':balão_de_pensamento:',
        'it': ':nuvoletta:',
        'fa': u':بالن_افکار:',
        'id': ':gelembung_pikiran:',
        'zh': u':内心活动气泡:'
    },
    u'\U0001F9F5': { # 🧵
        'en' : ':thread:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':faden:',
        'es': ':hilo:',
        'fr': ':bobine_de_fil:',
        'ja': u':糸:',
        'ko': u':실타래:',
        'pt': ':carretel:',
        'it': ':filo:',
        'fa': u':نخ:',
        'id': ':benang:',
        'zh': u':线:'
    },
    u'\U0001F55E': { # 🕞
        'en' : ':three-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock330:'],
        'variant': True,
        'de': ':3.30_uhr:',
        'es': ':tres_y_media:',
        'fr': ':trois_heures_et_demie:',
        'ja': u':3時半:',
        'ko': u':세_시_반:',
        'pt': u':três_e_meia:',
        'it': ':ore_tre_e_mezza:',
        'fa': u':ساعت_سه_و_نیم:',
        'id': ':jam_setengah_empat:',
        'zh': u':三点半:'
    },
    u'\U0001F552': { # 🕒
        'en' : u':three_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock3:'],
        'variant': True,
        'de': ':3.00_uhr:',
        'es': ':3_en_punto:',
        'fr': ':trois_heures:',
        'ja': u':3時:',
        'ko': u':세_시:',
        'pt': ':3_horas:',
        'it': ':ore_tre:',
        'fa': u':ساعت_سه:',
        'id': ':jam_tiga_tepat:',
        'zh': u':三点:'
    },
    u'\U0001F44E': { # 👎
        'en' : ':thumbs_down:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':thumbsdown:', ':__1:', ':-1:'],
        'variant': True,
        'de': ':daumen_runter:',
        'es': ':pulgar_hacia_abajo:',
        'fr': ':pouce_vers_le_bas:',
        'ja': u':サムズダウン:',
        'ko': u':내린_엄지:',
        'pt': ':polegar_para_baixo:',
        'it': ':pollice_verso:',
        'fa': u':نپسندیدن:',
        'id': ':jempol_ke_bawah:',
        'zh': u':拇指向下:'
    },
    u'\U0001F44E\U0001F3FF': { # 👎🏿
        'en' : ':thumbs_down_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_runter_dunkle_hautfarbe:',
        'es': ':pulgar_hacia_abajo_tono_de_piel_oscuro:',
        'fr': u':pouce_vers_le_bas_peau_foncée:',
        'ja': u':サムズダウン_濃い肌色:',
        'ko': u':내린_엄지_검은색_피부:',
        'pt': ':polegar_para_baixo_pele_escura:',
        'it': ':pollice_verso_carnagione_scura:',
        'fa': u':نپسندیدن_پوست_آبنوسی:',
        'id': ':jempol_ke_bawah_warna_kulit_gelap:',
        'zh': u':拇指向下_较深肤色:'
    },
    u'\U0001F44E\U0001F3FB': { # 👎🏻
        'en' : ':thumbs_down_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_runter_helle_hautfarbe:',
        'es': ':pulgar_hacia_abajo_tono_de_piel_claro:',
        'fr': ':pouce_vers_le_bas_peau_claire:',
        'ja': u':サムズダウン_薄い肌色:',
        'ko': u':내린_엄지_하얀_피부:',
        'pt': ':polegar_para_baixo_pele_clara:',
        'it': ':pollice_verso_carnagione_chiara:',
        'fa': u':نپسندیدن_پوست_سفید:',
        'id': ':jempol_ke_bawah_warna_kulit_cerah:',
        'zh': u':拇指向下_较浅肤色:'
    },
    u'\U0001F44E\U0001F3FE': { # 👎🏾
        'en' : ':thumbs_down_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_runter_mitteldunkle_hautfarbe:',
        'es': ':pulgar_hacia_abajo_tono_de_piel_oscuro_medio:',
        'fr': ':pouce_vers_le_bas_peau_mate:',
        'ja': u':サムズダウン_やや濃い肌色:',
        'ko': u':내린_엄지_진한_갈색_피부:',
        'pt': ':polegar_para_baixo_pele_morena_escura:',
        'it': ':pollice_verso_carnagione_abbastanza_scura:',
        'fa': u':نپسندیدن_پوست_گندمی:',
        'id': ':jempol_ke_bawah_warna_kulit_gelap-sedang:',
        'zh': u':拇指向下_中等深肤色:'
    },
    u'\U0001F44E\U0001F3FC': { # 👎🏼
        'en' : ':thumbs_down_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_runter_mittelhelle_hautfarbe:',
        'es': ':pulgar_hacia_abajo_tono_de_piel_claro_medio:',
        'fr': ':pouce_vers_le_bas_peau_moyennement_claire:',
        'ja': u':サムズダウン_やや薄い肌色:',
        'ko': u':내린_엄지_연한_갈색_피부:',
        'pt': ':polegar_para_baixo_pele_morena_clara:',
        'it': ':pollice_verso_carnagione_abbastanza_chiara:',
        'fa': u':نپسندیدن_پوست_روشن:',
        'id': ':jempol_ke_bawah_warna_kulit_cerah-sedang:',
        'zh': u':拇指向下_中等浅肤色:'
    },
    u'\U0001F44E\U0001F3FD': { # 👎🏽
        'en' : ':thumbs_down_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_runter_mittlere_hautfarbe:',
        'es': ':pulgar_hacia_abajo_tono_de_piel_medio:',
        'fr': u':pouce_vers_le_bas_peau_légèrement_mate:',
        'ja': u':サムズダウン_中間の肌色:',
        'ko': u':내린_엄지_갈색_피부:',
        'pt': ':polegar_para_baixo_pele_morena:',
        'it': ':pollice_verso_carnagione_olivastra:',
        'fa': u':نپسندیدن_پوست_طلایی:',
        'id': ':jempol_ke_bawah_warna_kulit_sedang:',
        'zh': u':拇指向下_中等肤色:'
    },
    u'\U0001F44D': { # 👍
        'en' : ':thumbs_up:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':thumbsup:', ':+1:'],
        'variant': True,
        'de': ':daumen_hoch:',
        'es': ':pulgar_hacia_arriba:',
        'fr': ':pouce_vers_le_haut:',
        'ja': u':サムズアップ:',
        'ko': u':올린_엄지:',
        'pt': ':polegar_para_cima:',
        'it': ':pollice_in_su:',
        'fa': u':پسندیدن:',
        'id': ':jempol_ke_atas:',
        'zh': u':拇指向上:'
    },
    u'\U0001F44D\U0001F3FF': { # 👍🏿
        'en' : ':thumbs_up_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_hoch_dunkle_hautfarbe:',
        'es': ':pulgar_hacia_arriba_tono_de_piel_oscuro:',
        'fr': u':pouce_vers_le_haut_peau_foncée:',
        'ja': u':サムズアップ_濃い肌色:',
        'ko': u':올린_엄지_검은색_피부:',
        'pt': ':polegar_para_cima_pele_escura:',
        'it': ':pollice_in_su_carnagione_scura:',
        'fa': u':پسندیدن_پوست_آبنوسی:',
        'id': ':jempol_ke_atas_warna_kulit_gelap:',
        'zh': u':拇指向上_较深肤色:'
    },
    u'\U0001F44D\U0001F3FB': { # 👍🏻
        'en' : ':thumbs_up_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_hoch_helle_hautfarbe:',
        'es': ':pulgar_hacia_arriba_tono_de_piel_claro:',
        'fr': ':pouce_vers_le_haut_peau_claire:',
        'ja': u':サムズアップ_薄い肌色:',
        'ko': u':올린_엄지_하얀_피부:',
        'pt': ':polegar_para_cima_pele_clara:',
        'it': ':pollice_in_su_carnagione_chiara:',
        'fa': u':پسندیدن_پوست_سفید:',
        'id': ':jempol_ke_atas_warna_kulit_cerah:',
        'zh': u':拇指向上_较浅肤色:'
    },
    u'\U0001F44D\U0001F3FE': { # 👍🏾
        'en' : ':thumbs_up_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_hoch_mitteldunkle_hautfarbe:',
        'es': ':pulgar_hacia_arriba_tono_de_piel_oscuro_medio:',
        'fr': ':pouce_vers_le_haut_peau_mate:',
        'ja': u':サムズアップ_やや濃い肌色:',
        'ko': u':올린_엄지_진한_갈색_피부:',
        'pt': ':polegar_para_cima_pele_morena_escura:',
        'it': ':pollice_in_su_carnagione_abbastanza_scura:',
        'fa': u':پسندیدن_پوست_گندمی:',
        'id': ':jempol_ke_atas_warna_kulit_gelap-sedang:',
        'zh': u':拇指向上_中等深肤色:'
    },
    u'\U0001F44D\U0001F3FC': { # 👍🏼
        'en' : ':thumbs_up_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_hoch_mittelhelle_hautfarbe:',
        'es': ':pulgar_hacia_arriba_tono_de_piel_claro_medio:',
        'fr': ':pouce_vers_le_haut_peau_moyennement_claire:',
        'ja': u':サムズアップ_やや薄い肌色:',
        'ko': u':올린_엄지_연한_갈색_피부:',
        'pt': ':polegar_para_cima_pele_morena_clara:',
        'it': ':pollice_in_su_carnagione_abbastanza_chiara:',
        'fa': u':پسندیدن_پوست_روشن:',
        'id': ':jempol_ke_atas_warna_kulit_cerah-sedang:',
        'zh': u':拇指向上_中等浅肤色:'
    },
    u'\U0001F44D\U0001F3FD': { # 👍🏽
        'en' : ':thumbs_up_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':daumen_hoch_mittlere_hautfarbe:',
        'es': ':pulgar_hacia_arriba_tono_de_piel_medio:',
        'fr': u':pouce_vers_le_haut_peau_légèrement_mate:',
        'ja': u':サムズアップ_中間の肌色:',
        'ko': u':올린_엄지_갈색_피부:',
        'pt': ':polegar_para_cima_pele_morena:',
        'it': ':pollice_in_su_carnagione_olivastra:',
        'fa': u':پسندیدن_پوست_طلایی:',
        'id': ':jempol_ke_atas_warna_kulit_sedang:',
        'zh': u':拇指向上_中等肤色:'
    },
    u'\U0001F3AB': { # 🎫
        'en' : ':ticket:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':ticket:',
        'es': ':tique:',
        'fr': ':billet:',
        'ja': u':チケット:',
        'ko': u':티켓:',
        'pt': ':ingresso:',
        'it': ':biglietto:',
        'fa': u':بلیت:',
        'id': ':tiket:',
        'zh': u':票:'
    },
    u'\U0001F405': { # 🐅
        'en' : ':tiger:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':tiger2:'],
        'de': ':tiger:',
        'es': ':tigre:',
        'fr': ':tigre:',
        'ja': u':トラ:',
        'ko': u':호랑이:',
        'pt': ':tigre:',
        'it': ':tigre:',
        'fa': u':ببر:',
        'id': ':harimau:',
        'zh': u':老虎:'
    },
    u'\U0001F42F': { # 🐯
        'en' : ':tiger_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tiger:'],
        'de': ':tigergesicht:',
        'es': ':cara_de_tigre:',
        'fr': u':tête_de_tigre:',
        'ja': u':トラの顔:',
        'ko': u':호랑이_얼굴:',
        'pt': ':rosto_de_tigre:',
        'it': ':muso_di_tigre:',
        'fa': u':صورت_ببر:',
        'id': ':wajah_harimau:',
        'zh': u':老虎头:'
    },
    u'\U000023F2\U0000FE0F': { # ⏲️
        'en' : ':timer_clock:',
        'status' : fully_qualified,
        'E' : 1,
        'variant': True,
        'de': ':zeitschaltuhr:',
        'es': ':temporizador:',
        'fr': ':horloge:',
        'ja': u':タイマー:',
        'ko': u':타이머_시계:',
        'pt': u':relógio_temporizador:',
        'it': ':timer:',
        'fa': u':تایمر:',
        'id': ':penghitung_waktu:',
        'zh': u':定时器:'
    },
    u'\U000023F2': { # ⏲
        'en' : ':timer_clock:',
        'status' : unqualified,
        'E' : 1,
        'variant': True,
        'de': ':zeitschaltuhr:',
        'es': ':temporizador:',
        'fr': ':horloge:',
        'ja': u':タイマー:',
        'ko': u':타이머_시계:',
        'pt': u':relógio_temporizador:',
        'it': ':timer:',
        'fa': u':تایمر:',
        'id': ':penghitung_waktu:',
        'zh': u':定时器:'
    },
    u'\U0001F62B': { # 😫
        'en' : ':tired_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':müdes_gesicht:',
        'es': ':cara_cansada:',
        'fr': u':visage_fatigué:',
        'ja': u':疲れた:',
        'ko': u':피곤한_얼굴:',
        'pt': ':rosto_cansado:',
        'it': ':faccina_stanca:',
        'fa': u':صورت_خسته:',
        'id': ':wajah_kelelahan:',
        'zh': u':累:'
    },
    u'\U0001F6BD': { # 🚽
        'en' : ':toilet:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':toilette:',
        'es': ':inodoro:',
        'fr': ':toilettes:',
        'ja': u':便器:',
        'ko': u':변기:',
        'pt': u':vaso_sanitário:',
        'it': ':toilette:',
        'fa': u':توالت:',
        'id': ':toilet:',
        'zh': u':马桶:'
    },
    u'\U0001F345': { # 🍅
        'en' : ':tomato:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':tomate:',
        'es': ':tomate:',
        'fr': ':tomate:',
        'ja': u':トマト:',
        'ko': u':토마토:',
        'pt': ':tomate:',
        'it': ':pomodoro:',
        'fa': u':گوجه_فرنگی:',
        'id': ':tomat:',
        'zh': u':西红柿:'
    },
    u'\U0001F445': { # 👅
        'en' : ':tongue:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':zunge:',
        'es': ':lengua:',
        'fr': ':langue:',
        'ja': u':舌:',
        'ko': u':혀:',
        'pt': u':língua:',
        'it': ':lingua:',
        'fa': u':زبان:',
        'id': ':lidah:',
        'zh': u':舌头:'
    },
    u'\U0001F9F0': { # 🧰
        'en' : ':toolbox:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':werkzeugkasten:',
        'es': ':caja_de_herramientas:',
        'fr': u':boîte_à_outils:',
        'ja': u':工具箱:',
        'ko': u':공구통:',
        'pt': ':caixa_de_ferramentas:',
        'it': ':cassetta_degli_attrezzi:',
        'fa': u':جعبه_ابزار:',
        'id': ':kotak_perkakas:',
        'zh': u':工具箱:'
    },
    u'\U0001F9B7': { # 🦷
        'en' : ':tooth:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':zahn:',
        'es': ':diente:',
        'fr': ':dent:',
        'ja': u':歯:',
        'ko': u':이빨:',
        'pt': ':dente:',
        'it': ':dente:',
        'fa': u':دندان:',
        'id': ':gigi:',
        'zh': u':牙齿:'
    },
    u'\U0001FAA5': { # 🪥
        'en' : ':toothbrush:',
        'status' : fully_qualified,
        'E' : 13,
        'de': u':zahnbürste:',
        'es': ':cepillo_de_dientes:',
        'fr': u':brosse_à_dents:',
        'ja': u':歯ブラシ:',
        'ko': u':칫솔:',
        'pt': ':escova_de_dentes:',
        'it': ':spazzolino_da_denti:',
        'fa': u':مسواک:',
        'id': ':sikat_gigi:',
        'zh': u':牙刷:'
    },
    u'\U0001F3A9': { # 🎩
        'en' : ':top_hat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tophat:'],
        'de': ':zylinder:',
        'es': ':sombrero_de_copa:',
        'fr': ':haut_de_forme:',
        'ja': u':シルクハット:',
        'ko': u':마술사_모자:',
        'pt': ':cartola:',
        'it': ':cilindro:',
        'fa': u':کلاه_مردانه_استوانه_ای:',
        'id': ':topi_tinggi:',
        'zh': u':礼帽:'
    },
    u'\U0001F32A\U0000FE0F': { # 🌪️
        'en' : ':tornado:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':cloud_with_tornado:'],
        'variant': True,
        'de': ':wirbelsturm:',
        'es': ':tornado:',
        'fr': ':tornade:',
        'ja': u':竜巻:',
        'ko': u':토네이도:',
        'pt': ':tornado:',
        'it': ':tornado:',
        'fa': u':گردباد:',
        'id': ':tornado:',
        'zh': u':龙卷风:'
    },
    u'\U0001F32A': { # 🌪
        'en' : ':tornado:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':cloud_with_tornado:'],
        'variant': True,
        'de': ':wirbelsturm:',
        'es': ':tornado:',
        'fr': ':tornade:',
        'ja': u':竜巻:',
        'ko': u':토네이도:',
        'pt': ':tornado:',
        'it': ':tornado:',
        'fa': u':گردباد:',
        'id': ':tornado:',
        'zh': u':龙卷风:'
    },
    u'\U0001F5B2\U0000FE0F': { # 🖲️
        'en' : ':trackball:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':trackball:',
        'es': ':bola_de_desplazamiento:',
        'fr': ':boule_de_commande:',
        'ja': u':トラックボール:',
        'ko': u':트랙볼:',
        'pt': ':trackball:',
        'it': ':trackball:',
        'fa': u':توپک:',
        'id': ':trackball:',
        'zh': u':轨迹球:'
    },
    u'\U0001F5B2': { # 🖲
        'en' : ':trackball:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':trackball:',
        'es': ':bola_de_desplazamiento:',
        'fr': ':boule_de_commande:',
        'ja': u':トラックボール:',
        'ko': u':트랙볼:',
        'pt': ':trackball:',
        'it': ':trackball:',
        'fa': u':توپک:',
        'id': ':trackball:',
        'zh': u':轨迹球:'
    },
    u'\U0001F69C': { # 🚜
        'en' : ':tractor:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':traktor:',
        'es': ':tractor:',
        'fr': ':tracteur:',
        'ja': u':トラクター:',
        'ko': u':트랙터:',
        'pt': ':trator:',
        'it': ':trattore:',
        'fa': u':تراکتور:',
        'id': ':traktor:',
        'zh': u':拖拉机:'
    },
    u'\U00002122\U0000FE0F': { # ™️
        'en' : ':trade_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':tm:'],
        'variant': True,
        'de': ':markenzeichen:',
        'es': u':símbolo_de_marca_comercial:',
        'fr': u':marque_commerciale_déposée:',
        'ja': u':商標マーク:',
        'ko': u':상표:',
        'pt': u':símbolo_de_marca_registrada:',
        'it': ':marchio:',
        'fa': u':نماد_بازرگانی:',
        'id': ':merek_dagang:',
        'zh': u':商标:'
    },
    u'\U00002122': { # ™
        'en' : ':trade_mark:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':tm:'],
        'variant': True,
        'de': ':markenzeichen:',
        'es': u':símbolo_de_marca_comercial:',
        'fr': u':marque_commerciale_déposée:',
        'ja': u':商標マーク:',
        'ko': u':상표:',
        'pt': u':símbolo_de_marca_registrada:',
        'it': ':marchio:',
        'fa': u':نماد_بازرگانی:',
        'id': ':merek_dagang:',
        'zh': u':商标:'
    },
    u'\U0001F686': { # 🚆
        'en' : ':train:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':train2:'],
        'de': ':zug:',
        'es': ':tren:',
        'fr': ':train:',
        'ja': u':電車正面:',
        'ko': u':기차:',
        'pt': ':trem:',
        'it': ':treno:',
        'fa': u':قطار:',
        'id': ':kereta:',
        'zh': u':火车:'
    },
    u'\U0001F68A': { # 🚊
        'en' : ':tram:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':straßenbahn:',
        'es': u':tranvía:',
        'fr': ':tramway:',
        'ja': u':路面電車正面:',
        'ko': u':트램:',
        'pt': u':bonde_elétrico:',
        'it': ':tram:',
        'fa': u':تراموا:',
        'id': ':trem:',
        'zh': u':路面电车:'
    },
    u'\U0001F68B': { # 🚋
        'en' : ':tram_car:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':train:'],
        'de': u':straßenbahnwagen:',
        'es': u':vagón_de_tranvía:',
        'fr': ':wagon_de_tramway:',
        'ja': u':路面電車:',
        'ko': u':트램_차량:',
        'pt': ':bonde:',
        'it': ':vagone_del_tram:',
        'fa': u':قطار_خیابانی:',
        'id': ':gerbong_trem:',
        'zh': u':有轨电车:'
    },
    u'\U0001F3F3\U0000FE0F\U0000200D\U000026A7\U0000FE0F': { # 🏳️‍⚧️
        'en' : ':transgender_flag:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':transgender-flagge:',
        'es': u':bandera_transgénero:',
        'fr': ':drapeau_transgenre:',
        'ja': u':トランスジェンダーフラッグ:',
        'ko': u':트랜스젠더_깃발:',
        'pt': u':bandeira_transgênero:',
        'it': ':bandiera_transgender:',
        'fa': u':پرچم_تراجنسیتی:',
        'id': ':bendera_transgender:',
        'zh': u':跨性别旗:'
    },
    u'\U0001F3F3\U0000200D\U000026A7\U0000FE0F': { # 🏳‍⚧️
        'en' : ':transgender_flag:',
        'status' : unqualified,
        'E' : 13,
        'de': ':transgender-flagge:',
        'es': u':bandera_transgénero:',
        'fr': ':drapeau_transgenre:',
        'ja': u':トランスジェンダーフラッグ:',
        'ko': u':트랜스젠더_깃발:',
        'pt': u':bandeira_transgênero:',
        'it': ':bandiera_transgender:',
        'fa': u':پرچم_تراجنسیتی:',
        'id': ':bendera_transgender:',
        'zh': u':跨性别旗:'
    },
    u'\U0001F3F3\U0000FE0F\U0000200D\U000026A7': { # 🏳️‍⚧
        'en' : ':transgender_flag:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':transgender-flagge:',
        'es': u':bandera_transgénero:',
        'fr': ':drapeau_transgenre:',
        'ja': u':トランスジェンダーフラッグ:',
        'ko': u':트랜스젠더_깃발:',
        'pt': u':bandeira_transgênero:',
        'it': ':bandiera_transgender:',
        'fa': u':پرچم_تراجنسیتی:',
        'id': ':bendera_transgender:',
        'zh': u':跨性别旗:'
    },
    u'\U0001F3F3\U0000200D\U000026A7': { # 🏳‍⚧
        'en' : ':transgender_flag:',
        'status' : unqualified,
        'E' : 13,
        'de': ':transgender-flagge:',
        'es': u':bandera_transgénero:',
        'fr': ':drapeau_transgenre:',
        'ja': u':トランスジェンダーフラッグ:',
        'ko': u':트랜스젠더_깃발:',
        'pt': u':bandeira_transgênero:',
        'it': ':bandiera_transgender:',
        'fa': u':پرچم_تراجنسیتی:',
        'id': ':bendera_transgender:',
        'zh': u':跨性别旗:'
    },
    u'\U000026A7\U0000FE0F': { # ⚧️
        'en' : ':transgender_symbol:',
        'status' : fully_qualified,
        'E' : 13,
        'variant': True,
        'de': u':symbol_für_transgender:',
        'es': u':símbolo_de_transgénero:',
        'fr': u':symbole_de_la_communauté_transgenre:',
        'ja': u':トランスジェンダーのマーク:',
        'ko': u':트랜스젠더_기호:',
        'pt': u':símbolo_transgênero:',
        'it': ':simbolo_transgender:',
        'fa': u':علامت_تراجنسیتی:',
        'id': ':simbol_transgender:',
        'zh': u':跨性别符号:'
    },
    u'\U000026A7': { # ⚧
        'en' : ':transgender_symbol:',
        'status' : unqualified,
        'E' : 13,
        'variant': True,
        'de': ':transgender-symbol:',
        'es': u':símbolo_de_transgénero:',
        'fr': u':symbole_de_la_communauté_transgenre:',
        'ja': u':トランスジェンダーのマーク:',
        'ko': u':트랜스젠더_기호:',
        'pt': u':símbolo_transgênero:',
        'it': ':simbolo_transgender:',
        'fa': u':علامت_تراجنسیتی:',
        'id': ':simbol_transgender:',
        'zh': u':跨性别符号:'
    },
    u'\U0001F6A9': { # 🚩
        'en' : ':triangular_flag:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':triangular_flag_on_post:'],
        'de': ':wimpel:',
        'es': ':bandera_triangular:',
        'fr': ':drapeau_triangulaire:',
        'ja': u':三角の旗:',
        'ko': u':세모_깃발:',
        'pt': ':bandeira_triangular:',
        'it': ':bandierina_rossa:',
        'fa': u':پرچم_مثلثی:',
        'id': ':bendera_segitiga:',
        'zh': u':三角旗:'
    },
    u'\U0001F4D0': { # 📐
        'en' : ':triangular_ruler:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':dreieckiges_lineal:',
        'es': ':escuadra:',
        'fr': u':équerre:',
        'ja': u':三角定規:',
        'ko': u':삼각자:',
        'pt': u':régua_triangular:',
        'it': ':squadra:',
        'fa': u':گونیا:',
        'id': ':penggaris_segitiga:',
        'zh': u':三角尺:'
    },
    u'\U0001F531': { # 🔱
        'en' : ':trident_emblem:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':trident:'],
        'de': ':dreizack:',
        'es': ':emblema_de_tridente:',
        'fr': ':trident:',
        'ja': u':トライデント:',
        'ko': u':삼지창:',
        'pt': ':emblema_de_tridente:',
        'it': ':tridente:',
        'fa': u':نیزهٔ_سه_شاخه:',
        'id': ':emblem_trisula:',
        'zh': u':三叉戟徽章:'
    },
    u'\U0001F9CC': { # 🧌
        'en' : ':troll:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':troll:',
        'es': ':trol:',
        'fr': ':troll:',
        'ja': u':トロール:',
        'ko': u':트롤:',
        'pt': ':troll:',
        'it': ':troll:',
        'fa': u':غول:',
        'id': ':raksasa:',
        'zh': u':穴居巨怪:'
    },
    u'\U0001F68E': { # 🚎
        'en' : ':trolleybus:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':oberleitungsbus:',
        'es': u':trolebús:',
        'fr': ':trolleybus:',
        'ja': u':トロリーバス:',
        'ko': u':트롤리_버스:',
        'pt': u':trólebus:',
        'it': ':filobus:',
        'fa': u':اتوبوس_برقی:',
        'id': ':bus_listrik:',
        'zh': u':无轨电车:'
    },
    u'\U0001F3C6': { # 🏆
        'en' : ':trophy:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':pokal:',
        'es': ':trofeo:',
        'fr': u':trophée:',
        'ja': u':トロフィー:',
        'ko': u':트로피:',
        'pt': u':troféu:',
        'it': ':coppa:',
        'fa': u':جام_ورزشی:',
        'id': ':piala:',
        'zh': u':奖杯:'
    },
    u'\U0001F379': { # 🍹
        'en' : ':tropical_drink:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':cocktail:',
        'es': ':bebida_tropical:',
        'fr': ':cocktail_tropical:',
        'ja': u':トロピカルドリンク:',
        'ko': u':음료수:',
        'pt': ':bebida_tropical:',
        'it': ':cocktail_tropicale:',
        'fa': u':نوشیدنی_استوایی:',
        'id': ':minuman_tropis:',
        'zh': u':热带水果饮料:'
    },
    u'\U0001F420': { # 🐠
        'en' : ':tropical_fish:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':tropenfisch:',
        'es': ':pez_tropical:',
        'fr': ':poisson_tropical:',
        'ja': u':熱帯魚:',
        'ko': u':열대어:',
        'pt': ':peixe_tropical:',
        'it': ':pesce_tropicale:',
        'fa': u':ماهی_استوایی:',
        'id': ':ikan_tropis:',
        'zh': u':热带鱼:'
    },
    u'\U0001F3BA': { # 🎺
        'en' : ':trumpet:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':trompete:',
        'es': ':trompeta:',
        'fr': ':trompette:',
        'ja': u':トランペット:',
        'ko': u':트럼펫:',
        'pt': ':trompete:',
        'it': ':tromba:',
        'fa': u':ترومپت:',
        'id': ':trompet:',
        'zh': u':小号:'
    },
    u'\U0001F337': { # 🌷
        'en' : ':tulip:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':tulpe:',
        'es': u':tulipán:',
        'fr': ':tulipe:',
        'ja': u':チューリップ:',
        'ko': u':튤립:',
        'pt': ':tulipa:',
        'it': ':tulipano:',
        'fa': u':لاله:',
        'id': ':tulip:',
        'zh': u':郁金香:'
    },
    u'\U0001F943': { # 🥃
        'en' : ':tumbler_glass:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':trinkglas:',
        'es': ':vaso_de_whisky:',
        'fr': ':verre_tumbler:',
        'ja': u':タンブラーグラス:',
        'ko': u':양주잔:',
        'pt': ':copo:',
        'it': ':bicchiere_tumbler:',
        'fa': u':لیوان_ته_گنبدی:',
        'id': ':gelas_tumbler:',
        'zh': u':平底杯:'
    },
    u'\U0001F983': { # 🦃
        'en' : ':turkey:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':truthahn:',
        'es': ':pavo:',
        'fr': ':dindon:',
        'ja': u':七面鳥:',
        'ko': u':칠면조:',
        'pt': ':peru:',
        'it': ':tacchino:',
        'fa': u':بوقلمون:',
        'id': ':kalkun:',
        'zh': u':火鸡:'
    },
    u'\U0001F422': { # 🐢
        'en' : ':turtle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':schildkröte:',
        'es': ':tortuga:',
        'fr': ':tortue:',
        'ja': u':カメ:',
        'ko': u':거북이:',
        'pt': ':tartaruga:',
        'it': ':tartaruga:',
        'fa': u':لاک_پشت:',
        'id': ':kura-kura:',
        'zh': u':龟:'
    },
    u'\U0001F567': { # 🕧
        'en' : ':twelve-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock1230:'],
        'variant': True,
        'de': ':12.30_uhr:',
        'es': ':doce_y_media:',
        'fr': ':midi/minuit_et_demie:',
        'ja': u':12時半:',
        'ko': u':열두_시_반:',
        'pt': ':doze_e_meia:',
        'it': ':ore_dodici_e_mezza:',
        'fa': u':ساعت_دوازده_و_نیم:',
        'id': ':jam_setengah_satu:',
        'zh': u':十二点半:'
    },
    u'\U0001F55B': { # 🕛
        'en' : u':twelve_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock12:'],
        'variant': True,
        'de': ':ziffernblatt_12.00_uhr:',
        'es': ':12_en_punto:',
        'fr': ':midi/minuit:',
        'ja': u':12時:',
        'ko': u':열두_시:',
        'pt': ':12_horas:',
        'it': ':ore_dodici:',
        'fa': u':ساعت_دوازده:',
        'id': ':jam_dua_belas_tepat:',
        'zh': u':十二点:'
    },
    u'\U0001F42B': { # 🐫
        'en' : ':two-hump_camel:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':camel:'],
        'de': ':kamel:',
        'es': ':camello:',
        'fr': ':chameau:',
        'ja': u':フタコブラクダ:',
        'ko': u':쌍봉_낙타:',
        'pt': ':camelo_com_duas_corcovas:',
        'it': ':cammello:',
        'fa': u':شتر_دو_کوهان:',
        'id': ':unta_berpunuk_dua:',
        'zh': u':双峰骆驼:'
    },
    u'\U0001F55D': { # 🕝
        'en' : ':two-thirty:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':clock230:'],
        'variant': True,
        'de': ':2.30_uhr:',
        'es': ':dos_y_media:',
        'fr': ':deux_heures_et_demie:',
        'ja': u':2時半:',
        'ko': u':두_시_반:',
        'pt': ':duas_e_meia:',
        'it': ':ore_due_e_mezza:',
        'fa': u':ساعت_دو_و_نیم:',
        'id': ':jam_setengah_tiga:',
        'zh': u':两点半:'
    },
    u'\U0001F495': { # 💕
        'en' : ':two_hearts:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':zwei_herzen:',
        'es': ':dos_corazones:',
        'fr': u':deux_cœurs:',
        'ja': u':2つのハート:',
        'ko': u':하트_두_개:',
        'pt': u':dois_corações:',
        'it': ':due_cuori:',
        'fa': u':دو_قلب:',
        'id': ':dua_hati:',
        'zh': u':两颗心:'
    },
    u'\U0001F551': { # 🕑
        'en' : u':two_o’clock:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':clock2:'],
        'variant': True,
        'de': ':2.00_uhr:',
        'es': ':2_en_punto:',
        'fr': ':deux_heures:',
        'ja': u':2時:',
        'ko': u':두_시:',
        'pt': ':2_horas:',
        'it': ':ore_due:',
        'fa': u':ساعت_دو:',
        'id': ':jam_dua_tepat:',
        'zh': u':两点:'
    },
    u'\U00002602\U0000FE0F': { # ☂️
        'en' : ':umbrella:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':open_umbrella:'],
        'variant': True,
        'de': ':regenschirm:',
        'es': ':paraguas:',
        'fr': ':parapluie_ouvert:',
        'ja': u':傘:',
        'ko': u':우산:',
        'pt': ':guarda-chuva:',
        'it': ':ombrello:',
        'fa': u':چتر:',
        'id': ':payung:',
        'zh': u':伞:'
    },
    u'\U00002602': { # ☂
        'en' : ':umbrella:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':open_umbrella:'],
        'variant': True,
        'de': ':regenschirm:',
        'es': ':paraguas:',
        'fr': ':parapluie_ouvert:',
        'ja': u':傘:',
        'ko': u':우산:',
        'pt': ':guarda-chuva:',
        'it': ':ombrello:',
        'fa': u':چتر:',
        'id': ':payung:',
        'zh': u':伞:'
    },
    u'\U000026F1\U0000FE0F': { # ⛱️
        'en' : ':umbrella_on_ground:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':parasol_on_ground:'],
        'variant': True,
        'de': ':aufgestellter_sonnenschirm:',
        'es': ':sombrilla_en_la_arena:',
        'fr': ':parasol_sur_le_sol:',
        'ja': u':パラソル:',
        'ko': u':땅에_꽂힌_파라솔:',
        'pt': ':guarda-sol:',
        'it': ':ombrellone:',
        'fa': u':چتر_روی_زمین:',
        'id': ':payung_di_tanah:',
        'zh': u':阳伞:'
    },
    u'\U000026F1': { # ⛱
        'en' : ':umbrella_on_ground:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':parasol_on_ground:'],
        'variant': True,
        'de': ':aufgestellter_sonnenschirm:',
        'es': ':sombrilla_en_la_arena:',
        'fr': ':parasol_sur_le_sol:',
        'ja': u':パラソル:',
        'ko': u':땅에_꽂힌_파라솔:',
        'pt': ':guarda-sol:',
        'it': ':ombrellone:',
        'fa': u':چتر_روی_زمین:',
        'id': ':payung_di_tanah:',
        'zh': u':阳伞:'
    },
    u'\U00002614': { # ☔
        'en' : ':umbrella_with_rain_drops:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':umbrella:'],
        'variant': True,
        'de': ':regenschirm_im_regen:',
        'es': ':paraguas_con_gotas_de_lluvia:',
        'fr': ':parapluie_avec_gouttes_de_pluie:',
        'ja': u':傘と雨:',
        'ko': u':빗방울이_있는_우산:',
        'pt': ':sombrinha_na_chuva:',
        'it': ':ombrello_con_gocce_di_pioggia:',
        'fa': u':چتر_خیس:',
        'id': ':payung_dengan_tetesan_hujan:',
        'zh': u':雨伞:'
    },
    u'\U0001F612': { # 😒
        'en' : ':unamused_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':unamused:'],
        'de': ':verstimmtes_gesicht:',
        'es': u':cara_de_desaprobación:',
        'fr': u':visage_blasé:',
        'ja': u':しらけた:',
        'ko': u':지루해하는_얼굴:',
        'pt': ':rosto_aborrecido:',
        'it': ':faccina_contrariata:',
        'fa': u':کسل:',
        'id': ':wajah_bosan:',
        'zh': u':不高兴:'
    },
    u'\U0001F984': { # 🦄
        'en' : ':unicorn:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':unicorn_face:'],
        'de': ':einhorn:',
        'es': ':unicornio:',
        'fr': ':licorne:',
        'ja': u':ユニコーンの顔:',
        'ko': u':유니콘_얼굴:',
        'pt': u':rosto_de_unicórnio:',
        'it': ':unicorno:',
        'fa': u':تک_شاخ:',
        'id': ':unicorn:',
        'zh': u':独角兽:'
    },
    u'\U0001F513': { # 🔓
        'en' : ':unlocked:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':unlock:'],
        'variant': True,
        'de': ':offenes_schloss:',
        'es': ':candado_abierto:',
        'fr': ':cadenas_ouvert:',
        'ja': u':開いた錠:',
        'ko': u':열린_자물쇠:',
        'pt': ':cadeado_aberto:',
        'it': ':lucchetto_aperto:',
        'fa': u':قفل_باز:',
        'id': ':gembok_terbuka:',
        'zh': u':打开的锁:'
    },
    u'\U00002195\U0000FE0F': { # ↕️
        'en' : ':up-down_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_up_down:'],
        'variant': True,
        'de': ':pfeil_nach_oben_und_unten:',
        'es': ':flecha_arriba_y_abajo:',
        'fr': u':flèche_haut_bas:',
        'ja': u':上下矢印:',
        'ko': u':상하향_화살표:',
        'pt': ':seta_para_cima_e_para_baixo:',
        'it': u':freccia_su-giù:',
        'fa': u':پیکان_بالا_و_پایین:',
        'id': ':tanda_panah_atas_bawah:',
        'zh': u':上下箭头:'
    },
    u'\U00002195': { # ↕
        'en' : ':up-down_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_up_down:'],
        'variant': True,
        'de': ':pfeil_nach_oben_und_unten:',
        'es': ':flecha_arriba_y_abajo:',
        'fr': u':flèche_haut_bas:',
        'ja': u':上下矢印:',
        'ko': u':상하향_화살표:',
        'pt': ':seta_para_cima_e_para_baixo:',
        'it': u':freccia_su-giù:',
        'fa': u':پیکان_بالا_و_پایین:',
        'id': ':tanda_panah_atas_bawah:',
        'zh': u':上下箭头:'
    },
    u'\U00002196\U0000FE0F': { # ↖️
        'en' : ':up-left_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_upper_left:'],
        'variant': True,
        'de': ':pfeil_nach_links_oben:',
        'es': ':flecha_hacia_la_esquina_superior_izquierda:',
        'fr': u':flèche_haut_gauche:',
        'ja': u':左上矢印:',
        'ko': u':좌상향_화살표:',
        'pt': ':seta_para_cima_e_para_a_esquerda:',
        'it': ':freccia_in_alto_a_sinistra:',
        'fa': u':پیکان_بالا_چپ:',
        'id': ':tanda_panah_kiri_atas:',
        'zh': u':左上箭头:'
    },
    u'\U00002196': { # ↖
        'en' : ':up-left_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_upper_left:'],
        'variant': True,
        'de': ':pfeil_nach_links_oben:',
        'es': ':flecha_hacia_la_esquina_superior_izquierda:',
        'fr': u':flèche_haut_gauche:',
        'ja': u':左上矢印:',
        'ko': u':좌상향_화살표:',
        'pt': ':seta_para_cima_e_para_a_esquerda:',
        'it': ':freccia_in_alto_a_sinistra:',
        'fa': u':پیکان_بالا_چپ:',
        'id': ':tanda_panah_kiri_atas:',
        'zh': u':左上箭头:'
    },
    u'\U00002197\U0000FE0F': { # ↗️
        'en' : ':up-right_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_upper_right:'],
        'variant': True,
        'de': ':pfeil_nach_rechts_oben:',
        'es': ':flecha_hacia_la_esquina_superior_derecha:',
        'fr': u':flèche_haut_droite:',
        'ja': u':右上矢印:',
        'ko': u':우상향_화살표:',
        'pt': ':seta_para_cima_e_para_a_direita:',
        'it': ':freccia_rivolta_verso_destra_che_punta_in_alto:',
        'fa': u':پیکان_بالا_راست:',
        'id': ':tanda_panah_kanan_atas:',
        'zh': u':右上箭头:'
    },
    u'\U00002197': { # ↗
        'en' : ':up-right_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_upper_right:'],
        'variant': True,
        'de': ':pfeil_nach_rechts_oben:',
        'es': ':flecha_hacia_la_esquina_superior_derecha:',
        'fr': u':flèche_haut_droite:',
        'ja': u':右上矢印:',
        'ko': u':우상향_화살표:',
        'pt': ':seta_para_cima_e_para_a_direita:',
        'it': ':freccia_rivolta_verso_destra_che_punta_in_alto:',
        'fa': u':پیکان_بالا_راست:',
        'id': ':tanda_panah_kanan_atas:',
        'zh': u':右上箭头:'
    },
    u'\U00002B06\U0000FE0F': { # ⬆️
        'en' : ':up_arrow:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_up:'],
        'variant': True,
        'de': ':pfeil_nach_oben:',
        'es': ':flecha_hacia_arriba:',
        'fr': u':flèche_haut:',
        'ja': u':上矢印:',
        'ko': u':상향_화살표:',
        'pt': ':seta_para_cima:',
        'it': u':freccia_rivolta_verso_l’alto:',
        'fa': u':پیکان_بالا:',
        'id': ':tanda_panah_atas:',
        'zh': u':向上箭头:'
    },
    u'\U00002B06': { # ⬆
        'en' : ':up_arrow:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':arrow_up:'],
        'variant': True,
        'de': ':pfeil_nach_oben:',
        'es': ':flecha_hacia_arriba:',
        'fr': u':flèche_haut:',
        'ja': u':上矢印:',
        'ko': u':상향_화살표:',
        'pt': ':seta_para_cima:',
        'it': u':freccia_rivolta_verso_l’alto:',
        'fa': u':پیکان_بالا:',
        'id': ':tanda_panah_atas:',
        'zh': u':向上箭头:'
    },
    u'\U0001F643': { # 🙃
        'en' : ':upside-down_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':upside_down_face:', ':upside__down_face:'],
        'de': ':umgekehrtes_gesicht:',
        'es': u':cara_al_revés:',
        'fr': u':tête_à_l’envers:',
        'ja': u':さかさまの顔:',
        'ko': u':거꾸로_된_얼굴:',
        'pt': u':rosto_de_cabeça_para_baixo:',
        'it': ':faccina_sottosopra:',
        'fa': u':صورت_وارونه:',
        'id': ':wajah_terbalik:',
        'zh': u':倒脸:'
    },
    u'\U0001F53C': { # 🔼
        'en' : ':upwards_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':arrow_up_small:'],
        'de': u':aufwärts-schaltfläche:',
        'es': u':triángulo_hacia_arriba:',
        'fr': ':petit_triangle_haut:',
        'ja': u':上ボタン:',
        'ko': u':위쪽_삼각형:',
        'pt': u':botão_apontando_para_cima:',
        'it': u':pulsante_a_triangolo_rivolto_verso_l’alto:',
        'fa': u':دکمهٔ_بالا:',
        'id': ':tombol_naik:',
        'zh': u':向上三角形按钮:'
    },
    u'\U0001F9DB': { # 🧛
        'en' : ':vampire:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':vampir:',
        'es': ':vampiro:',
        'fr': ':vampire:',
        'ja': u':吸血鬼:',
        'ko': u':뱀파이어:',
        'pt': ':vampiro:',
        'it': ':vampiro:',
        'fa': u':خون_آشام:',
        'id': ':vampir:',
        'zh': u':吸血鬼:'
    },
    u'\U0001F9DB\U0001F3FF': { # 🧛🏿
        'en' : ':vampire_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':vampir_dunkle_hautfarbe:',
        'es': ':vampiro_tono_de_piel_oscuro:',
        'fr': u':vampire_peau_foncée:',
        'ja': u':吸血鬼_濃い肌色:',
        'ko': u':뱀파이어_검은색_피부:',
        'pt': ':vampiro_pele_escura:',
        'it': ':vampiro_carnagione_scura:',
        'fa': u':خون_آشام_پوست_آبنوسی:',
        'id': ':vampir_warna_kulit_gelap:',
        'zh': u':吸血鬼_较深肤色:'
    },
    u'\U0001F9DB\U0001F3FB': { # 🧛🏻
        'en' : ':vampire_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':vampir_helle_hautfarbe:',
        'es': ':vampiro_tono_de_piel_claro:',
        'fr': ':vampire_peau_claire:',
        'ja': u':吸血鬼_薄い肌色:',
        'ko': u':뱀파이어_하얀_피부:',
        'pt': ':vampiro_pele_clara:',
        'it': ':vampiro_carnagione_chiara:',
        'fa': u':خون_آشام_پوست_سفید:',
        'id': ':vampir_warna_kulit_cerah:',
        'zh': u':吸血鬼_较浅肤色:'
    },
    u'\U0001F9DB\U0001F3FE': { # 🧛🏾
        'en' : ':vampire_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':vampir_mitteldunkle_hautfarbe:',
        'es': ':vampiro_tono_de_piel_oscuro_medio:',
        'fr': ':vampire_peau_mate:',
        'ja': u':吸血鬼_やや濃い肌色:',
        'ko': u':뱀파이어_진한_갈색_피부:',
        'pt': ':vampiro_pele_morena_escura:',
        'it': ':vampiro_carnagione_abbastanza_scura:',
        'fa': u':خون_آشام_پوست_گندمی:',
        'id': ':vampir_warna_kulit_gelap-sedang:',
        'zh': u':吸血鬼_中等深肤色:'
    },
    u'\U0001F9DB\U0001F3FC': { # 🧛🏼
        'en' : ':vampire_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':vampir_mittelhelle_hautfarbe:',
        'es': ':vampiro_tono_de_piel_claro_medio:',
        'fr': ':vampire_peau_moyennement_claire:',
        'ja': u':吸血鬼_やや薄い肌色:',
        'ko': u':뱀파이어_연한_갈색_피부:',
        'pt': ':vampiro_pele_morena_clara:',
        'it': ':vampiro_carnagione_abbastanza_chiara:',
        'fa': u':خون_آشام_پوست_روشن:',
        'id': ':vampir_warna_kulit_cerah-sedang:',
        'zh': u':吸血鬼_中等浅肤色:'
    },
    u'\U0001F9DB\U0001F3FD': { # 🧛🏽
        'en' : ':vampire_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':vampir_mittlere_hautfarbe:',
        'es': ':vampiro_tono_de_piel_medio:',
        'fr': u':vampire_peau_légèrement_mate:',
        'ja': u':吸血鬼_中間の肌色:',
        'ko': u':뱀파이어_갈색_피부:',
        'pt': ':vampiro_pele_morena:',
        'it': ':vampiro_carnagione_olivastra:',
        'fa': u':خون_آشام_پوست_طلایی:',
        'id': ':vampir_warna_kulit_sedang:',
        'zh': u':吸血鬼_中等肤色:'
    },
    u'\U0001F6A6': { # 🚦
        'en' : ':vertical_traffic_light:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':vertikale_verkehrsampel:',
        'es': u':semáforo:',
        'fr': ':feu_tricolore_vertical:',
        'ja': u':信号縦:',
        'ko': u':세로_신호등:',
        'pt': u':semáforo_vertical:',
        'it': ':semaforo_verticale:',
        'fa': u':چراغ_راهنمایی_عمودی:',
        'id': ':lampu_lalu_lintas_vertikal:',
        'zh': u':纵向的红绿灯:'
    },
    u'\U0001F4F3': { # 📳
        'en' : ':vibration_mode:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':vibrationsmodus:',
        'es': u':modo_vibración:',
        'fr': ':mode_vibreur:',
        'ja': u':マナーモード:',
        'ko': u':진동_모드:',
        'pt': u':modo_vibratório:',
        'it': u':modalità_vibrazione:',
        'fa': u':حالت_لرزش:',
        'id': ':mode_getar:',
        'zh': u':振动模式:'
    },
    u'\U0000270C\U0000FE0F': { # ✌️
        'en' : ':victory_hand:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':v:'],
        'variant': True,
        'de': ':victory-geste:',
        'es': u':mano_con_señal_de_victoria:',
        'fr': ':v_de_la_victoire:',
        'ja': u':vサイン:',
        'ko': u':브이_표시:',
        'pt': u':mão_em_v_de_vitória:',
        'it': ':vittoria:',
        'fa': u':علامت_پیروزی:',
        'id': ':isyarat_kemenangan:',
        'zh': u':胜利手势:'
    },
    u'\U0000270C': { # ✌
        'en' : ':victory_hand:',
        'status' : unqualified,
        'E' : 0.6,
        'alias' : [':v:'],
        'variant': True,
        'de': ':victory-geste:',
        'es': u':mano_con_señal_de_victoria:',
        'fr': ':v_de_la_victoire:',
        'ja': u':vサイン:',
        'ko': u':브이_표시:',
        'pt': u':mão_em_v_de_vitória:',
        'it': ':vittoria:',
        'fa': u':علامت_پیروزی:',
        'id': ':isyarat_kemenangan:',
        'zh': u':胜利手势:'
    },
    u'\U0000270C\U0001F3FF': { # ✌🏿
        'en' : ':victory_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':victory-geste_dunkle_hautfarbe:',
        'es': u':mano_con_señal_de_victoria_tono_de_piel_oscuro:',
        'fr': u':v_de_la_victoire_peau_foncée:',
        'ja': u':vサイン_濃い肌色:',
        'ko': u':브이_표시_검은색_피부:',
        'pt': u':mão_em_v_de_vitória_pele_escura:',
        'it': ':vittoria_carnagione_scura:',
        'fa': u':علامت_پیروزی_پوست_آبنوسی:',
        'id': ':isyarat_kemenangan_warna_kulit_gelap:',
        'zh': u':胜利手势_较深肤色:'
    },
    u'\U0000270C\U0001F3FB': { # ✌🏻
        'en' : ':victory_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':victory-geste_helle_hautfarbe:',
        'es': u':mano_con_señal_de_victoria_tono_de_piel_claro:',
        'fr': ':v_de_la_victoire_peau_claire:',
        'ja': u':vサイン_薄い肌色:',
        'ko': u':브이_표시_하얀_피부:',
        'pt': u':mão_em_v_de_vitória_pele_clara:',
        'it': ':vittoria_carnagione_chiara:',
        'fa': u':علامت_پیروزی_پوست_سفید:',
        'id': ':isyarat_kemenangan_warna_kulit_cerah:',
        'zh': u':胜利手势_较浅肤色:'
    },
    u'\U0000270C\U0001F3FE': { # ✌🏾
        'en' : ':victory_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':victory-geste_mitteldunkle_hautfarbe:',
        'es': u':mano_con_señal_de_victoria_tono_de_piel_oscuro_medio:',
        'fr': ':v_de_la_victoire_peau_mate:',
        'ja': u':vサイン_やや濃い肌色:',
        'ko': u':브이_표시_진한_갈색_피부:',
        'pt': u':mão_em_v_de_vitória_pele_morena_escura:',
        'it': ':vittoria_carnagione_abbastanza_scura:',
        'fa': u':علامت_پیروزی_پوست_گندمی:',
        'id': ':isyarat_kemenangan_warna_kulit_gelap-sedang:',
        'zh': u':胜利手势_中等深肤色:'
    },
    u'\U0000270C\U0001F3FC': { # ✌🏼
        'en' : ':victory_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':victory-geste_mittelhelle_hautfarbe:',
        'es': u':mano_con_señal_de_victoria_tono_de_piel_claro_medio:',
        'fr': ':v_de_la_victoire_peau_moyennement_claire:',
        'ja': u':vサイン_やや薄い肌色:',
        'ko': u':브이_표시_연한_갈색_피부:',
        'pt': u':mão_em_v_de_vitória_pele_morena_clara:',
        'it': ':vittoria_carnagione_abbastanza_chiara:',
        'fa': u':علامت_پیروزی_پوست_روشن:',
        'id': ':isyarat_kemenangan_warna_kulit_cerah-sedang:',
        'zh': u':胜利手势_中等浅肤色:'
    },
    u'\U0000270C\U0001F3FD': { # ✌🏽
        'en' : ':victory_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':victory-geste_mittlere_hautfarbe:',
        'es': u':mano_con_señal_de_victoria_tono_de_piel_medio:',
        'fr': u':v_de_la_victoire_peau_légèrement_mate:',
        'ja': u':vサイン_中間の肌色:',
        'ko': u':브이_표시_갈색_피부:',
        'pt': u':mão_em_v_de_vitória_pele_morena:',
        'it': ':vittoria_carnagione_olivastra:',
        'fa': u':علامت_پیروزی_پوست_طلایی:',
        'id': ':isyarat_kemenangan_warna_kulit_sedang:',
        'zh': u':胜利手势_中等肤色:'
    },
    u'\U0001F4F9': { # 📹
        'en' : ':video_camera:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':videokamera:',
        'es': u':videocámara:',
        'fr': u':caméscope:',
        'ja': u':ビデオカメラ:',
        'ko': u':캠코더:',
        'pt': u':câmera_de_vídeo:',
        'it': ':videocamera:',
        'fa': u':دوربین_فیلم_برداری:',
        'id': ':kamera_video:',
        'zh': u':摄像机:'
    },
    u'\U0001F3AE': { # 🎮
        'en' : ':video_game:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':gamepad:',
        'es': ':mando_de_videoconsola:',
        'fr': u':jeu_vidéo:',
        'ja': u':テレビゲーム:',
        'ko': u':비디오_게임:',
        'pt': ':videogame:',
        'it': ':gamepad:',
        'fa': u':بازی_ویدیویی:',
        'id': ':video_game:',
        'zh': u':游戏手柄:'
    },
    u'\U0001F4FC': { # 📼
        'en' : ':videocassette:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':vhs:'],
        'de': ':videokassette:',
        'es': u':cinta_de_vídeo:',
        'fr': u':cassette_vidéo:',
        'ja': u':ビデオテープ:',
        'ko': u':비디오테이프:',
        'pt': ':videocassete:',
        'it': ':videocassetta:',
        'fa': u':کاست_ویدیویی:',
        'id': ':kaset_video:',
        'zh': u':录像带:'
    },
    u'\U0001F3BB': { # 🎻
        'en' : ':violin:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':geige:',
        'es': u':violín:',
        'fr': ':violon:',
        'ja': u':バイオリン:',
        'ko': u':바이올린:',
        'pt': ':violino:',
        'it': ':violino:',
        'fa': u':ویولن:',
        'id': ':biola:',
        'zh': u':小提琴:'
    },
    u'\U0001F30B': { # 🌋
        'en' : ':volcano:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':vulkan:',
        'es': u':volcán:',
        'fr': ':volcan:',
        'ja': u':火山:',
        'ko': u':화산:',
        'pt': u':vulcão:',
        'it': ':vulcano:',
        'fa': u':آتشفشان:',
        'id': ':gunung_berapi:',
        'zh': u':火山:'
    },
    u'\U0001F3D0': { # 🏐
        'en' : ':volleyball:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':volleyball:',
        'es': ':pelota_de_voleibol:',
        'fr': ':volley-ball:',
        'ja': u':バレーボール:',
        'ko': u':배구공:',
        'pt': u':bola_de_vôlei:',
        'it': ':palla_da_pallavolo:',
        'fa': u':والیبال:',
        'id': ':bola_voli:',
        'zh': u':排球:'
    },
    u'\U0001F596': { # 🖖
        'en' : ':vulcan_salute:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':raised_hand_with_part_between_middle_and_ring_fingers:'],
        'de': u':vulkanischer_gruß:',
        'es': ':saludo_vulcano:',
        'fr': ':salut_vulcain:',
        'ja': u':バルカンの挨拶:',
        'ko': u':벌칸식_인사:',
        'pt': u':saudação_vulcana:',
        'it': ':saluto_vulcaniano:',
        'fa': u':سلام_ولکان:',
        'id': ':salam_vulcan:',
        'zh': u':瓦肯举手礼:'
    },
    u'\U0001F596\U0001F3FF': { # 🖖🏿
        'en' : ':vulcan_salute_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':vulkanischer_gruß_dunkle_hautfarbe:',
        'es': ':saludo_vulcano_tono_de_piel_oscuro:',
        'fr': u':salut_vulcain_peau_foncée:',
        'ja': u':バルカンの挨拶_濃い肌色:',
        'ko': u':벌칸식_인사_검은색_피부:',
        'pt': u':saudação_vulcana_pele_escura:',
        'it': ':saluto_vulcaniano_carnagione_scura:',
        'fa': u':سلام_ولکان_پوست_آبنوسی:',
        'id': ':salam_vulcan_warna_kulit_gelap:',
        'zh': u':瓦肯举手礼_较深肤色:'
    },
    u'\U0001F596\U0001F3FB': { # 🖖🏻
        'en' : ':vulcan_salute_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':vulkanischer_gruß_helle_hautfarbe:',
        'es': ':saludo_vulcano_tono_de_piel_claro:',
        'fr': ':salut_vulcain_peau_claire:',
        'ja': u':バルカンの挨拶_薄い肌色:',
        'ko': u':벌칸식_인사_하얀_피부:',
        'pt': u':saudação_vulcana_pele_clara:',
        'it': ':saluto_vulcaniano_carnagione_chiara:',
        'fa': u':سلام_ولکان_پوست_سفید:',
        'id': ':salam_vulcan_warna_kulit_cerah:',
        'zh': u':瓦肯举手礼_较浅肤色:'
    },
    u'\U0001F596\U0001F3FE': { # 🖖🏾
        'en' : ':vulcan_salute_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':vulkanischer_gruß_mitteldunkle_hautfarbe:',
        'es': ':saludo_vulcano_tono_de_piel_oscuro_medio:',
        'fr': ':salut_vulcain_peau_mate:',
        'ja': u':バルカンの挨拶_やや濃い肌色:',
        'ko': u':벌칸식_인사_진한_갈색_피부:',
        'pt': u':saudação_vulcana_pele_morena_escura:',
        'it': ':saluto_vulcaniano_carnagione_abbastanza_scura:',
        'fa': u':سلام_ولکان_پوست_گندمی:',
        'id': ':salam_vulcan_warna_kulit_gelap-sedang:',
        'zh': u':瓦肯举手礼_中等深肤色:'
    },
    u'\U0001F596\U0001F3FC': { # 🖖🏼
        'en' : ':vulcan_salute_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':vulkanischer_gruß_mittelhelle_hautfarbe:',
        'es': ':saludo_vulcano_tono_de_piel_claro_medio:',
        'fr': ':salut_vulcain_peau_moyennement_claire:',
        'ja': u':バルカンの挨拶_やや薄い肌色:',
        'ko': u':벌칸식_인사_연한_갈색_피부:',
        'pt': u':saudação_vulcana_pele_morena_clara:',
        'it': ':saluto_vulcaniano_carnagione_abbastanza_chiara:',
        'fa': u':سلام_ولکان_پوست_روشن:',
        'id': ':salam_vulcan_warna_kulit_cerah-sedang:',
        'zh': u':瓦肯举手礼_中等浅肤色:'
    },
    u'\U0001F596\U0001F3FD': { # 🖖🏽
        'en' : ':vulcan_salute_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':vulkanischer_gruß_mittlere_hautfarbe:',
        'es': ':saludo_vulcano_tono_de_piel_medio:',
        'fr': u':salut_vulcain_peau_légèrement_mate:',
        'ja': u':バルカンの挨拶_中間の肌色:',
        'ko': u':벌칸식_인사_갈색_피부:',
        'pt': u':saudação_vulcana_pele_morena:',
        'it': ':saluto_vulcaniano_carnagione_olivastra:',
        'fa': u':سلام_ولکان_پوست_طلایی:',
        'id': ':salam_vulcan_warna_kulit_sedang:',
        'zh': u':瓦肯举手礼_中等肤色:'
    },
    u'\U0001F9C7': { # 🧇
        'en' : ':waffle:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':waffel:',
        'es': ':gofre:',
        'fr': ':gaufre:',
        'ja': u':ワッフル:',
        'ko': u':와플:',
        'pt': ':waffle:',
        'it': ':waffle:',
        'fa': u':وافل:',
        'id': ':wafel:',
        'zh': u':华夫饼:'
    },
    u'\U0001F318': { # 🌘
        'en' : ':waning_crescent_moon:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':letztes_mondviertel:',
        'es': ':luna_menguante:',
        'fr': u':lune_décroissante:',
        'ja': u':有明月:',
        'ko': u':그믐달_하현:',
        'pt': u':lua_minguante_côncava:',
        'it': ':luna_calante:',
        'fa': u':هلال_کاهنده_ماه:',
        'id': ':bulan_sabit_akhir:',
        'zh': u':残月:'
    },
    u'\U0001F316': { # 🌖
        'en' : ':waning_gibbous_moon:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':drittes_mondviertel:',
        'es': ':luna_gibosa_menguante:',
        'fr': u':lune_gibbeuse_décroissante:',
        'ja': u':寝待月:',
        'ko': u':하현달:',
        'pt': ':lua_minguante_convexa:',
        'it': ':luna_gibbosa_calante:',
        'fa': u':کوژماه_کاهنده:',
        'id': ':bulan_cembung_akhir:',
        'zh': u':亏凸月:'
    },
    u'\U000026A0\U0000FE0F': { # ⚠️
        'en' : ':warning:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':warnung:',
        'es': ':advertencia:',
        'fr': u':symbole_d’avertissement:',
        'ja': u':警告:',
        'ko': u':주의:',
        'pt': ':aviso:',
        'it': ':simbolo_di_avviso:',
        'fa': u':هشدار:',
        'id': ':peringatan:',
        'zh': u':警告:'
    },
    u'\U000026A0': { # ⚠
        'en' : ':warning:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':warnung:',
        'es': ':advertencia:',
        'fr': u':symbole_d’avertissement:',
        'ja': u':警告:',
        'ko': u':주의:',
        'pt': ':aviso:',
        'it': ':simbolo_di_avviso:',
        'fa': u':هشدار:',
        'id': ':peringatan:',
        'zh': u':警告:'
    },
    u'\U0001F5D1\U0000FE0F': { # 🗑️
        'en' : ':wastebasket:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':papierkorb:',
        'es': ':papelera:',
        'fr': u':corbeille_à_papiers:',
        'ja': u':ごみ箱:',
        'ko': u':쓰레기통:',
        'pt': ':lixeira:',
        'it': ':cestino:',
        'fa': u':سطل_کاغذ_باطله:',
        'id': ':keranjang_sampah:',
        'zh': u':垃圾桶:'
    },
    u'\U0001F5D1': { # 🗑
        'en' : ':wastebasket:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':papierkorb:',
        'es': ':papelera:',
        'fr': u':corbeille_à_papiers:',
        'ja': u':ごみ箱:',
        'ko': u':쓰레기통:',
        'pt': ':lixeira:',
        'it': ':cestino:',
        'fa': u':سطل_کاغذ_باطله:',
        'id': ':keranjang_sampah:',
        'zh': u':垃圾桶:'
    },
    u'\U0000231A': { # ⌚
        'en' : ':watch:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':armbanduhr:',
        'es': ':reloj:',
        'fr': ':montre:',
        'ja': u':腕時計:',
        'ko': u':시계:',
        'pt': u':relógio_de_pulso:',
        'it': ':orologio:',
        'fa': u':ساعت_مچی:',
        'id': ':jam_tangan:',
        'zh': u':手表:'
    },
    u'\U0001F403': { # 🐃
        'en' : ':water_buffalo:',
        'status' : fully_qualified,
        'E' : 1,
        'de': u':wasserbüffel:',
        'es': u':búfalo_de_agua:',
        'fr': ':buffle:',
        'ja': u':水牛:',
        'ko': u':물소:',
        'pt': u':búfalo-asiático:',
        'it': u':bufalo_d’acqua:',
        'fa': u':بوفالوی_آبی:',
        'id': ':kerbau:',
        'zh': u':水牛:'
    },
    u'\U0001F6BE': { # 🚾
        'en' : ':water_closet:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':wc:'],
        'de': ':wc:',
        'es': ':aseos:',
        'fr': ':wc:',
        'ja': ':wc:',
        'ko': u':더블유씨:',
        'pt': ':wc:',
        'it': ':simbolo_del_wc:',
        'fa': u':سرویس_بهداشتی:',
        'id': ':kloset_air:',
        'zh': u':厕所:'
    },
    u'\U0001F52B': { # 🔫
        'en' : ':water_pistol:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':gun:'],
        'de': ':wasserpistole:',
        'es': ':pistola_de_agua:',
        'fr': u':pistolet_à_eau:',
        'ja': u':水鉄砲:',
        'ko': u':물총:',
        'pt': u':pistola_d’água:',
        'it': ':pistola_ad_acqua:',
        'fa': u':تفنگ_آب_پاش:',
        'id': ':pistol_air:',
        'zh': u':水枪:'
    },
    u'\U0001F30A': { # 🌊
        'en' : ':water_wave:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':ocean:'],
        'de': ':welle:',
        'es': ':ola_de_mar:',
        'fr': ':vague:',
        'ja': u':波:',
        'ko': u':파도:',
        'pt': ':onda:',
        'it': ':onda:',
        'fa': u':موج_آب:',
        'id': ':ombak:',
        'zh': u':浪花:'
    },
    u'\U0001F349': { # 🍉
        'en' : ':watermelon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wassermelone:',
        'es': u':sandía:',
        'fr': u':pastèque:',
        'ja': u':スイカ:',
        'ko': u':수박:',
        'pt': ':melancia:',
        'it': ':anguria:',
        'fa': u':هندوانه:',
        'id': ':semangka:',
        'zh': u':西瓜:'
    },
    u'\U0001F44B': { # 👋
        'en' : ':waving_hand:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':wave:'],
        'de': ':winkende_hand:',
        'es': ':mano_saludando:',
        'fr': ':signe_de_la_main:',
        'ja': u':手を振る:',
        'ko': u':흔드는_손:',
        'pt': u':mão_acenando:',
        'it': ':mano_che_saluta:',
        'fa': u':تکان_دادن_دست:',
        'id': ':tangan_melambai:',
        'zh': u':挥手:'
    },
    u'\U0001F44B\U0001F3FF': { # 👋🏿
        'en' : ':waving_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':winkende_hand_dunkle_hautfarbe:',
        'es': ':mano_saludando_tono_de_piel_oscuro:',
        'fr': u':signe_de_la_main_peau_foncée:',
        'ja': u':手を振る_濃い肌色:',
        'ko': u':흔드는_손_검은색_피부:',
        'pt': u':mão_acenando_pele_escura:',
        'it': ':mano_che_saluta_carnagione_scura:',
        'fa': u':تکان_دادن_دست_پوست_آبنوسی:',
        'id': ':tangan_melambai_warna_kulit_gelap:',
        'zh': u':挥手_较深肤色:'
    },
    u'\U0001F44B\U0001F3FB': { # 👋🏻
        'en' : ':waving_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':winkende_hand_helle_hautfarbe:',
        'es': ':mano_saludando_tono_de_piel_claro:',
        'fr': ':signe_de_la_main_peau_claire:',
        'ja': u':手を振る_薄い肌色:',
        'ko': u':흔드는_손_하얀_피부:',
        'pt': u':mão_acenando_pele_clara:',
        'it': ':mano_che_saluta_carnagione_chiara:',
        'fa': u':تکان_دادن_دست_پوست_سفید:',
        'id': ':tangan_melambai_warna_kulit_cerah:',
        'zh': u':挥手_较浅肤色:'
    },
    u'\U0001F44B\U0001F3FE': { # 👋🏾
        'en' : ':waving_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':winkende_hand_mitteldunkle_hautfarbe:',
        'es': ':mano_saludando_tono_de_piel_oscuro_medio:',
        'fr': ':signe_de_la_main_peau_mate:',
        'ja': u':手を振る_やや濃い肌色:',
        'ko': u':흔드는_손_진한_갈색_피부:',
        'pt': u':mão_acenando_pele_morena_escura:',
        'it': ':mano_che_saluta_carnagione_abbastanza_scura:',
        'fa': u':تکان_دادن_دست_پوست_گندمی:',
        'id': ':tangan_melambai_warna_kulit_gelap-sedang:',
        'zh': u':挥手_中等深肤色:'
    },
    u'\U0001F44B\U0001F3FC': { # 👋🏼
        'en' : ':waving_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':winkende_hand_mittelhelle_hautfarbe:',
        'es': ':mano_saludando_tono_de_piel_claro_medio:',
        'fr': ':signe_de_la_main_peau_moyennement_claire:',
        'ja': u':手を振る_やや薄い肌色:',
        'ko': u':흔드는_손_연한_갈색_피부:',
        'pt': u':mão_acenando_pele_morena_clara:',
        'it': ':mano_che_saluta_carnagione_abbastanza_chiara:',
        'fa': u':تکان_دادن_دست_پوست_روشن:',
        'id': ':tangan_melambai_warna_kulit_cerah-sedang:',
        'zh': u':挥手_中等浅肤色:'
    },
    u'\U0001F44B\U0001F3FD': { # 👋🏽
        'en' : ':waving_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':winkende_hand_mittlere_hautfarbe:',
        'es': ':mano_saludando_tono_de_piel_medio:',
        'fr': u':signe_de_la_main_peau_légèrement_mate:',
        'ja': u':手を振る_中間の肌色:',
        'ko': u':흔드는_손_갈색_피부:',
        'pt': u':mão_acenando_pele_morena:',
        'it': ':mano_che_saluta_carnagione_olivastra:',
        'fa': u':تکان_دادن_دست_پوست_طلایی:',
        'id': ':tangan_melambai_warna_kulit_sedang:',
        'zh': u':挥手_中等肤色:'
    },
    u'\U00003030\U0000FE0F': { # 〰️
        'en' : ':wavy_dash:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': ':wellenlinie:',
        'es': ':guion_ondulado:',
        'fr': u':ligne_ondulée:',
        'ja': u':波線:',
        'ko': u':물결_모양_대시:',
        'pt': u':travessão_ondulado:',
        'it': ':trattino_ondulato:',
        'fa': u':خط_موج_دار:',
        'id': ':garis_bergelombang:',
        'zh': u':波浪型破折号:'
    },
    u'\U00003030': { # 〰
        'en' : ':wavy_dash:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': ':wellenlinie:',
        'es': ':guion_ondulado:',
        'fr': u':ligne_ondulée:',
        'ja': u':波線:',
        'ko': u':물결_모양_대시:',
        'pt': u':travessão_ondulado:',
        'it': ':trattino_ondulato:',
        'fa': u':خط_موج_دار:',
        'id': ':garis_bergelombang:',
        'zh': u':波浪型破折号:'
    },
    u'\U0001F312': { # 🌒
        'en' : ':waxing_crescent_moon:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':erstes_mondviertel:',
        'es': ':luna_creciente:',
        'fr': ':lune_croissante:',
        'ja': u':初月:',
        'ko': u':초승달_상현:',
        'pt': u':lua_crescente_côncava:',
        'it': ':luna_crescente:',
        'fa': u':هلال_فزاینده_ماه:',
        'id': ':bulan_sabit_awal:',
        'zh': u':娥眉月:'
    },
    u'\U0001F314': { # 🌔
        'en' : ':waxing_gibbous_moon:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':moon:'],
        'de': ':zweites_mondviertel:',
        'es': ':luna_gibosa_creciente:',
        'fr': ':lune_gibbeuse_croissante:',
        'ja': u':十三夜月:',
        'ko': u':상현달:',
        'pt': ':lua_crescente_convexa:',
        'it': ':luna_gibbosa_crescente:',
        'fa': u':کوژماه_افزاینده:',
        'id': ':bulan_cembung_awal:',
        'zh': u':盈凸月:'
    },
    u'\U0001F640': { # 🙀
        'en' : ':weary_cat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':scream_cat:'],
        'de': u':erschöpfte_katze:',
        'es': ':gato_asustado:',
        'fr': u':chat_fatigué:',
        'ja': u':絶望する猫:',
        'ko': u':절규하는_고양이_얼굴:',
        'pt': ':rosto_de_gato_desolado:',
        'it': ':gatto_esterrefatto:',
        'fa': u':گربهٔ_بهت_زده:',
        'id': ':wajah_kucing_ketakutan:',
        'zh': u':疲倦的猫:'
    },
    u'\U0001F629': { # 😩
        'en' : ':weary_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':weary:'],
        'de': u':erschöpftes_gesicht:',
        'es': ':cara_agotada:',
        'fr': u':visage_épuisé:',
        'ja': u':あきらめ:',
        'ko': u':지친_얼굴:',
        'pt': ':rosto_desolado:',
        'it': ':faccina_esausta:',
        'fa': u':ازپاافتاده:',
        'id': ':wajah_terlalu_lelah:',
        'zh': u':累死了:'
    },
    u'\U0001F492': { # 💒
        'en' : ':wedding:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':hochzeit:',
        'es': ':iglesia_celebrando_boda:',
        'fr': ':mariage:',
        'ja': u':結婚式:',
        'ko': u':결혼식:',
        'pt': ':capela_de_casamento:',
        'it': ':chiesa_per_matrimonio:',
        'fa': u':ازدواج:',
        'id': ':pernikahan:',
        'zh': u':婚礼:'
    },
    u'\U0001F40B': { # 🐋
        'en' : ':whale:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':whale2:'],
        'de': ':wal:',
        'es': ':ballena:',
        'fr': ':baleine:',
        'ja': u':クジラ:',
        'ko': u':고래:',
        'pt': ':baleia:',
        'it': ':balena:',
        'fa': u':نهنگ:',
        'id': ':ikan_paus:',
        'zh': u':鲸鱼:'
    },
    u'\U0001F6DE': { # 🛞
        'en' : ':wheel:',
        'status' : fully_qualified,
        'E' : 14,
        'de': ':autorad:',
        'es': ':rueda:',
        'fr': ':roue:',
        'ja': u':ホイール:',
        'ko': u':휠:',
        'pt': ':roda:',
        'it': ':ruota:',
        'fa': u':چرخ:',
        'id': ':roda:',
        'zh': u':车轮:'
    },
    u'\U00002638\U0000FE0F': { # ☸️
        'en' : ':wheel_of_dharma:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':dharma-rad:',
        'es': ':rueda_del_dharma:',
        'fr': ':roue_du_dharma:',
        'ja': u':法輪:',
        'ko': u':진리의_수레바퀴:',
        'pt': ':roda_do_dharma:',
        'it': ':ruota_del_dharma:',
        'fa': u':چرخ_دارما:',
        'id': ':roda_dharma:',
        'zh': u':法轮:'
    },
    u'\U00002638': { # ☸
        'en' : ':wheel_of_dharma:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':dharma-rad:',
        'es': ':rueda_del_dharma:',
        'fr': ':roue_du_dharma:',
        'ja': u':法輪:',
        'ko': u':진리의_수레바퀴:',
        'pt': ':roda_do_dharma:',
        'it': ':ruota_del_dharma:',
        'fa': u':چرخ_دارما:',
        'id': ':roda_dharma:',
        'zh': u':法轮:'
    },
    u'\U0000267F': { # ♿
        'en' : ':wheelchair_symbol:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':wheelchair:'],
        'variant': True,
        'de': ':symbol_rollstuhl:',
        'es': u':símbolo_de_silla_de_ruedas:',
        'fr': u':symbole_accès_handicapés:',
        'ja': u':車椅子:',
        'ko': u':휠체어:',
        'pt': u':símbolo_de_cadeira_de_rodas:',
        'it': u':simbolo_della_disabilità:',
        'fa': u':علامت_صندلی_چرخ_دار:',
        'id': ':simbol_kursi_roda:',
        'zh': u':轮椅标识:'
    },
    u'\U0001F9AF': { # 🦯
        'en' : ':white_cane:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':probing_cane:'],
        'de': ':blindenstock:',
        'es': u':bastón:',
        'fr': ':canne_blanche:',
        'ja': u':白杖:',
        'ko': u':시각장애인_지팡이:',
        'pt': ':bengala_para_cegos:',
        'it': ':bastone_per_non_vedenti:',
        'fa': u':عصای_سفید:',
        'id': ':tongkat_tunanetra:',
        'zh': u':盲杖:'
    },
    u'\U000026AA': { # ⚪
        'en' : ':white_circle:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':weißer_punkt:',
        'es': u':círculo_blanco:',
        'fr': ':disque_blanc:',
        'ja': u':白い丸:',
        'ko': u':흰색_원:',
        'pt': u':círculo_branco:',
        'it': ':cerchio_bianco:',
        'fa': u':دایره_سفید:',
        'id': ':lingkaran_putih:',
        'zh': u':白色圆:'
    },
    u'\U00002755': { # ❕
        'en' : ':white_exclamation_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':grey_exclamation:'],
        'de': u':weißes_ausrufezeichen:',
        'es': u':exclamación_blanca:',
        'fr': u':point_d’exclamation_blanc:',
        'ja': u':白い感嘆符:',
        'ko': u':하얀색_느낌표:',
        'pt': u':ponto_de_exclamação_branco:',
        'it': ':punto_esclamativo_bianco:',
        'fa': u':علامت_تعجب_سفید:',
        'id': ':tanda_seru_putih:',
        'zh': u':白色感叹号:'
    },
    u'\U0001F3F3\U0000FE0F': { # 🏳️
        'en' : ':white_flag:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':waving_white_flag:'],
        'variant': True,
        'de': u':weiße_flagge:',
        'es': ':bandera_blanca:',
        'fr': ':drapeau_blanc:',
        'ja': u':白旗:',
        'ko': u':펄럭이는_흰색_깃발:',
        'pt': ':bandeira_branca:',
        'it': ':bandiera_bianca:',
        'fa': u':پرچم_سفید:',
        'id': ':bendera_putih:',
        'zh': u':举白旗:'
    },
    u'\U0001F3F3': { # 🏳
        'en' : ':white_flag:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':waving_white_flag:'],
        'variant': True,
        'de': u':weiße_flagge:',
        'es': ':bandera_blanca:',
        'fr': ':drapeau_blanc:',
        'ja': u':白旗:',
        'ko': u':펄럭이는_흰색_깃발:',
        'pt': ':bandeira_branca:',
        'it': ':bandiera_bianca:',
        'fa': u':پرچم_سفید:',
        'id': ':bendera_putih:',
        'zh': u':举白旗:'
    },
    u'\U0001F4AE': { # 💮
        'en' : ':white_flower:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':blumenstempel:',
        'es': ':flor_blanca:',
        'fr': ':fleur_blanche:',
        'ja': u':大変よくできました:',
        'ko': u':흰_꽃:',
        'pt': ':flor_branca:',
        'it': ':fiore_bianco:',
        'fa': u':گل_سفید:',
        'id': ':bunga_putih:',
        'zh': u':白花:'
    },
    u'\U0001F9B3': { # 🦳
        'en' : ':white_hair:',
        'status' : component,
        'E' : 11,
        'de': u':weißes_haar:',
        'es': ':pelo_blanco:',
        'fr': ':cheveux_blancs:',
        'ja': u':白髪:',
        'ko': u':백발:',
        'pt': ':cabelo_branco:',
        'it': ':capelli_bianchi:',
        'fa': u':موسفید:',
        'id': ':rambut_putih:',
        'zh': u':白发:'
    },
    u'\U0001F90D': { # 🤍
        'en' : ':white_heart:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':weißes_herz:',
        'es': u':corazón_blanco:',
        'fr': u':cœur_blanc:',
        'ja': u':白いハート:',
        'ko': u':흰색_하트:',
        'pt': u':coração_branco:',
        'it': ':cuore_bianco:',
        'fa': u':قلب_سفید:',
        'id': ':hati_putih:',
        'zh': u':白心:'
    },
    u'\U00002B1C': { # ⬜
        'en' : ':white_large_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':großes_weißes_quadrat:',
        'es': ':cuadrado_blanco_grande:',
        'fr': u':grand_carré_blanc:',
        'ja': u':白四角特大:',
        'ko': u':큰_흰색_사각형:',
        'pt': ':quadrado_branco_grande:',
        'it': ':quadrato_bianco_grande:',
        'fa': u':مربع_سفید_بزرگ:',
        'id': ':persegi_besar_putih:',
        'zh': u':白线大方框:'
    },
    u'\U000025FD': { # ◽
        'en' : ':white_medium-small_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':white_medium_small_square:'],
        'variant': True,
        'de': u':mittelkleines_weißes_quadrat:',
        'es': u':cuadrado_blanco_mediano-pequeño:',
        'fr': u':carré_petit_moyen_blanc:',
        'ja': u':白四角中:',
        'ko': u':중간_작은_흰색_사각형:',
        'pt': u':quadrado_branco_médio_menor:',
        'it': ':quadrato_bianco_medio-piccolo:',
        'fa': u':مربع_سفید_نسبتاً_کوچک:',
        'id': ':persegi_kecil_medium_putih:',
        'zh': u':白色中小方块:'
    },
    u'\U000025FB\U0000FE0F': { # ◻️
        'en' : ':white_medium_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':mittelgroßes_weißes_quadrat:',
        'es': ':cuadrado_blanco_mediano:',
        'fr': u':carré_moyen_blanc:',
        'ja': u':白四角大:',
        'ko': u':중간_흰색_사각형:',
        'pt': u':quadrado_branco_médio:',
        'it': ':quadrato_bianco_medio:',
        'fa': u':مربع_سفید_متوسط:',
        'id': ':persegi_medium_putih:',
        'zh': u':白色中方块:'
    },
    u'\U000025FB': { # ◻
        'en' : ':white_medium_square:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': u':mittelgroßes_weißes_quadrat:',
        'es': ':cuadrado_blanco_mediano:',
        'fr': u':carré_moyen_blanc:',
        'ja': u':白四角大:',
        'ko': u':중간_흰색_사각형:',
        'pt': u':quadrado_branco_médio:',
        'it': ':quadrato_bianco_medio:',
        'fa': u':مربع_سفید_متوسط:',
        'id': ':persegi_medium_putih:',
        'zh': u':白色中方块:'
    },
    u'\U00002754': { # ❔
        'en' : ':white_question_mark:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':grey_question:'],
        'de': u':weißes_fragezeichen:',
        'es': u':interrogación_blanca:',
        'fr': u':point_d’interrogation_blanc:',
        'ja': u':白い疑問符:',
        'ko': u':하얀색_물음표:',
        'pt': u':ponto_de_interrogação_branco:',
        'it': ':punto_interrogativo_bianco:',
        'fa': u':علامت_سؤال_سفید:',
        'id': ':tanda_tanya_putih:',
        'zh': u':白色问号:'
    },
    u'\U000025AB\U0000FE0F': { # ▫️
        'en' : ':white_small_square:',
        'status' : fully_qualified,
        'E' : 0.6,
        'variant': True,
        'de': u':kleines_weißes_quadrat:',
        'es': u':cuadrado_blanco_pequeño:',
        'fr': u':petit_carré_blanc:',
        'ja': u':白四角小:',
        'ko': u':작은_흰색_사각형:',
        'pt': ':quadrado_branco_pequeno:',
        'it': ':quadrato_bianco_piccolo:',
        'fa': u':مربع_سفید_کوچک:',
        'id': ':persegi_kecil_putih:',
        'zh': u':白色小方块:'
    },
    u'\U000025AB': { # ▫
        'en' : ':white_small_square:',
        'status' : unqualified,
        'E' : 0.6,
        'variant': True,
        'de': u':kleines_weißes_quadrat:',
        'es': u':cuadrado_blanco_pequeño:',
        'fr': u':petit_carré_blanc:',
        'ja': u':白四角小:',
        'ko': u':작은_흰색_사각형:',
        'pt': ':quadrado_branco_pequeno:',
        'it': ':quadrato_bianco_piccolo:',
        'fa': u':مربع_سفید_کوچک:',
        'id': ':persegi_kecil_putih:',
        'zh': u':白色小方块:'
    },
    u'\U0001F533': { # 🔳
        'en' : ':white_square_button:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':weiße_quadratische_schaltfläche:',
        'es': u':botón_cuadrado_con_borde_blanco:',
        'fr': u':carré_blanc:',
        'ja': u':白枠四角:',
        'ko': u':테두리가_하얀_사각_버튼:',
        'pt': u':botão_quadrado_branco:',
        'it': ':tasto_quadrato_nero_con_bordo_bianco:',
        'fa': u':دکمۀ_مربع_سفید:',
        'id': ':tombol_persegi_putih:',
        'zh': u':白色方形按钮:'
    },
    u'\U0001F940': { # 🥀
        'en' : ':wilted_flower:',
        'status' : fully_qualified,
        'E' : 3,
        'de': ':welke_blume:',
        'es': ':flor_marchita:',
        'fr': u':fleur_fanée:',
        'ja': u':しおれた花:',
        'ko': u':시든_꽃:',
        'pt': ':flor_murcha:',
        'it': ':fiore_appassito:',
        'fa': u':گل_پژمرده:',
        'id': ':bunga_layu:',
        'zh': u':枯萎的花:'
    },
    u'\U0001F390': { # 🎐
        'en' : ':wind_chime:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':japanisches_windspiel:',
        'es': ':campanilla_de_viento:',
        'fr': u':carillon_éolien:',
        'ja': u':風鈴:',
        'ko': u':풍경:',
        'pt': u':carrilhão_de_vento:',
        'it': ':campana_al_vento:',
        'fa': u':باد_سِنج:',
        'id': ':lonceng_angin:',
        'zh': u':风铃:'
    },
    u'\U0001F32C\U0000FE0F': { # 🌬️
        'en' : ':wind_face:',
        'status' : fully_qualified,
        'E' : 0.7,
        'alias' : [':wind_blowing_face:'],
        'variant': True,
        'de': ':wind:',
        'es': ':cara_de_viento:',
        'fr': ':vent_avec_visage:',
        'ja': u':顔のある風:',
        'ko': u':얼굴이_있는_바람:',
        'pt': ':rosto_de_vento:',
        'it': ':vento:',
        'fa': u':صورت_باد:',
        'id': ':wajah_tertiup_angin:',
        'zh': u':大风:'
    },
    u'\U0001F32C': { # 🌬
        'en' : ':wind_face:',
        'status' : unqualified,
        'E' : 0.7,
        'alias' : [':wind_blowing_face:'],
        'variant': True,
        'de': ':wind:',
        'es': ':cara_de_viento:',
        'fr': ':vent_avec_visage:',
        'ja': u':顔のある風:',
        'ko': u':얼굴이_있는_바람:',
        'pt': ':rosto_de_vento:',
        'it': ':vento:',
        'fa': u':صورت_باد:',
        'id': ':wajah_tertiup_angin:',
        'zh': u':大风:'
    },
    u'\U0001FA9F': { # 🪟
        'en' : ':window:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':fenster:',
        'es': ':ventana:',
        'fr': u':fenêtre:',
        'ja': u':窓:',
        'ko': u':창문:',
        'pt': ':janela:',
        'it': ':finestra:',
        'fa': u':پنجره:',
        'id': ':jendela:',
        'zh': u':窗户:'
    },
    u'\U0001F377': { # 🍷
        'en' : ':wine_glass:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':weinglas:',
        'es': ':copa_de_vino:',
        'fr': ':verre_de_vin:',
        'ja': u':ワイングラス:',
        'ko': u':와인잔:',
        'pt': ':vinho:',
        'it': ':bicchiere_di_vino:',
        'fa': u':جام_شراب:',
        'id': ':gelas_anggur:',
        'zh': u':葡萄酒:'
    },
    u'\U0001FABD': { # 🪽
        'en' : ':wing:',
        'status' : fully_qualified,
        'E' : 15,
        'de': u':flügel:',
        'es': ':ala:',
        'fr': ':aile:',
        'ja': u':翼:',
        'ko': u':날개:',
        'pt': ':asa:',
        'it': ':ala:',
        'fa': u':بال:',
        'id': ':sayap:',
        'zh': u':翅膀:'
    },
    u'\U0001F609': { # 😉
        'en' : ':winking_face:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':wink:'],
        'de': ':zwinkerndes_gesicht:',
        'es': u':cara_guiñando_el_ojo:',
        'fr': u':visage_faisant_un_clin_d’œil:',
        'ja': u':ウインク:',
        'ko': u':윙크하는_얼굴:',
        'pt': ':rosto_com_olho_piscando:',
        'it': u':faccina_che_fa_l’occhiolino:',
        'fa': u':چشمک:',
        'id': ':wajah_berkedip:',
        'zh': u':眨眼:'
    },
    u'\U0001F61C': { # 😜
        'en' : ':winking_face_with_tongue:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':stuck_out_tongue_winking_eye:'],
        'de': ':zwinkerndes_gesicht_mit_herausgestreckter_zunge:',
        'es': u':cara_sacando_la_lengua_y_guiñando_un_ojo:',
        'fr': u':visage_qui_tire_la_langue_et_fait_un_clin_d’œil:',
        'ja': u':あっかんべー:',
        'ko': u':윙크하면서_혀를_내민_얼굴:',
        'pt': u':rosto_piscando_e_com_língua_para_fora:',
        'it': u':faccina_che_fa_l’occhiolino_e_mostra_la_lingua:',
        'fa': u':زبونک_و_چشمک:',
        'id': ':wajah_menjulurkan_lidah_dan_mengedipkan_mata:',
        'zh': u':单眼吐舌:'
    },
    u'\U0001F6DC': { # 🛜
        'en' : ':wireless:',
        'status' : fully_qualified,
        'E' : 15,
        'de': ':wlan:',
        'es': ':wifi:',
        'fr': ':sans_fil:',
        'ja': ':wi-fi:',
        'ko': u':무선:',
        'pt': ':sem_fio:',
        'it': ':wireless:',
        'fa': u':بی_سیم:',
        'id': ':nirkabel:',
        'zh': u':无线:'
    },
    u'\U0001F43A': { # 🐺
        'en' : ':wolf:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':wolf:',
        'es': ':lobo:',
        'fr': ':loup:',
        'ja': u':オオカミの顔:',
        'ko': u':늑대_얼굴:',
        'pt': ':rosto_de_lobo:',
        'it': ':lupo:',
        'fa': u':گرگ:',
        'id': ':serigala:',
        'zh': u':狼:'
    },
    u'\U0001F469': { # 👩
        'en' : ':woman:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':frau:',
        'es': ':mujer:',
        'fr': ':femme:',
        'ja': u':女性:',
        'ko': u':여자:',
        'pt': ':mulher:',
        'it': ':donna:',
        'fa': u':زن:',
        'id': ':wanita:',
        'zh': u':女人:'
    },
    u'\U0001F46B': { # 👫
        'en' : ':woman_and_man_holding_hands:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':couple:'],
        'de': u':mann_und_frau_halten_hände:',
        'es': ':mujer_y_hombre_de_la_mano:',
        'fr': ':femme_et_homme_se_tenant_la_main:',
        'ja': u':手をつなぐ男女:',
        'ko': u':손을_잡고_있는_남녀:',
        'pt': u':homem_e_mulher_de_mãos_dadas:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano:',
        'fa': u':زن_و_مرد_دست_در_دست:',
        'id': ':pria_dan_wanita_bergandengan:',
        'zh': u':手拉手的一男一女:'
    },
    u'\U0001F46B\U0001F3FF': { # 👫🏿
        'en' : ':woman_and_man_holding_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_dunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_foncée:',
        'ja': u':手をつなぐ男女_濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_검은색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_آبنوسی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap:',
        'zh': u':手拉手的一男一女_较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👩🏿‍🤝‍👨🏻
        'en' : ':woman_and_man_holding_hands_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_dunkle_hautfarbe,_helle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_foncée_et_peau_claire:',
        'ja': u':手をつなぐ男女_濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_검은색_피부_하얀_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_escura_e_pele_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_scura_e_carnagione_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_آبنوسی_پوست_سفید:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':手拉手的一男一女_较深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👩🏿‍🤝‍👨🏾
        'en' : ':woman_and_man_holding_hands_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_dunkle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_oscuro_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_foncée_et_peau_mate:',
        'ja': u':手をつなぐ男女_濃い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_검은색_피부_진한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_escura_e_pele_morena_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_آبنوسی_پوست_گندمی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的一男一女_较深肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👩🏿‍🤝‍👨🏼
        'en' : ':woman_and_man_holding_hands_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_dunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男女_濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_검은색_피부_연한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_escura_e_pele_morena_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_آبنوسی_پوست_روشن:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的一男一女_较深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👩🏿‍🤝‍👨🏽
        'en' : ':woman_and_man_holding_hands_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_dunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男女_濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_남녀_검은색_피부_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_escura_e_pele_morena:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_آبنوسی_پوست_طلایی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':手拉手的一男一女_较深肤色中等肤色:'
    },
    u'\U0001F46B\U0001F3FB': { # 👫🏻
        'en' : ':woman_and_man_holding_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_helle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_claire:',
        'ja': u':手をつなぐ男女_薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_하얀_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_سفید:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah:',
        'zh': u':手拉手的一男一女_较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👩🏻‍🤝‍👨🏿
        'en' : ':woman_and_man_holding_hands_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_helle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_claire_et_peau_foncée:',
        'ja': u':手をつなぐ男女_薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_하얀_피부_검은색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_clara_e_pele_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_سفید_پوست_آبنوسی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':手拉手的一男一女_较浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👩🏻‍🤝‍👨🏾
        'en' : ':woman_and_man_holding_hands_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_helle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro_medio:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_claire_et_peau_mate:',
        'ja': u':手をつなぐ男女_薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_하얀_피부_진한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_clara_e_pele_morena_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_سفید_پوست_گندمی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的一男一女_较浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👩🏻‍🤝‍👨🏼
        'en' : ':woman_and_man_holding_hands_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_helle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_y_tono_de_piel_claro_medio:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_claire_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男女_薄い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_하얀_피부_연한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_clara_e_pele_morena_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_سفید_پوست_روشن:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的一男一女_较浅肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👩🏻‍🤝‍👨🏽
        'en' : ':woman_and_man_holding_hands_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_helle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_y_tono_de_piel_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男女_薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_남녀_하얀_피부_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_clara_e_pele_morena:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_سفید_پوست_طلایی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':手拉手的一男一女_较浅肤色中等肤色:'
    },
    u'\U0001F46B\U0001F3FE': { # 👫🏾
        'en' : ':woman_and_man_holding_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mitteldunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_medio:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_mate:',
        'ja': u':手をつなぐ男女_やや濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_진한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_گندمی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的一男一女_中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👩🏾‍🤝‍👨🏿
        'en' : ':woman_and_man_holding_hands_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mitteldunkle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_oscuro:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_mate_et_peau_foncée:',
        'ja': u':手をつなぐ男女_やや濃い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_진한_갈색_피부_검은색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_escura_e_pele_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_گندمی_پوست_آبنوسی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的一男一女_中等深肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👩🏾‍🤝‍👨🏻
        'en' : ':woman_and_man_holding_hands_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mitteldunkle_hautfarbe,_helle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_mate_et_peau_claire:',
        'ja': u':手をつなぐ男女_やや濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_진한_갈색_피부_하얀_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_escura_e_pele_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_گندمی_پوست_سفید:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的一男一女_中等深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👩🏾‍🤝‍👨🏼
        'en' : ':woman_and_man_holding_hands_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mitteldunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro_medio:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男女_やや濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_진한_갈색_피부_연한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_escura_e_pele_morena_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_گندمی_پوست_روشن:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的一男一女_中等深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👩🏾‍🤝‍👨🏽
        'en' : ':woman_and_man_holding_hands_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mitteldunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_mate_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男女_やや濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_남녀_진한_갈색_피부_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_escura_e_pele_morena:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_گندمی_پوست_طلایی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的一男一女_中等深肤色中等肤色:'
    },
    u'\U0001F46B\U0001F3FC': { # 👫🏼
        'en' : ':woman_and_man_holding_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittelhelle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_medio:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_moyennement_claire:',
        'ja': u':手をつなぐ男女_やや薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_연한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_روشن:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的一男一女_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👩🏼‍🤝‍👨🏿
        'en' : ':woman_and_man_holding_hands_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittelhelle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':手をつなぐ男女_やや薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_연한_갈색_피부_검은색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_clara_e_pele_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_روشن_پوست_آبنوسی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的一男一女_中等浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👩🏼‍🤝‍👨🏻
        'en' : ':woman_and_man_holding_hands_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittelhelle_hautfarbe,_helle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_claro:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_moyennement_claire_et_peau_claire:',
        'ja': u':手をつなぐ男女_やや薄い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_연한_갈색_피부_하얀_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_clara_e_pele_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_روشن_پوست_سفید:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的一男一女_中等浅肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👩🏼‍🤝‍👨🏾
        'en' : ':woman_and_man_holding_hands_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittelhelle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro_medio:',
        'fr': ':femme_et_homme_se_tenant_la_main_peau_moyennement_claire_et_peau_mate:',
        'ja': u':手をつなぐ男女_やや薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_연한_갈색_피부_진한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_clara_e_pele_morena_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_روشن_پوست_گندمی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的一男一女_中等浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FD': { # 👩🏼‍🤝‍👨🏽
        'en' : ':woman_and_man_holding_hands_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittelhelle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ男女_やや薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_남녀_연한_갈색_피부_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_clara_e_pele_morena:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_روشن_پوست_طلایی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的一男一女_中等浅肤色中等肤色:'
    },
    u'\U0001F46B\U0001F3FD': { # 👫🏽
        'en' : ':woman_and_man_holding_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittlere_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_légèrement_mate:',
        'ja': u':手をつなぐ男女_中間の肌色:',
        'ko': u':손을_잡고_있는_남녀_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_olivastra:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_طلایی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_sedang:',
        'zh': u':手拉手的一男一女_中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FF': { # 👩🏽‍🤝‍👨🏿
        'en' : ':woman_and_man_holding_hands_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittlere_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':手をつなぐ男女_中間の肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_갈색_피부_검은색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_e_pele_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_طلایی_پوست_آبنوسی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':手拉手的一男一女_中等肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FB': { # 👩🏽‍🤝‍👨🏻
        'en' : ':woman_and_man_holding_hands_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittlere_hautfarbe,_helle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_medio_y_tono_de_piel_claro:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_légèrement_mate_et_peau_claire:',
        'ja': u':手をつなぐ男女_中間の肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_갈색_피부_하얀_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_e_pele_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_طلایی_پوست_سفید:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':手拉手的一男一女_中等肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FE': { # 👩🏽‍🤝‍👨🏾
        'en' : ':woman_and_man_holding_hands_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittlere_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_légèrement_mate_et_peau_mate:',
        'ja': u':手をつなぐ男女_中間の肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_남녀_갈색_피부_진한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_e_pele_morena_escura:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_طلایی_پوست_گندمی:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的一男一女_中等肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F468\U0001F3FC': { # 👩🏽‍🤝‍👨🏼
        'en' : ':woman_and_man_holding_hands_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':mann_und_frau_halten_hände_mittlere_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujer_y_hombre_de_la_mano_tono_de_piel_medio_y_tono_de_piel_claro_medio:',
        'fr': u':femme_et_homme_se_tenant_la_main_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ男女_中間の肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_남녀_갈색_피부_연한_갈색_피부:',
        'pt': u':homem_e_mulher_de_mãos_dadas_pele_morena_e_pele_morena_clara:',
        'it': ':uomo_e_donna_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_مرد_دست_در_دست_پوست_طلایی_پوست_روشن:',
        'id': ':pria_dan_wanita_bergandengan_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的一男一女_中等肤色中等浅肤色:'
    },
    u'\U0001F469\U0000200D\U0001F3A8': { # 👩‍🎨
        'en' : ':woman_artist:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstlerin:',
        'es': ':artista_mujer:',
        'fr': ':artiste_femme:',
        'ja': u':女性の芸術家:',
        'ko': u':여자_화가:',
        'pt': u':artista_plástica:',
        'it': ':artista_donna:',
        'fa': u':هنرمند_زن:',
        'id': ':seniman_wanita:',
        'zh': u':女艺术家:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F3A8': { # 👩🏿‍🎨
        'en' : ':woman_artist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstlerin_dunkle_hautfarbe:',
        'es': ':artista_mujer_tono_de_piel_oscuro:',
        'fr': u':artiste_femme_peau_foncée:',
        'ja': u':女性の芸術家_濃い肌色:',
        'ko': u':여자_화가_검은색_피부:',
        'pt': u':artista_plástica_pele_escura:',
        'it': ':artista_donna_carnagione_scura:',
        'fa': u':هنرمند_زن_پوست_آبنوسی:',
        'id': ':seniman_wanita_warna_kulit_gelap:',
        'zh': u':女艺术家_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F3A8': { # 👩🏻‍🎨
        'en' : ':woman_artist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstlerin_helle_hautfarbe:',
        'es': ':artista_mujer_tono_de_piel_claro:',
        'fr': ':artiste_femme_peau_claire:',
        'ja': u':女性の芸術家_薄い肌色:',
        'ko': u':여자_화가_하얀_피부:',
        'pt': u':artista_plástica_pele_clara:',
        'it': ':artista_donna_carnagione_chiara:',
        'fa': u':هنرمند_زن_پوست_سفید:',
        'id': ':seniman_wanita_warna_kulit_cerah:',
        'zh': u':女艺术家_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F3A8': { # 👩🏾‍🎨
        'en' : ':woman_artist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstlerin_mitteldunkle_hautfarbe:',
        'es': ':artista_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':artiste_femme_peau_mate:',
        'ja': u':女性の芸術家_やや濃い肌色:',
        'ko': u':여자_화가_진한_갈색_피부:',
        'pt': u':artista_plástica_pele_morena_escura:',
        'it': ':artista_donna_carnagione_abbastanza_scura:',
        'fa': u':هنرمند_زن_پوست_گندمی:',
        'id': ':seniman_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女艺术家_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F3A8': { # 👩🏼‍🎨
        'en' : ':woman_artist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstlerin_mittelhelle_hautfarbe:',
        'es': ':artista_mujer_tono_de_piel_claro_medio:',
        'fr': ':artiste_femme_peau_moyennement_claire:',
        'ja': u':女性の芸術家_やや薄い肌色:',
        'ko': u':여자_화가_연한_갈색_피부:',
        'pt': u':artista_plástica_pele_morena_clara:',
        'it': ':artista_donna_carnagione_abbastanza_chiara:',
        'fa': u':هنرمند_زن_پوست_روشن:',
        'id': ':seniman_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女艺术家_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F3A8': { # 👩🏽‍🎨
        'en' : ':woman_artist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':künstlerin_mittlere_hautfarbe:',
        'es': ':artista_mujer_tono_de_piel_medio:',
        'fr': u':artiste_femme_peau_légèrement_mate:',
        'ja': u':女性の芸術家_中間の肌色:',
        'ko': u':여자_화가_갈색_피부:',
        'pt': u':artista_plástica_pele_morena:',
        'it': ':artista_donna_carnagione_olivastra:',
        'fa': u':هنرمند_زن_پوست_طلایی:',
        'id': ':seniman_wanita_warna_kulit_sedang:',
        'zh': u':女艺术家_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F680': { # 👩‍🚀
        'en' : ':woman_astronaut:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronautin:',
        'es': ':astronauta_mujer:',
        'fr': ':astronaute_femme:',
        'ja': u':女性宇宙飛行士:',
        'ko': u':여자_우주비행사:',
        'pt': ':astronauta_mulher:',
        'it': ':astronauta_donna:',
        'fa': u':فضانورد_زن:',
        'id': ':antariksawan_wanita:',
        'zh': u':女宇航员:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F680': { # 👩🏿‍🚀
        'en' : ':woman_astronaut_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronautin_dunkle_hautfarbe:',
        'es': ':astronauta_mujer_tono_de_piel_oscuro:',
        'fr': u':astronaute_femme_peau_foncée:',
        'ja': u':女性宇宙飛行士_濃い肌色:',
        'ko': u':여자_우주비행사_검은색_피부:',
        'pt': ':astronauta_mulher_pele_escura:',
        'it': ':astronauta_donna_carnagione_scura:',
        'fa': u':فضانورد_زن_پوست_آبنوسی:',
        'id': ':antariksawan_wanita_warna_kulit_gelap:',
        'zh': u':女宇航员_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F680': { # 👩🏻‍🚀
        'en' : ':woman_astronaut_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronautin_helle_hautfarbe:',
        'es': ':astronauta_mujer_tono_de_piel_claro:',
        'fr': ':astronaute_femme_peau_claire:',
        'ja': u':女性宇宙飛行士_薄い肌色:',
        'ko': u':여자_우주비행사_하얀_피부:',
        'pt': ':astronauta_mulher_pele_clara:',
        'it': ':astronauta_donna_carnagione_chiara:',
        'fa': u':فضانورد_زن_پوست_سفید:',
        'id': ':antariksawan_wanita_warna_kulit_cerah:',
        'zh': u':女宇航员_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F680': { # 👩🏾‍🚀
        'en' : ':woman_astronaut_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronautin_mitteldunkle_hautfarbe:',
        'es': ':astronauta_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':astronaute_femme_peau_mate:',
        'ja': u':女性宇宙飛行士_やや濃い肌色:',
        'ko': u':여자_우주비행사_진한_갈색_피부:',
        'pt': ':astronauta_mulher_pele_morena_escura:',
        'it': ':astronauta_donna_carnagione_abbastanza_scura:',
        'fa': u':فضانورد_زن_پوست_گندمی:',
        'id': ':antariksawan_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女宇航员_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F680': { # 👩🏼‍🚀
        'en' : ':woman_astronaut_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronautin_mittelhelle_hautfarbe:',
        'es': ':astronauta_mujer_tono_de_piel_claro_medio:',
        'fr': ':astronaute_femme_peau_moyennement_claire:',
        'ja': u':女性宇宙飛行士_やや薄い肌色:',
        'ko': u':여자_우주비행사_연한_갈색_피부:',
        'pt': ':astronauta_mulher_pele_morena_clara:',
        'it': ':astronauta_donna_carnagione_abbastanza_chiara:',
        'fa': u':فضانورد_زن_پوست_روشن:',
        'id': ':antariksawan_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女宇航员_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F680': { # 👩🏽‍🚀
        'en' : ':woman_astronaut_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':astronautin_mittlere_hautfarbe:',
        'es': ':astronauta_mujer_tono_de_piel_medio:',
        'fr': u':astronaute_femme_peau_légèrement_mate:',
        'ja': u':女性宇宙飛行士_中間の肌色:',
        'ko': u':여자_우주비행사_갈색_피부:',
        'pt': ':astronauta_mulher_pele_morena:',
        'it': ':astronauta_donna_carnagione_olivastra:',
        'fa': u':فضانورد_زن_پوست_طلایی:',
        'id': ':antariksawan_wanita_warna_kulit_sedang:',
        'zh': u':女宇航员_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F9B2': { # 👩‍🦲
        'en' : ':woman_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':bald_woman:'],
        'de': ':frau_glatze:',
        'es': ':mujer_sin_pelo:',
        'fr': ':femme_chauve:',
        'ja': u':女性_はげ頭:',
        'ko': u':여자_대머리:',
        'pt': ':mulher_careca:',
        'it': ':donna_calvo:',
        'fa': u':زن_تاس:',
        'id': ':wanita_gundul:',
        'zh': u':女人_秃顶:'
    },
    u'\U0001F9D4\U0000200D\U00002640\U0000FE0F': { # 🧔‍♀️
        'en' : ':woman_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':frau_bart:',
        'es': ':mujer_barba:',
        'fr': ':femme_barbue:',
        'ja': u':あごひげの女性:',
        'ko': u':수염_난_여자:',
        'pt': ':mulher_barba:',
        'it': ':donna_con_la_barba:',
        'fa': u':زن_ریش:',
        'id': ':wanita_janggut:',
        'zh': u':有络腮胡子的女人:'
    },
    u'\U0001F9D4\U0000200D\U00002640': { # 🧔‍♀
        'en' : ':woman_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':frau_bart:',
        'es': ':mujer_barba:',
        'fr': ':femme_barbue:',
        'ja': u':あごひげの女性:',
        'ko': u':수염_난_여자:',
        'pt': ':mulher_barba:',
        'it': ':donna_con_la_barba:',
        'fa': u':زن_ریش:',
        'id': ':wanita_janggut:',
        'zh': u':有络腮胡子的女人:'
    },
    u'\U0001F6B4\U0000200D\U00002640\U0000FE0F': { # 🚴‍♀️
        'en' : ':woman_biking:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':biking_woman:'],
        'de': ':radfahrerin:',
        'es': ':mujer_en_bicicleta:',
        'fr': ':cycliste_femme:',
        'ja': u':自転車に乗る女:',
        'ko': u':자전거_타는_여자:',
        'pt': ':mulher_ciclista:',
        'it': ':ciclista_donna:',
        'fa': u':دوچرخه_سوار_زن:',
        'id': ':wanita_bersepeda:',
        'zh': u':女生骑自行车:'
    },
    u'\U0001F6B4\U0000200D\U00002640': { # 🚴‍♀
        'en' : ':woman_biking:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':biking_woman:'],
        'de': ':radfahrerin:',
        'es': ':mujer_en_bicicleta:',
        'fr': ':cycliste_femme:',
        'ja': u':自転車に乗る女:',
        'ko': u':자전거_타는_여자:',
        'pt': ':mulher_ciclista:',
        'it': ':ciclista_donna:',
        'fa': u':دوچرخه_سوار_زن:',
        'id': ':wanita_bersepeda:',
        'zh': u':女生骑自行车:'
    },
    u'\U0001F6B4\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🚴🏿‍♀️
        'en' : ':woman_biking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrerin_dunkle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_oscuro:',
        'fr': u':cycliste_femme_peau_foncée:',
        'ja': u':自転車に乗る女_濃い肌色:',
        'ko': u':자전거_타는_여자_검은색_피부:',
        'pt': ':mulher_ciclista_pele_escura:',
        'it': ':ciclista_donna_carnagione_scura:',
        'fa': u':دوچرخه_سوار_زن_پوست_آبنوسی:',
        'id': ':wanita_bersepeda_warna_kulit_gelap:',
        'zh': u':女生骑自行车_较深肤色:'
    },
    u'\U0001F6B4\U0001F3FF\U0000200D\U00002640': { # 🚴🏿‍♀
        'en' : ':woman_biking_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrerin_dunkle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_oscuro:',
        'fr': u':cycliste_femme_peau_foncée:',
        'ja': u':自転車に乗る女_濃い肌色:',
        'ko': u':자전거_타는_여자_검은색_피부:',
        'pt': ':mulher_ciclista_pele_escura:',
        'it': ':ciclista_donna_carnagione_scura:',
        'fa': u':دوچرخه_سوار_زن_پوست_آبنوسی:',
        'id': ':wanita_bersepeda_warna_kulit_gelap:',
        'zh': u':女生骑自行车_较深肤色:'
    },
    u'\U0001F6B4\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🚴🏻‍♀️
        'en' : ':woman_biking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrerin_helle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_claro:',
        'fr': ':cycliste_femme_peau_claire:',
        'ja': u':自転車に乗る女_薄い肌色:',
        'ko': u':자전거_타는_여자_하얀_피부:',
        'pt': ':mulher_ciclista_pele_clara:',
        'it': ':ciclista_donna_carnagione_chiara:',
        'fa': u':دوچرخه_سوار_زن_پوست_سفید:',
        'id': ':wanita_bersepeda_warna_kulit_cerah:',
        'zh': u':女生骑自行车_较浅肤色:'
    },
    u'\U0001F6B4\U0001F3FB\U0000200D\U00002640': { # 🚴🏻‍♀
        'en' : ':woman_biking_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrerin_helle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_claro:',
        'fr': ':cycliste_femme_peau_claire:',
        'ja': u':自転車に乗る女_薄い肌色:',
        'ko': u':자전거_타는_여자_하얀_피부:',
        'pt': ':mulher_ciclista_pele_clara:',
        'it': ':ciclista_donna_carnagione_chiara:',
        'fa': u':دوچرخه_سوار_زن_پوست_سفید:',
        'id': ':wanita_bersepeda_warna_kulit_cerah:',
        'zh': u':女生骑自行车_较浅肤色:'
    },
    u'\U0001F6B4\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🚴🏾‍♀️
        'en' : ':woman_biking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_oscuro_medio:',
        'fr': ':cycliste_femme_peau_mate:',
        'ja': u':自転車に乗る女_やや濃い肌色:',
        'ko': u':자전거_타는_여자_진한_갈색_피부:',
        'pt': ':mulher_ciclista_pele_morena_escura:',
        'it': ':ciclista_donna_carnagione_abbastanza_scura:',
        'fa': u':دوچرخه_سوار_زن_پوست_گندمی:',
        'id': ':wanita_bersepeda_warna_kulit_gelap-sedang:',
        'zh': u':女生骑自行车_中等深肤色:'
    },
    u'\U0001F6B4\U0001F3FE\U0000200D\U00002640': { # 🚴🏾‍♀
        'en' : ':woman_biking_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_oscuro_medio:',
        'fr': ':cycliste_femme_peau_mate:',
        'ja': u':自転車に乗る女_やや濃い肌色:',
        'ko': u':자전거_타는_여자_진한_갈색_피부:',
        'pt': ':mulher_ciclista_pele_morena_escura:',
        'it': ':ciclista_donna_carnagione_abbastanza_scura:',
        'fa': u':دوچرخه_سوار_زن_پوست_گندمی:',
        'id': ':wanita_bersepeda_warna_kulit_gelap-sedang:',
        'zh': u':女生骑自行车_中等深肤色:'
    },
    u'\U0001F6B4\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🚴🏼‍♀️
        'en' : ':woman_biking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrerin_mittelhelle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_claro_medio:',
        'fr': ':cycliste_femme_peau_moyennement_claire:',
        'ja': u':自転車に乗る女_やや薄い肌色:',
        'ko': u':자전거_타는_여자_연한_갈색_피부:',
        'pt': ':mulher_ciclista_pele_morena_clara:',
        'it': ':ciclista_donna_carnagione_abbastanza_chiara:',
        'fa': u':دوچرخه_سوار_زن_پوست_روشن:',
        'id': ':wanita_bersepeda_warna_kulit_cerah-sedang:',
        'zh': u':女生骑自行车_中等浅肤色:'
    },
    u'\U0001F6B4\U0001F3FC\U0000200D\U00002640': { # 🚴🏼‍♀
        'en' : ':woman_biking_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrerin_mittelhelle_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_claro_medio:',
        'fr': ':cycliste_femme_peau_moyennement_claire:',
        'ja': u':自転車に乗る女_やや薄い肌色:',
        'ko': u':자전거_타는_여자_연한_갈색_피부:',
        'pt': ':mulher_ciclista_pele_morena_clara:',
        'it': ':ciclista_donna_carnagione_abbastanza_chiara:',
        'fa': u':دوچرخه_سوار_زن_پوست_روشن:',
        'id': ':wanita_bersepeda_warna_kulit_cerah-sedang:',
        'zh': u':女生骑自行车_中等浅肤色:'
    },
    u'\U0001F6B4\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🚴🏽‍♀️
        'en' : ':woman_biking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':radfahrerin_mittlere_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_medio:',
        'fr': u':cycliste_femme_peau_légèrement_mate:',
        'ja': u':自転車に乗る女_中間の肌色:',
        'ko': u':자전거_타는_여자_갈색_피부:',
        'pt': ':mulher_ciclista_pele_morena:',
        'it': ':ciclista_donna_carnagione_olivastra:',
        'fa': u':دوچرخه_سوار_زن_پوست_طلایی:',
        'id': ':wanita_bersepeda_warna_kulit_sedang:',
        'zh': u':女生骑自行车_中等肤色:'
    },
    u'\U0001F6B4\U0001F3FD\U0000200D\U00002640': { # 🚴🏽‍♀
        'en' : ':woman_biking_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':radfahrerin_mittlere_hautfarbe:',
        'es': ':mujer_en_bicicleta_tono_de_piel_medio:',
        'fr': u':cycliste_femme_peau_légèrement_mate:',
        'ja': u':自転車に乗る女_中間の肌色:',
        'ko': u':자전거_타는_여자_갈색_피부:',
        'pt': ':mulher_ciclista_pele_morena:',
        'it': ':ciclista_donna_carnagione_olivastra:',
        'fa': u':دوچرخه_سوار_زن_پوست_طلایی:',
        'id': ':wanita_bersepeda_warna_kulit_sedang:',
        'zh': u':女生骑自行车_中等肤色:'
    },
    u'\U0001F471\U0000200D\U00002640\U0000FE0F': { # 👱‍♀️
        'en' : ':woman_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':blonde_woman:', ':blond_haired_woman:'],
        'de': ':frau_blond:',
        'es': ':mujer_rubia:',
        'fr': ':femme_blonde:',
        'ja': u':金髪の女性:',
        'ko': u':금발_여자:',
        'pt': ':mulher_cabelo_loiro:',
        'it': ':donna_bionda:',
        'fa': u':زن_موبور:',
        'id': ':wanita_berambut_pirang:',
        'zh': u':金发女:'
    },
    u'\U0001F471\U0000200D\U00002640': { # 👱‍♀
        'en' : ':woman_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':blonde_woman:', ':blond_haired_woman:'],
        'de': ':frau_blond:',
        'es': ':mujer_rubia:',
        'fr': ':femme_blonde:',
        'ja': u':金髪の女性:',
        'ko': u':금발_여자:',
        'pt': ':mulher_cabelo_loiro:',
        'it': ':donna_bionda:',
        'fa': u':زن_موبور:',
        'id': ':wanita_berambut_pirang:',
        'zh': u':金发女:'
    },
    u'\U000026F9\U0000FE0F\U0000200D\U00002640\U0000FE0F': { # ⛹️‍♀️
        'en' : ':woman_bouncing_ball:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':basketball_woman:', ':bouncing_ball_woman:'],
        'de': ':frau_mit_ball:',
        'es': u':mujer_botando_un_balón:',
        'fr': ':femme_avec_ballon:',
        'ja': u':バスケットボールをする女:',
        'ko': u':공_가진_여자:',
        'pt': ':mulher_jogando_basquete:',
        'it': ':donna_che_fa_rimbalzare_una_palla:',
        'fa': u':زن_و_توپ:',
        'id': ':wanita_memantulkan_bola:',
        'zh': u':女生玩球:'
    },
    u'\U000026F9\U0000200D\U00002640\U0000FE0F': { # ⛹‍♀️
        'en' : ':woman_bouncing_ball:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':basketball_woman:', ':bouncing_ball_woman:'],
        'de': ':frau_mit_ball:',
        'es': u':mujer_botando_un_balón:',
        'fr': ':femme_avec_ballon:',
        'ja': u':バスケットボールをする女:',
        'ko': u':공_가진_여자:',
        'pt': ':mulher_jogando_basquete:',
        'it': ':donna_che_fa_rimbalzare_una_palla:',
        'fa': u':زن_و_توپ:',
        'id': ':wanita_memantulkan_bola:',
        'zh': u':女生玩球:'
    },
    u'\U000026F9\U0000FE0F\U0000200D\U00002640': { # ⛹️‍♀
        'en' : ':woman_bouncing_ball:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':basketball_woman:', ':bouncing_ball_woman:'],
        'de': ':frau_mit_ball:',
        'es': u':mujer_botando_un_balón:',
        'fr': ':femme_avec_ballon:',
        'ja': u':バスケットボールをする女:',
        'ko': u':공_가진_여자:',
        'pt': ':mulher_jogando_basquete:',
        'it': ':donna_che_fa_rimbalzare_una_palla:',
        'fa': u':زن_و_توپ:',
        'id': ':wanita_memantulkan_bola:',
        'zh': u':女生玩球:'
    },
    u'\U000026F9\U0000200D\U00002640': { # ⛹‍♀
        'en' : ':woman_bouncing_ball:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':basketball_woman:', ':bouncing_ball_woman:'],
        'de': ':frau_mit_ball:',
        'es': u':mujer_botando_un_balón:',
        'fr': ':femme_avec_ballon:',
        'ja': u':バスケットボールをする女:',
        'ko': u':공_가진_여자:',
        'pt': ':mulher_jogando_basquete:',
        'it': ':donna_che_fa_rimbalzare_una_palla:',
        'fa': u':زن_و_توپ:',
        'id': ':wanita_memantulkan_bola:',
        'zh': u':女生玩球:'
    },
    u'\U000026F9\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # ⛹🏿‍♀️
        'en' : ':woman_bouncing_ball_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_dunkle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_oscuro:',
        'fr': u':femme_avec_ballon_peau_foncée:',
        'ja': u':バスケットボールをする女_濃い肌色:',
        'ko': u':공_가진_여자_검은색_피부:',
        'pt': ':mulher_jogando_basquete_pele_escura:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_scura:',
        'fa': u':زن_و_توپ_پوست_آبنوسی:',
        'id': ':wanita_memantulkan_bola_warna_kulit_gelap:',
        'zh': u':女生玩球_较深肤色:'
    },
    u'\U000026F9\U0001F3FF\U0000200D\U00002640': { # ⛹🏿‍♀
        'en' : ':woman_bouncing_ball_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_dunkle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_oscuro:',
        'fr': u':femme_avec_ballon_peau_foncée:',
        'ja': u':バスケットボールをする女_濃い肌色:',
        'ko': u':공_가진_여자_검은색_피부:',
        'pt': ':mulher_jogando_basquete_pele_escura:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_scura:',
        'fa': u':زن_و_توپ_پوست_آبنوسی:',
        'id': ':wanita_memantulkan_bola_warna_kulit_gelap:',
        'zh': u':女生玩球_较深肤色:'
    },
    u'\U000026F9\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # ⛹🏻‍♀️
        'en' : ':woman_bouncing_ball_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_helle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_claro:',
        'fr': ':femme_avec_ballon_peau_claire:',
        'ja': u':バスケットボールをする女_薄い肌色:',
        'ko': u':공_가진_여자_하얀_피부:',
        'pt': ':mulher_jogando_basquete_pele_clara:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_chiara:',
        'fa': u':زن_و_توپ_پوست_سفید:',
        'id': ':wanita_memantulkan_bola_warna_kulit_cerah:',
        'zh': u':女生玩球_较浅肤色:'
    },
    u'\U000026F9\U0001F3FB\U0000200D\U00002640': { # ⛹🏻‍♀
        'en' : ':woman_bouncing_ball_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_helle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_claro:',
        'fr': ':femme_avec_ballon_peau_claire:',
        'ja': u':バスケットボールをする女_薄い肌色:',
        'ko': u':공_가진_여자_하얀_피부:',
        'pt': ':mulher_jogando_basquete_pele_clara:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_chiara:',
        'fa': u':زن_و_توپ_پوست_سفید:',
        'id': ':wanita_memantulkan_bola_warna_kulit_cerah:',
        'zh': u':女生玩球_较浅肤色:'
    },
    u'\U000026F9\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # ⛹🏾‍♀️
        'en' : ':woman_bouncing_ball_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_mitteldunkle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_ballon_peau_mate:',
        'ja': u':バスケットボールをする女_やや濃い肌色:',
        'ko': u':공_가진_여자_진한_갈색_피부:',
        'pt': ':mulher_jogando_basquete_pele_morena_escura:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_abbastanza_scura:',
        'fa': u':زن_و_توپ_پوست_گندمی:',
        'id': ':wanita_memantulkan_bola_warna_kulit_gelap-sedang:',
        'zh': u':女生玩球_中等深肤色:'
    },
    u'\U000026F9\U0001F3FE\U0000200D\U00002640': { # ⛹🏾‍♀
        'en' : ':woman_bouncing_ball_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_mitteldunkle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_ballon_peau_mate:',
        'ja': u':バスケットボールをする女_やや濃い肌色:',
        'ko': u':공_가진_여자_진한_갈색_피부:',
        'pt': ':mulher_jogando_basquete_pele_morena_escura:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_abbastanza_scura:',
        'fa': u':زن_و_توپ_پوست_گندمی:',
        'id': ':wanita_memantulkan_bola_warna_kulit_gelap-sedang:',
        'zh': u':女生玩球_中等深肤色:'
    },
    u'\U000026F9\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # ⛹🏼‍♀️
        'en' : ':woman_bouncing_ball_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_mittelhelle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_ballon_peau_moyennement_claire:',
        'ja': u':バスケットボールをする女_やや薄い肌色:',
        'ko': u':공_가진_여자_연한_갈색_피부:',
        'pt': ':mulher_jogando_basquete_pele_morena_clara:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_توپ_پوست_روشن:',
        'id': ':wanita_memantulkan_bola_warna_kulit_cerah-sedang:',
        'zh': u':女生玩球_中等浅肤色:'
    },
    u'\U000026F9\U0001F3FC\U0000200D\U00002640': { # ⛹🏼‍♀
        'en' : ':woman_bouncing_ball_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_mittelhelle_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_ballon_peau_moyennement_claire:',
        'ja': u':バスケットボールをする女_やや薄い肌色:',
        'ko': u':공_가진_여자_연한_갈색_피부:',
        'pt': ':mulher_jogando_basquete_pele_morena_clara:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_توپ_پوست_روشن:',
        'id': ':wanita_memantulkan_bola_warna_kulit_cerah-sedang:',
        'zh': u':女生玩球_中等浅肤色:'
    },
    u'\U000026F9\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # ⛹🏽‍♀️
        'en' : ':woman_bouncing_ball_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_mittlere_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_medio:',
        'fr': u':femme_avec_ballon_peau_légèrement_mate:',
        'ja': u':バスケットボールをする女_中間の肌色:',
        'ko': u':공_가진_여자_갈색_피부:',
        'pt': ':mulher_jogando_basquete_pele_morena:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_olivastra:',
        'fa': u':زن_و_توپ_پوست_طلایی:',
        'id': ':wanita_memantulkan_bola_warna_kulit_sedang:',
        'zh': u':女生玩球_中等肤色:'
    },
    u'\U000026F9\U0001F3FD\U0000200D\U00002640': { # ⛹🏽‍♀
        'en' : ':woman_bouncing_ball_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_ball_mittlere_hautfarbe:',
        'es': u':mujer_botando_un_balón_tono_de_piel_medio:',
        'fr': u':femme_avec_ballon_peau_légèrement_mate:',
        'ja': u':バスケットボールをする女_中間の肌色:',
        'ko': u':공_가진_여자_갈색_피부:',
        'pt': ':mulher_jogando_basquete_pele_morena:',
        'it': ':donna_che_fa_rimbalzare_una_palla_carnagione_olivastra:',
        'fa': u':زن_و_توپ_پوست_طلایی:',
        'id': ':wanita_memantulkan_bola_warna_kulit_sedang:',
        'zh': u':女生玩球_中等肤色:'
    },
    u'\U0001F647\U0000200D\U00002640\U0000FE0F': { # 🙇‍♀️
        'en' : ':woman_bowing:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':bowing_woman:'],
        'de': ':sich_verbeugende_frau:',
        'es': ':mujer_haciendo_una_reverencia:',
        'fr': u':femme_qui_s’incline:',
        'ja': u':おじぎする女:',
        'ko': u':절하는_여자:',
        'pt': u':mulher_fazendo_reverência:',
        'it': ':donna_che_fa_inchino_profondo:',
        'fa': u':زن_تعظیم_می_کند:',
        'id': ':wanita_membungkuk:',
        'zh': u':女生鞠躬:'
    },
    u'\U0001F647\U0000200D\U00002640': { # 🙇‍♀
        'en' : ':woman_bowing:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':bowing_woman:'],
        'de': ':sich_verbeugende_frau:',
        'es': ':mujer_haciendo_una_reverencia:',
        'fr': u':femme_qui_s’incline:',
        'ja': u':おじぎする女:',
        'ko': u':절하는_여자:',
        'pt': u':mulher_fazendo_reverência:',
        'it': ':donna_che_fa_inchino_profondo:',
        'fa': u':زن_تعظیم_می_کند:',
        'id': ':wanita_membungkuk:',
        'zh': u':女生鞠躬:'
    },
    u'\U0001F647\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🙇🏿‍♀️
        'en' : ':woman_bowing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_oscuro:',
        'fr': u':femme_qui_s’incline_peau_foncée:',
        'ja': u':おじぎする女_濃い肌色:',
        'ko': u':절하는_여자_검은색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_escura:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_scura:',
        'fa': u':زن_تعظیم_می_کند_پوست_آبنوسی:',
        'id': ':wanita_membungkuk_warna_kulit_gelap:',
        'zh': u':女生鞠躬_较深肤色:'
    },
    u'\U0001F647\U0001F3FF\U0000200D\U00002640': { # 🙇🏿‍♀
        'en' : ':woman_bowing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_oscuro:',
        'fr': u':femme_qui_s’incline_peau_foncée:',
        'ja': u':おじぎする女_濃い肌色:',
        'ko': u':절하는_여자_검은색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_escura:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_scura:',
        'fa': u':زن_تعظیم_می_کند_پوست_آبنوسی:',
        'id': ':wanita_membungkuk_warna_kulit_gelap:',
        'zh': u':女生鞠躬_较深肤色:'
    },
    u'\U0001F647\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🙇🏻‍♀️
        'en' : ':woman_bowing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_helle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_claro:',
        'fr': u':femme_qui_s’incline_peau_claire:',
        'ja': u':おじぎする女_薄い肌色:',
        'ko': u':절하는_여자_하얀_피부:',
        'pt': u':mulher_fazendo_reverência_pele_clara:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_chiara:',
        'fa': u':زن_تعظیم_می_کند_پوست_سفید:',
        'id': ':wanita_membungkuk_warna_kulit_cerah:',
        'zh': u':女生鞠躬_较浅肤色:'
    },
    u'\U0001F647\U0001F3FB\U0000200D\U00002640': { # 🙇🏻‍♀
        'en' : ':woman_bowing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_helle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_claro:',
        'fr': u':femme_qui_s’incline_peau_claire:',
        'ja': u':おじぎする女_薄い肌色:',
        'ko': u':절하는_여자_하얀_피부:',
        'pt': u':mulher_fazendo_reverência_pele_clara:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_chiara:',
        'fa': u':زن_تعظیم_می_کند_پوست_سفید:',
        'id': ':wanita_membungkuk_warna_kulit_cerah:',
        'zh': u':女生鞠躬_较浅肤色:'
    },
    u'\U0001F647\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🙇🏾‍♀️
        'en' : ':woman_bowing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_oscuro_medio:',
        'fr': u':femme_qui_s’incline_peau_mate:',
        'ja': u':おじぎする女_やや濃い肌色:',
        'ko': u':절하는_여자_진한_갈색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_morena_escura:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_abbastanza_scura:',
        'fa': u':زن_تعظیم_می_کند_پوست_گندمی:',
        'id': ':wanita_membungkuk_warna_kulit_gelap-sedang:',
        'zh': u':女生鞠躬_中等深肤色:'
    },
    u'\U0001F647\U0001F3FE\U0000200D\U00002640': { # 🙇🏾‍♀
        'en' : ':woman_bowing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_oscuro_medio:',
        'fr': u':femme_qui_s’incline_peau_mate:',
        'ja': u':おじぎする女_やや濃い肌色:',
        'ko': u':절하는_여자_진한_갈색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_morena_escura:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_abbastanza_scura:',
        'fa': u':زن_تعظیم_می_کند_پوست_گندمی:',
        'id': ':wanita_membungkuk_warna_kulit_gelap-sedang:',
        'zh': u':女生鞠躬_中等深肤色:'
    },
    u'\U0001F647\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🙇🏼‍♀️
        'en' : ':woman_bowing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_claro_medio:',
        'fr': u':femme_qui_s’incline_peau_moyennement_claire:',
        'ja': u':おじぎする女_やや薄い肌色:',
        'ko': u':절하는_여자_연한_갈색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_morena_clara:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_abbastanza_chiara:',
        'fa': u':زن_تعظیم_می_کند_پوست_روشن:',
        'id': ':wanita_membungkuk_warna_kulit_cerah-sedang:',
        'zh': u':女生鞠躬_中等浅肤色:'
    },
    u'\U0001F647\U0001F3FC\U0000200D\U00002640': { # 🙇🏼‍♀
        'en' : ':woman_bowing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_claro_medio:',
        'fr': u':femme_qui_s’incline_peau_moyennement_claire:',
        'ja': u':おじぎする女_やや薄い肌色:',
        'ko': u':절하는_여자_연한_갈색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_morena_clara:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_abbastanza_chiara:',
        'fa': u':زن_تعظیم_می_کند_پوست_روشن:',
        'id': ':wanita_membungkuk_warna_kulit_cerah-sedang:',
        'zh': u':女生鞠躬_中等浅肤色:'
    },
    u'\U0001F647\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🙇🏽‍♀️
        'en' : ':woman_bowing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_medio:',
        'fr': u':femme_qui_s’incline_peau_légèrement_mate:',
        'ja': u':おじぎする女_中間の肌色:',
        'ko': u':절하는_여자_갈색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_morena:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_olivastra:',
        'fa': u':زن_تعظیم_می_کند_پوست_طلایی:',
        'id': ':wanita_membungkuk_warna_kulit_sedang:',
        'zh': u':女生鞠躬_中等肤色:'
    },
    u'\U0001F647\U0001F3FD\U0000200D\U00002640': { # 🙇🏽‍♀
        'en' : ':woman_bowing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_verbeugende_frau_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_una_reverencia_tono_de_piel_medio:',
        'fr': u':femme_qui_s’incline_peau_légèrement_mate:',
        'ja': u':おじぎする女_中間の肌色:',
        'ko': u':절하는_여자_갈색_피부:',
        'pt': u':mulher_fazendo_reverência_pele_morena:',
        'it': ':donna_che_fa_inchino_profondo_carnagione_olivastra:',
        'fa': u':زن_تعظیم_می_کند_پوست_طلایی:',
        'id': ':wanita_membungkuk_warna_kulit_sedang:',
        'zh': u':女生鞠躬_中等肤色:'
    },
    u'\U0001F938\U0000200D\U00002640\U0000FE0F': { # 🤸‍♀️
        'en' : ':woman_cartwheeling:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau:',
        'es': ':mujer_haciendo_voltereta_lateral:',
        'fr': ':femme_faisant_la_roue:',
        'ja': u':側転する女:',
        'ko': u':옆돌기하는_여자:',
        'pt': ':mulher_fazendo_estrela:',
        'it': ':donna_che_fa_la_ruota:',
        'fa': u':زنِ_چرخ_وفلک_زن:',
        'id': ':wanita_melakukan_gerakan_meroda:',
        'zh': u':女生侧手翻:'
    },
    u'\U0001F938\U0000200D\U00002640': { # 🤸‍♀
        'en' : ':woman_cartwheeling:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau:',
        'es': ':mujer_dando_una_voltereta_lateral:',
        'fr': ':femme_faisant_la_roue:',
        'ja': u':側転する女:',
        'ko': u':옆돌기하는_여자:',
        'pt': ':mulher_fazendo_estrela:',
        'it': ':donna_che_fa_la_ruota:',
        'fa': u':زنِ_چرخ_وفلک_زن:',
        'id': ':wanita_melakukan_gerakan_meroda:',
        'zh': u':女生侧手翻:'
    },
    u'\U0001F938\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🤸🏿‍♀️
        'en' : ':woman_cartwheeling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_oscuro:',
        'fr': u':femme_faisant_la_roue_peau_foncée:',
        'ja': u':側転する女_濃い肌色:',
        'ko': u':옆돌기하는_여자_검은색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_escura:',
        'it': ':donna_che_fa_la_ruota_carnagione_scura:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_آبنوسی:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_gelap:',
        'zh': u':女生侧手翻_较深肤色:'
    },
    u'\U0001F938\U0001F3FF\U0000200D\U00002640': { # 🤸🏿‍♀
        'en' : ':woman_cartwheeling_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_oscuro:',
        'fr': u':femme_faisant_la_roue_peau_foncée:',
        'ja': u':側転する女_濃い肌色:',
        'ko': u':옆돌기하는_여자_검은색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_escura:',
        'it': ':donna_che_fa_la_ruota_carnagione_scura:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_آبنوسی:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_gelap:',
        'zh': u':女生侧手翻_较深肤色:'
    },
    u'\U0001F938\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🤸🏻‍♀️
        'en' : ':woman_cartwheeling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_helle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_claro:',
        'fr': ':femme_faisant_la_roue_peau_claire:',
        'ja': u':側転する女_薄い肌色:',
        'ko': u':옆돌기하는_여자_하얀_피부:',
        'pt': ':mulher_fazendo_estrela_pele_clara:',
        'it': ':donna_che_fa_la_ruota_carnagione_chiara:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_سفید:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_cerah:',
        'zh': u':女生侧手翻_较浅肤色:'
    },
    u'\U0001F938\U0001F3FB\U0000200D\U00002640': { # 🤸🏻‍♀
        'en' : ':woman_cartwheeling_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_helle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_claro:',
        'fr': ':femme_faisant_la_roue_peau_claire:',
        'ja': u':側転する女_薄い肌色:',
        'ko': u':옆돌기하는_여자_하얀_피부:',
        'pt': ':mulher_fazendo_estrela_pele_clara:',
        'it': ':donna_che_fa_la_ruota_carnagione_chiara:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_سفید:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_cerah:',
        'zh': u':女生侧手翻_较浅肤色:'
    },
    u'\U0001F938\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🤸🏾‍♀️
        'en' : ':woman_cartwheeling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_oscuro_medio:',
        'fr': ':femme_faisant_la_roue_peau_mate:',
        'ja': u':側転する女_やや濃い肌色:',
        'ko': u':옆돌기하는_여자_진한_갈색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_morena_escura:',
        'it': ':donna_che_fa_la_ruota_carnagione_abbastanza_scura:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_گندمی:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_gelap-sedang:',
        'zh': u':女生侧手翻_中等深肤色:'
    },
    u'\U0001F938\U0001F3FE\U0000200D\U00002640': { # 🤸🏾‍♀
        'en' : ':woman_cartwheeling_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_oscuro_medio:',
        'fr': ':femme_faisant_la_roue_peau_mate:',
        'ja': u':側転する女_やや濃い肌色:',
        'ko': u':옆돌기하는_여자_진한_갈색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_morena_escura:',
        'it': ':donna_che_fa_la_ruota_carnagione_abbastanza_scura:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_گندمی:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_gelap-sedang:',
        'zh': u':女生侧手翻_中等深肤色:'
    },
    u'\U0001F938\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🤸🏼‍♀️
        'en' : ':woman_cartwheeling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_claro_medio:',
        'fr': ':femme_faisant_la_roue_peau_moyennement_claire:',
        'ja': u':側転する女_やや薄い肌色:',
        'ko': u':옆돌기하는_여자_연한_갈색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_morena_clara:',
        'it': ':donna_che_fa_la_ruota_carnagione_abbastanza_chiara:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_روشن:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_cerah-sedang:',
        'zh': u':女生侧手翻_中等浅肤色:'
    },
    u'\U0001F938\U0001F3FC\U0000200D\U00002640': { # 🤸🏼‍♀
        'en' : ':woman_cartwheeling_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_claro_medio:',
        'fr': ':femme_faisant_la_roue_peau_moyennement_claire:',
        'ja': u':側転する女_やや薄い肌色:',
        'ko': u':옆돌기하는_여자_연한_갈색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_morena_clara:',
        'it': ':donna_che_fa_la_ruota_carnagione_abbastanza_chiara:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_روشن:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_cerah-sedang:',
        'zh': u':女生侧手翻_中等浅肤色:'
    },
    u'\U0001F938\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🤸🏽‍♀️
        'en' : ':woman_cartwheeling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_medio:',
        'fr': u':femme_faisant_la_roue_peau_légèrement_mate:',
        'ja': u':側転する女_中間の肌色:',
        'ko': u':옆돌기하는_여자_갈색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_morena:',
        'it': ':donna_che_fa_la_ruota_carnagione_olivastra:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_طلایی:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_sedang:',
        'zh': u':女生侧手翻_中等肤色:'
    },
    u'\U0001F938\U0001F3FD\U0000200D\U00002640': { # 🤸🏽‍♀
        'en' : ':woman_cartwheeling_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':rad_schlagende_frau_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_voltereta_lateral_tono_de_piel_medio:',
        'fr': u':femme_faisant_la_roue_peau_légèrement_mate:',
        'ja': u':側転する女_中間の肌色:',
        'ko': u':옆돌기하는_여자_갈색_피부:',
        'pt': ':mulher_fazendo_estrela_pele_morena:',
        'it': ':donna_che_fa_la_ruota_carnagione_olivastra:',
        'fa': u':زنِ_چرخ_وفلک_زن_پوست_طلایی:',
        'id': ':wanita_melakukan_gerakan_meroda_warna_kulit_sedang:',
        'zh': u':女生侧手翻_中等肤色:'
    },
    u'\U0001F9D7\U0000200D\U00002640\U0000FE0F': { # 🧗‍♀️
        'en' : ':woman_climbing:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':climbing_woman:'],
        'de': ':bergsteigerin:',
        'es': ':mujer_escalando:',
        'fr': ':femme_qui_grimpe:',
        'ja': u':山を登る女:',
        'ko': u':클라이밍하는_여자:',
        'pt': ':mulher_escalando:',
        'it': ':scalatrice:',
        'fa': u':زن_کوه_نوردی_می_کند:',
        'id': ':wanita_memanjat:',
        'zh': u':攀爬的女人:'
    },
    u'\U0001F9D7\U0000200D\U00002640': { # 🧗‍♀
        'en' : ':woman_climbing:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':climbing_woman:'],
        'de': ':bergsteigerin:',
        'es': ':mujer_escalando:',
        'fr': ':femme_qui_grimpe:',
        'ja': u':山を登る女:',
        'ko': u':클라이밍하는_여자:',
        'pt': ':mulher_escalando:',
        'it': ':scalatrice:',
        'fa': u':زن_کوه_نوردی_می_کند:',
        'id': ':wanita_memanjat:',
        'zh': u':攀爬的女人:'
    },
    u'\U0001F9D7\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧗🏿‍♀️
        'en' : ':woman_climbing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteigerin_dunkle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_oscuro:',
        'fr': u':femme_qui_grimpe_peau_foncée:',
        'ja': u':山を登る女_濃い肌色:',
        'ko': u':클라이밍하는_여자_검은색_피부:',
        'pt': ':mulher_escalando_pele_escura:',
        'it': ':scalatrice_carnagione_scura:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_آبنوسی:',
        'id': ':wanita_memanjat_warna_kulit_gelap:',
        'zh': u':攀爬的女人_较深肤色:'
    },
    u'\U0001F9D7\U0001F3FF\U0000200D\U00002640': { # 🧗🏿‍♀
        'en' : ':woman_climbing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteigerin_dunkle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_oscuro:',
        'fr': u':femme_qui_grimpe_peau_foncée:',
        'ja': u':山を登る女_濃い肌色:',
        'ko': u':클라이밍하는_여자_검은색_피부:',
        'pt': ':mulher_escalando_pele_escura:',
        'it': ':scalatrice_carnagione_scura:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_آبنوسی:',
        'id': ':wanita_memanjat_warna_kulit_gelap:',
        'zh': u':攀爬的女人_较深肤色:'
    },
    u'\U0001F9D7\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧗🏻‍♀️
        'en' : ':woman_climbing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteigerin_helle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_claro:',
        'fr': ':femme_qui_grimpe_peau_claire:',
        'ja': u':山を登る女_薄い肌色:',
        'ko': u':클라이밍하는_여자_하얀_피부:',
        'pt': ':mulher_escalando_pele_clara:',
        'it': ':scalatrice_carnagione_chiara:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_سفید:',
        'id': ':wanita_memanjat_warna_kulit_cerah:',
        'zh': u':攀爬的女人_较浅肤色:'
    },
    u'\U0001F9D7\U0001F3FB\U0000200D\U00002640': { # 🧗🏻‍♀
        'en' : ':woman_climbing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteigerin_helle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_claro:',
        'fr': ':femme_qui_grimpe_peau_claire:',
        'ja': u':山を登る女_薄い肌色:',
        'ko': u':클라이밍하는_여자_하얀_피부:',
        'pt': ':mulher_escalando_pele_clara:',
        'it': ':scalatrice_carnagione_chiara:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_سفید:',
        'id': ':wanita_memanjat_warna_kulit_cerah:',
        'zh': u':攀爬的女人_较浅肤色:'
    },
    u'\U0001F9D7\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧗🏾‍♀️
        'en' : ':woman_climbing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteigerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_grimpe_peau_mate:',
        'ja': u':山を登る女_やや濃い肌色:',
        'ko': u':클라이밍하는_여자_진한_갈색_피부:',
        'pt': ':mulher_escalando_pele_morena_escura:',
        'it': ':scalatrice_carnagione_abbastanza_scura:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_گندمی:',
        'id': ':wanita_memanjat_warna_kulit_gelap-sedang:',
        'zh': u':攀爬的女人_中等深肤色:'
    },
    u'\U0001F9D7\U0001F3FE\U0000200D\U00002640': { # 🧗🏾‍♀
        'en' : ':woman_climbing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteigerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_grimpe_peau_mate:',
        'ja': u':山を登る女_やや濃い肌色:',
        'ko': u':클라이밍하는_여자_진한_갈색_피부:',
        'pt': ':mulher_escalando_pele_morena_escura:',
        'it': ':scalatrice_carnagione_abbastanza_scura:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_گندمی:',
        'id': ':wanita_memanjat_warna_kulit_gelap-sedang:',
        'zh': u':攀爬的女人_中等深肤色:'
    },
    u'\U0001F9D7\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧗🏼‍♀️
        'en' : ':woman_climbing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteigerin_mittelhelle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_grimpe_peau_moyennement_claire:',
        'ja': u':山を登る女_やや薄い肌色:',
        'ko': u':클라이밍하는_여자_연한_갈색_피부:',
        'pt': ':mulher_escalando_pele_morena_clara:',
        'it': ':scalatrice_carnagione_abbastanza_chiara:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_روشن:',
        'id': ':wanita_memanjat_warna_kulit_cerah-sedang:',
        'zh': u':攀爬的女人_中等浅肤色:'
    },
    u'\U0001F9D7\U0001F3FC\U0000200D\U00002640': { # 🧗🏼‍♀
        'en' : ':woman_climbing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteigerin_mittelhelle_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_grimpe_peau_moyennement_claire:',
        'ja': u':山を登る女_やや薄い肌色:',
        'ko': u':클라이밍하는_여자_연한_갈색_피부:',
        'pt': ':mulher_escalando_pele_morena_clara:',
        'it': ':scalatrice_carnagione_abbastanza_chiara:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_روشن:',
        'id': ':wanita_memanjat_warna_kulit_cerah-sedang:',
        'zh': u':攀爬的女人_中等浅肤色:'
    },
    u'\U0001F9D7\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧗🏽‍♀️
        'en' : ':woman_climbing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':bergsteigerin_mittlere_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_medio:',
        'fr': u':femme_qui_grimpe_peau_légèrement_mate:',
        'ja': u':山を登る女_中間の肌色:',
        'ko': u':클라이밍하는_여자_갈색_피부:',
        'pt': ':mulher_escalando_pele_morena:',
        'it': ':scalatrice_carnagione_olivastra:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_طلایی:',
        'id': ':wanita_memanjat_warna_kulit_sedang:',
        'zh': u':攀爬的女人_中等肤色:'
    },
    u'\U0001F9D7\U0001F3FD\U0000200D\U00002640': { # 🧗🏽‍♀
        'en' : ':woman_climbing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':bergsteigerin_mittlere_hautfarbe:',
        'es': ':mujer_escalando_tono_de_piel_medio:',
        'fr': u':femme_qui_grimpe_peau_légèrement_mate:',
        'ja': u':山を登る女_中間の肌色:',
        'ko': u':클라이밍하는_여자_갈색_피부:',
        'pt': ':mulher_escalando_pele_morena:',
        'it': ':scalatrice_carnagione_olivastra:',
        'fa': u':زن_کوه_نوردی_می_کند_پوست_طلایی:',
        'id': ':wanita_memanjat_warna_kulit_sedang:',
        'zh': u':攀爬的女人_中等肤色:'
    },
    u'\U0001F477\U0000200D\U00002640\U0000FE0F': { # 👷‍♀️
        'en' : ':woman_construction_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':construction_worker_woman:'],
        'de': ':bauarbeiterin:',
        'es': u':profesional_de_la_construcción_mujer:',
        'fr': u':ouvrière_du_bâtiment:',
        'ja': u':女性の建設作業員:',
        'ko': u':건설_현장_여자_노동자:',
        'pt': ':pedreira:',
        'it': ':operaia_edile:',
        'fa': u':کارگر_ساختمانی_زن:',
        'id': ':pekerja_konstruksi_wanita:',
        'zh': u':女建筑工人:'
    },
    u'\U0001F477\U0000200D\U00002640': { # 👷‍♀
        'en' : ':woman_construction_worker:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':construction_worker_woman:'],
        'de': ':bauarbeiterin:',
        'es': u':profesional_de_la_construcción_mujer:',
        'fr': u':ouvrière_du_bâtiment:',
        'ja': u':女性の建設作業員:',
        'ko': u':건설_현장_여자_노동자:',
        'pt': ':pedreira:',
        'it': ':operaia_edile:',
        'fa': u':کارگر_ساختمانی_زن:',
        'id': ':pekerja_konstruksi_wanita:',
        'zh': u':女建筑工人:'
    },
    u'\U0001F477\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 👷🏿‍♀️
        'en' : ':woman_construction_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_dunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_oscuro:',
        'fr': u':ouvrière_du_bâtiment_peau_foncée:',
        'ja': u':女性の建設作業員_濃い肌色:',
        'ko': u':건설_현장_여자_노동자_검은색_피부:',
        'pt': ':pedreira_pele_escura:',
        'it': ':operaia_edile_carnagione_scura:',
        'fa': u':کارگر_ساختمانی_زن_پوست_آبنوسی:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_gelap:',
        'zh': u':女建筑工人_较深肤色:'
    },
    u'\U0001F477\U0001F3FF\U0000200D\U00002640': { # 👷🏿‍♀
        'en' : ':woman_construction_worker_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_dunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_oscuro:',
        'fr': u':ouvrière_du_bâtiment_peau_foncée:',
        'ja': u':女性の建設作業員_濃い肌色:',
        'ko': u':건설_현장_여자_노동자_검은색_피부:',
        'pt': ':pedreira_pele_escura:',
        'it': ':operaia_edile_carnagione_scura:',
        'fa': u':کارگر_ساختمانی_زن_پوست_آبنوسی:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_gelap:',
        'zh': u':女建筑工人_较深肤色:'
    },
    u'\U0001F477\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 👷🏻‍♀️
        'en' : ':woman_construction_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_helle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_claro:',
        'fr': u':ouvrière_du_bâtiment_peau_claire:',
        'ja': u':女性の建設作業員_薄い肌色:',
        'ko': u':건설_현장_여자_노동자_하얀_피부:',
        'pt': ':pedreira_pele_clara:',
        'it': ':operaia_edile_carnagione_chiara:',
        'fa': u':کارگر_ساختمانی_زن_پوست_سفید:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_cerah:',
        'zh': u':女建筑工人_较浅肤色:'
    },
    u'\U0001F477\U0001F3FB\U0000200D\U00002640': { # 👷🏻‍♀
        'en' : ':woman_construction_worker_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_helle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_claro:',
        'fr': u':ouvrière_du_bâtiment_peau_claire:',
        'ja': u':女性の建設作業員_薄い肌色:',
        'ko': u':건설_현장_여자_노동자_하얀_피부:',
        'pt': ':pedreira_pele_clara:',
        'it': ':operaia_edile_carnagione_chiara:',
        'fa': u':کارگر_ساختمانی_زن_پوست_سفید:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_cerah:',
        'zh': u':女建筑工人_较浅肤色:'
    },
    u'\U0001F477\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 👷🏾‍♀️
        'en' : ':woman_construction_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':ouvrière_du_bâtiment_peau_mate:',
        'ja': u':女性の建設作業員_やや濃い肌色:',
        'ko': u':건설_현장_여자_노동자_진한_갈색_피부:',
        'pt': ':pedreira_pele_morena_escura:',
        'it': ':operaia_edile_carnagione_abbastanza_scura:',
        'fa': u':کارگر_ساختمانی_زن_پوست_گندمی:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女建筑工人_中等深肤色:'
    },
    u'\U0001F477\U0001F3FE\U0000200D\U00002640': { # 👷🏾‍♀
        'en' : ':woman_construction_worker_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':ouvrière_du_bâtiment_peau_mate:',
        'ja': u':女性の建設作業員_やや濃い肌色:',
        'ko': u':건설_현장_여자_노동자_진한_갈색_피부:',
        'pt': ':pedreira_pele_morena_escura:',
        'it': ':operaia_edile_carnagione_abbastanza_scura:',
        'fa': u':کارگر_ساختمانی_زن_پوست_گندمی:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女建筑工人_中等深肤色:'
    },
    u'\U0001F477\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 👷🏼‍♀️
        'en' : ':woman_construction_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_claro_medio:',
        'fr': u':ouvrière_du_bâtiment_peau_moyennement_claire:',
        'ja': u':女性の建設作業員_やや薄い肌色:',
        'ko': u':건설_현장_여자_노동자_연한_갈색_피부:',
        'pt': ':pedreira_pele_morena_clara:',
        'it': ':operaia_edile_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_ساختمانی_زن_پوست_روشن:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女建筑工人_中等浅肤色:'
    },
    u'\U0001F477\U0001F3FC\U0000200D\U00002640': { # 👷🏼‍♀
        'en' : ':woman_construction_worker_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_claro_medio:',
        'fr': u':ouvrière_du_bâtiment_peau_moyennement_claire:',
        'ja': u':女性の建設作業員_やや薄い肌色:',
        'ko': u':건설_현장_여자_노동자_연한_갈색_피부:',
        'pt': ':pedreira_pele_morena_clara:',
        'it': ':operaia_edile_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_ساختمانی_زن_پوست_روشن:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女建筑工人_中等浅肤色:'
    },
    u'\U0001F477\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 👷🏽‍♀️
        'en' : ':woman_construction_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_mittlere_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_medio:',
        'fr': u':ouvrière_du_bâtiment_peau_légèrement_mate:',
        'ja': u':女性の建設作業員_中間の肌色:',
        'ko': u':건설_현장_여자_노동자_갈색_피부:',
        'pt': ':pedreira_pele_morena:',
        'it': ':operaia_edile_carnagione_olivastra:',
        'fa': u':کارگر_ساختمانی_زن_پوست_طلایی:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_sedang:',
        'zh': u':女建筑工人_中等肤色:'
    },
    u'\U0001F477\U0001F3FD\U0000200D\U00002640': { # 👷🏽‍♀
        'en' : ':woman_construction_worker_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':bauarbeiterin_mittlere_hautfarbe:',
        'es': u':profesional_de_la_construcción_mujer_tono_de_piel_medio:',
        'fr': u':ouvrière_du_bâtiment_peau_légèrement_mate:',
        'ja': u':女性の建設作業員_中間の肌色:',
        'ko': u':건설_현장_여자_노동자_갈색_피부:',
        'pt': ':pedreira_pele_morena:',
        'it': ':operaia_edile_carnagione_olivastra:',
        'fa': u':کارگر_ساختمانی_زن_پوست_طلایی:',
        'id': ':pekerja_konstruksi_wanita_warna_kulit_sedang:',
        'zh': u':女建筑工人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F373': { # 👩‍🍳
        'en' : ':woman_cook:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':köchin:',
        'es': ':chef_mujer:',
        'fr': u':cuisinière:',
        'ja': u':女性のコック:',
        'ko': u':여자_요리사:',
        'pt': ':cozinheira:',
        'it': ':cuoca:',
        'fa': u':آشپز_زن:',
        'id': ':koki_wanita:',
        'zh': u':女厨师:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F373': { # 👩🏿‍🍳
        'en' : ':woman_cook_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':köchin_dunkle_hautfarbe:',
        'es': ':chef_mujer_tono_de_piel_oscuro:',
        'fr': u':cuisinière_peau_foncée:',
        'ja': u':女性のコック_濃い肌色:',
        'ko': u':여자_요리사_검은색_피부:',
        'pt': ':cozinheira_pele_escura:',
        'it': ':cuoca_carnagione_scura:',
        'fa': u':آشپز_زن_پوست_آبنوسی:',
        'id': ':koki_wanita_warna_kulit_gelap:',
        'zh': u':女厨师_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F373': { # 👩🏻‍🍳
        'en' : ':woman_cook_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':köchin_helle_hautfarbe:',
        'es': ':chef_mujer_tono_de_piel_claro:',
        'fr': u':cuisinière_peau_claire:',
        'ja': u':女性のコック_薄い肌色:',
        'ko': u':여자_요리사_하얀_피부:',
        'pt': ':cozinheira_pele_clara:',
        'it': ':cuoca_carnagione_chiara:',
        'fa': u':آشپز_زن_پوست_سفید:',
        'id': ':koki_wanita_warna_kulit_cerah:',
        'zh': u':女厨师_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F373': { # 👩🏾‍🍳
        'en' : ':woman_cook_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':köchin_mitteldunkle_hautfarbe:',
        'es': ':chef_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':cuisinière_peau_mate:',
        'ja': u':女性のコック_やや濃い肌色:',
        'ko': u':여자_요리사_진한_갈색_피부:',
        'pt': ':cozinheira_pele_morena_escura:',
        'it': ':cuoca_carnagione_abbastanza_scura:',
        'fa': u':آشپز_زن_پوست_گندمی:',
        'id': ':koki_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女厨师_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F373': { # 👩🏼‍🍳
        'en' : ':woman_cook_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':köchin_mittelhelle_hautfarbe:',
        'es': ':chef_mujer_tono_de_piel_claro_medio:',
        'fr': u':cuisinière_peau_moyennement_claire:',
        'ja': u':女性のコック_やや薄い肌色:',
        'ko': u':여자_요리사_연한_갈색_피부:',
        'pt': ':cozinheira_pele_morena_clara:',
        'it': ':cuoca_carnagione_abbastanza_chiara:',
        'fa': u':آشپز_زن_پوست_روشن:',
        'id': ':koki_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女厨师_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F373': { # 👩🏽‍🍳
        'en' : ':woman_cook_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':köchin_mittlere_hautfarbe:',
        'es': ':chef_mujer_tono_de_piel_medio:',
        'fr': u':cuisinière_peau_légèrement_mate:',
        'ja': u':女性のコック_中間の肌色:',
        'ko': u':여자_요리사_갈색_피부:',
        'pt': ':cozinheira_pele_morena:',
        'it': ':cuoca_carnagione_olivastra:',
        'fa': u':آشپز_زن_پوست_طلایی:',
        'id': ':koki_wanita_warna_kulit_sedang:',
        'zh': u':女厨师_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F9B1': { # 👩‍🦱
        'en' : ':woman_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':curly_haired_woman:'],
        'de': ':frau_lockiges_haar:',
        'es': ':mujer_pelo_rizado:',
        'fr': u':femme_cheveux_bouclés:',
        'ja': u':女性_巻き毛:',
        'ko': u':여자_곱슬머리:',
        'pt': ':mulher_cabelo_cacheado:',
        'it': ':donna_capelli_ricci:',
        'fa': u':زن_موفرفری:',
        'id': ':wanita_rambut_keriting:',
        'zh': u':女人_卷发:'
    },
    u'\U0001F483': { # 💃
        'en' : ':woman_dancing:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':dancer:'],
        'de': ':tanzende_frau:',
        'es': ':mujer_bailando:',
        'fr': ':danseuse:',
        'ja': u':踊る女:',
        'ko': u':여자_댄서:',
        'pt': u':mulher_dançando:',
        'it': ':donna_che_balla:',
        'fa': u':رقاص:',
        'id': ':wanita_menari:',
        'zh': u':跳舞的女人:'
    },
    u'\U0001F483\U0001F3FF': { # 💃🏿
        'en' : ':woman_dancing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':tanzende_frau_dunkle_hautfarbe:',
        'es': ':mujer_bailando_tono_de_piel_oscuro:',
        'fr': u':danseuse_peau_foncée:',
        'ja': u':踊る女_濃い肌色:',
        'ko': u':여자_댄서_검은색_피부:',
        'pt': u':mulher_dançando_pele_escura:',
        'it': ':donna_che_balla_carnagione_scura:',
        'fa': u':رقاص_پوست_آبنوسی:',
        'id': ':wanita_menari_warna_kulit_gelap:',
        'zh': u':跳舞的女人_较深肤色:'
    },
    u'\U0001F483\U0001F3FB': { # 💃🏻
        'en' : ':woman_dancing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':tanzende_frau_helle_hautfarbe:',
        'es': ':mujer_bailando_tono_de_piel_claro:',
        'fr': ':danseuse_peau_claire:',
        'ja': u':踊る女_薄い肌色:',
        'ko': u':여자_댄서_하얀_피부:',
        'pt': u':mulher_dançando_pele_clara:',
        'it': ':donna_che_balla_carnagione_chiara:',
        'fa': u':رقاص_پوست_سفید:',
        'id': ':wanita_menari_warna_kulit_cerah:',
        'zh': u':跳舞的女人_较浅肤色:'
    },
    u'\U0001F483\U0001F3FE': { # 💃🏾
        'en' : ':woman_dancing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':tanzende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_bailando_tono_de_piel_oscuro_medio:',
        'fr': ':danseuse_peau_mate:',
        'ja': u':踊る女_やや濃い肌色:',
        'ko': u':여자_댄서_진한_갈색_피부:',
        'pt': u':mulher_dançando_pele_morena_escura:',
        'it': ':donna_che_balla_carnagione_abbastanza_scura:',
        'fa': u':رقاص_پوست_گندمی:',
        'id': ':wanita_menari_warna_kulit_gelap-sedang:',
        'zh': u':跳舞的女人_中等深肤色:'
    },
    u'\U0001F483\U0001F3FC': { # 💃🏼
        'en' : ':woman_dancing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':tanzende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_bailando_tono_de_piel_claro_medio:',
        'fr': ':danseuse_peau_moyennement_claire:',
        'ja': u':踊る女_やや薄い肌色:',
        'ko': u':여자_댄서_연한_갈색_피부:',
        'pt': u':mulher_dançando_pele_morena_clara:',
        'it': ':donna_che_balla_carnagione_abbastanza_chiara:',
        'fa': u':رقاص_پوست_روشن:',
        'id': ':wanita_menari_warna_kulit_cerah-sedang:',
        'zh': u':跳舞的女人_中等浅肤色:'
    },
    u'\U0001F483\U0001F3FD': { # 💃🏽
        'en' : ':woman_dancing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':tanzende_frau_mittlere_hautfarbe:',
        'es': ':mujer_bailando_tono_de_piel_medio:',
        'fr': u':danseuse_peau_légèrement_mate:',
        'ja': u':踊る女_中間の肌色:',
        'ko': u':여자_댄서_갈색_피부:',
        'pt': u':mulher_dançando_pele_morena:',
        'it': ':donna_che_balla_carnagione_olivastra:',
        'fa': u':رقاص_پوست_طلایی:',
        'id': ':wanita_menari_warna_kulit_sedang:',
        'zh': u':跳舞的女人_中等肤色:'
    },
    u'\U0001F469\U0001F3FF': { # 👩🏿
        'en' : ':woman_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':frau_dunkle_hautfarbe:',
        'es': ':mujer_tono_de_piel_oscuro:',
        'fr': u':femme_peau_foncée:',
        'ja': u':女性_濃い肌色:',
        'ko': u':여자_검은색_피부:',
        'pt': ':mulher_pele_escura:',
        'it': ':donna_carnagione_scura:',
        'fa': u':زن_پوست_آبنوسی:',
        'id': ':wanita_warna_kulit_gelap:',
        'zh': u':女人_较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F9B2': { # 👩🏿‍🦲
        'en' : ':woman_dark_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_dunkle_hautfarbe,_glatze:',
        'es': ':mujer_tono_de_piel_oscuro_y_sin_pelo:',
        'fr': u':femme_peau_foncée_et_chauve:',
        'ja': u':女性_濃い肌色_はげ頭:',
        'ko': u':여자_검은색_피부_대머리:',
        'pt': ':mulher_pele_escura_e_careca:',
        'it': ':donna_carnagione_scura_e_calvo:',
        'fa': u':زن_پوست_آبنوسی_تاس:',
        'id': ':wanita_warna_kulit_gelap_gundul:',
        'zh': u':女人_较深肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧔🏿‍♀️
        'en' : ':woman_dark_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':frau_dunkle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_oscuro_y_barba:',
        'fr': u':femme_barbue__peau_foncée:',
        'ja': u':あごひげの女性_濃い肌色:',
        'ko': u':수염_난_여자_검은색_피부:',
        'pt': ':mulher_pele_escura_e_barba:',
        'it': ':donna_con_la_barba_carnagione_scura:',
        'fa': u':زن_پوست_آبنوسی_ریش:',
        'id': ':wanita_warna_kulit_gelap_janggut:',
        'zh': u':有络腮胡子的女人_较深肤色:'
    },
    u'\U0001F9D4\U0001F3FF\U0000200D\U00002640': { # 🧔🏿‍♀
        'en' : ':woman_dark_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':frau_dunkle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_oscuro_y_barba:',
        'fr': u':femme_barbue__peau_foncée:',
        'ja': u':あごひげの女性_濃い肌色:',
        'ko': u':수염_난_여자_검은색_피부:',
        'pt': ':mulher_pele_escura_e_barba:',
        'it': ':donna_con_la_barba_carnagione_scura:',
        'fa': u':زن_پوست_آبنوسی_ریش:',
        'id': ':wanita_warna_kulit_gelap_janggut:',
        'zh': u':有络腮胡子的女人_较深肤色:'
    },
    u'\U0001F471\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 👱🏿‍♀️
        'en' : ':woman_dark_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_dunkle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_oscuro:',
        'fr': u':femme_blonde_peau_foncée:',
        'ja': u':金髪の女性_濃い肌色:',
        'ko': u':금발_여자_검은색_피부:',
        'pt': ':mulher_pele_escura_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_scura:',
        'fa': u':زن_پوست_آبنوسی_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_gelap:',
        'zh': u':金发女_较深肤色:'
    },
    u'\U0001F471\U0001F3FF\U0000200D\U00002640': { # 👱🏿‍♀
        'en' : ':woman_dark_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_dunkle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_oscuro:',
        'fr': u':femme_blonde_peau_foncée:',
        'ja': u':金髪の女性_濃い肌色:',
        'ko': u':금발_여자_검은색_피부:',
        'pt': ':mulher_pele_escura_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_scura:',
        'fa': u':زن_پوست_آبنوسی_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_gelap:',
        'zh': u':金发女_较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F9B1': { # 👩🏿‍🦱
        'en' : ':woman_dark_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_dunkle_hautfarbe,_lockiges_haar:',
        'es': ':mujer_tono_de_piel_oscuro_y_pelo_rizado:',
        'fr': u':femme_peau_foncée_et_cheveux_bouclés:',
        'ja': u':女性_濃い肌色_巻き毛:',
        'ko': u':여자_검은색_피부_곱슬머리:',
        'pt': ':mulher_pele_escura_e_cabelo_cacheado:',
        'it': ':donna_carnagione_scura_e_capelli_ricci:',
        'fa': u':زن_پوست_آبنوسی_موفرفری:',
        'id': ':wanita_warna_kulit_gelap_rambut_keriting:',
        'zh': u':女人_较深肤色卷发:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F9B0': { # 👩🏿‍🦰
        'en' : ':woman_dark_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_dunkle_hautfarbe,_rotes_haar:',
        'es': ':mujer_tono_de_piel_oscuro_y_pelo_pelirrojo:',
        'fr': u':femme_peau_foncée_et_cheveux_roux:',
        'ja': u':女性_濃い肌色_赤毛:',
        'ko': u':여자_검은색_피부_빨간_머리:',
        'pt': ':mulher_pele_escura_e_cabelo_vermelho:',
        'it': ':donna_carnagione_scura_e_capelli_rossi:',
        'fa': u':زن_پوست_آبنوسی_موقرمز:',
        'id': ':wanita_warna_kulit_gelap_rambut_merah:',
        'zh': u':女人_较深肤色红发:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F9B3': { # 👩🏿‍🦳
        'en' : ':woman_dark_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':frau_dunkle_hautfarbe,_weißes_haar:',
        'es': ':mujer_tono_de_piel_oscuro_y_pelo_blanco:',
        'fr': u':femme_peau_foncée_et_cheveux_blancs:',
        'ja': u':女性_濃い肌色_白髪:',
        'ko': u':여자_검은색_피부_백발:',
        'pt': ':mulher_pele_escura_e_cabelo_branco:',
        'it': ':donna_carnagione_scura_e_capelli_bianchi:',
        'fa': u':زن_پوست_آبنوسی_موسفید:',
        'id': ':wanita_warna_kulit_gelap_rambut_putih:',
        'zh': u':女人_较深肤色白发:'
    },
    u'\U0001F575\U0000FE0F\U0000200D\U00002640\U0000FE0F': { # 🕵️‍♀️
        'en' : ':woman_detective:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':female_detective:'],
        'de': ':detektivin:',
        'es': ':detective_mujer:',
        'fr': u':détective_femme:',
        'ja': u':女性の探偵:',
        'ko': u':여자_탐정:',
        'pt': ':detetive_mulher:',
        'it': ':investigatrice:',
        'fa': u':کارآگاه_زن:',
        'id': ':detektif_wanita:',
        'zh': u':女侦探:'
    },
    u'\U0001F575\U0000200D\U00002640\U0000FE0F': { # 🕵‍♀️
        'en' : ':woman_detective:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':female_detective:'],
        'de': ':detektivin:',
        'es': ':detective_mujer:',
        'fr': u':détective_femme:',
        'ja': u':女性の探偵:',
        'ko': u':여자_탐정:',
        'pt': ':detetive_mulher:',
        'it': ':investigatrice:',
        'fa': u':کارآگاه_زن:',
        'id': ':detektif_wanita:',
        'zh': u':女侦探:'
    },
    u'\U0001F575\U0000FE0F\U0000200D\U00002640': { # 🕵️‍♀
        'en' : ':woman_detective:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':female_detective:'],
        'de': ':detektivin:',
        'es': ':detective_mujer:',
        'fr': u':détective_femme:',
        'ja': u':女性の探偵:',
        'ko': u':여자_탐정:',
        'pt': ':detetive_mulher:',
        'it': ':investigatrice:',
        'fa': u':کارآگاه_زن:',
        'id': ':detektif_wanita:',
        'zh': u':女侦探:'
    },
    u'\U0001F575\U0000200D\U00002640': { # 🕵‍♀
        'en' : ':woman_detective:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':female_detective:'],
        'de': ':detektivin:',
        'es': ':detective_mujer:',
        'fr': u':détective_femme:',
        'ja': u':女性の探偵:',
        'ko': u':여자_탐정:',
        'pt': ':detetive_mulher:',
        'it': ':investigatrice:',
        'fa': u':کارآگاه_زن:',
        'id': ':detektif_wanita:',
        'zh': u':女侦探:'
    },
    u'\U0001F575\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🕵🏿‍♀️
        'en' : ':woman_detective_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektivin_dunkle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_oscuro:',
        'fr': u':détective_femme_peau_foncée:',
        'ja': u':女性の探偵_濃い肌色:',
        'ko': u':여자_탐정_검은색_피부:',
        'pt': ':detetive_mulher_pele_escura:',
        'it': ':investigatrice_carnagione_scura:',
        'fa': u':کارآگاه_زن_پوست_آبنوسی:',
        'id': ':detektif_wanita_warna_kulit_gelap:',
        'zh': u':女侦探_较深肤色:'
    },
    u'\U0001F575\U0001F3FF\U0000200D\U00002640': { # 🕵🏿‍♀
        'en' : ':woman_detective_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektivin_dunkle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_oscuro:',
        'fr': u':détective_femme_peau_foncée:',
        'ja': u':女性の探偵_濃い肌色:',
        'ko': u':여자_탐정_검은색_피부:',
        'pt': ':detetive_mulher_pele_escura:',
        'it': ':investigatrice_carnagione_scura:',
        'fa': u':کارآگاه_زن_پوست_آبنوسی:',
        'id': ':detektif_wanita_warna_kulit_gelap:',
        'zh': u':女侦探_较深肤色:'
    },
    u'\U0001F575\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🕵🏻‍♀️
        'en' : ':woman_detective_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektivin_helle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_claro:',
        'fr': u':détective_femme_peau_claire:',
        'ja': u':女性の探偵_薄い肌色:',
        'ko': u':여자_탐정_하얀_피부:',
        'pt': ':detetive_mulher_pele_clara:',
        'it': ':investigatrice_carnagione_chiara:',
        'fa': u':کارآگاه_زن_پوست_سفید:',
        'id': ':detektif_wanita_warna_kulit_cerah:',
        'zh': u':女侦探_较浅肤色:'
    },
    u'\U0001F575\U0001F3FB\U0000200D\U00002640': { # 🕵🏻‍♀
        'en' : ':woman_detective_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektivin_helle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_claro:',
        'fr': u':détective_femme_peau_claire:',
        'ja': u':女性の探偵_薄い肌色:',
        'ko': u':여자_탐정_하얀_피부:',
        'pt': ':detetive_mulher_pele_clara:',
        'it': ':investigatrice_carnagione_chiara:',
        'fa': u':کارآگاه_زن_پوست_سفید:',
        'id': ':detektif_wanita_warna_kulit_cerah:',
        'zh': u':女侦探_较浅肤色:'
    },
    u'\U0001F575\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🕵🏾‍♀️
        'en' : ':woman_detective_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektivin_mitteldunkle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':détective_femme_peau_mate:',
        'ja': u':女性の探偵_やや濃い肌色:',
        'ko': u':여자_탐정_진한_갈색_피부:',
        'pt': ':detetive_mulher_pele_morena_escura:',
        'it': ':investigatrice_carnagione_abbastanza_scura:',
        'fa': u':کارآگاه_زن_پوست_گندمی:',
        'id': ':detektif_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女侦探_中等深肤色:'
    },
    u'\U0001F575\U0001F3FE\U0000200D\U00002640': { # 🕵🏾‍♀
        'en' : ':woman_detective_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektivin_mitteldunkle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':détective_femme_peau_mate:',
        'ja': u':女性の探偵_やや濃い肌色:',
        'ko': u':여자_탐정_진한_갈색_피부:',
        'pt': ':detetive_mulher_pele_morena_escura:',
        'it': ':investigatrice_carnagione_abbastanza_scura:',
        'fa': u':کارآگاه_زن_پوست_گندمی:',
        'id': ':detektif_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女侦探_中等深肤色:'
    },
    u'\U0001F575\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🕵🏼‍♀️
        'en' : ':woman_detective_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektivin_mittelhelle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_claro_medio:',
        'fr': u':détective_femme_peau_moyennement_claire:',
        'ja': u':女性の探偵_やや薄い肌色:',
        'ko': u':여자_탐정_연한_갈색_피부:',
        'pt': ':detetive_mulher_pele_morena_clara:',
        'it': ':investigatrice_carnagione_abbastanza_chiara:',
        'fa': u':کارآگاه_زن_پوست_روشن:',
        'id': ':detektif_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女侦探_中等浅肤色:'
    },
    u'\U0001F575\U0001F3FC\U0000200D\U00002640': { # 🕵🏼‍♀
        'en' : ':woman_detective_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektivin_mittelhelle_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_claro_medio:',
        'fr': u':détective_femme_peau_moyennement_claire:',
        'ja': u':女性の探偵_やや薄い肌色:',
        'ko': u':여자_탐정_연한_갈색_피부:',
        'pt': ':detetive_mulher_pele_morena_clara:',
        'it': ':investigatrice_carnagione_abbastanza_chiara:',
        'fa': u':کارآگاه_زن_پوست_روشن:',
        'id': ':detektif_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女侦探_中等浅肤色:'
    },
    u'\U0001F575\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🕵🏽‍♀️
        'en' : ':woman_detective_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':detektivin_mittlere_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_medio:',
        'fr': u':détective_femme_peau_légèrement_mate:',
        'ja': u':女性の探偵_中間の肌色:',
        'ko': u':여자_탐정_갈색_피부:',
        'pt': ':detetive_mulher_pele_morena:',
        'it': ':investigatrice_carnagione_olivastra:',
        'fa': u':کارآگاه_زن_پوست_طلایی:',
        'id': ':detektif_wanita_warna_kulit_sedang:',
        'zh': u':女侦探_中等肤色:'
    },
    u'\U0001F575\U0001F3FD\U0000200D\U00002640': { # 🕵🏽‍♀
        'en' : ':woman_detective_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':detektivin_mittlere_hautfarbe:',
        'es': ':detective_mujer_tono_de_piel_medio:',
        'fr': u':détective_femme_peau_légèrement_mate:',
        'ja': u':女性の探偵_中間の肌色:',
        'ko': u':여자_탐정_갈색_피부:',
        'pt': ':detetive_mulher_pele_morena:',
        'it': ':investigatrice_carnagione_olivastra:',
        'fa': u':کارآگاه_زن_پوست_طلایی:',
        'id': ':detektif_wanita_warna_kulit_sedang:',
        'zh': u':女侦探_中等肤色:'
    },
    u'\U0001F9DD\U0000200D\U00002640\U0000FE0F': { # 🧝‍♀️
        'en' : ':woman_elf:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':elf_woman:'],
        'de': ':elfe:',
        'es': ':elfa:',
        'fr': ':elfe_femme:',
        'ja': u':女のエルフ:',
        'ko': u':여자_엘프:',
        'pt': ':elfa:',
        'it': ':elfo_donna:',
        'fa': u':اِلف_زن:',
        'id': ':kurcaci_wanita:',
        'zh': u':女小精灵:'
    },
    u'\U0001F9DD\U0000200D\U00002640': { # 🧝‍♀
        'en' : ':woman_elf:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':elf_woman:'],
        'de': ':elfe:',
        'es': ':elfa:',
        'fr': ':elfe_femme:',
        'ja': u':女のエルフ:',
        'ko': u':여자_엘프:',
        'pt': ':elfa:',
        'it': ':elfo_donna:',
        'fa': u':اِلف_زن:',
        'id': ':kurcaci_wanita:',
        'zh': u':女小精灵:'
    },
    u'\U0001F9DD\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧝🏿‍♀️
        'en' : ':woman_elf_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elfe_dunkle_hautfarbe:',
        'es': ':elfa_tono_de_piel_oscuro:',
        'fr': u':elfe_femme_peau_foncée:',
        'ja': u':女のエルフ_濃い肌色:',
        'ko': u':여자_엘프_검은색_피부:',
        'pt': ':elfa_pele_escura:',
        'it': ':elfo_donna_carnagione_scura:',
        'fa': u':اِلف_زن_پوست_آبنوسی:',
        'id': ':kurcaci_wanita_warna_kulit_gelap:',
        'zh': u':女小精灵_较深肤色:'
    },
    u'\U0001F9DD\U0001F3FF\U0000200D\U00002640': { # 🧝🏿‍♀
        'en' : ':woman_elf_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elfe_dunkle_hautfarbe:',
        'es': ':elfa_tono_de_piel_oscuro:',
        'fr': u':elfe_femme_peau_foncée:',
        'ja': u':女のエルフ_濃い肌色:',
        'ko': u':여자_엘프_검은색_피부:',
        'pt': ':elfa_pele_escura:',
        'it': ':elfo_donna_carnagione_scura:',
        'fa': u':اِلف_زن_پوست_آبنوسی:',
        'id': ':kurcaci_wanita_warna_kulit_gelap:',
        'zh': u':女小精灵_较深肤色:'
    },
    u'\U0001F9DD\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧝🏻‍♀️
        'en' : ':woman_elf_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elfe_helle_hautfarbe:',
        'es': ':elfa_tono_de_piel_claro:',
        'fr': ':elfe_femme_peau_claire:',
        'ja': u':女のエルフ_薄い肌色:',
        'ko': u':여자_엘프_하얀_피부:',
        'pt': ':elfa_pele_clara:',
        'it': ':elfo_donna_carnagione_chiara:',
        'fa': u':اِلف_زن_پوست_سفید:',
        'id': ':kurcaci_wanita_warna_kulit_cerah:',
        'zh': u':女小精灵_较浅肤色:'
    },
    u'\U0001F9DD\U0001F3FB\U0000200D\U00002640': { # 🧝🏻‍♀
        'en' : ':woman_elf_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elfe_helle_hautfarbe:',
        'es': ':elfa_tono_de_piel_claro:',
        'fr': ':elfe_femme_peau_claire:',
        'ja': u':女のエルフ_薄い肌色:',
        'ko': u':여자_엘프_하얀_피부:',
        'pt': ':elfa_pele_clara:',
        'it': ':elfo_donna_carnagione_chiara:',
        'fa': u':اِلف_زن_پوست_سفید:',
        'id': ':kurcaci_wanita_warna_kulit_cerah:',
        'zh': u':女小精灵_较浅肤色:'
    },
    u'\U0001F9DD\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧝🏾‍♀️
        'en' : ':woman_elf_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elfe_mitteldunkle_hautfarbe:',
        'es': ':elfa_tono_de_piel_oscuro_medio:',
        'fr': ':elfe_femme_peau_mate:',
        'ja': u':女のエルフ_やや濃い肌色:',
        'ko': u':여자_엘프_진한_갈색_피부:',
        'pt': ':elfa_pele_morena_escura:',
        'it': ':elfo_donna_carnagione_abbastanza_scura:',
        'fa': u':اِلف_زن_پوست_گندمی:',
        'id': ':kurcaci_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女小精灵_中等深肤色:'
    },
    u'\U0001F9DD\U0001F3FE\U0000200D\U00002640': { # 🧝🏾‍♀
        'en' : ':woman_elf_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elfe_mitteldunkle_hautfarbe:',
        'es': ':elfa_tono_de_piel_oscuro_medio:',
        'fr': ':elfe_femme_peau_mate:',
        'ja': u':女のエルフ_やや濃い肌色:',
        'ko': u':여자_엘프_진한_갈색_피부:',
        'pt': ':elfa_pele_morena_escura:',
        'it': ':elfo_donna_carnagione_abbastanza_scura:',
        'fa': u':اِلف_زن_پوست_گندمی:',
        'id': ':kurcaci_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女小精灵_中等深肤色:'
    },
    u'\U0001F9DD\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧝🏼‍♀️
        'en' : ':woman_elf_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elfe_mittelhelle_hautfarbe:',
        'es': ':elfa_tono_de_piel_claro_medio:',
        'fr': ':elfe_femme_peau_moyennement_claire:',
        'ja': u':女のエルフ_やや薄い肌色:',
        'ko': u':여자_엘프_연한_갈색_피부:',
        'pt': ':elfa_pele_morena_clara:',
        'it': ':elfo_donna_carnagione_abbastanza_chiara:',
        'fa': u':اِلف_زن_پوست_روشن:',
        'id': ':kurcaci_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女小精灵_中等浅肤色:'
    },
    u'\U0001F9DD\U0001F3FC\U0000200D\U00002640': { # 🧝🏼‍♀
        'en' : ':woman_elf_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elfe_mittelhelle_hautfarbe:',
        'es': ':elfa_tono_de_piel_claro_medio:',
        'fr': ':elfe_femme_peau_moyennement_claire:',
        'ja': u':女のエルフ_やや薄い肌色:',
        'ko': u':여자_엘프_연한_갈색_피부:',
        'pt': ':elfa_pele_morena_clara:',
        'it': ':elfo_donna_carnagione_abbastanza_chiara:',
        'fa': u':اِلف_زن_پوست_روشن:',
        'id': ':kurcaci_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女小精灵_中等浅肤色:'
    },
    u'\U0001F9DD\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧝🏽‍♀️
        'en' : ':woman_elf_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':elfe_mittlere_hautfarbe:',
        'es': ':elfa_tono_de_piel_medio:',
        'fr': u':elfe_femme_peau_légèrement_mate:',
        'ja': u':女のエルフ_中間の肌色:',
        'ko': u':여자_엘프_갈색_피부:',
        'pt': ':elfa_pele_morena:',
        'it': ':elfo_donna_carnagione_olivastra:',
        'fa': u':اِلف_زن_پوست_طلایی:',
        'id': ':kurcaci_wanita_warna_kulit_sedang:',
        'zh': u':女小精灵_中等肤色:'
    },
    u'\U0001F9DD\U0001F3FD\U0000200D\U00002640': { # 🧝🏽‍♀
        'en' : ':woman_elf_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':elfe_mittlere_hautfarbe:',
        'es': ':elfa_tono_de_piel_medio:',
        'fr': u':elfe_femme_peau_légèrement_mate:',
        'ja': u':女のエルフ_中間の肌色:',
        'ko': u':여자_엘프_갈색_피부:',
        'pt': ':elfa_pele_morena:',
        'it': ':elfo_donna_carnagione_olivastra:',
        'fa': u':اِلف_زن_پوست_طلایی:',
        'id': ':kurcaci_wanita_warna_kulit_sedang:',
        'zh': u':女小精灵_中等肤色:'
    },
    u'\U0001F926\U0000200D\U00002640\U0000FE0F': { # 🤦‍♀️
        'en' : ':woman_facepalming:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau:',
        'es': ':mujer_con_la_mano_en_la_frente:',
        'fr': ':femme_avec_la_paume_sur_le_visage:',
        'ja': u':ひたいに手をあてる女:',
        'ko': u':골치_아파하는_여자:',
        'pt': ':mulher_decepcionada:',
        'it': ':donna_esasperata:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند:',
        'id': ':wanita_tepuk_jidat:',
        'zh': u':女生捂脸:'
    },
    u'\U0001F926\U0000200D\U00002640': { # 🤦‍♀
        'en' : ':woman_facepalming:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau:',
        'es': ':mujer_con_la_mano_en_la_frente:',
        'fr': ':femme_avec_la_paume_sur_le_visage:',
        'ja': u':ひたいに手をあてる女:',
        'ko': u':골치_아파하는_여자:',
        'pt': ':mulher_decepcionada:',
        'it': ':donna_esasperata:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند:',
        'id': ':wanita_tepuk_jidat:',
        'zh': u':女生捂脸:'
    },
    u'\U0001F926\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🤦🏿‍♀️
        'en' : ':woman_facepalming_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_dunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_oscuro:',
        'fr': u':femme_avec_la_paume_sur_le_visage_peau_foncée:',
        'ja': u':ひたいに手をあてる女_濃い肌色:',
        'ko': u':골치_아파하는_여자_검은색_피부:',
        'pt': ':mulher_decepcionada_pele_escura:',
        'it': ':donna_esasperata_carnagione_scura:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_آبنوسی:',
        'id': ':wanita_tepuk_jidat_warna_kulit_gelap:',
        'zh': u':女生捂脸_较深肤色:'
    },
    u'\U0001F926\U0001F3FF\U0000200D\U00002640': { # 🤦🏿‍♀
        'en' : ':woman_facepalming_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_dunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_oscuro:',
        'fr': u':femme_avec_la_paume_sur_le_visage_peau_foncée:',
        'ja': u':ひたいに手をあてる女_濃い肌色:',
        'ko': u':골치_아파하는_여자_검은색_피부:',
        'pt': ':mulher_decepcionada_pele_escura:',
        'it': ':donna_esasperata_carnagione_scura:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_آبنوسی:',
        'id': ':wanita_tepuk_jidat_warna_kulit_gelap:',
        'zh': u':女生捂脸_较深肤色:'
    },
    u'\U0001F926\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🤦🏻‍♀️
        'en' : ':woman_facepalming_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_helle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_claro:',
        'fr': ':femme_avec_la_paume_sur_le_visage_peau_claire:',
        'ja': u':ひたいに手をあてる女_薄い肌色:',
        'ko': u':골치_아파하는_여자_하얀_피부:',
        'pt': ':mulher_decepcionada_pele_clara:',
        'it': ':donna_esasperata_carnagione_chiara:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_سفید:',
        'id': ':wanita_tepuk_jidat_warna_kulit_cerah:',
        'zh': u':女生捂脸_较浅肤色:'
    },
    u'\U0001F926\U0001F3FB\U0000200D\U00002640': { # 🤦🏻‍♀
        'en' : ':woman_facepalming_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_helle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_claro:',
        'fr': ':femme_avec_la_paume_sur_le_visage_peau_claire:',
        'ja': u':ひたいに手をあてる女_薄い肌色:',
        'ko': u':골치_아파하는_여자_하얀_피부:',
        'pt': ':mulher_decepcionada_pele_clara:',
        'it': ':donna_esasperata_carnagione_chiara:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_سفید:',
        'id': ':wanita_tepuk_jidat_warna_kulit_cerah:',
        'zh': u':女生捂脸_较浅肤色:'
    },
    u'\U0001F926\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🤦🏾‍♀️
        'en' : ':woman_facepalming_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_la_paume_sur_le_visage_peau_mate:',
        'ja': u':ひたいに手をあてる女_やや濃い肌色:',
        'ko': u':골치_아파하는_여자_진한_갈색_피부:',
        'pt': ':mulher_decepcionada_pele_morena_escura:',
        'it': ':donna_esasperata_carnagione_abbastanza_scura:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_گندمی:',
        'id': ':wanita_tepuk_jidat_warna_kulit_gelap-sedang:',
        'zh': u':女生捂脸_中等深肤色:'
    },
    u'\U0001F926\U0001F3FE\U0000200D\U00002640': { # 🤦🏾‍♀
        'en' : ':woman_facepalming_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_la_paume_sur_le_visage_peau_mate:',
        'ja': u':ひたいに手をあてる女_やや濃い肌色:',
        'ko': u':골치_아파하는_여자_진한_갈색_피부:',
        'pt': ':mulher_decepcionada_pele_morena_escura:',
        'it': ':donna_esasperata_carnagione_abbastanza_scura:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_گندمی:',
        'id': ':wanita_tepuk_jidat_warna_kulit_gelap-sedang:',
        'zh': u':女生捂脸_中等深肤色:'
    },
    u'\U0001F926\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🤦🏼‍♀️
        'en' : ':woman_facepalming_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_la_paume_sur_le_visage_peau_moyennement_claire:',
        'ja': u':ひたいに手をあてる女_やや薄い肌色:',
        'ko': u':골치_아파하는_여자_연한_갈색_피부:',
        'pt': ':mulher_decepcionada_pele_morena_clara:',
        'it': ':donna_esasperata_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_روشن:',
        'id': ':wanita_tepuk_jidat_warna_kulit_cerah-sedang:',
        'zh': u':女生捂脸_中等浅肤色:'
    },
    u'\U0001F926\U0001F3FC\U0000200D\U00002640': { # 🤦🏼‍♀
        'en' : ':woman_facepalming_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_la_paume_sur_le_visage_peau_moyennement_claire:',
        'ja': u':ひたいに手をあてる女_やや薄い肌色:',
        'ko': u':골치_아파하는_여자_연한_갈색_피부:',
        'pt': ':mulher_decepcionada_pele_morena_clara:',
        'it': ':donna_esasperata_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_روشن:',
        'id': ':wanita_tepuk_jidat_warna_kulit_cerah-sedang:',
        'zh': u':女生捂脸_中等浅肤色:'
    },
    u'\U0001F926\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🤦🏽‍♀️
        'en' : ':woman_facepalming_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_mittlere_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_medio:',
        'fr': u':femme_avec_la_paume_sur_le_visage_peau_légèrement_mate:',
        'ja': u':ひたいに手をあてる女_中間の肌色:',
        'ko': u':골치_아파하는_여자_갈색_피부:',
        'pt': ':mulher_decepcionada_pele_morena:',
        'it': ':donna_esasperata_carnagione_olivastra:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_طلایی:',
        'id': ':wanita_tepuk_jidat_warna_kulit_sedang:',
        'zh': u':女生捂脸_中等肤色:'
    },
    u'\U0001F926\U0001F3FD\U0000200D\U00002640': { # 🤦🏽‍♀
        'en' : ':woman_facepalming_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':sich_an_den_kopf_fassende_frau_mittlere_hautfarbe:',
        'es': ':mujer_con_la_mano_en_la_frente_tono_de_piel_medio:',
        'fr': u':femme_avec_la_paume_sur_le_visage_peau_légèrement_mate:',
        'ja': u':ひたいに手をあてる女_中間の肌色:',
        'ko': u':골치_아파하는_여자_갈색_피부:',
        'pt': ':mulher_decepcionada_pele_morena:',
        'it': ':donna_esasperata_carnagione_olivastra:',
        'fa': u':زن_با_کف_دست_به_پیشانی_می_زند_پوست_طلایی:',
        'id': ':wanita_tepuk_jidat_warna_kulit_sedang:',
        'zh': u':女生捂脸_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F3ED': { # 👩‍🏭
        'en' : ':woman_factory_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiterin:',
        'es': ':profesional_industrial_mujer:',
        'fr': u':ouvrière:',
        'ja': u':女性の溶接工:',
        'ko': u':공장_여자_직원:',
        'pt': u':operária:',
        'it': ':operaia:',
        'fa': u':کارگر_کارخانه_زن:',
        'id': ':pekerja_pabrik_wanita:',
        'zh': u':女工人:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F3ED': { # 👩🏿‍🏭
        'en' : ':woman_factory_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiterin_dunkle_hautfarbe:',
        'es': ':profesional_industrial_mujer_tono_de_piel_oscuro:',
        'fr': u':ouvrière_peau_foncée:',
        'ja': u':女性の溶接工_濃い肌色:',
        'ko': u':공장_여자_직원_검은색_피부:',
        'pt': u':operária_pele_escura:',
        'it': ':operaia_carnagione_scura:',
        'fa': u':کارگر_کارخانه_زن_پوست_آبنوسی:',
        'id': ':pekerja_pabrik_wanita_warna_kulit_gelap:',
        'zh': u':女工人_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F3ED': { # 👩🏻‍🏭
        'en' : ':woman_factory_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiterin_helle_hautfarbe:',
        'es': ':profesional_industrial_mujer_tono_de_piel_claro:',
        'fr': u':ouvrière_peau_claire:',
        'ja': u':女性の溶接工_薄い肌色:',
        'ko': u':공장_여자_직원_하얀_피부:',
        'pt': u':operária_pele_clara:',
        'it': ':operaia_carnagione_chiara:',
        'fa': u':کارگر_کارخانه_زن_پوست_سفید:',
        'id': ':pekerja_pabrik_wanita_warna_kulit_cerah:',
        'zh': u':女工人_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F3ED': { # 👩🏾‍🏭
        'en' : ':woman_factory_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiterin_mitteldunkle_hautfarbe:',
        'es': ':profesional_industrial_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':ouvrière_peau_mate:',
        'ja': u':女性の溶接工_やや濃い肌色:',
        'ko': u':공장_여자_직원_진한_갈색_피부:',
        'pt': u':operária_pele_morena_escura:',
        'it': ':operaia_carnagione_abbastanza_scura:',
        'fa': u':کارگر_کارخانه_زن_پوست_گندمی:',
        'id': ':pekerja_pabrik_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女工人_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F3ED': { # 👩🏼‍🏭
        'en' : ':woman_factory_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiterin_mittelhelle_hautfarbe:',
        'es': ':profesional_industrial_mujer_tono_de_piel_claro_medio:',
        'fr': u':ouvrière_peau_moyennement_claire:',
        'ja': u':女性の溶接工_やや薄い肌色:',
        'ko': u':공장_여자_직원_연한_갈색_피부:',
        'pt': u':operária_pele_morena_clara:',
        'it': ':operaia_carnagione_abbastanza_chiara:',
        'fa': u':کارگر_کارخانه_زن_پوست_روشن:',
        'id': ':pekerja_pabrik_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女工人_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F3ED': { # 👩🏽‍🏭
        'en' : ':woman_factory_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':fabrikarbeiterin_mittlere_hautfarbe:',
        'es': ':profesional_industrial_mujer_tono_de_piel_medio:',
        'fr': u':ouvrière_peau_légèrement_mate:',
        'ja': u':女性の溶接工_中間の肌色:',
        'ko': u':공장_여자_직원_갈색_피부:',
        'pt': u':operária_pele_morena:',
        'it': ':operaia_carnagione_olivastra:',
        'fa': u':کارگر_کارخانه_زن_پوست_طلایی:',
        'id': ':pekerja_pabrik_wanita_warna_kulit_sedang:',
        'zh': u':女工人_中等肤色:'
    },
    u'\U0001F9DA\U0000200D\U00002640\U0000FE0F': { # 🧚‍♀️
        'en' : ':woman_fairy:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':fairy_woman:'],
        'de': ':fee:',
        'es': ':hada_mujer:',
        'fr': u':fée:',
        'ja': u':女の妖精:',
        'ko': u':여자_요정:',
        'pt': ':mulher_fada:',
        'it': ':fata_donna:',
        'fa': u':پری_زن:',
        'id': ':peri_wanita:',
        'zh': u':仙女:'
    },
    u'\U0001F9DA\U0000200D\U00002640': { # 🧚‍♀
        'en' : ':woman_fairy:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':fairy_woman:'],
        'de': ':fee:',
        'es': ':hada_mujer:',
        'fr': u':fée:',
        'ja': u':女の妖精:',
        'ko': u':여자_요정:',
        'pt': ':mulher_fada:',
        'it': ':fata_donna:',
        'fa': u':پری_زن:',
        'id': ':peri_wanita:',
        'zh': u':仙女:'
    },
    u'\U0001F9DA\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧚🏿‍♀️
        'en' : ':woman_fairy_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':fee_dunkle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_oscuro:',
        'fr': u':fée_peau_foncée:',
        'ja': u':女の妖精_濃い肌色:',
        'ko': u':여자_요정_검은색_피부:',
        'pt': ':mulher_fada_pele_escura:',
        'it': ':fata_donna_carnagione_scura:',
        'fa': u':پری_زن_پوست_آبنوسی:',
        'id': ':peri_wanita_warna_kulit_gelap:',
        'zh': u':仙女_较深肤色:'
    },
    u'\U0001F9DA\U0001F3FF\U0000200D\U00002640': { # 🧚🏿‍♀
        'en' : ':woman_fairy_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':fee_dunkle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_oscuro:',
        'fr': u':fée_peau_foncée:',
        'ja': u':女の妖精_濃い肌色:',
        'ko': u':여자_요정_검은색_피부:',
        'pt': ':mulher_fada_pele_escura:',
        'it': ':fata_donna_carnagione_scura:',
        'fa': u':پری_زن_پوست_آبنوسی:',
        'id': ':peri_wanita_warna_kulit_gelap:',
        'zh': u':仙女_较深肤色:'
    },
    u'\U0001F9DA\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧚🏻‍♀️
        'en' : ':woman_fairy_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':fee_helle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_claro:',
        'fr': u':fée_peau_claire:',
        'ja': u':女の妖精_薄い肌色:',
        'ko': u':여자_요정_하얀_피부:',
        'pt': ':mulher_fada_pele_clara:',
        'it': ':fata_donna_carnagione_chiara:',
        'fa': u':پری_زن_پوست_سفید:',
        'id': ':peri_wanita_warna_kulit_cerah:',
        'zh': u':仙女_较浅肤色:'
    },
    u'\U0001F9DA\U0001F3FB\U0000200D\U00002640': { # 🧚🏻‍♀
        'en' : ':woman_fairy_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':fee_helle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_claro:',
        'fr': u':fée_peau_claire:',
        'ja': u':女の妖精_薄い肌色:',
        'ko': u':여자_요정_하얀_피부:',
        'pt': ':mulher_fada_pele_clara:',
        'it': ':fata_donna_carnagione_chiara:',
        'fa': u':پری_زن_پوست_سفید:',
        'id': ':peri_wanita_warna_kulit_cerah:',
        'zh': u':仙女_较浅肤色:'
    },
    u'\U0001F9DA\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧚🏾‍♀️
        'en' : ':woman_fairy_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':fee_mitteldunkle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':fée_peau_mate:',
        'ja': u':女の妖精_やや濃い肌色:',
        'ko': u':여자_요정_진한_갈색_피부:',
        'pt': ':mulher_fada_pele_morena_escura:',
        'it': ':fata_donna_carnagione_abbastanza_scura:',
        'fa': u':پری_زن_پوست_گندمی:',
        'id': ':peri_wanita_warna_kulit_gelap-sedang:',
        'zh': u':仙女_中等深肤色:'
    },
    u'\U0001F9DA\U0001F3FE\U0000200D\U00002640': { # 🧚🏾‍♀
        'en' : ':woman_fairy_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':fee_mitteldunkle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':fée_peau_mate:',
        'ja': u':女の妖精_やや濃い肌色:',
        'ko': u':여자_요정_진한_갈색_피부:',
        'pt': ':mulher_fada_pele_morena_escura:',
        'it': ':fata_donna_carnagione_abbastanza_scura:',
        'fa': u':پری_زن_پوست_گندمی:',
        'id': ':peri_wanita_warna_kulit_gelap-sedang:',
        'zh': u':仙女_中等深肤色:'
    },
    u'\U0001F9DA\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧚🏼‍♀️
        'en' : ':woman_fairy_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':fee_mittelhelle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_claro_medio:',
        'fr': u':fée_peau_moyennement_claire:',
        'ja': u':女の妖精_やや薄い肌色:',
        'ko': u':여자_요정_연한_갈색_피부:',
        'pt': ':mulher_fada_pele_morena_clara:',
        'it': ':fata_donna_carnagione_abbastanza_chiara:',
        'fa': u':پری_زن_پوست_روشن:',
        'id': ':peri_wanita_warna_kulit_cerah-sedang:',
        'zh': u':仙女_中等浅肤色:'
    },
    u'\U0001F9DA\U0001F3FC\U0000200D\U00002640': { # 🧚🏼‍♀
        'en' : ':woman_fairy_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':fee_mittelhelle_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_claro_medio:',
        'fr': u':fée_peau_moyennement_claire:',
        'ja': u':女の妖精_やや薄い肌色:',
        'ko': u':여자_요정_연한_갈색_피부:',
        'pt': ':mulher_fada_pele_morena_clara:',
        'it': ':fata_donna_carnagione_abbastanza_chiara:',
        'fa': u':پری_زن_پوست_روشن:',
        'id': ':peri_wanita_warna_kulit_cerah-sedang:',
        'zh': u':仙女_中等浅肤色:'
    },
    u'\U0001F9DA\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧚🏽‍♀️
        'en' : ':woman_fairy_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':fee_mittlere_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_medio:',
        'fr': u':fée_peau_légèrement_mate:',
        'ja': u':女の妖精_中間の肌色:',
        'ko': u':여자_요정_갈색_피부:',
        'pt': ':mulher_fada_pele_morena:',
        'it': ':fata_donna_carnagione_olivastra:',
        'fa': u':پری_زن_پوست_طلایی:',
        'id': ':peri_wanita_warna_kulit_sedang:',
        'zh': u':仙女_中等肤色:'
    },
    u'\U0001F9DA\U0001F3FD\U0000200D\U00002640': { # 🧚🏽‍♀
        'en' : ':woman_fairy_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':fee_mittlere_hautfarbe:',
        'es': ':hada_mujer_tono_de_piel_medio:',
        'fr': u':fée_peau_légèrement_mate:',
        'ja': u':女の妖精_中間の肌色:',
        'ko': u':여자_요정_갈색_피부:',
        'pt': ':mulher_fada_pele_morena:',
        'it': ':fata_donna_carnagione_olivastra:',
        'fa': u':پری_زن_پوست_طلایی:',
        'id': ':peri_wanita_warna_kulit_sedang:',
        'zh': u':仙女_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F33E': { # 👩‍🌾
        'en' : ':woman_farmer:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':bäuerin:',
        'es': ':profesional_de_la_agricultura_mujer:',
        'fr': u':fermière:',
        'ja': u':農家の女性:',
        'ko': u':여자_농부:',
        'pt': ':fazendeira:',
        'it': ':contadina:',
        'fa': u':کشاورز_زن:',
        'id': ':petani_wanita:',
        'zh': u':农妇:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F33E': { # 👩🏿‍🌾
        'en' : ':woman_farmer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':bäuerin_dunkle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_mujer_tono_de_piel_oscuro:',
        'fr': u':fermière_peau_foncée:',
        'ja': u':農家の女性_濃い肌色:',
        'ko': u':여자_농부_검은색_피부:',
        'pt': ':fazendeira_pele_escura:',
        'it': ':contadina_carnagione_scura:',
        'fa': u':کشاورز_زن_پوست_آبنوسی:',
        'id': ':petani_wanita_warna_kulit_gelap:',
        'zh': u':农妇_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F33E': { # 👩🏻‍🌾
        'en' : ':woman_farmer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':bäuerin_helle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_mujer_tono_de_piel_claro:',
        'fr': u':fermière_peau_claire:',
        'ja': u':農家の女性_薄い肌色:',
        'ko': u':여자_농부_하얀_피부:',
        'pt': ':fazendeira_pele_clara:',
        'it': ':contadina_carnagione_chiara:',
        'fa': u':کشاورز_زن_پوست_سفید:',
        'id': ':petani_wanita_warna_kulit_cerah:',
        'zh': u':农妇_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F33E': { # 👩🏾‍🌾
        'en' : ':woman_farmer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':bäuerin_mitteldunkle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':fermière_peau_mate:',
        'ja': u':農家の女性_やや濃い肌色:',
        'ko': u':여자_농부_진한_갈색_피부:',
        'pt': ':fazendeira_pele_morena_escura:',
        'it': ':contadina_carnagione_abbastanza_scura:',
        'fa': u':کشاورز_زن_پوست_گندمی:',
        'id': ':petani_wanita_warna_kulit_gelap-sedang:',
        'zh': u':农妇_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F33E': { # 👩🏼‍🌾
        'en' : ':woman_farmer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':bäuerin_mittelhelle_hautfarbe:',
        'es': ':profesional_de_la_agricultura_mujer_tono_de_piel_claro_medio:',
        'fr': u':fermière_peau_moyennement_claire:',
        'ja': u':農家の女性_やや薄い肌色:',
        'ko': u':여자_농부_연한_갈색_피부:',
        'pt': ':fazendeira_pele_morena_clara:',
        'it': ':contadina_carnagione_abbastanza_chiara:',
        'fa': u':کشاورز_زن_پوست_روشن:',
        'id': ':petani_wanita_warna_kulit_cerah-sedang:',
        'zh': u':农妇_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F33E': { # 👩🏽‍🌾
        'en' : ':woman_farmer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':bäuerin_mittlere_hautfarbe:',
        'es': ':profesional_de_la_agricultura_mujer_tono_de_piel_medio:',
        'fr': u':fermière_peau_légèrement_mate:',
        'ja': u':農家の女性_中間の肌色:',
        'ko': u':여자_농부_갈색_피부:',
        'pt': ':fazendeira_pele_morena:',
        'it': ':contadina_carnagione_olivastra:',
        'fa': u':کشاورز_زن_پوست_طلایی:',
        'id': ':petani_wanita_warna_kulit_sedang:',
        'zh': u':农妇_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F37C': { # 👩‍🍼
        'en' : ':woman_feeding_baby:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_frau:',
        'es': u':mujer_alimentando_a_bebé:',
        'fr': u':femme_allaitant_un_bébé:',
        'ja': u':授乳する女性:',
        'ko': u':수유_중인_여자:',
        'pt': u':mulher_alimentando_bebê:',
        'it': ':donna_che_allatta:',
        'fa': u':زنی_که_به_بچه_شیر_می_دهد:',
        'id': ':wanita_menyusui_bayi:',
        'zh': u':哺乳的女人:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F37C': { # 👩🏿‍🍼
        'en' : ':woman_feeding_baby_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_frau_dunkle_hautfarbe:',
        'es': u':mujer_alimentando_a_bebé_tono_de_piel_oscuro:',
        'fr': u':femme_allaitant_un_bébé_peau_foncée:',
        'ja': u':授乳する女性_濃い肌色:',
        'ko': u':수유_중인_여자_검은색_피부:',
        'pt': u':mulher_alimentando_bebê_pele_escura:',
        'it': ':donna_che_allatta_carnagione_scura:',
        'fa': u':زنی_که_به_بچه_شیر_می_دهد_پوست_آبنوسی:',
        'id': ':wanita_menyusui_bayi_warna_kulit_gelap:',
        'zh': u':哺乳的女人_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F37C': { # 👩🏻‍🍼
        'en' : ':woman_feeding_baby_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_frau_helle_hautfarbe:',
        'es': u':mujer_alimentando_a_bebé_tono_de_piel_claro:',
        'fr': u':femme_allaitant_un_bébé_peau_claire:',
        'ja': u':授乳する女性_薄い肌色:',
        'ko': u':수유_중인_여자_하얀_피부:',
        'pt': u':mulher_alimentando_bebê_pele_clara:',
        'it': ':donna_che_allatta_carnagione_chiara:',
        'fa': u':زنی_که_به_بچه_شیر_می_دهد_پوست_سفید:',
        'id': ':wanita_menyusui_bayi_warna_kulit_cerah:',
        'zh': u':哺乳的女人_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F37C': { # 👩🏾‍🍼
        'en' : ':woman_feeding_baby_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_frau_mitteldunkle_hautfarbe:',
        'es': u':mujer_alimentando_a_bebé_tono_de_piel_oscuro_medio:',
        'fr': u':femme_allaitant_un_bébé_peau_mate:',
        'ja': u':授乳する女性_やや濃い肌色:',
        'ko': u':수유_중인_여자_진한_갈색_피부:',
        'pt': u':mulher_alimentando_bebê_pele_morena_escura:',
        'it': ':donna_che_allatta_carnagione_abbastanza_scura:',
        'fa': u':زنی_که_به_بچه_شیر_می_دهد_پوست_گندمی:',
        'id': ':wanita_menyusui_bayi_warna_kulit_gelap-sedang:',
        'zh': u':哺乳的女人_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F37C': { # 👩🏼‍🍼
        'en' : ':woman_feeding_baby_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_frau_mittelhelle_hautfarbe:',
        'es': u':mujer_alimentando_a_bebé_tono_de_piel_claro_medio:',
        'fr': u':femme_allaitant_un_bébé_peau_moyennement_claire:',
        'ja': u':授乳する女性_やや薄い肌色:',
        'ko': u':수유_중인_여자_연한_갈색_피부:',
        'pt': u':mulher_alimentando_bebê_pele_morena_clara:',
        'it': ':donna_che_allatta_carnagione_abbastanza_chiara:',
        'fa': u':زنی_که_به_بچه_شیر_می_دهد_پوست_روشن:',
        'id': ':wanita_menyusui_bayi_warna_kulit_cerah-sedang:',
        'zh': u':哺乳的女人_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F37C': { # 👩🏽‍🍼
        'en' : ':woman_feeding_baby_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':stillende_frau_mittlere_hautfarbe:',
        'es': u':mujer_alimentando_a_bebé_tono_de_piel_medio:',
        'fr': u':femme_allaitant_un_bébé_peau_légèrement_mate:',
        'ja': u':授乳する女性_中間の肌色:',
        'ko': u':수유_중인_여자_갈색_피부:',
        'pt': u':mulher_alimentando_bebê_pele_morena:',
        'it': ':donna_che_allatta_carnagione_olivastra:',
        'fa': u':زنی_که_به_بچه_شیر_می_دهد_پوست_طلایی:',
        'id': ':wanita_menyusui_bayi_warna_kulit_sedang:',
        'zh': u':哺乳的女人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F692': { # 👩‍🚒
        'en' : ':woman_firefighter:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrfrau:',
        'es': ':bombera:',
        'fr': ':pompier_femme:',
        'ja': u':女性消防士:',
        'ko': u':여자_소방관:',
        'pt': ':bombeira:',
        'it': ':pompiere_donna:',
        'fa': u':آتش_نشان_زن:',
        'id': ':pemadam_kebakaran_wanita:',
        'zh': u':女消防员:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F692': { # 👩🏿‍🚒
        'en' : ':woman_firefighter_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrfrau_dunkle_hautfarbe:',
        'es': ':bombera_tono_de_piel_oscuro:',
        'fr': u':pompier_femme_peau_foncée:',
        'ja': u':女性消防士_濃い肌色:',
        'ko': u':여자_소방관_검은색_피부:',
        'pt': ':bombeira_pele_escura:',
        'it': ':pompiere_donna_carnagione_scura:',
        'fa': u':آتش_نشان_زن_پوست_آبنوسی:',
        'id': ':pemadam_kebakaran_wanita_warna_kulit_gelap:',
        'zh': u':女消防员_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F692': { # 👩🏻‍🚒
        'en' : ':woman_firefighter_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrfrau_helle_hautfarbe:',
        'es': ':bombera_tono_de_piel_claro:',
        'fr': ':pompier_femme_peau_claire:',
        'ja': u':女性消防士_薄い肌色:',
        'ko': u':여자_소방관_하얀_피부:',
        'pt': ':bombeira_pele_clara:',
        'it': ':pompiere_donna_carnagione_chiara:',
        'fa': u':آتش_نشان_زن_پوست_سفید:',
        'id': ':pemadam_kebakaran_wanita_warna_kulit_cerah:',
        'zh': u':女消防员_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F692': { # 👩🏾‍🚒
        'en' : ':woman_firefighter_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrfrau_mitteldunkle_hautfarbe:',
        'es': ':bombera_tono_de_piel_oscuro_medio:',
        'fr': ':pompier_femme_peau_mate:',
        'ja': u':女性消防士_やや濃い肌色:',
        'ko': u':여자_소방관_진한_갈색_피부:',
        'pt': ':bombeira_pele_morena_escura:',
        'it': ':pompiere_donna_carnagione_abbastanza_scura:',
        'fa': u':آتش_نشان_زن_پوست_گندمی:',
        'id': ':pemadam_kebakaran_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女消防员_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F692': { # 👩🏼‍🚒
        'en' : ':woman_firefighter_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrfrau_mittelhelle_hautfarbe:',
        'es': ':bombera_tono_de_piel_claro_medio:',
        'fr': ':pompier_femme_peau_moyennement_claire:',
        'ja': u':女性消防士_やや薄い肌色:',
        'ko': u':여자_소방관_연한_갈색_피부:',
        'pt': ':bombeira_pele_morena_clara:',
        'it': ':pompiere_donna_carnagione_abbastanza_chiara:',
        'fa': u':آتش_نشان_زن_پوست_روشن:',
        'id': ':pemadam_kebakaran_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女消防员_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F692': { # 👩🏽‍🚒
        'en' : ':woman_firefighter_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':feuerwehrfrau_mittlere_hautfarbe:',
        'es': ':bombera_tono_de_piel_medio:',
        'fr': u':pompier_femme_peau_légèrement_mate:',
        'ja': u':女性消防士_中間の肌色:',
        'ko': u':여자_소방관_갈색_피부:',
        'pt': ':bombeira_pele_morena:',
        'it': ':pompiere_donna_carnagione_olivastra:',
        'fa': u':آتش_نشان_زن_پوست_طلایی:',
        'id': ':pemadam_kebakaran_wanita_warna_kulit_sedang:',
        'zh': u':女消防员_中等肤色:'
    },
    u'\U0001F64D\U0000200D\U00002640\U0000FE0F': { # 🙍‍♀️
        'en' : ':woman_frowning:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':frowning_woman:'],
        'de': ':missmutige_frau:',
        'es': u':mujer_frunciendo_el_ceño:',
        'fr': u':femme_fronçant_les_sourcils:',
        'ja': u':しかめ面の女:',
        'ko': u':찌푸린_여자:',
        'pt': ':mulher_franzindo_a_sobrancelha:',
        'it': ':donna_corrucciata:',
        'fa': u':زن_اخم_می_کند:',
        'id': ':wanita_muka_tidak_senang:',
        'zh': u':皱眉女:'
    },
    u'\U0001F64D\U0000200D\U00002640': { # 🙍‍♀
        'en' : ':woman_frowning:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':frowning_woman:'],
        'de': ':missmutige_frau:',
        'es': u':mujer_frunciendo_el_ceño:',
        'fr': u':femme_fronçant_les_sourcils:',
        'ja': u':しかめ面の女:',
        'ko': u':찌푸린_여자:',
        'pt': ':mulher_franzindo_a_sobrancelha:',
        'it': ':donna_corrucciata:',
        'fa': u':زن_اخم_می_کند:',
        'id': ':wanita_muka_tidak_senang:',
        'zh': u':皱眉女:'
    },
    u'\U0001F64D\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🙍🏿‍♀️
        'en' : ':woman_frowning_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutige_frau_dunkle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_oscuro:',
        'fr': u':femme_fronçant_les_sourcils_peau_foncée:',
        'ja': u':しかめ面の女_濃い肌色:',
        'ko': u':찌푸린_여자_검은색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_escura:',
        'it': ':donna_corrucciata_carnagione_scura:',
        'fa': u':زن_اخم_می_کند_پوست_آبنوسی:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_gelap:',
        'zh': u':皱眉女_较深肤色:'
    },
    u'\U0001F64D\U0001F3FF\U0000200D\U00002640': { # 🙍🏿‍♀
        'en' : ':woman_frowning_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutige_frau_dunkle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_oscuro:',
        'fr': u':femme_fronçant_les_sourcils_peau_foncée:',
        'ja': u':しかめ面の女_濃い肌色:',
        'ko': u':찌푸린_여자_검은색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_escura:',
        'it': ':donna_corrucciata_carnagione_scura:',
        'fa': u':زن_اخم_می_کند_پوست_آبنوسی:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_gelap:',
        'zh': u':皱眉女_较深肤色:'
    },
    u'\U0001F64D\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🙍🏻‍♀️
        'en' : ':woman_frowning_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutige_frau_helle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_claro:',
        'fr': u':femme_fronçant_les_sourcils_peau_claire:',
        'ja': u':しかめ面の女_薄い肌色:',
        'ko': u':찌푸린_여자_하얀_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_clara:',
        'it': ':donna_corrucciata_carnagione_chiara:',
        'fa': u':زن_اخم_می_کند_پوست_سفید:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_cerah:',
        'zh': u':皱眉女_较浅肤色:'
    },
    u'\U0001F64D\U0001F3FB\U0000200D\U00002640': { # 🙍🏻‍♀
        'en' : ':woman_frowning_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutige_frau_helle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_claro:',
        'fr': u':femme_fronçant_les_sourcils_peau_claire:',
        'ja': u':しかめ面の女_薄い肌色:',
        'ko': u':찌푸린_여자_하얀_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_clara:',
        'it': ':donna_corrucciata_carnagione_chiara:',
        'fa': u':زن_اخم_می_کند_پوست_سفید:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_cerah:',
        'zh': u':皱眉女_较浅肤色:'
    },
    u'\U0001F64D\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🙍🏾‍♀️
        'en' : ':woman_frowning_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutige_frau_mitteldunkle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_oscuro_medio:',
        'fr': u':femme_fronçant_les_sourcils_peau_mate:',
        'ja': u':しかめ面の女_やや濃い肌色:',
        'ko': u':찌푸린_여자_진한_갈색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_morena_escura:',
        'it': ':donna_corrucciata_carnagione_abbastanza_scura:',
        'fa': u':زن_اخم_می_کند_پوست_گندمی:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':皱眉女_中等深肤色:'
    },
    u'\U0001F64D\U0001F3FE\U0000200D\U00002640': { # 🙍🏾‍♀
        'en' : ':woman_frowning_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutige_frau_mitteldunkle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_oscuro_medio:',
        'fr': u':femme_fronçant_les_sourcils_peau_mate:',
        'ja': u':しかめ面の女_やや濃い肌色:',
        'ko': u':찌푸린_여자_진한_갈색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_morena_escura:',
        'it': ':donna_corrucciata_carnagione_abbastanza_scura:',
        'fa': u':زن_اخم_می_کند_پوست_گندمی:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':皱眉女_中等深肤色:'
    },
    u'\U0001F64D\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🙍🏼‍♀️
        'en' : ':woman_frowning_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutige_frau_mittelhelle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_claro_medio:',
        'fr': u':femme_fronçant_les_sourcils_peau_moyennement_claire:',
        'ja': u':しかめ面の女_やや薄い肌色:',
        'ko': u':찌푸린_여자_연한_갈색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_morena_clara:',
        'it': ':donna_corrucciata_carnagione_abbastanza_chiara:',
        'fa': u':زن_اخم_می_کند_پوست_روشن:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':皱眉女_中等浅肤色:'
    },
    u'\U0001F64D\U0001F3FC\U0000200D\U00002640': { # 🙍🏼‍♀
        'en' : ':woman_frowning_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutige_frau_mittelhelle_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_claro_medio:',
        'fr': u':femme_fronçant_les_sourcils_peau_moyennement_claire:',
        'ja': u':しかめ面の女_やや薄い肌色:',
        'ko': u':찌푸린_여자_연한_갈색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_morena_clara:',
        'it': ':donna_corrucciata_carnagione_abbastanza_chiara:',
        'fa': u':زن_اخم_می_کند_پوست_روشن:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':皱眉女_中等浅肤色:'
    },
    u'\U0001F64D\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🙍🏽‍♀️
        'en' : ':woman_frowning_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':missmutige_frau_mittlere_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_medio:',
        'fr': u':femme_fronçant_les_sourcils_peau_légèrement_mate:',
        'ja': u':しかめ面の女_中間の肌色:',
        'ko': u':찌푸린_여자_갈색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_morena:',
        'it': ':donna_corrucciata_carnagione_olivastra:',
        'fa': u':زن_اخم_می_کند_پوست_طلایی:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_sedang:',
        'zh': u':皱眉女_中等肤色:'
    },
    u'\U0001F64D\U0001F3FD\U0000200D\U00002640': { # 🙍🏽‍♀
        'en' : ':woman_frowning_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':missmutige_frau_mittlere_hautfarbe:',
        'es': u':mujer_frunciendo_el_ceño_tono_de_piel_medio:',
        'fr': u':femme_fronçant_les_sourcils_peau_légèrement_mate:',
        'ja': u':しかめ面の女_中間の肌色:',
        'ko': u':찌푸린_여자_갈색_피부:',
        'pt': ':mulher_franzindo_a_sobrancelha_pele_morena:',
        'it': ':donna_corrucciata_carnagione_olivastra:',
        'fa': u':زن_اخم_می_کند_پوست_طلایی:',
        'id': ':wanita_muka_tidak_senang_warna_kulit_sedang:',
        'zh': u':皱眉女_中等肤色:'
    },
    u'\U0001F9DE\U0000200D\U00002640\U0000FE0F': { # 🧞‍♀️
        'en' : ':woman_genie:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':genie_woman:'],
        'de': ':weiblicher_flaschengeist:',
        'es': ':genio_mujer:',
        'fr': u':génie_femme:',
        'ja': u':女の精霊:',
        'ko': u':여자_지니:',
        'pt': u':mulher_gênio:',
        'it': ':genio_donna:',
        'fa': u':زن_جن:',
        'id': ':jin_wanita:',
        'zh': u':女妖怪:'
    },
    u'\U0001F9DE\U0000200D\U00002640': { # 🧞‍♀
        'en' : ':woman_genie:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':genie_woman:'],
        'de': ':weiblicher_flaschengeist:',
        'es': ':genio_mujer:',
        'fr': u':génie_femme:',
        'ja': u':女の精霊:',
        'ko': u':여자_지니:',
        'pt': u':mulher_gênio:',
        'it': ':genio_donna:',
        'fa': u':زن_جن:',
        'id': ':jin_wanita:',
        'zh': u':女妖怪:'
    },
    u'\U0001F645\U0000200D\U00002640\U0000FE0F': { # 🙅‍♀️
        'en' : ':woman_gesturing_NO:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':ng_woman:', ':no_good_woman:'],
        'de': u':frau_mit_überkreuzten_armen:',
        'es': ':mujer_haciendo_el_gesto_de_no:',
        'fr': u':femme_faisant_un_geste_d’interdiction:',
        'ja': u':ダメのポーズをする女:',
        'ko': u':안_된다는_제스처를_하는_여자:',
        'pt': u':mulher_fazendo_gesto_de_“não”:',
        'it': ':donna_con_gesto_di_rifiuto:',
        'fa': u':زن_نمی_پذیرد:',
        'id': ':wanita_mengisyaratkan_tidak:',
        'zh': u':禁止手势女:'
    },
    u'\U0001F645\U0000200D\U00002640': { # 🙅‍♀
        'en' : ':woman_gesturing_NO:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':ng_woman:', ':no_good_woman:'],
        'de': u':frau_mit_überkreuzten_armen:',
        'es': ':mujer_haciendo_el_gesto_de_no:',
        'fr': u':femme_faisant_un_geste_d’interdiction:',
        'ja': u':ダメのポーズをする女:',
        'ko': u':안_된다는_제스처를_하는_여자:',
        'pt': u':mulher_fazendo_gesto_de_“não”:',
        'it': ':donna_con_gesto_di_rifiuto:',
        'fa': u':زن_نمی_پذیرد:',
        'id': ':wanita_mengisyaratkan_tidak:',
        'zh': u':禁止手势女:'
    },
    u'\U0001F645\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🙅🏿‍♀️
        'en' : ':woman_gesturing_NO_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_oscuro:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_foncée:',
        'ja': u':ダメのポーズをする女_濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_검은색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_escura:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_scura:',
        'fa': u':زن_نمی_پذیرد_پوست_آبنوسی:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_gelap:',
        'zh': u':禁止手势女_较深肤色:'
    },
    u'\U0001F645\U0001F3FF\U0000200D\U00002640': { # 🙅🏿‍♀
        'en' : ':woman_gesturing_NO_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_oscuro:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_foncée:',
        'ja': u':ダメのポーズをする女_濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_검은색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_escura:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_scura:',
        'fa': u':زن_نمی_پذیرد_پوست_آبنوسی:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_gelap:',
        'zh': u':禁止手势女_较深肤色:'
    },
    u'\U0001F645\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🙅🏻‍♀️
        'en' : ':woman_gesturing_NO_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_helle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_claro:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_claire:',
        'ja': u':ダメのポーズをする女_薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_하얀_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_clara:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_chiara:',
        'fa': u':زن_نمی_پذیرد_پوست_سفید:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_cerah:',
        'zh': u':禁止手势女_较浅肤色:'
    },
    u'\U0001F645\U0001F3FB\U0000200D\U00002640': { # 🙅🏻‍♀
        'en' : ':woman_gesturing_NO_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_helle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_claro:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_claire:',
        'ja': u':ダメのポーズをする女_薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_하얀_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_clara:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_chiara:',
        'fa': u':زن_نمی_پذیرد_پوست_سفید:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_cerah:',
        'zh': u':禁止手势女_较浅肤色:'
    },
    u'\U0001F645\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🙅🏾‍♀️
        'en' : ':woman_gesturing_NO_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_oscuro_medio:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_mate:',
        'ja': u':ダメのポーズをする女_やや濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_진한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_morena_escura:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_abbastanza_scura:',
        'fa': u':زن_نمی_پذیرد_پوست_گندمی:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_gelap-sedang:',
        'zh': u':禁止手势女_中等深肤色:'
    },
    u'\U0001F645\U0001F3FE\U0000200D\U00002640': { # 🙅🏾‍♀
        'en' : ':woman_gesturing_NO_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_oscuro_medio:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_mate:',
        'ja': u':ダメのポーズをする女_やや濃い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_진한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_morena_escura:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_abbastanza_scura:',
        'fa': u':زن_نمی_پذیرد_پوست_گندمی:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_gelap-sedang:',
        'zh': u':禁止手势女_中等深肤色:'
    },
    u'\U0001F645\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🙅🏼‍♀️
        'en' : ':woman_gesturing_NO_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_claro_medio:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_moyennement_claire:',
        'ja': u':ダメのポーズをする女_やや薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_연한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_morena_clara:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_abbastanza_chiara:',
        'fa': u':زن_نمی_پذیرد_پوست_روشن:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_cerah-sedang:',
        'zh': u':禁止手势女_中等浅肤色:'
    },
    u'\U0001F645\U0001F3FC\U0000200D\U00002640': { # 🙅🏼‍♀
        'en' : ':woman_gesturing_NO_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_claro_medio:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_moyennement_claire:',
        'ja': u':ダメのポーズをする女_やや薄い肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_연한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_morena_clara:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_abbastanza_chiara:',
        'fa': u':زن_نمی_پذیرد_پوست_روشن:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_cerah-sedang:',
        'zh': u':禁止手势女_中等浅肤色:'
    },
    u'\U0001F645\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🙅🏽‍♀️
        'en' : ':woman_gesturing_NO_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_medio:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_légèrement_mate:',
        'ja': u':ダメのポーズをする女_中間の肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_morena:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_olivastra:',
        'fa': u':زن_نمی_پذیرد_پوست_طلایی:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_sedang:',
        'zh': u':禁止手势女_中等肤色:'
    },
    u'\U0001F645\U0001F3FD\U0000200D\U00002640': { # 🙅🏽‍♀
        'en' : ':woman_gesturing_NO_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_überkreuzten_armen_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_no_tono_de_piel_medio:',
        'fr': u':femme_faisant_un_geste_d’interdiction_peau_légèrement_mate:',
        'ja': u':ダメのポーズをする女_中間の肌色:',
        'ko': u':안_된다는_제스처를_하는_여자_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“não”_pele_morena:',
        'it': ':donna_con_gesto_di_rifiuto_carnagione_olivastra:',
        'fa': u':زن_نمی_پذیرد_پوست_طلایی:',
        'id': ':wanita_mengisyaratkan_tidak_warna_kulit_sedang:',
        'zh': u':禁止手势女_中等肤色:'
    },
    u'\U0001F646\U0000200D\U00002640\U0000FE0F': { # 🙆‍♀️
        'en' : ':woman_gesturing_OK:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':ok_woman:'],
        'de': u':frau_mit_händen_auf_dem_kopf:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo:',
        'fr': u':femme_faisant_un_geste_d’acceptation:',
        'ja': u':okのポーズをする女:',
        'ko': u':오케이라는_제스처를_하는_여자:',
        'pt': u':mulher_fazendo_gesto_de_“ok”:',
        'it': ':donna_con_gesto_ok:',
        'fa': u':زن_می_پذیرد:',
        'id': ':wanita_mengisyaratkan_oke:',
        'zh': u':OK手势女:'
    },
    u'\U0001F646\U0000200D\U00002640': { # 🙆‍♀
        'en' : ':woman_gesturing_OK:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':ok_woman:'],
        'de': u':frau_mit_händen_auf_dem_kopf:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo:',
        'fr': u':femme_faisant_un_geste_d’acceptation:',
        'ja': u':okのポーズをする女:',
        'ko': u':오케이라는_제스처를_하는_여자:',
        'pt': u':mulher_fazendo_gesto_de_“ok”:',
        'it': ':donna_con_gesto_ok:',
        'fa': u':زن_می_پذیرد:',
        'id': ':wanita_mengisyaratkan_oke:',
        'zh': u':OK手势女:'
    },
    u'\U0001F646\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🙆🏿‍♀️
        'en' : ':woman_gesturing_OK_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_foncée:',
        'ja': u':okのポーズをする女_濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_검은색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_escura:',
        'it': ':donna_con_gesto_ok_carnagione_scura:',
        'fa': u':زن_می_پذیرد_پوست_آبنوسی:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_gelap:',
        'zh': u':OK手势女_较深肤色:'
    },
    u'\U0001F646\U0001F3FF\U0000200D\U00002640': { # 🙆🏿‍♀
        'en' : ':woman_gesturing_OK_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_foncée:',
        'ja': u':okのポーズをする女_濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_검은색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_escura:',
        'it': ':donna_con_gesto_ok_carnagione_scura:',
        'fa': u':زن_می_پذیرد_پوست_آبنوسی:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_gelap:',
        'zh': u':OK手势女_较深肤色:'
    },
    u'\U0001F646\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🙆🏻‍♀️
        'en' : ':woman_gesturing_OK_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_helle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_claire:',
        'ja': u':okのポーズをする女_薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_하얀_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_clara:',
        'it': ':donna_con_gesto_ok_carnagione_chiara:',
        'fa': u':زن_می_پذیرد_پوست_سفید:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_cerah:',
        'zh': u':OK手势女_较浅肤色:'
    },
    u'\U0001F646\U0001F3FB\U0000200D\U00002640': { # 🙆🏻‍♀
        'en' : ':woman_gesturing_OK_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_helle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_claire:',
        'ja': u':okのポーズをする女_薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_하얀_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_clara:',
        'it': ':donna_con_gesto_ok_carnagione_chiara:',
        'fa': u':زن_می_پذیرد_پوست_سفید:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_cerah:',
        'zh': u':OK手势女_较浅肤色:'
    },
    u'\U0001F646\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🙆🏾‍♀️
        'en' : ':woman_gesturing_OK_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro_medio:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_mate:',
        'ja': u':okのポーズをする女_やや濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_진한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_morena_escura:',
        'it': ':donna_con_gesto_ok_carnagione_abbastanza_scura:',
        'fa': u':زن_می_پذیرد_پوست_گندمی:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_gelap-sedang:',
        'zh': u':OK手势女_中等深肤色:'
    },
    u'\U0001F646\U0001F3FE\U0000200D\U00002640': { # 🙆🏾‍♀
        'en' : ':woman_gesturing_OK_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_oscuro_medio:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_mate:',
        'ja': u':okのポーズをする女_やや濃い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_진한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_morena_escura:',
        'it': ':donna_con_gesto_ok_carnagione_abbastanza_scura:',
        'fa': u':زن_می_پذیرد_پوست_گندمی:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_gelap-sedang:',
        'zh': u':OK手势女_中等深肤色:'
    },
    u'\U0001F646\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🙆🏼‍♀️
        'en' : ':woman_gesturing_OK_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro_medio:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_moyennement_claire:',
        'ja': u':okのポーズをする女_やや薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_연한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_morena_clara:',
        'it': ':donna_con_gesto_ok_carnagione_abbastanza_chiara:',
        'fa': u':زن_می_پذیرد_پوست_روشن:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_cerah-sedang:',
        'zh': u':OK手势女_中等浅肤色:'
    },
    u'\U0001F646\U0001F3FC\U0000200D\U00002640': { # 🙆🏼‍♀
        'en' : ':woman_gesturing_OK_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_claro_medio:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_moyennement_claire:',
        'ja': u':okのポーズをする女_やや薄い肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_연한_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_morena_clara:',
        'it': ':donna_con_gesto_ok_carnagione_abbastanza_chiara:',
        'fa': u':زن_می_پذیرد_پوست_روشن:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_cerah-sedang:',
        'zh': u':OK手势女_中等浅肤色:'
    },
    u'\U0001F646\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🙆🏽‍♀️
        'en' : ':woman_gesturing_OK_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_medio:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_légèrement_mate:',
        'ja': u':okのポーズをする女_中間の肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_morena:',
        'it': ':donna_con_gesto_ok_carnagione_olivastra:',
        'fa': u':زن_می_پذیرد_پوست_طلایی:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_sedang:',
        'zh': u':OK手势女_中等肤色:'
    },
    u'\U0001F646\U0001F3FD\U0000200D\U00002640': { # 🙆🏽‍♀
        'en' : ':woman_gesturing_OK_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':frau_mit_händen_auf_dem_kopf_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_el_gesto_de_de_acuerdo_tono_de_piel_medio:',
        'fr': u':femme_faisant_un_geste_d’acceptation_peau_légèrement_mate:',
        'ja': u':okのポーズをする女_中間の肌色:',
        'ko': u':오케이라는_제스처를_하는_여자_갈색_피부:',
        'pt': u':mulher_fazendo_gesto_de_“ok”_pele_morena:',
        'it': ':donna_con_gesto_ok_carnagione_olivastra:',
        'fa': u':زن_می_پذیرد_پوست_طلایی:',
        'id': ':wanita_mengisyaratkan_oke_warna_kulit_sedang:',
        'zh': u':OK手势女_中等肤色:'
    },
    u'\U0001F487\U0000200D\U00002640\U0000FE0F': { # 💇‍♀️
        'en' : ':woman_getting_haircut:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':haircut_woman:'],
        'de': ':frau_beim_haareschneiden:',
        'es': u':mujer_cortándose_el_pelo:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux:',
        'ja': u':散髪される女:',
        'ko': u':여자_헤어컷:',
        'pt': ':mulher_cortando_o_cabelo:',
        'it': ':taglio_di_capelli_per_donna:',
        'fa': u':زن_مو_کوتاه_می_کند:',
        'id': ':wanita_potong_rambut:',
        'zh': u':女生理发:'
    },
    u'\U0001F487\U0000200D\U00002640': { # 💇‍♀
        'en' : ':woman_getting_haircut:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':haircut_woman:'],
        'de': ':frau_beim_haareschneiden:',
        'es': u':mujer_cortándose_el_pelo:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux:',
        'ja': u':散髪される女:',
        'ko': u':여자_헤어컷:',
        'pt': ':mulher_cortando_o_cabelo:',
        'it': ':taglio_di_capelli_per_donna:',
        'fa': u':زن_مو_کوتاه_می_کند:',
        'id': ':wanita_potong_rambut:',
        'zh': u':女生理发:'
    },
    u'\U0001F487\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 💇🏿‍♀️
        'en' : ':woman_getting_haircut_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_dunkle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_oscuro:',
        'fr': u':femme_qui_se_fait_couper_les_cheveux_peau_foncée:',
        'ja': u':散髪される女_濃い肌色:',
        'ko': u':여자_헤어컷_검은색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_escura:',
        'it': ':taglio_di_capelli_per_donna_carnagione_scura:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_آبنوسی:',
        'id': ':wanita_potong_rambut_warna_kulit_gelap:',
        'zh': u':女生理发_较深肤色:'
    },
    u'\U0001F487\U0001F3FF\U0000200D\U00002640': { # 💇🏿‍♀
        'en' : ':woman_getting_haircut_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_dunkle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_oscuro:',
        'fr': u':femme_qui_se_fait_couper_les_cheveux_peau_foncée:',
        'ja': u':散髪される女_濃い肌色:',
        'ko': u':여자_헤어컷_검은색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_escura:',
        'it': ':taglio_di_capelli_per_donna_carnagione_scura:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_آبنوسی:',
        'id': ':wanita_potong_rambut_warna_kulit_gelap:',
        'zh': u':女生理发_较深肤色:'
    },
    u'\U0001F487\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 💇🏻‍♀️
        'en' : ':woman_getting_haircut_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_helle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_claro:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux_peau_claire:',
        'ja': u':散髪される女_薄い肌色:',
        'ko': u':여자_헤어컷_하얀_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_clara:',
        'it': ':taglio_di_capelli_per_donna_carnagione_chiara:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_سفید:',
        'id': ':wanita_potong_rambut_warna_kulit_cerah:',
        'zh': u':女生理发_较浅肤色:'
    },
    u'\U0001F487\U0001F3FB\U0000200D\U00002640': { # 💇🏻‍♀
        'en' : ':woman_getting_haircut_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_helle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_claro:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux_peau_claire:',
        'ja': u':散髪される女_薄い肌色:',
        'ko': u':여자_헤어컷_하얀_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_clara:',
        'it': ':taglio_di_capelli_per_donna_carnagione_chiara:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_سفید:',
        'id': ':wanita_potong_rambut_warna_kulit_cerah:',
        'zh': u':女生理发_较浅肤色:'
    },
    u'\U0001F487\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 💇🏾‍♀️
        'en' : ':woman_getting_haircut_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_mitteldunkle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux_peau_mate:',
        'ja': u':散髪される女_やや濃い肌色:',
        'ko': u':여자_헤어컷_진한_갈색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_morena_escura:',
        'it': ':taglio_di_capelli_per_donna_carnagione_abbastanza_scura:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_گندمی:',
        'id': ':wanita_potong_rambut_warna_kulit_gelap-sedang:',
        'zh': u':女生理发_中等深肤色:'
    },
    u'\U0001F487\U0001F3FE\U0000200D\U00002640': { # 💇🏾‍♀
        'en' : ':woman_getting_haircut_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_mitteldunkle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux_peau_mate:',
        'ja': u':散髪される女_やや濃い肌色:',
        'ko': u':여자_헤어컷_진한_갈색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_morena_escura:',
        'it': ':taglio_di_capelli_per_donna_carnagione_abbastanza_scura:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_گندمی:',
        'id': ':wanita_potong_rambut_warna_kulit_gelap-sedang:',
        'zh': u':女生理发_中等深肤色:'
    },
    u'\U0001F487\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 💇🏼‍♀️
        'en' : ':woman_getting_haircut_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_mittelhelle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux_peau_moyennement_claire:',
        'ja': u':散髪される女_やや薄い肌色:',
        'ko': u':여자_헤어컷_연한_갈색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_morena_clara:',
        'it': ':taglio_di_capelli_per_donna_carnagione_abbastanza_chiara:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_روشن:',
        'id': ':wanita_potong_rambut_warna_kulit_cerah-sedang:',
        'zh': u':女生理发_中等浅肤色:'
    },
    u'\U0001F487\U0001F3FC\U0000200D\U00002640': { # 💇🏼‍♀
        'en' : ':woman_getting_haircut_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_mittelhelle_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_se_fait_couper_les_cheveux_peau_moyennement_claire:',
        'ja': u':散髪される女_やや薄い肌色:',
        'ko': u':여자_헤어컷_연한_갈색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_morena_clara:',
        'it': ':taglio_di_capelli_per_donna_carnagione_abbastanza_chiara:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_روشن:',
        'id': ':wanita_potong_rambut_warna_kulit_cerah-sedang:',
        'zh': u':女生理发_中等浅肤色:'
    },
    u'\U0001F487\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 💇🏽‍♀️
        'en' : ':woman_getting_haircut_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_mittlere_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_medio:',
        'fr': u':femme_qui_se_fait_couper_les_cheveux_peau_légèrement_mate:',
        'ja': u':散髪される女_中間の肌色:',
        'ko': u':여자_헤어컷_갈색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_morena:',
        'it': ':taglio_di_capelli_per_donna_carnagione_olivastra:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_طلایی:',
        'id': ':wanita_potong_rambut_warna_kulit_sedang:',
        'zh': u':女生理发_中等肤色:'
    },
    u'\U0001F487\U0001F3FD\U0000200D\U00002640': { # 💇🏽‍♀
        'en' : ':woman_getting_haircut_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_beim_haareschneiden_mittlere_hautfarbe:',
        'es': u':mujer_cortándose_el_pelo_tono_de_piel_medio:',
        'fr': u':femme_qui_se_fait_couper_les_cheveux_peau_légèrement_mate:',
        'ja': u':散髪される女_中間の肌色:',
        'ko': u':여자_헤어컷_갈색_피부:',
        'pt': ':mulher_cortando_o_cabelo_pele_morena:',
        'it': ':taglio_di_capelli_per_donna_carnagione_olivastra:',
        'fa': u':زن_مو_کوتاه_می_کند_پوست_طلایی:',
        'id': ':wanita_potong_rambut_warna_kulit_sedang:',
        'zh': u':女生理发_中等肤色:'
    },
    u'\U0001F486\U0000200D\U00002640\U0000FE0F': { # 💆‍♀️
        'en' : ':woman_getting_massage:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':massage_woman:'],
        'de': ':frau,_die_eine_kopfmassage_bekommt:',
        'es': ':mujer_recibiendo_masaje:',
        'fr': ':femme_qui_se_fait_masser:',
        'ja': u':フェイスマッサージ中の女:',
        'ko': u':마사지_받는_여자:',
        'pt': ':mulher_recebendo_massagem_facial:',
        'it': ':donna_che_riceve_un_massaggio:',
        'fa': u':ماساژ_صورت_زن:',
        'id': ':wanita_dipijat:',
        'zh': u':女生按摩:'
    },
    u'\U0001F486\U0000200D\U00002640': { # 💆‍♀
        'en' : ':woman_getting_massage:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':massage_woman:'],
        'de': ':frau_die_eine_kopfmassage_bekommt:',
        'es': ':mujer_recibiendo_masaje:',
        'fr': ':femme_qui_se_fait_masser:',
        'ja': u':フェイスマッサージ中の女:',
        'ko': u':마사지_받는_여자:',
        'pt': ':mulher_recebendo_massagem_facial:',
        'it': ':donna_che_riceve_un_massaggio:',
        'fa': u':ماساژ_صورت_زن:',
        'id': ':wanita_dipijat:',
        'zh': u':女生按摩:'
    },
    u'\U0001F486\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 💆🏿‍♀️
        'en' : ':woman_getting_massage_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_dunkle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_oscuro:',
        'fr': u':femme_qui_se_fait_masser_peau_foncée:',
        'ja': u':フェイスマッサージ中の女_濃い肌色:',
        'ko': u':마사지_받는_여자_검은색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_escura:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_scura:',
        'fa': u':ماساژ_صورت_زن_پوست_آبنوسی:',
        'id': ':wanita_dipijat_warna_kulit_gelap:',
        'zh': u':女生按摩_较深肤色:'
    },
    u'\U0001F486\U0001F3FF\U0000200D\U00002640': { # 💆🏿‍♀
        'en' : ':woman_getting_massage_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_dunkle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_oscuro:',
        'fr': u':femme_qui_se_fait_masser_peau_foncée:',
        'ja': u':フェイスマッサージ中の女_濃い肌色:',
        'ko': u':마사지_받는_여자_검은색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_escura:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_scura:',
        'fa': u':ماساژ_صورت_زن_پوست_آبنوسی:',
        'id': ':wanita_dipijat_warna_kulit_gelap:',
        'zh': u':女生按摩_较深肤色:'
    },
    u'\U0001F486\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 💆🏻‍♀️
        'en' : ':woman_getting_massage_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_helle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_claro:',
        'fr': ':femme_qui_se_fait_masser_peau_claire:',
        'ja': u':フェイスマッサージ中の女_薄い肌色:',
        'ko': u':마사지_받는_여자_하얀_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_clara:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_chiara:',
        'fa': u':ماساژ_صورت_زن_پوست_سفید:',
        'id': ':wanita_dipijat_warna_kulit_cerah:',
        'zh': u':女生按摩_较浅肤色:'
    },
    u'\U0001F486\U0001F3FB\U0000200D\U00002640': { # 💆🏻‍♀
        'en' : ':woman_getting_massage_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_helle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_claro:',
        'fr': ':femme_qui_se_fait_masser_peau_claire:',
        'ja': u':フェイスマッサージ中の女_薄い肌色:',
        'ko': u':마사지_받는_여자_하얀_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_clara:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_chiara:',
        'fa': u':ماساژ_صورت_زن_پوست_سفید:',
        'id': ':wanita_dipijat_warna_kulit_cerah:',
        'zh': u':女生按摩_较浅肤色:'
    },
    u'\U0001F486\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 💆🏾‍♀️
        'en' : ':woman_getting_massage_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_mitteldunkle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_se_fait_masser_peau_mate:',
        'ja': u':フェイスマッサージ中の女_やや濃い肌色:',
        'ko': u':마사지_받는_여자_진한_갈색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_morena_escura:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_abbastanza_scura:',
        'fa': u':ماساژ_صورت_زن_پوست_گندمی:',
        'id': ':wanita_dipijat_warna_kulit_gelap-sedang:',
        'zh': u':女生按摩_中等深肤色:'
    },
    u'\U0001F486\U0001F3FE\U0000200D\U00002640': { # 💆🏾‍♀
        'en' : ':woman_getting_massage_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_mitteldunkle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_se_fait_masser_peau_mate:',
        'ja': u':フェイスマッサージ中の女_やや濃い肌色:',
        'ko': u':마사지_받는_여자_진한_갈색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_morena_escura:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_abbastanza_scura:',
        'fa': u':ماساژ_صورت_زن_پوست_گندمی:',
        'id': ':wanita_dipijat_warna_kulit_gelap-sedang:',
        'zh': u':女生按摩_中等深肤色:'
    },
    u'\U0001F486\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 💆🏼‍♀️
        'en' : ':woman_getting_massage_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_mittelhelle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_se_fait_masser_peau_moyennement_claire:',
        'ja': u':フェイスマッサージ中の女_やや薄い肌色:',
        'ko': u':마사지_받는_여자_연한_갈색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_morena_clara:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_abbastanza_chiara:',
        'fa': u':ماساژ_صورت_زن_پوست_روشن:',
        'id': ':wanita_dipijat_warna_kulit_cerah-sedang:',
        'zh': u':女生按摩_中等浅肤色:'
    },
    u'\U0001F486\U0001F3FC\U0000200D\U00002640': { # 💆🏼‍♀
        'en' : ':woman_getting_massage_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_mittelhelle_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_se_fait_masser_peau_moyennement_claire:',
        'ja': u':フェイスマッサージ中の女_やや薄い肌色:',
        'ko': u':마사지_받는_여자_연한_갈색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_morena_clara:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_abbastanza_chiara:',
        'fa': u':ماساژ_صورت_زن_پوست_روشن:',
        'id': ':wanita_dipijat_warna_kulit_cerah-sedang:',
        'zh': u':女生按摩_中等浅肤色:'
    },
    u'\U0001F486\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 💆🏽‍♀️
        'en' : ':woman_getting_massage_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_mittlere_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_medio:',
        'fr': u':femme_qui_se_fait_masser_peau_légèrement_mate:',
        'ja': u':フェイスマッサージ中の女_中間の肌色:',
        'ko': u':마사지_받는_여자_갈색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_morena:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_olivastra:',
        'fa': u':ماساژ_صورت_زن_پوست_طلایی:',
        'id': ':wanita_dipijat_warna_kulit_sedang:',
        'zh': u':女生按摩_中等肤色:'
    },
    u'\U0001F486\U0001F3FD\U0000200D\U00002640': { # 💆🏽‍♀
        'en' : ':woman_getting_massage_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau,_die_eine_kopfmassage_bekommt_mittlere_hautfarbe:',
        'es': ':mujer_recibiendo_masaje_tono_de_piel_medio:',
        'fr': u':femme_qui_se_fait_masser_peau_légèrement_mate:',
        'ja': u':フェイスマッサージ中の女_中間の肌色:',
        'ko': u':마사지_받는_여자_갈색_피부:',
        'pt': ':mulher_recebendo_massagem_facial_pele_morena:',
        'it': ':donna_che_riceve_un_massaggio_carnagione_olivastra:',
        'fa': u':ماساژ_صورت_زن_پوست_طلایی:',
        'id': ':wanita_dipijat_warna_kulit_sedang:',
        'zh': u':女生按摩_中等肤色:'
    },
    u'\U0001F3CC\U0000FE0F\U0000200D\U00002640\U0000FE0F': { # 🏌️‍♀️
        'en' : ':woman_golfing:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':golfing_woman:'],
        'de': ':golferin:',
        'es': ':mujer_jugando_al_golf:',
        'fr': ':golfeuse:',
        'ja': u':ゴルフをする女:',
        'ko': u':골프치는_여자:',
        'pt': ':mulher_golfista:',
        'it': ':golfista_donna:',
        'fa': u':گلف_باز_زن:',
        'id': ':wanita_bermain_golf:',
        'zh': u':女生打高尔夫:'
    },
    u'\U0001F3CC\U0000200D\U00002640\U0000FE0F': { # 🏌‍♀️
        'en' : ':woman_golfing:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':golfing_woman:'],
        'de': ':golferin:',
        'es': ':mujer_jugando_al_golf:',
        'fr': ':golfeuse:',
        'ja': u':ゴルフをする女:',
        'ko': u':골프치는_여자:',
        'pt': ':mulher_golfista:',
        'it': ':golfista_donna:',
        'fa': u':گلف_باز_زن:',
        'id': ':wanita_bermain_golf:',
        'zh': u':女生打高尔夫:'
    },
    u'\U0001F3CC\U0000FE0F\U0000200D\U00002640': { # 🏌️‍♀
        'en' : ':woman_golfing:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':golfing_woman:'],
        'de': ':golferin:',
        'es': ':mujer_jugando_al_golf:',
        'fr': ':golfeuse:',
        'ja': u':ゴルフをする女:',
        'ko': u':골프치는_여자:',
        'pt': ':mulher_golfista:',
        'it': ':golfista_donna:',
        'fa': u':گلف_باز_زن:',
        'id': ':wanita_bermain_golf:',
        'zh': u':女生打高尔夫:'
    },
    u'\U0001F3CC\U0000200D\U00002640': { # 🏌‍♀
        'en' : ':woman_golfing:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':golfing_woman:'],
        'de': ':golferin:',
        'es': ':mujer_jugando_al_golf:',
        'fr': ':golfeuse:',
        'ja': u':ゴルフをする女:',
        'ko': u':골프치는_여자:',
        'pt': ':mulher_golfista:',
        'it': ':golfista_donna:',
        'fa': u':گلف_باز_زن:',
        'id': ':wanita_bermain_golf:',
        'zh': u':女生打高尔夫:'
    },
    u'\U0001F3CC\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🏌🏿‍♀️
        'en' : ':woman_golfing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golferin_dunkle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_oscuro:',
        'fr': u':golfeuse_peau_foncée:',
        'ja': u':ゴルフをする女_濃い肌色:',
        'ko': u':골프치는_여자_검은색_피부:',
        'pt': ':mulher_golfista_pele_escura:',
        'it': ':golfista_donna_carnagione_scura:',
        'fa': u':گلف_باز_زن_پوست_آبنوسی:',
        'id': ':wanita_bermain_golf_warna_kulit_gelap:',
        'zh': u':女生打高尔夫_较深肤色:'
    },
    u'\U0001F3CC\U0001F3FF\U0000200D\U00002640': { # 🏌🏿‍♀
        'en' : ':woman_golfing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golferin_dunkle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_oscuro:',
        'fr': u':golfeuse_peau_foncée:',
        'ja': u':ゴルフをする女_濃い肌色:',
        'ko': u':골프치는_여자_검은색_피부:',
        'pt': ':mulher_golfista_pele_escura:',
        'it': ':golfista_donna_carnagione_scura:',
        'fa': u':گلف_باز_زن_پوست_آبنوسی:',
        'id': ':wanita_bermain_golf_warna_kulit_gelap:',
        'zh': u':女生打高尔夫_较深肤色:'
    },
    u'\U0001F3CC\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🏌🏻‍♀️
        'en' : ':woman_golfing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golferin_helle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_claro:',
        'fr': ':golfeuse_peau_claire:',
        'ja': u':ゴルフをする女_薄い肌色:',
        'ko': u':골프치는_여자_하얀_피부:',
        'pt': ':mulher_golfista_pele_clara:',
        'it': ':golfista_donna_carnagione_chiara:',
        'fa': u':گلف_باز_زن_پوست_سفید:',
        'id': ':wanita_bermain_golf_warna_kulit_cerah:',
        'zh': u':女生打高尔夫_较浅肤色:'
    },
    u'\U0001F3CC\U0001F3FB\U0000200D\U00002640': { # 🏌🏻‍♀
        'en' : ':woman_golfing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golferin_helle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_claro:',
        'fr': ':golfeuse_peau_claire:',
        'ja': u':ゴルフをする女_薄い肌色:',
        'ko': u':골프치는_여자_하얀_피부:',
        'pt': ':mulher_golfista_pele_clara:',
        'it': ':golfista_donna_carnagione_chiara:',
        'fa': u':گلف_باز_زن_پوست_سفید:',
        'id': ':wanita_bermain_golf_warna_kulit_cerah:',
        'zh': u':女生打高尔夫_较浅肤色:'
    },
    u'\U0001F3CC\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🏌🏾‍♀️
        'en' : ':woman_golfing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golferin_mitteldunkle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_oscuro_medio:',
        'fr': ':golfeuse_peau_mate:',
        'ja': u':ゴルフをする女_やや濃い肌色:',
        'ko': u':골프치는_여자_진한_갈색_피부:',
        'pt': ':mulher_golfista_pele_morena_escura:',
        'it': ':golfista_donna_carnagione_abbastanza_scura:',
        'fa': u':گلف_باز_زن_پوست_گندمی:',
        'id': ':wanita_bermain_golf_warna_kulit_gelap-sedang:',
        'zh': u':女生打高尔夫_中等深肤色:'
    },
    u'\U0001F3CC\U0001F3FE\U0000200D\U00002640': { # 🏌🏾‍♀
        'en' : ':woman_golfing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golferin_mitteldunkle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_oscuro_medio:',
        'fr': ':golfeuse_peau_mate:',
        'ja': u':ゴルフをする女_やや濃い肌色:',
        'ko': u':골프치는_여자_진한_갈색_피부:',
        'pt': ':mulher_golfista_pele_morena_escura:',
        'it': ':golfista_donna_carnagione_abbastanza_scura:',
        'fa': u':گلف_باز_زن_پوست_گندمی:',
        'id': ':wanita_bermain_golf_warna_kulit_gelap-sedang:',
        'zh': u':女生打高尔夫_中等深肤色:'
    },
    u'\U0001F3CC\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🏌🏼‍♀️
        'en' : ':woman_golfing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golferin_mittelhelle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_claro_medio:',
        'fr': ':golfeuse_peau_moyennement_claire:',
        'ja': u':ゴルフをする女_やや薄い肌色:',
        'ko': u':골프치는_여자_연한_갈색_피부:',
        'pt': ':mulher_golfista_pele_morena_clara:',
        'it': ':golfista_donna_carnagione_abbastanza_chiara:',
        'fa': u':گلف_باز_زن_پوست_روشن:',
        'id': ':wanita_bermain_golf_warna_kulit_cerah-sedang:',
        'zh': u':女生打高尔夫_中等浅肤色:'
    },
    u'\U0001F3CC\U0001F3FC\U0000200D\U00002640': { # 🏌🏼‍♀
        'en' : ':woman_golfing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golferin_mittelhelle_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_claro_medio:',
        'fr': ':golfeuse_peau_moyennement_claire:',
        'ja': u':ゴルフをする女_やや薄い肌色:',
        'ko': u':골프치는_여자_연한_갈색_피부:',
        'pt': ':mulher_golfista_pele_morena_clara:',
        'it': ':golfista_donna_carnagione_abbastanza_chiara:',
        'fa': u':گلف_باز_زن_پوست_روشن:',
        'id': ':wanita_bermain_golf_warna_kulit_cerah-sedang:',
        'zh': u':女生打高尔夫_中等浅肤色:'
    },
    u'\U0001F3CC\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🏌🏽‍♀️
        'en' : ':woman_golfing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':golferin_mittlere_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_medio:',
        'fr': u':golfeuse_peau_légèrement_mate:',
        'ja': u':ゴルフをする女_中間の肌色:',
        'ko': u':골프치는_여자_갈색_피부:',
        'pt': ':mulher_golfista_pele_morena:',
        'it': ':golfista_donna_carnagione_olivastra:',
        'fa': u':گلف_باز_زن_پوست_طلایی:',
        'id': ':wanita_bermain_golf_warna_kulit_sedang:',
        'zh': u':女生打高尔夫_中等肤色:'
    },
    u'\U0001F3CC\U0001F3FD\U0000200D\U00002640': { # 🏌🏽‍♀
        'en' : ':woman_golfing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':golferin_mittlere_hautfarbe:',
        'es': ':mujer_jugando_al_golf_tono_de_piel_medio:',
        'fr': u':golfeuse_peau_légèrement_mate:',
        'ja': u':ゴルフをする女_中間の肌色:',
        'ko': u':골프치는_여자_갈색_피부:',
        'pt': ':mulher_golfista_pele_morena:',
        'it': ':golfista_donna_carnagione_olivastra:',
        'fa': u':گلف_باز_زن_پوست_طلایی:',
        'id': ':wanita_bermain_golf_warna_kulit_sedang:',
        'zh': u':女生打高尔夫_中等肤色:'
    },
    u'\U0001F482\U0000200D\U00002640\U0000FE0F': { # 💂‍♀️
        'en' : ':woman_guard:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':guardswoman:'],
        'de': ':wachfrau:',
        'es': ':guardia_mujer:',
        'fr': ':garde_femme:',
        'ja': u':女性の衛兵:',
        'ko': u':여자_근위병:',
        'pt': ':guarda_mulher:',
        'it': ':guardia_donna:',
        'fa': u':گارد_زن:',
        'id': ':penjaga_wanita:',
        'zh': u':女卫兵:'
    },
    u'\U0001F482\U0000200D\U00002640': { # 💂‍♀
        'en' : ':woman_guard:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':guardswoman:'],
        'de': ':wachsoldatin:',
        'es': ':guardia_mujer:',
        'fr': ':garde_femme:',
        'ja': u':女性の衛兵:',
        'ko': u':여자_근위병:',
        'pt': ':guarda_mulher:',
        'it': ':guardia_donna:',
        'fa': u':گارد_زن:',
        'id': ':penjaga_wanita:',
        'zh': u':女卫兵:'
    },
    u'\U0001F482\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 💂🏿‍♀️
        'en' : ':woman_guard_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachfrau_dunkle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_oscuro:',
        'fr': u':garde_femme_peau_foncée:',
        'ja': u':女性の衛兵_濃い肌色:',
        'ko': u':여자_근위병_검은색_피부:',
        'pt': ':guarda_mulher_pele_escura:',
        'it': ':guardia_donna_carnagione_scura:',
        'fa': u':گارد_زن_پوست_آبنوسی:',
        'id': ':penjaga_wanita_warna_kulit_gelap:',
        'zh': u':女卫兵_较深肤色:'
    },
    u'\U0001F482\U0001F3FF\U0000200D\U00002640': { # 💂🏿‍♀
        'en' : ':woman_guard_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachfrau_dunkle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_oscuro:',
        'fr': u':garde_femme_peau_foncée:',
        'ja': u':女性の衛兵_濃い肌色:',
        'ko': u':여자_근위병_검은색_피부:',
        'pt': ':guarda_mulher_pele_escura:',
        'it': ':guardia_donna_carnagione_scura:',
        'fa': u':گارد_زن_پوست_آبنوسی:',
        'id': ':penjaga_wanita_warna_kulit_gelap:',
        'zh': u':女卫兵_较深肤色:'
    },
    u'\U0001F482\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 💂🏻‍♀️
        'en' : ':woman_guard_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachfrau_helle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_claro:',
        'fr': ':garde_femme_peau_claire:',
        'ja': u':女性の衛兵_薄い肌色:',
        'ko': u':여자_근위병_하얀_피부:',
        'pt': ':guarda_mulher_pele_clara:',
        'it': ':guardia_donna_carnagione_chiara:',
        'fa': u':گارد_زن_پوست_سفید:',
        'id': ':penjaga_wanita_warna_kulit_cerah:',
        'zh': u':女卫兵_较浅肤色:'
    },
    u'\U0001F482\U0001F3FB\U0000200D\U00002640': { # 💂🏻‍♀
        'en' : ':woman_guard_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachfrau_helle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_claro:',
        'fr': ':garde_femme_peau_claire:',
        'ja': u':女性の衛兵_薄い肌色:',
        'ko': u':여자_근위병_하얀_피부:',
        'pt': ':guarda_mulher_pele_clara:',
        'it': ':guardia_donna_carnagione_chiara:',
        'fa': u':گارد_زن_پوست_سفید:',
        'id': ':penjaga_wanita_warna_kulit_cerah:',
        'zh': u':女卫兵_较浅肤色:'
    },
    u'\U0001F482\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 💂🏾‍♀️
        'en' : ':woman_guard_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachfrau_mitteldunkle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':garde_femme_peau_mate:',
        'ja': u':女性の衛兵_やや濃い肌色:',
        'ko': u':여자_근위병_진한_갈색_피부:',
        'pt': ':guarda_mulher_pele_morena_escura:',
        'it': ':guardia_donna_carnagione_abbastanza_scura:',
        'fa': u':گارد_زن_پوست_گندمی:',
        'id': ':penjaga_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女卫兵_中等深肤色:'
    },
    u'\U0001F482\U0001F3FE\U0000200D\U00002640': { # 💂🏾‍♀
        'en' : ':woman_guard_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachfrau_mitteldunkle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':garde_femme_peau_mate:',
        'ja': u':女性の衛兵_やや濃い肌色:',
        'ko': u':여자_근위병_진한_갈색_피부:',
        'pt': ':guarda_mulher_pele_morena_escura:',
        'it': ':guardia_donna_carnagione_abbastanza_scura:',
        'fa': u':گارد_زن_پوست_گندمی:',
        'id': ':penjaga_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女卫兵_中等深肤色:'
    },
    u'\U0001F482\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 💂🏼‍♀️
        'en' : ':woman_guard_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachfrau_mittelhelle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_claro_medio:',
        'fr': ':garde_femme_peau_moyennement_claire:',
        'ja': u':女性の衛兵_やや薄い肌色:',
        'ko': u':여자_근위병_연한_갈색_피부:',
        'pt': ':guarda_mulher_pele_morena_clara:',
        'it': ':guardia_donna_carnagione_abbastanza_chiara:',
        'fa': u':گارد_زن_پوست_روشن:',
        'id': ':penjaga_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女卫兵_中等浅肤色:'
    },
    u'\U0001F482\U0001F3FC\U0000200D\U00002640': { # 💂🏼‍♀
        'en' : ':woman_guard_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachfrau_mittelhelle_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_claro_medio:',
        'fr': ':garde_femme_peau_moyennement_claire:',
        'ja': u':女性の衛兵_やや薄い肌色:',
        'ko': u':여자_근위병_연한_갈색_피부:',
        'pt': ':guarda_mulher_pele_morena_clara:',
        'it': ':guardia_donna_carnagione_abbastanza_chiara:',
        'fa': u':گارد_زن_پوست_روشن:',
        'id': ':penjaga_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女卫兵_中等浅肤色:'
    },
    u'\U0001F482\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 💂🏽‍♀️
        'en' : ':woman_guard_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wachfrau_mittlere_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_medio:',
        'fr': u':garde_femme_peau_légèrement_mate:',
        'ja': u':女性の衛兵_中間の肌色:',
        'ko': u':여자_근위병_갈색_피부:',
        'pt': ':guarda_mulher_pele_morena:',
        'it': ':guardia_donna_carnagione_olivastra:',
        'fa': u':گارد_زن_پوست_طلایی:',
        'id': ':penjaga_wanita_warna_kulit_sedang:',
        'zh': u':女卫兵_中等肤色:'
    },
    u'\U0001F482\U0001F3FD\U0000200D\U00002640': { # 💂🏽‍♀
        'en' : ':woman_guard_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wachfrau_mittlere_hautfarbe:',
        'es': ':guardia_mujer_tono_de_piel_medio:',
        'fr': u':garde_femme_peau_légèrement_mate:',
        'ja': u':女性の衛兵_中間の肌色:',
        'ko': u':여자_근위병_갈색_피부:',
        'pt': ':guarda_mulher_pele_morena:',
        'it': ':guardia_donna_carnagione_olivastra:',
        'fa': u':گارد_زن_پوست_طلایی:',
        'id': ':penjaga_wanita_warna_kulit_sedang:',
        'zh': u':女卫兵_中等肤色:'
    },
    u'\U0001F469\U0000200D\U00002695\U0000FE0F': { # 👩‍⚕️
        'en' : ':woman_health_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':ärztin:',
        'es': ':profesional_sanitario_mujer:',
        'fr': u':professionnelle_de_la_santé:',
        'ja': u':女性の医者:',
        'ko': u':여자_의료인:',
        'pt': u':mulher_profissional_da_saúde:',
        'it': ':operatrice_sanitaria:',
        'fa': u':مددکار_بهداشت_زن:',
        'id': ':pekerja_kesehatan_wanita:',
        'zh': u':女医生:'
    },
    u'\U0001F469\U0000200D\U00002695': { # 👩‍⚕
        'en' : ':woman_health_worker:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':ärztin:',
        'es': ':profesional_sanitario_mujer:',
        'fr': u':professionnelle_de_la_santé:',
        'ja': u':女性の医者:',
        'ko': u':여자_의료인:',
        'pt': u':mulher_profissional_da_saúde:',
        'it': ':operatrice_sanitaria:',
        'fa': u':مددکار_بهداشت_زن:',
        'id': ':pekerja_kesehatan_wanita:',
        'zh': u':女医生:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002695\U0000FE0F': { # 👩🏿‍⚕️
        'en' : ':woman_health_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':ärztin_dunkle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_oscuro:',
        'fr': u':professionnelle_de_la_santé_peau_foncée:',
        'ja': u':女性の医者_濃い肌色:',
        'ko': u':여자_의료인_검은색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_escura:',
        'it': ':operatrice_sanitaria_carnagione_scura:',
        'fa': u':مددکار_بهداشت_زن_پوست_آبنوسی:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_gelap:',
        'zh': u':女医生_较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002695': { # 👩🏿‍⚕
        'en' : ':woman_health_worker_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':ärztin_dunkle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_oscuro:',
        'fr': u':professionnelle_de_la_santé_peau_foncée:',
        'ja': u':女性の医者_濃い肌色:',
        'ko': u':여자_의료인_검은색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_escura:',
        'it': ':operatrice_sanitaria_carnagione_scura:',
        'fa': u':مددکار_بهداشت_زن_پوست_آبنوسی:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_gelap:',
        'zh': u':女医生_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002695\U0000FE0F': { # 👩🏻‍⚕️
        'en' : ':woman_health_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':ärztin_helle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_claro:',
        'fr': u':professionnelle_de_la_santé_peau_claire:',
        'ja': u':女性の医者_薄い肌色:',
        'ko': u':여자_의료인_하얀_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_clara:',
        'it': ':operatrice_sanitaria_carnagione_chiara:',
        'fa': u':مددکار_بهداشت_زن_پوست_سفید:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_cerah:',
        'zh': u':女医生_较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002695': { # 👩🏻‍⚕
        'en' : ':woman_health_worker_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':ärztin_helle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_claro:',
        'fr': u':professionnelle_de_la_santé_peau_claire:',
        'ja': u':女性の医者_薄い肌色:',
        'ko': u':여자_의료인_하얀_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_clara:',
        'it': ':operatrice_sanitaria_carnagione_chiara:',
        'fa': u':مددکار_بهداشت_زن_پوست_سفید:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_cerah:',
        'zh': u':女医生_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002695\U0000FE0F': { # 👩🏾‍⚕️
        'en' : ':woman_health_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':ärztin_mitteldunkle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':professionnelle_de_la_santé_peau_mate:',
        'ja': u':女性の医者_やや濃い肌色:',
        'ko': u':여자_의료인_진한_갈색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_morena_escura:',
        'it': ':operatrice_sanitaria_carnagione_abbastanza_scura:',
        'fa': u':مددکار_بهداشت_زن_پوست_گندمی:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女医生_中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002695': { # 👩🏾‍⚕
        'en' : ':woman_health_worker_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':ärztin_mitteldunkle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':professionnelle_de_la_santé_peau_mate:',
        'ja': u':女性の医者_やや濃い肌色:',
        'ko': u':여자_의료인_진한_갈색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_morena_escura:',
        'it': ':operatrice_sanitaria_carnagione_abbastanza_scura:',
        'fa': u':مددکار_بهداشت_زن_پوست_گندمی:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女医生_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002695\U0000FE0F': { # 👩🏼‍⚕️
        'en' : ':woman_health_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':ärztin_mittelhelle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_claro_medio:',
        'fr': u':professionnelle_de_la_santé_peau_moyennement_claire:',
        'ja': u':女性の医者_やや薄い肌色:',
        'ko': u':여자_의료인_연한_갈색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_morena_clara:',
        'it': ':operatrice_sanitaria_carnagione_abbastanza_chiara:',
        'fa': u':مددکار_بهداشت_زن_پوست_روشن:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女医生_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002695': { # 👩🏼‍⚕
        'en' : ':woman_health_worker_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':ärztin_mittelhelle_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_claro_medio:',
        'fr': u':professionnelle_de_la_santé_peau_moyennement_claire:',
        'ja': u':女性の医者_やや薄い肌色:',
        'ko': u':여자_의료인_연한_갈색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_morena_clara:',
        'it': ':operatrice_sanitaria_carnagione_abbastanza_chiara:',
        'fa': u':مددکار_بهداشت_زن_پوست_روشن:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女医生_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002695\U0000FE0F': { # 👩🏽‍⚕️
        'en' : ':woman_health_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':ärztin_mittlere_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_medio:',
        'fr': u':professionnelle_de_la_santé_peau_légèrement_mate:',
        'ja': u':女性の医者_中間の肌色:',
        'ko': u':여자_의료인_갈색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_morena:',
        'it': ':operatrice_sanitaria_carnagione_olivastra:',
        'fa': u':مددکار_بهداشت_زن_پوست_طلایی:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_sedang:',
        'zh': u':女医生_中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002695': { # 👩🏽‍⚕
        'en' : ':woman_health_worker_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':ärztin_mittlere_hautfarbe:',
        'es': ':profesional_sanitario_mujer_tono_de_piel_medio:',
        'fr': u':professionnelle_de_la_santé_peau_légèrement_mate:',
        'ja': u':女性の医者_中間の肌色:',
        'ko': u':여자_의료인_갈색_피부:',
        'pt': u':mulher_profissional_da_saúde_pele_morena:',
        'it': ':operatrice_sanitaria_carnagione_olivastra:',
        'fa': u':مددکار_بهداشت_زن_پوست_طلایی:',
        'id': ':pekerja_kesehatan_wanita_warna_kulit_sedang:',
        'zh': u':女医生_中等肤色:'
    },
    u'\U0001F9D8\U0000200D\U00002640\U0000FE0F': { # 🧘‍♀️
        'en' : ':woman_in_lotus_position:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':lotus_position_woman:'],
        'de': ':frau_im_lotossitz:',
        'es': u':mujer_en_posición_de_loto:',
        'fr': ':femme_dans_la_posture_du_lotus:',
        'ja': u':ヨガのポーズをする女:',
        'ko': u':가부좌한_여자:',
        'pt': u':mulher_na_posição_de_lótus:',
        'it': ':donna_in_posizione_del_loto:',
        'fa': u':زن_در_حالت_خلسه:',
        'id': ':wanita_dalam_posisi_teratai:',
        'zh': u':盘腿的女人:'
    },
    u'\U0001F9D8\U0000200D\U00002640': { # 🧘‍♀
        'en' : ':woman_in_lotus_position:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':lotus_position_woman:'],
        'de': ':frau_im_lotossitz:',
        'es': u':mujer_en_posición_de_loto:',
        'fr': ':femme_dans_la_posture_du_lotus:',
        'ja': u':ヨガのポーズをする女:',
        'ko': u':가부좌한_여자:',
        'pt': u':mulher_na_posição_de_lótus:',
        'it': ':donna_in_posizione_del_loto:',
        'fa': u':زن_در_حالت_خلسه:',
        'id': ':wanita_dalam_posisi_teratai:',
        'zh': u':盘腿的女人:'
    },
    u'\U0001F9D8\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧘🏿‍♀️
        'en' : ':woman_in_lotus_position_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_dunkle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_oscuro:',
        'fr': u':femme_dans_la_posture_du_lotus_peau_foncée:',
        'ja': u':ヨガのポーズをする女_濃い肌色:',
        'ko': u':가부좌한_여자_검은색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_escura:',
        'it': ':donna_in_posizione_del_loto_carnagione_scura:',
        'fa': u':زن_در_حالت_خلسه_پوست_آبنوسی:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_gelap:',
        'zh': u':盘腿的女人_较深肤色:'
    },
    u'\U0001F9D8\U0001F3FF\U0000200D\U00002640': { # 🧘🏿‍♀
        'en' : ':woman_in_lotus_position_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_dunkle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_oscuro:',
        'fr': u':femme_dans_la_posture_du_lotus_peau_foncée:',
        'ja': u':ヨガのポーズをする女_濃い肌色:',
        'ko': u':가부좌한_여자_검은색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_escura:',
        'it': ':donna_in_posizione_del_loto_carnagione_scura:',
        'fa': u':زن_در_حالت_خلسه_پوست_آبنوسی:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_gelap:',
        'zh': u':盘腿的女人_较深肤色:'
    },
    u'\U0001F9D8\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧘🏻‍♀️
        'en' : ':woman_in_lotus_position_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_helle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_claro:',
        'fr': ':femme_dans_la_posture_du_lotus_peau_claire:',
        'ja': u':ヨガのポーズをする女_薄い肌色:',
        'ko': u':가부좌한_여자_하얀_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_clara:',
        'it': ':donna_in_posizione_del_loto_carnagione_chiara:',
        'fa': u':زن_در_حالت_خلسه_پوست_سفید:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_cerah:',
        'zh': u':盘腿的女人_较浅肤色:'
    },
    u'\U0001F9D8\U0001F3FB\U0000200D\U00002640': { # 🧘🏻‍♀
        'en' : ':woman_in_lotus_position_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_helle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_claro:',
        'fr': ':femme_dans_la_posture_du_lotus_peau_claire:',
        'ja': u':ヨガのポーズをする女_薄い肌色:',
        'ko': u':가부좌한_여자_하얀_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_clara:',
        'it': ':donna_in_posizione_del_loto_carnagione_chiara:',
        'fa': u':زن_در_حالت_خلسه_پوست_سفید:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_cerah:',
        'zh': u':盘腿的女人_较浅肤色:'
    },
    u'\U0001F9D8\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧘🏾‍♀️
        'en' : ':woman_in_lotus_position_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_mitteldunkle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_oscuro_medio:',
        'fr': ':femme_dans_la_posture_du_lotus_peau_mate:',
        'ja': u':ヨガのポーズをする女_やや濃い肌色:',
        'ko': u':가부좌한_여자_진한_갈색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_morena_escura:',
        'it': ':donna_in_posizione_del_loto_carnagione_abbastanza_scura:',
        'fa': u':زن_در_حالت_خلسه_پوست_گندمی:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_gelap-sedang:',
        'zh': u':盘腿的女人_中等深肤色:'
    },
    u'\U0001F9D8\U0001F3FE\U0000200D\U00002640': { # 🧘🏾‍♀
        'en' : ':woman_in_lotus_position_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_mitteldunkle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_oscuro_medio:',
        'fr': ':femme_dans_la_posture_du_lotus_peau_mate:',
        'ja': u':ヨガのポーズをする女_やや濃い肌色:',
        'ko': u':가부좌한_여자_진한_갈색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_morena_escura:',
        'it': ':donna_in_posizione_del_loto_carnagione_abbastanza_scura:',
        'fa': u':زن_در_حالت_خلسه_پوست_گندمی:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_gelap-sedang:',
        'zh': u':盘腿的女人_中等深肤色:'
    },
    u'\U0001F9D8\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧘🏼‍♀️
        'en' : ':woman_in_lotus_position_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_mittelhelle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_claro_medio:',
        'fr': ':femme_dans_la_posture_du_lotus_peau_moyennement_claire:',
        'ja': u':ヨガのポーズをする女_やや薄い肌色:',
        'ko': u':가부좌한_여자_연한_갈색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_morena_clara:',
        'it': ':donna_in_posizione_del_loto_carnagione_abbastanza_chiara:',
        'fa': u':زن_در_حالت_خلسه_پوست_روشن:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_cerah-sedang:',
        'zh': u':盘腿的女人_中等浅肤色:'
    },
    u'\U0001F9D8\U0001F3FC\U0000200D\U00002640': { # 🧘🏼‍♀
        'en' : ':woman_in_lotus_position_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_mittelhelle_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_claro_medio:',
        'fr': ':femme_dans_la_posture_du_lotus_peau_moyennement_claire:',
        'ja': u':ヨガのポーズをする女_やや薄い肌色:',
        'ko': u':가부좌한_여자_연한_갈색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_morena_clara:',
        'it': ':donna_in_posizione_del_loto_carnagione_abbastanza_chiara:',
        'fa': u':زن_در_حالت_خلسه_پوست_روشن:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_cerah-sedang:',
        'zh': u':盘腿的女人_中等浅肤色:'
    },
    u'\U0001F9D8\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧘🏽‍♀️
        'en' : ':woman_in_lotus_position_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_mittlere_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_medio:',
        'fr': u':femme_dans_la_posture_du_lotus_peau_légèrement_mate:',
        'ja': u':ヨガのポーズをする女_中間の肌色:',
        'ko': u':가부좌한_여자_갈색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_morena:',
        'it': ':donna_in_posizione_del_loto_carnagione_olivastra:',
        'fa': u':زن_در_حالت_خلسه_پوست_طلایی:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_sedang:',
        'zh': u':盘腿的女人_中等肤色:'
    },
    u'\U0001F9D8\U0001F3FD\U0000200D\U00002640': { # 🧘🏽‍♀
        'en' : ':woman_in_lotus_position_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_im_lotossitz_mittlere_hautfarbe:',
        'es': u':mujer_en_posición_de_loto_tono_de_piel_medio:',
        'fr': u':femme_dans_la_posture_du_lotus_peau_légèrement_mate:',
        'ja': u':ヨガのポーズをする女_中間の肌色:',
        'ko': u':가부좌한_여자_갈색_피부:',
        'pt': u':mulher_na_posição_de_lótus_pele_morena:',
        'it': ':donna_in_posizione_del_loto_carnagione_olivastra:',
        'fa': u':زن_در_حالت_خلسه_پوست_طلایی:',
        'id': ':wanita_dalam_posisi_teratai_warna_kulit_sedang:',
        'zh': u':盘腿的女人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F9BD': { # 👩‍🦽
        'en' : ':woman_in_manual_wheelchair:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_manuellem_rollstuhl:',
        'es': ':mujer_en_silla_de_ruedas_manual:',
        'fr': ':femme_en_fauteuil_roulant_manuel:',
        'ja': u':手動式車椅子の女性:',
        'ko': u':수동_휠체어를_탄_여자:',
        'pt': ':mulher_em_cadeira_de_rodas_manual:',
        'it': ':donna_su_sedia_a_rotelle_manuale:',
        'fa': u':زن_در_صندلی_چرخ_دار_دستی:',
        'id': ':wanita_dengan_kursi_roda_manual:',
        'zh': u':坐手动轮椅的女人:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F9BD': { # 👩🏿‍🦽
        'en' : ':woman_in_manual_wheelchair_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_manuellem_rollstuhl_dunkle_hautfarbe:',
        'es': ':mujer_en_silla_de_ruedas_manual_tono_de_piel_oscuro:',
        'fr': u':femme_en_fauteuil_roulant_manuel_peau_foncée:',
        'ja': u':手動式車椅子の女性_濃い肌色:',
        'ko': u':수동_휠체어를_탄_여자_검은색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_manual_pele_escura:',
        'it': ':donna_su_sedia_a_rotelle_manuale_carnagione_scura:',
        'fa': u':زن_در_صندلی_چرخ_دار_دستی_پوست_آبنوسی:',
        'id': ':wanita_dengan_kursi_roda_manual_warna_kulit_gelap:',
        'zh': u':坐手动轮椅的女人_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F9BD': { # 👩🏻‍🦽
        'en' : ':woman_in_manual_wheelchair_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_manuellem_rollstuhl_helle_hautfarbe:',
        'es': ':mujer_en_silla_de_ruedas_manual_tono_de_piel_claro:',
        'fr': ':femme_en_fauteuil_roulant_manuel_peau_claire:',
        'ja': u':手動式車椅子の女性_薄い肌色:',
        'ko': u':수동_휠체어를_탄_여자_하얀_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_manual_pele_clara:',
        'it': ':donna_su_sedia_a_rotelle_manuale_carnagione_chiara:',
        'fa': u':زن_در_صندلی_چرخ_دار_دستی_پوست_سفید:',
        'id': ':wanita_dengan_kursi_roda_manual_warna_kulit_cerah:',
        'zh': u':坐手动轮椅的女人_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F9BD': { # 👩🏾‍🦽
        'en' : ':woman_in_manual_wheelchair_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_manuellem_rollstuhl_mitteldunkle_hautfarbe:',
        'es': ':mujer_en_silla_de_ruedas_manual_tono_de_piel_oscuro_medio:',
        'fr': ':femme_en_fauteuil_roulant_manuel_peau_mate:',
        'ja': u':手動式車椅子の女性_やや濃い肌色:',
        'ko': u':수동_휠체어를_탄_여자_진한_갈색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_manual_pele_morena_escura:',
        'it': ':donna_su_sedia_a_rotelle_manuale_carnagione_abbastanza_scura:',
        'fa': u':زن_در_صندلی_چرخ_دار_دستی_پوست_گندمی:',
        'id': ':wanita_dengan_kursi_roda_manual_warna_kulit_gelap-sedang:',
        'zh': u':坐手动轮椅的女人_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F9BD': { # 👩🏼‍🦽
        'en' : ':woman_in_manual_wheelchair_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_manuellem_rollstuhl_mittelhelle_hautfarbe:',
        'es': ':mujer_en_silla_de_ruedas_manual_tono_de_piel_claro_medio:',
        'fr': ':femme_en_fauteuil_roulant_manuel_peau_moyennement_claire:',
        'ja': u':手動式車椅子の女性_やや薄い肌色:',
        'ko': u':수동_휠체어를_탄_여자_연한_갈색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_manual_pele_morena_clara:',
        'it': ':donna_su_sedia_a_rotelle_manuale_carnagione_abbastanza_chiara:',
        'fa': u':زن_در_صندلی_چرخ_دار_دستی_پوست_روشن:',
        'id': ':wanita_dengan_kursi_roda_manual_warna_kulit_cerah-sedang:',
        'zh': u':坐手动轮椅的女人_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F9BD': { # 👩🏽‍🦽
        'en' : ':woman_in_manual_wheelchair_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_manuellem_rollstuhl_mittlere_hautfarbe:',
        'es': ':mujer_en_silla_de_ruedas_manual_tono_de_piel_medio:',
        'fr': u':femme_en_fauteuil_roulant_manuel_peau_légèrement_mate:',
        'ja': u':手動式車椅子の女性_中間の肌色:',
        'ko': u':수동_휠체어를_탄_여자_갈색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_manual_pele_morena:',
        'it': ':donna_su_sedia_a_rotelle_manuale_carnagione_olivastra:',
        'fa': u':زن_در_صندلی_چرخ_دار_دستی_پوست_طلایی:',
        'id': ':wanita_dengan_kursi_roda_manual_warna_kulit_sedang:',
        'zh': u':坐手动轮椅的女人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F9BC': { # 👩‍🦼
        'en' : ':woman_in_motorized_wheelchair:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_elektrischem_rollstuhl:',
        'es': u':mujer_en_silla_de_ruedas_eléctrica:',
        'fr': u':femme_en_fauteuil_motorisé:',
        'ja': u':電動車椅子の女性:',
        'ko': u':전동_휠체어를_탄_여자:',
        'pt': ':mulher_em_cadeira_de_rodas_motorizada:',
        'it': ':donna_su_sedia_a_rotelle_motorizzata:',
        'fa': u':زن_در_صندلی_چرخ_دار_برقی:',
        'id': ':wanita_dengan_kursi_roda_bermotor:',
        'zh': u':坐电动轮椅的女人:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F9BC': { # 👩🏿‍🦼
        'en' : ':woman_in_motorized_wheelchair_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_elektrischem_rollstuhl_dunkle_hautfarbe:',
        'es': u':mujer_en_silla_de_ruedas_eléctrica_tono_de_piel_oscuro:',
        'fr': u':femme_en_fauteuil_motorisé_peau_foncée:',
        'ja': u':電動車椅子の女性_濃い肌色:',
        'ko': u':전동_휠체어를_탄_여자_검은색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_motorizada_pele_escura:',
        'it': ':donna_su_sedia_a_rotelle_motorizzata_carnagione_scura:',
        'fa': u':زن_در_صندلی_چرخ_دار_برقی_پوست_آبنوسی:',
        'id': ':wanita_dengan_kursi_roda_bermotor_warna_kulit_gelap:',
        'zh': u':坐电动轮椅的女人_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F9BC': { # 👩🏻‍🦼
        'en' : ':woman_in_motorized_wheelchair_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_elektrischem_rollstuhl_helle_hautfarbe:',
        'es': u':mujer_en_silla_de_ruedas_eléctrica_tono_de_piel_claro:',
        'fr': u':femme_en_fauteuil_motorisé_peau_claire:',
        'ja': u':電動車椅子の女性_薄い肌色:',
        'ko': u':전동_휠체어를_탄_여자_하얀_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_motorizada_pele_clara:',
        'it': ':donna_su_sedia_a_rotelle_motorizzata_carnagione_chiara:',
        'fa': u':زن_در_صندلی_چرخ_دار_برقی_پوست_سفید:',
        'id': ':wanita_dengan_kursi_roda_bermotor_warna_kulit_cerah:',
        'zh': u':坐电动轮椅的女人_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F9BC': { # 👩🏾‍🦼
        'en' : ':woman_in_motorized_wheelchair_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_elektrischem_rollstuhl_mitteldunkle_hautfarbe:',
        'es': u':mujer_en_silla_de_ruedas_eléctrica_tono_de_piel_oscuro_medio:',
        'fr': u':femme_en_fauteuil_motorisé_peau_mate:',
        'ja': u':電動車椅子の女性_やや濃い肌色:',
        'ko': u':전동_휠체어를_탄_여자_진한_갈색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_motorizada_pele_morena_escura:',
        'it': ':donna_su_sedia_a_rotelle_motorizzata_carnagione_abbastanza_scura:',
        'fa': u':زن_در_صندلی_چرخ_دار_برقی_پوست_گندمی:',
        'id': ':wanita_dengan_kursi_roda_bermotor_warna_kulit_gelap-sedang:',
        'zh': u':坐电动轮椅的女人_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F9BC': { # 👩🏼‍🦼
        'en' : ':woman_in_motorized_wheelchair_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_elektrischem_rollstuhl_mittelhelle_hautfarbe:',
        'es': u':mujer_en_silla_de_ruedas_eléctrica_tono_de_piel_claro_medio:',
        'fr': u':femme_en_fauteuil_motorisé_peau_moyennement_claire:',
        'ja': u':電動車椅子の女性_やや薄い肌色:',
        'ko': u':전동_휠체어를_탄_여자_연한_갈색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_motorizada_pele_morena_clara:',
        'it': ':donna_su_sedia_a_rotelle_motorizzata_carnagione_abbastanza_chiara:',
        'fa': u':زن_در_صندلی_چرخ_دار_برقی_پوست_روشن:',
        'id': ':wanita_dengan_kursi_roda_bermotor_warna_kulit_cerah-sedang:',
        'zh': u':坐电动轮椅的女人_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F9BC': { # 👩🏽‍🦼
        'en' : ':woman_in_motorized_wheelchair_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_in_elektrischem_rollstuhl_mittlere_hautfarbe:',
        'es': u':mujer_en_silla_de_ruedas_eléctrica_tono_de_piel_medio:',
        'fr': u':femme_en_fauteuil_motorisé_peau_légèrement_mate:',
        'ja': u':電動車椅子の女性_中間の肌色:',
        'ko': u':전동_휠체어를_탄_여자_갈색_피부:',
        'pt': ':mulher_em_cadeira_de_rodas_motorizada_pele_morena:',
        'it': ':donna_su_sedia_a_rotelle_motorizzata_carnagione_olivastra:',
        'fa': u':زن_در_صندلی_چرخ_دار_برقی_پوست_طلایی:',
        'id': ':wanita_dengan_kursi_roda_bermotor_warna_kulit_sedang:',
        'zh': u':坐电动轮椅的女人_中等肤色:'
    },
    u'\U0001F9D6\U0000200D\U00002640\U0000FE0F': { # 🧖‍♀️
        'en' : ':woman_in_steamy_room:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':sauna_woman:'],
        'de': ':frau_in_dampfsauna:',
        'es': ':mujer_en_una_sauna:',
        'fr': ':femme_au_hammam:',
        'ja': u':サウナに入る女:',
        'ko': u':사우나_하는_여자:',
        'pt': ':mulher_na_sauna:',
        'it': ':donna_in_sauna:',
        'fa': u':زن_در_حمام_بخار:',
        'id': ':wanita_di_ruangan_beruap:',
        'zh': u':蒸房里的女人:'
    },
    u'\U0001F9D6\U0000200D\U00002640': { # 🧖‍♀
        'en' : ':woman_in_steamy_room:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':sauna_woman:'],
        'de': ':frau_in_dampfsauna:',
        'es': ':mujer_en_una_sauna:',
        'fr': ':femme_au_hammam:',
        'ja': u':サウナに入る女:',
        'ko': u':사우나_하는_여자:',
        'pt': ':mulher_na_sauna:',
        'it': ':donna_in_sauna:',
        'fa': u':زن_در_حمام_بخار:',
        'id': ':wanita_di_ruangan_beruap:',
        'zh': u':蒸房里的女人:'
    },
    u'\U0001F9D6\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧖🏿‍♀️
        'en' : ':woman_in_steamy_room_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_dunkle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_oscuro:',
        'fr': u':femme_au_hammam_peau_foncée:',
        'ja': u':サウナに入る女_濃い肌色:',
        'ko': u':사우나_하는_여자_검은색_피부:',
        'pt': ':mulher_na_sauna_pele_escura:',
        'it': ':donna_in_sauna_carnagione_scura:',
        'fa': u':زن_در_حمام_بخار_پوست_آبنوسی:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_gelap:',
        'zh': u':蒸房里的女人_较深肤色:'
    },
    u'\U0001F9D6\U0001F3FF\U0000200D\U00002640': { # 🧖🏿‍♀
        'en' : ':woman_in_steamy_room_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_dunkle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_oscuro:',
        'fr': u':femme_au_hammam_peau_foncée:',
        'ja': u':サウナに入る女_濃い肌色:',
        'ko': u':사우나_하는_여자_검은색_피부:',
        'pt': ':mulher_na_sauna_pele_escura:',
        'it': ':donna_in_sauna_carnagione_scura:',
        'fa': u':زن_در_حمام_بخار_پوست_آبنوسی:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_gelap:',
        'zh': u':蒸房里的女人_较深肤色:'
    },
    u'\U0001F9D6\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧖🏻‍♀️
        'en' : ':woman_in_steamy_room_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_helle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_claro:',
        'fr': ':femme_au_hammam_peau_claire:',
        'ja': u':サウナに入る女_薄い肌色:',
        'ko': u':사우나_하는_여자_하얀_피부:',
        'pt': ':mulher_na_sauna_pele_clara:',
        'it': ':donna_in_sauna_carnagione_chiara:',
        'fa': u':زن_در_حمام_بخار_پوست_سفید:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_cerah:',
        'zh': u':蒸房里的女人_较浅肤色:'
    },
    u'\U0001F9D6\U0001F3FB\U0000200D\U00002640': { # 🧖🏻‍♀
        'en' : ':woman_in_steamy_room_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_helle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_claro:',
        'fr': ':femme_au_hammam_peau_claire:',
        'ja': u':サウナに入る女_薄い肌色:',
        'ko': u':사우나_하는_여자_하얀_피부:',
        'pt': ':mulher_na_sauna_pele_clara:',
        'it': ':donna_in_sauna_carnagione_chiara:',
        'fa': u':زن_در_حمام_بخار_پوست_سفید:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_cerah:',
        'zh': u':蒸房里的女人_较浅肤色:'
    },
    u'\U0001F9D6\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧖🏾‍♀️
        'en' : ':woman_in_steamy_room_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_mitteldunkle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_oscuro_medio:',
        'fr': ':femme_au_hammam_peau_mate:',
        'ja': u':サウナに入る女_やや濃い肌色:',
        'ko': u':사우나_하는_여자_진한_갈색_피부:',
        'pt': ':mulher_na_sauna_pele_morena_escura:',
        'it': ':donna_in_sauna_carnagione_abbastanza_scura:',
        'fa': u':زن_در_حمام_بخار_پوست_گندمی:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_gelap-sedang:',
        'zh': u':蒸房里的女人_中等深肤色:'
    },
    u'\U0001F9D6\U0001F3FE\U0000200D\U00002640': { # 🧖🏾‍♀
        'en' : ':woman_in_steamy_room_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_mitteldunkle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_oscuro_medio:',
        'fr': ':femme_au_hammam_peau_mate:',
        'ja': u':サウナに入る女_やや濃い肌色:',
        'ko': u':사우나_하는_여자_진한_갈색_피부:',
        'pt': ':mulher_na_sauna_pele_morena_escura:',
        'it': ':donna_in_sauna_carnagione_abbastanza_scura:',
        'fa': u':زن_در_حمام_بخار_پوست_گندمی:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_gelap-sedang:',
        'zh': u':蒸房里的女人_中等深肤色:'
    },
    u'\U0001F9D6\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧖🏼‍♀️
        'en' : ':woman_in_steamy_room_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_mittelhelle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_claro_medio:',
        'fr': ':femme_au_hammam_peau_moyennement_claire:',
        'ja': u':サウナに入る女_やや薄い肌色:',
        'ko': u':사우나_하는_여자_연한_갈색_피부:',
        'pt': ':mulher_na_sauna_pele_morena_clara:',
        'it': ':donna_in_sauna_carnagione_abbastanza_chiara:',
        'fa': u':زن_در_حمام_بخار_پوست_روشن:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_cerah-sedang:',
        'zh': u':蒸房里的女人_中等浅肤色:'
    },
    u'\U0001F9D6\U0001F3FC\U0000200D\U00002640': { # 🧖🏼‍♀
        'en' : ':woman_in_steamy_room_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_mittelhelle_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_claro_medio:',
        'fr': ':femme_au_hammam_peau_moyennement_claire:',
        'ja': u':サウナに入る女_やや薄い肌色:',
        'ko': u':사우나_하는_여자_연한_갈색_피부:',
        'pt': ':mulher_na_sauna_pele_morena_clara:',
        'it': ':donna_in_sauna_carnagione_abbastanza_chiara:',
        'fa': u':زن_در_حمام_بخار_پوست_روشن:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_cerah-sedang:',
        'zh': u':蒸房里的女人_中等浅肤色:'
    },
    u'\U0001F9D6\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧖🏽‍♀️
        'en' : ':woman_in_steamy_room_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_mittlere_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_medio:',
        'fr': u':femme_au_hammam_peau_légèrement_mate:',
        'ja': u':サウナに入る女_中間の肌色:',
        'ko': u':사우나_하는_여자_갈색_피부:',
        'pt': ':mulher_na_sauna_pele_morena:',
        'it': ':donna_in_sauna_carnagione_olivastra:',
        'fa': u':زن_در_حمام_بخار_پوست_طلایی:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_sedang:',
        'zh': u':蒸房里的女人_中等肤色:'
    },
    u'\U0001F9D6\U0001F3FD\U0000200D\U00002640': { # 🧖🏽‍♀
        'en' : ':woman_in_steamy_room_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':frau_in_dampfsauna_mittlere_hautfarbe:',
        'es': ':mujer_en_una_sauna_tono_de_piel_medio:',
        'fr': u':femme_au_hammam_peau_légèrement_mate:',
        'ja': u':サウナに入る女_中間の肌色:',
        'ko': u':사우나_하는_여자_갈색_피부:',
        'pt': ':mulher_na_sauna_pele_morena:',
        'it': ':donna_in_sauna_carnagione_olivastra:',
        'fa': u':زن_در_حمام_بخار_پوست_طلایی:',
        'id': ':wanita_di_ruangan_beruap_warna_kulit_sedang:',
        'zh': u':蒸房里的女人_中等肤色:'
    },
    u'\U0001F935\U0000200D\U00002640\U0000FE0F': { # 🤵‍♀️
        'en' : ':woman_in_tuxedo:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_im_smoking:',
        'es': ':mujer_con_esmoquin:',
        'fr': ':femme_en_smoking:',
        'ja': u':タキシードの女性:',
        'ko': u':턱시도를_입은_여자:',
        'pt': ':mulher_de_smoking:',
        'it': ':donna_in_smoking:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون:',
        'id': ':wanita_bertuksedo:',
        'zh': u':穿礼服的女人:'
    },
    u'\U0001F935\U0000200D\U00002640': { # 🤵‍♀
        'en' : ':woman_in_tuxedo:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_im_smoking:',
        'es': ':mujer_con_esmoquin:',
        'fr': ':femme_en_smoking:',
        'ja': u':タキシードの女性:',
        'ko': u':턱시도를_입은_여자:',
        'pt': ':mulher_de_smoking:',
        'it': ':donna_in_smoking:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون:',
        'id': ':wanita_bertuksedo:',
        'zh': u':穿礼服的女人:'
    },
    u'\U0001F935\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🤵🏿‍♀️
        'en' : ':woman_in_tuxedo_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_dunkle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_oscuro:',
        'fr': u':femme_en_smoking_peau_foncée:',
        'ja': u':タキシードの女性_濃い肌色:',
        'ko': u':턱시도를_입은_여자_검은색_피부:',
        'pt': ':mulher_de_smoking_pele_escura:',
        'it': ':donna_in_smoking_carnagione_scura:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_آبنوسی:',
        'id': ':wanita_bertuksedo_warna_kulit_gelap:',
        'zh': u':穿礼服的女人_较深肤色:'
    },
    u'\U0001F935\U0001F3FF\U0000200D\U00002640': { # 🤵🏿‍♀
        'en' : ':woman_in_tuxedo_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_dunkle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_oscuro:',
        'fr': u':femme_en_smoking_peau_foncée:',
        'ja': u':タキシードの女性_濃い肌色:',
        'ko': u':턱시도를_입은_여자_검은색_피부:',
        'pt': ':mulher_de_smoking_pele_escura:',
        'it': ':donna_in_smoking_carnagione_scura:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_آبنوسی:',
        'id': ':wanita_bertuksedo_warna_kulit_gelap:',
        'zh': u':穿礼服的女人_较深肤色:'
    },
    u'\U0001F935\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🤵🏻‍♀️
        'en' : ':woman_in_tuxedo_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_helle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_claro:',
        'fr': ':femme_en_smoking_peau_claire:',
        'ja': u':タキシードの女性_薄い肌色:',
        'ko': u':턱시도를_입은_여자_하얀_피부:',
        'pt': ':mulher_de_smoking_pele_clara:',
        'it': ':donna_in_smoking_carnagione_chiara:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_سفید:',
        'id': ':wanita_bertuksedo_warna_kulit_cerah:',
        'zh': u':穿礼服的女人_较浅肤色:'
    },
    u'\U0001F935\U0001F3FB\U0000200D\U00002640': { # 🤵🏻‍♀
        'en' : ':woman_in_tuxedo_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_helle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_claro:',
        'fr': ':femme_en_smoking_peau_claire:',
        'ja': u':タキシードの女性_薄い肌色:',
        'ko': u':턱시도를_입은_여자_하얀_피부:',
        'pt': ':mulher_de_smoking_pele_clara:',
        'it': ':donna_in_smoking_carnagione_chiara:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_سفید:',
        'id': ':wanita_bertuksedo_warna_kulit_cerah:',
        'zh': u':穿礼服的女人_较浅肤色:'
    },
    u'\U0001F935\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🤵🏾‍♀️
        'en' : ':woman_in_tuxedo_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_oscuro_medio:',
        'fr': ':femme_en_smoking_peau_mate:',
        'ja': u':タキシードの女性_やや濃い肌色:',
        'ko': u':턱시도를_입은_여자_진한_갈색_피부:',
        'pt': ':mulher_de_smoking_pele_morena_escura:',
        'it': ':donna_in_smoking_carnagione_abbastanza_scura:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_گندمی:',
        'id': ':wanita_bertuksedo_warna_kulit_gelap-sedang:',
        'zh': u':穿礼服的女人_中等深肤色:'
    },
    u'\U0001F935\U0001F3FE\U0000200D\U00002640': { # 🤵🏾‍♀
        'en' : ':woman_in_tuxedo_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_oscuro_medio:',
        'fr': ':femme_en_smoking_peau_mate:',
        'ja': u':タキシードの女性_やや濃い肌色:',
        'ko': u':턱시도를_입은_여자_진한_갈색_피부:',
        'pt': ':mulher_de_smoking_pele_morena_escura:',
        'it': ':donna_in_smoking_carnagione_abbastanza_scura:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_گندمی:',
        'id': ':wanita_bertuksedo_warna_kulit_gelap-sedang:',
        'zh': u':穿礼服的女人_中等深肤色:'
    },
    u'\U0001F935\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🤵🏼‍♀️
        'en' : ':woman_in_tuxedo_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_mittelhelle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_claro_medio:',
        'fr': ':femme_en_smoking_peau_moyennement_claire:',
        'ja': u':タキシードの女性_やや薄い肌色:',
        'ko': u':턱시도를_입은_여자_연한_갈색_피부:',
        'pt': ':mulher_de_smoking_pele_morena_clara:',
        'it': ':donna_in_smoking_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_روشن:',
        'id': ':wanita_bertuksedo_warna_kulit_cerah-sedang:',
        'zh': u':穿礼服的女人_中等浅肤色:'
    },
    u'\U0001F935\U0001F3FC\U0000200D\U00002640': { # 🤵🏼‍♀
        'en' : ':woman_in_tuxedo_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_mittelhelle_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_claro_medio:',
        'fr': ':femme_en_smoking_peau_moyennement_claire:',
        'ja': u':タキシードの女性_やや薄い肌色:',
        'ko': u':턱시도를_입은_여자_연한_갈색_피부:',
        'pt': ':mulher_de_smoking_pele_morena_clara:',
        'it': ':donna_in_smoking_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_روشن:',
        'id': ':wanita_bertuksedo_warna_kulit_cerah-sedang:',
        'zh': u':穿礼服的女人_中等浅肤色:'
    },
    u'\U0001F935\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🤵🏽‍♀️
        'en' : ':woman_in_tuxedo_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_mittlere_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_medio:',
        'fr': u':femme_en_smoking_peau_légèrement_mate:',
        'ja': u':タキシードの女性_中間の肌色:',
        'ko': u':턱시도를_입은_여자_갈색_피부:',
        'pt': ':mulher_de_smoking_pele_morena:',
        'it': ':donna_in_smoking_carnagione_olivastra:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_طلایی:',
        'id': ':wanita_bertuksedo_warna_kulit_sedang:',
        'zh': u':穿礼服的女人_中等肤色:'
    },
    u'\U0001F935\U0001F3FD\U0000200D\U00002640': { # 🤵🏽‍♀
        'en' : ':woman_in_tuxedo_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_im_smoking_mittlere_hautfarbe:',
        'es': ':mujer_con_esmoquin_tono_de_piel_medio:',
        'fr': u':femme_en_smoking_peau_légèrement_mate:',
        'ja': u':タキシードの女性_中間の肌色:',
        'ko': u':턱시도를_입은_여자_갈색_피부:',
        'pt': ':mulher_de_smoking_pele_morena:',
        'it': ':donna_in_smoking_carnagione_olivastra:',
        'fa': u':زن_با_کت_و_شلوار_و_پاپیون_پوست_طلایی:',
        'id': ':wanita_bertuksedo_warna_kulit_sedang:',
        'zh': u':穿礼服的女人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U00002696\U0000FE0F': { # 👩‍⚖️
        'en' : ':woman_judge:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richterin:',
        'es': ':fiscal_mujer:',
        'fr': ':juge_femme:',
        'ja': u':女性の裁判官:',
        'ko': u':여자_판사:',
        'pt': u':juíza:',
        'it': ':giudice_donna:',
        'fa': u':قاضی_زن:',
        'id': ':hakim_wanita:',
        'zh': u':女法官:'
    },
    u'\U0001F469\U0000200D\U00002696': { # 👩‍⚖
        'en' : ':woman_judge:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richterin:',
        'es': ':fiscal_mujer:',
        'fr': ':juge_femme:',
        'ja': u':女性の裁判官:',
        'ko': u':여자_판사:',
        'pt': u':juíza:',
        'it': ':giudice_donna:',
        'fa': u':قاضی_زن:',
        'id': ':hakim_wanita:',
        'zh': u':女法官:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002696\U0000FE0F': { # 👩🏿‍⚖️
        'en' : ':woman_judge_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richterin_dunkle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_oscuro:',
        'fr': u':juge_femme_peau_foncée:',
        'ja': u':女性の裁判官_濃い肌色:',
        'ko': u':여자_판사_검은색_피부:',
        'pt': u':juíza_pele_escura:',
        'it': ':giudice_donna_carnagione_scura:',
        'fa': u':قاضی_زن_پوست_آبنوسی:',
        'id': ':hakim_wanita_warna_kulit_gelap:',
        'zh': u':女法官_较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002696': { # 👩🏿‍⚖
        'en' : ':woman_judge_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richterin_dunkle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_oscuro:',
        'fr': u':juge_femme_peau_foncée:',
        'ja': u':女性の裁判官_濃い肌色:',
        'ko': u':여자_판사_검은색_피부:',
        'pt': u':juíza_pele_escura:',
        'it': ':giudice_donna_carnagione_scura:',
        'fa': u':قاضی_زن_پوست_آبنوسی:',
        'id': ':hakim_wanita_warna_kulit_gelap:',
        'zh': u':女法官_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002696\U0000FE0F': { # 👩🏻‍⚖️
        'en' : ':woman_judge_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richterin_helle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_claro:',
        'fr': ':juge_femme_peau_claire:',
        'ja': u':女性の裁判官_薄い肌色:',
        'ko': u':여자_판사_하얀_피부:',
        'pt': u':juíza_pele_clara:',
        'it': ':giudice_donna_carnagione_chiara:',
        'fa': u':قاضی_زن_پوست_سفید:',
        'id': ':hakim_wanita_warna_kulit_cerah:',
        'zh': u':女法官_较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002696': { # 👩🏻‍⚖
        'en' : ':woman_judge_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richterin_helle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_claro:',
        'fr': ':juge_femme_peau_claire:',
        'ja': u':女性の裁判官_薄い肌色:',
        'ko': u':여자_판사_하얀_피부:',
        'pt': u':juíza_pele_clara:',
        'it': ':giudice_donna_carnagione_chiara:',
        'fa': u':قاضی_زن_پوست_سفید:',
        'id': ':hakim_wanita_warna_kulit_cerah:',
        'zh': u':女法官_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002696\U0000FE0F': { # 👩🏾‍⚖️
        'en' : ':woman_judge_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richterin_mitteldunkle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':juge_femme_peau_mate:',
        'ja': u':女性の裁判官_やや濃い肌色:',
        'ko': u':여자_판사_진한_갈색_피부:',
        'pt': u':juíza_pele_morena_escura:',
        'it': ':giudice_donna_carnagione_abbastanza_scura:',
        'fa': u':قاضی_زن_پوست_گندمی:',
        'id': ':hakim_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女法官_中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002696': { # 👩🏾‍⚖
        'en' : ':woman_judge_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richterin_mitteldunkle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':juge_femme_peau_mate:',
        'ja': u':女性の裁判官_やや濃い肌色:',
        'ko': u':여자_판사_진한_갈색_피부:',
        'pt': u':juíza_pele_morena_escura:',
        'it': ':giudice_donna_carnagione_abbastanza_scura:',
        'fa': u':قاضی_زن_پوست_گندمی:',
        'id': ':hakim_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女法官_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002696\U0000FE0F': { # 👩🏼‍⚖️
        'en' : ':woman_judge_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richterin_mittelhelle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_claro_medio:',
        'fr': ':juge_femme_peau_moyennement_claire:',
        'ja': u':女性の裁判官_やや薄い肌色:',
        'ko': u':여자_판사_연한_갈색_피부:',
        'pt': u':juíza_pele_morena_clara:',
        'it': ':giudice_donna_carnagione_abbastanza_chiara:',
        'fa': u':قاضی_زن_پوست_روشن:',
        'id': ':hakim_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女法官_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002696': { # 👩🏼‍⚖
        'en' : ':woman_judge_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richterin_mittelhelle_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_claro_medio:',
        'fr': ':juge_femme_peau_moyennement_claire:',
        'ja': u':女性の裁判官_やや薄い肌色:',
        'ko': u':여자_판사_연한_갈색_피부:',
        'pt': u':juíza_pele_morena_clara:',
        'it': ':giudice_donna_carnagione_abbastanza_chiara:',
        'fa': u':قاضی_زن_پوست_روشن:',
        'id': ':hakim_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女法官_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002696\U0000FE0F': { # 👩🏽‍⚖️
        'en' : ':woman_judge_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':richterin_mittlere_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_medio:',
        'fr': u':juge_femme_peau_légèrement_mate:',
        'ja': u':女性の裁判官_中間の肌色:',
        'ko': u':여자_판사_갈색_피부:',
        'pt': u':juíza_pele_morena:',
        'it': ':giudice_donna_carnagione_olivastra:',
        'fa': u':قاضی_زن_پوست_طلایی:',
        'id': ':hakim_wanita_warna_kulit_sedang:',
        'zh': u':女法官_中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002696': { # 👩🏽‍⚖
        'en' : ':woman_judge_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':richterin_mittlere_hautfarbe:',
        'es': ':fiscal_mujer_tono_de_piel_medio:',
        'fr': u':juge_femme_peau_légèrement_mate:',
        'ja': u':女性の裁判官_中間の肌色:',
        'ko': u':여자_판사_갈색_피부:',
        'pt': u':juíza_pele_morena:',
        'it': ':giudice_donna_carnagione_olivastra:',
        'fa': u':قاضی_زن_پوست_طلایی:',
        'id': ':hakim_wanita_warna_kulit_sedang:',
        'zh': u':女法官_中等肤色:'
    },
    u'\U0001F939\U0000200D\U00002640\U0000FE0F': { # 🤹‍♀️
        'en' : ':woman_juggling:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleurin:',
        'es': ':mujer_haciendo_malabares:',
        'fr': ':jongleuse:',
        'ja': u':ジャグリングをする女:',
        'ko': u':저글링하는_여자:',
        'pt': ':mulher_malabarista:',
        'it': ':giocoliere_donna:',
        'fa': u':زن_ژانگولربازی_می_کند:',
        'id': ':wanita_melempar:',
        'zh': u':女生抛接杂耍:'
    },
    u'\U0001F939\U0000200D\U00002640': { # 🤹‍♀
        'en' : ':woman_juggling:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleurin:',
        'es': ':mujer_haciendo_malabares:',
        'fr': ':jongleuse:',
        'ja': u':ジャグリングをする女:',
        'ko': u':저글링하는_여자:',
        'pt': ':mulher_malabarista:',
        'it': ':giocoliere_donna:',
        'fa': u':زن_ژانگولربازی_می_کند:',
        'id': ':wanita_melempar:',
        'zh': u':女生抛接杂耍:'
    },
    u'\U0001F939\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🤹🏿‍♀️
        'en' : ':woman_juggling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleurin_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_oscuro:',
        'fr': u':jongleuse_peau_foncée:',
        'ja': u':ジャグリングをする女_濃い肌色:',
        'ko': u':저글링하는_여자_검은색_피부:',
        'pt': ':mulher_malabarista_pele_escura:',
        'it': ':giocoliere_donna_carnagione_scura:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_آبنوسی:',
        'id': ':wanita_melempar_warna_kulit_gelap:',
        'zh': u':女生抛接杂耍_较深肤色:'
    },
    u'\U0001F939\U0001F3FF\U0000200D\U00002640': { # 🤹🏿‍♀
        'en' : ':woman_juggling_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleurin_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_oscuro:',
        'fr': u':jongleuse_peau_foncée:',
        'ja': u':ジャグリングをする女_濃い肌色:',
        'ko': u':저글링하는_여자_검은색_피부:',
        'pt': ':mulher_malabarista_pele_escura:',
        'it': ':giocoliere_donna_carnagione_scura:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_آبنوسی:',
        'id': ':wanita_melempar_warna_kulit_gelap:',
        'zh': u':女生抛接杂耍_较深肤色:'
    },
    u'\U0001F939\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🤹🏻‍♀️
        'en' : ':woman_juggling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleurin_helle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_claro:',
        'fr': ':jongleuse_peau_claire:',
        'ja': u':ジャグリングをする女_薄い肌色:',
        'ko': u':저글링하는_여자_하얀_피부:',
        'pt': ':mulher_malabarista_pele_clara:',
        'it': ':giocoliere_donna_carnagione_chiara:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_سفید:',
        'id': ':wanita_melempar_warna_kulit_cerah:',
        'zh': u':女生抛接杂耍_较浅肤色:'
    },
    u'\U0001F939\U0001F3FB\U0000200D\U00002640': { # 🤹🏻‍♀
        'en' : ':woman_juggling_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleurin_helle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_claro:',
        'fr': ':jongleuse_peau_claire:',
        'ja': u':ジャグリングをする女_薄い肌色:',
        'ko': u':저글링하는_여자_하얀_피부:',
        'pt': ':mulher_malabarista_pele_clara:',
        'it': ':giocoliere_donna_carnagione_chiara:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_سفید:',
        'id': ':wanita_melempar_warna_kulit_cerah:',
        'zh': u':女生抛接杂耍_较浅肤色:'
    },
    u'\U0001F939\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🤹🏾‍♀️
        'en' : ':woman_juggling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleurin_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_oscuro_medio:',
        'fr': ':jongleuse_peau_mate:',
        'ja': u':ジャグリングをする女_やや濃い肌色:',
        'ko': u':저글링하는_여자_진한_갈색_피부:',
        'pt': ':mulher_malabarista_pele_morena_escura:',
        'it': ':giocoliere_donna_carnagione_abbastanza_scura:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_گندمی:',
        'id': ':wanita_melempar_warna_kulit_gelap-sedang:',
        'zh': u':女生抛接杂耍_中等深肤色:'
    },
    u'\U0001F939\U0001F3FE\U0000200D\U00002640': { # 🤹🏾‍♀
        'en' : ':woman_juggling_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleurin_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_oscuro_medio:',
        'fr': ':jongleuse_peau_mate:',
        'ja': u':ジャグリングをする女_やや濃い肌色:',
        'ko': u':저글링하는_여자_진한_갈색_피부:',
        'pt': ':mulher_malabarista_pele_morena_escura:',
        'it': ':giocoliere_donna_carnagione_abbastanza_scura:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_گندمی:',
        'id': ':wanita_melempar_warna_kulit_gelap-sedang:',
        'zh': u':女生抛接杂耍_中等深肤色:'
    },
    u'\U0001F939\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🤹🏼‍♀️
        'en' : ':woman_juggling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleurin_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_claro_medio:',
        'fr': ':jongleuse_peau_moyennement_claire:',
        'ja': u':ジャグリングをする女_やや薄い肌色:',
        'ko': u':저글링하는_여자_연한_갈색_피부:',
        'pt': ':mulher_malabarista_pele_morena_clara:',
        'it': ':giocoliere_donna_carnagione_abbastanza_chiara:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_روشن:',
        'id': ':wanita_melempar_warna_kulit_cerah-sedang:',
        'zh': u':女生抛接杂耍_中等浅肤色:'
    },
    u'\U0001F939\U0001F3FC\U0000200D\U00002640': { # 🤹🏼‍♀
        'en' : ':woman_juggling_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleurin_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_claro_medio:',
        'fr': ':jongleuse_peau_moyennement_claire:',
        'ja': u':ジャグリングをする女_やや薄い肌色:',
        'ko': u':저글링하는_여자_연한_갈색_피부:',
        'pt': ':mulher_malabarista_pele_morena_clara:',
        'it': ':giocoliere_donna_carnagione_abbastanza_chiara:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_روشن:',
        'id': ':wanita_melempar_warna_kulit_cerah-sedang:',
        'zh': u':女生抛接杂耍_中等浅肤色:'
    },
    u'\U0001F939\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🤹🏽‍♀️
        'en' : ':woman_juggling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':jongleurin_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_medio:',
        'fr': u':jongleuse_peau_légèrement_mate:',
        'ja': u':ジャグリングをする女_中間の肌色:',
        'ko': u':저글링하는_여자_갈색_피부:',
        'pt': ':mulher_malabarista_pele_morena:',
        'it': ':giocoliere_donna_carnagione_olivastra:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_طلایی:',
        'id': ':wanita_melempar_warna_kulit_sedang:',
        'zh': u':女生抛接杂耍_中等肤色:'
    },
    u'\U0001F939\U0001F3FD\U0000200D\U00002640': { # 🤹🏽‍♀
        'en' : ':woman_juggling_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':jongleurin_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_malabares_tono_de_piel_medio:',
        'fr': u':jongleuse_peau_légèrement_mate:',
        'ja': u':ジャグリングをする女_中間の肌色:',
        'ko': u':저글링하는_여자_갈색_피부:',
        'pt': ':mulher_malabarista_pele_morena:',
        'it': ':giocoliere_donna_carnagione_olivastra:',
        'fa': u':زن_ژانگولربازی_می_کند_پوست_طلایی:',
        'id': ':wanita_melempar_warna_kulit_sedang:',
        'zh': u':女生抛接杂耍_中等肤色:'
    },
    u'\U0001F9CE\U0000200D\U00002640\U0000FE0F': { # 🧎‍♀️
        'en' : ':woman_kneeling:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':kneeling_woman:'],
        'de': ':kniende_frau:',
        'es': ':mujer_de_rodillas:',
        'fr': u':femme_à_genoux:',
        'ja': u':正座する女性:',
        'ko': u':무릎을_꿇은_여자:',
        'pt': ':mulher_ajoelhando:',
        'it': ':donna_inginocchiata:',
        'fa': u':زن_زانوزده:',
        'id': ':wanita_berlutut:',
        'zh': u':跪下的女人:'
    },
    u'\U0001F9CE\U0000200D\U00002640': { # 🧎‍♀
        'en' : ':woman_kneeling:',
        'status' : minimally_qualified,
        'E' : 12,
        'alias' : [':kneeling_woman:'],
        'de': ':kniende_frau:',
        'es': ':mujer_de_rodillas:',
        'fr': u':femme_à_genoux:',
        'ja': u':正座する女性:',
        'ko': u':무릎을_꿇은_여자:',
        'pt': ':mulher_ajoelhando:',
        'it': ':donna_inginocchiata:',
        'fa': u':زن_زانوزده:',
        'id': ':wanita_berlutut:',
        'zh': u':跪下的女人:'
    },
    u'\U0001F9CE\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧎🏿‍♀️
        'en' : ':woman_kneeling_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_frau_dunkle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_oscuro:',
        'fr': u':femme_à_genoux_peau_foncée:',
        'ja': u':正座する女性_濃い肌色:',
        'ko': u':무릎을_꿇은_여자_검은색_피부:',
        'pt': ':mulher_ajoelhando_pele_escura:',
        'it': ':donna_inginocchiata_carnagione_scura:',
        'fa': u':زن_زانوزده_پوست_آبنوسی:',
        'id': ':wanita_berlutut_warna_kulit_gelap:',
        'zh': u':跪下的女人_较深肤色:'
    },
    u'\U0001F9CE\U0001F3FF\U0000200D\U00002640': { # 🧎🏿‍♀
        'en' : ':woman_kneeling_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniende_frau_dunkle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_oscuro:',
        'fr': u':femme_à_genoux_peau_foncée:',
        'ja': u':正座する女性_濃い肌色:',
        'ko': u':무릎을_꿇은_여자_검은색_피부:',
        'pt': ':mulher_ajoelhando_pele_escura:',
        'it': ':donna_inginocchiata_carnagione_scura:',
        'fa': u':زن_زانوزده_پوست_آبنوسی:',
        'id': ':wanita_berlutut_warna_kulit_gelap:',
        'zh': u':跪下的女人_较深肤色:'
    },
    u'\U0001F9CE\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧎🏻‍♀️
        'en' : ':woman_kneeling_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_frau_helle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_claro:',
        'fr': u':femme_à_genoux_peau_claire:',
        'ja': u':正座する女性_薄い肌色:',
        'ko': u':무릎을_꿇은_여자_하얀_피부:',
        'pt': ':mulher_ajoelhando_pele_clara:',
        'it': ':donna_inginocchiata_carnagione_chiara:',
        'fa': u':زن_زانوزده_پوست_سفید:',
        'id': ':wanita_berlutut_warna_kulit_cerah:',
        'zh': u':跪下的女人_较浅肤色:'
    },
    u'\U0001F9CE\U0001F3FB\U0000200D\U00002640': { # 🧎🏻‍♀
        'en' : ':woman_kneeling_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniende_frau_helle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_claro:',
        'fr': u':femme_à_genoux_peau_claire:',
        'ja': u':正座する女性_薄い肌色:',
        'ko': u':무릎을_꿇은_여자_하얀_피부:',
        'pt': ':mulher_ajoelhando_pele_clara:',
        'it': ':donna_inginocchiata_carnagione_chiara:',
        'fa': u':زن_زانوزده_پوست_سفید:',
        'id': ':wanita_berlutut_warna_kulit_cerah:',
        'zh': u':跪下的女人_较浅肤色:'
    },
    u'\U0001F9CE\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧎🏾‍♀️
        'en' : ':woman_kneeling_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_oscuro_medio:',
        'fr': u':femme_à_genoux_peau_mate:',
        'ja': u':正座する女性_やや濃い肌色:',
        'ko': u':무릎을_꿇은_여자_진한_갈색_피부:',
        'pt': ':mulher_ajoelhando_pele_morena_escura:',
        'it': ':donna_inginocchiata_carnagione_abbastanza_scura:',
        'fa': u':زن_زانوزده_پوست_گندمی:',
        'id': ':wanita_berlutut_warna_kulit_gelap-sedang:',
        'zh': u':跪下的女人_中等深肤色:'
    },
    u'\U0001F9CE\U0001F3FE\U0000200D\U00002640': { # 🧎🏾‍♀
        'en' : ':woman_kneeling_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_oscuro_medio:',
        'fr': u':femme_à_genoux_peau_mate:',
        'ja': u':正座する女性_やや濃い肌色:',
        'ko': u':무릎을_꿇은_여자_진한_갈색_피부:',
        'pt': ':mulher_ajoelhando_pele_morena_escura:',
        'it': ':donna_inginocchiata_carnagione_abbastanza_scura:',
        'fa': u':زن_زانوزده_پوست_گندمی:',
        'id': ':wanita_berlutut_warna_kulit_gelap-sedang:',
        'zh': u':跪下的女人_中等深肤色:'
    },
    u'\U0001F9CE\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧎🏼‍♀️
        'en' : ':woman_kneeling_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_claro_medio:',
        'fr': u':femme_à_genoux_peau_moyennement_claire:',
        'ja': u':正座する女性_やや薄い肌色:',
        'ko': u':무릎을_꿇은_여자_연한_갈색_피부:',
        'pt': ':mulher_ajoelhando_pele_morena_clara:',
        'it': ':donna_inginocchiata_carnagione_abbastanza_chiara:',
        'fa': u':زن_زانوزده_پوست_روشن:',
        'id': ':wanita_berlutut_warna_kulit_cerah-sedang:',
        'zh': u':跪下的女人_中等浅肤色:'
    },
    u'\U0001F9CE\U0001F3FC\U0000200D\U00002640': { # 🧎🏼‍♀
        'en' : ':woman_kneeling_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_claro_medio:',
        'fr': u':femme_à_genoux_peau_moyennement_claire:',
        'ja': u':正座する女性_やや薄い肌色:',
        'ko': u':무릎을_꿇은_여자_연한_갈색_피부:',
        'pt': ':mulher_ajoelhando_pele_morena_clara:',
        'it': ':donna_inginocchiata_carnagione_abbastanza_chiara:',
        'fa': u':زن_زانوزده_پوست_روشن:',
        'id': ':wanita_berlutut_warna_kulit_cerah-sedang:',
        'zh': u':跪下的女人_中等浅肤色:'
    },
    u'\U0001F9CE\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧎🏽‍♀️
        'en' : ':woman_kneeling_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':kniende_frau_mittlere_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_medio:',
        'fr': u':femme_à_genoux_peau_légèrement_mate:',
        'ja': u':正座する女性_中間の肌色:',
        'ko': u':무릎을_꿇은_여자_갈색_피부:',
        'pt': ':mulher_ajoelhando_pele_morena:',
        'it': ':donna_inginocchiata_carnagione_olivastra:',
        'fa': u':زن_زانوزده_پوست_طلایی:',
        'id': ':wanita_berlutut_warna_kulit_sedang:',
        'zh': u':跪下的女人_中等肤色:'
    },
    u'\U0001F9CE\U0001F3FD\U0000200D\U00002640': { # 🧎🏽‍♀
        'en' : ':woman_kneeling_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':kniende_frau_mittlere_hautfarbe:',
        'es': ':mujer_de_rodillas_tono_de_piel_medio:',
        'fr': u':femme_à_genoux_peau_légèrement_mate:',
        'ja': u':正座する女性_中間の肌色:',
        'ko': u':무릎을_꿇은_여자_갈색_피부:',
        'pt': ':mulher_ajoelhando_pele_morena:',
        'it': ':donna_inginocchiata_carnagione_olivastra:',
        'fa': u':زن_زانوزده_پوست_طلایی:',
        'id': ':wanita_berlutut_warna_kulit_sedang:',
        'zh': u':跪下的女人_中等肤色:'
    },
    u'\U0001F3CB\U0000FE0F\U0000200D\U00002640\U0000FE0F': { # 🏋️‍♀️
        'en' : ':woman_lifting_weights:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':weight_lifting_woman:'],
        'de': ':gewichtheberin:',
        'es': ':mujer_levantando_pesas:',
        'fr': u':femme_haltérophile:',
        'ja': u':重量挙げをする女:',
        'ko': u':여자_역도_선수:',
        'pt': ':mulher_levantando_peso:',
        'it': ':donna_che_solleva_pesi:',
        'fa': u':وزنه_بردار_زن:',
        'id': ':wanita_mengangkat_beban:',
        'zh': u':女生举重:'
    },
    u'\U0001F3CB\U0000200D\U00002640\U0000FE0F': { # 🏋‍♀️
        'en' : ':woman_lifting_weights:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':weight_lifting_woman:'],
        'de': ':gewichtheberin:',
        'es': ':mujer_levantando_pesas:',
        'fr': u':femme_haltérophile:',
        'ja': u':重量挙げをする女:',
        'ko': u':여자_역도_선수:',
        'pt': ':mulher_levantando_peso:',
        'it': ':donna_che_solleva_pesi:',
        'fa': u':وزنه_بردار_زن:',
        'id': ':wanita_mengangkat_beban:',
        'zh': u':女生举重:'
    },
    u'\U0001F3CB\U0000FE0F\U0000200D\U00002640': { # 🏋️‍♀
        'en' : ':woman_lifting_weights:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':weight_lifting_woman:'],
        'de': ':gewichtheberin:',
        'es': ':mujer_levantando_pesas:',
        'fr': u':femme_haltérophile:',
        'ja': u':重量挙げをする女:',
        'ko': u':여자_역도_선수:',
        'pt': ':mulher_levantando_peso:',
        'it': ':donna_che_solleva_pesi:',
        'fa': u':وزنه_بردار_زن:',
        'id': ':wanita_mengangkat_beban:',
        'zh': u':女生举重:'
    },
    u'\U0001F3CB\U0000200D\U00002640': { # 🏋‍♀
        'en' : ':woman_lifting_weights:',
        'status' : unqualified,
        'E' : 4,
        'alias' : [':weight_lifting_woman:'],
        'de': ':gewichtheberin:',
        'es': ':mujer_levantando_pesas:',
        'fr': u':femme_haltérophile:',
        'ja': u':重量挙げをする女:',
        'ko': u':여자_역도_선수:',
        'pt': ':mulher_levantando_peso:',
        'it': ':donna_che_solleva_pesi:',
        'fa': u':وزنه_بردار_زن:',
        'id': ':wanita_mengangkat_beban:',
        'zh': u':女生举重:'
    },
    u'\U0001F3CB\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🏋🏿‍♀️
        'en' : ':woman_lifting_weights_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheberin_dunkle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_oscuro:',
        'fr': u':femme_haltérophile_peau_foncée:',
        'ja': u':重量挙げをする女_濃い肌色:',
        'ko': u':여자_역도_선수_검은색_피부:',
        'pt': ':mulher_levantando_peso_pele_escura:',
        'it': ':donna_che_solleva_pesi_carnagione_scura:',
        'fa': u':وزنه_بردار_زن_پوست_آبنوسی:',
        'id': ':wanita_mengangkat_beban_warna_kulit_gelap:',
        'zh': u':女生举重_较深肤色:'
    },
    u'\U0001F3CB\U0001F3FF\U0000200D\U00002640': { # 🏋🏿‍♀
        'en' : ':woman_lifting_weights_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheberin_dunkle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_oscuro:',
        'fr': u':femme_haltérophile_peau_foncée:',
        'ja': u':重量挙げをする女_濃い肌色:',
        'ko': u':여자_역도_선수_검은색_피부:',
        'pt': ':mulher_levantando_peso_pele_escura:',
        'it': ':donna_che_solleva_pesi_carnagione_scura:',
        'fa': u':وزنه_بردار_زن_پوست_آبنوسی:',
        'id': ':wanita_mengangkat_beban_warna_kulit_gelap:',
        'zh': u':女生举重_较深肤色:'
    },
    u'\U0001F3CB\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🏋🏻‍♀️
        'en' : ':woman_lifting_weights_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheberin_helle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_claro:',
        'fr': u':femme_haltérophile_peau_claire:',
        'ja': u':重量挙げをする女_薄い肌色:',
        'ko': u':여자_역도_선수_하얀_피부:',
        'pt': ':mulher_levantando_peso_pele_clara:',
        'it': ':donna_che_solleva_pesi_carnagione_chiara:',
        'fa': u':وزنه_بردار_زن_پوست_سفید:',
        'id': ':wanita_mengangkat_beban_warna_kulit_cerah:',
        'zh': u':女生举重_较浅肤色:'
    },
    u'\U0001F3CB\U0001F3FB\U0000200D\U00002640': { # 🏋🏻‍♀
        'en' : ':woman_lifting_weights_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheberin_helle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_claro:',
        'fr': u':femme_haltérophile_peau_claire:',
        'ja': u':重量挙げをする女_薄い肌色:',
        'ko': u':여자_역도_선수_하얀_피부:',
        'pt': ':mulher_levantando_peso_pele_clara:',
        'it': ':donna_che_solleva_pesi_carnagione_chiara:',
        'fa': u':وزنه_بردار_زن_پوست_سفید:',
        'id': ':wanita_mengangkat_beban_warna_kulit_cerah:',
        'zh': u':女生举重_较浅肤色:'
    },
    u'\U0001F3CB\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🏋🏾‍♀️
        'en' : ':woman_lifting_weights_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheberin_mitteldunkle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_oscuro_medio:',
        'fr': u':femme_haltérophile_peau_mate:',
        'ja': u':重量挙げをする女_やや濃い肌色:',
        'ko': u':여자_역도_선수_진한_갈색_피부:',
        'pt': ':mulher_levantando_peso_pele_morena_escura:',
        'it': ':donna_che_solleva_pesi_carnagione_abbastanza_scura:',
        'fa': u':وزنه_بردار_زن_پوست_گندمی:',
        'id': ':wanita_mengangkat_beban_warna_kulit_gelap-sedang:',
        'zh': u':女生举重_中等深肤色:'
    },
    u'\U0001F3CB\U0001F3FE\U0000200D\U00002640': { # 🏋🏾‍♀
        'en' : ':woman_lifting_weights_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheberin_mitteldunkle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_oscuro_medio:',
        'fr': u':femme_haltérophile_peau_mate:',
        'ja': u':重量挙げをする女_やや濃い肌色:',
        'ko': u':여자_역도_선수_진한_갈색_피부:',
        'pt': ':mulher_levantando_peso_pele_morena_escura:',
        'it': ':donna_che_solleva_pesi_carnagione_abbastanza_scura:',
        'fa': u':وزنه_بردار_زن_پوست_گندمی:',
        'id': ':wanita_mengangkat_beban_warna_kulit_gelap-sedang:',
        'zh': u':女生举重_中等深肤色:'
    },
    u'\U0001F3CB\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🏋🏼‍♀️
        'en' : ':woman_lifting_weights_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheberin_mittelhelle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_claro_medio:',
        'fr': u':femme_haltérophile_peau_moyennement_claire:',
        'ja': u':重量挙げをする女_やや薄い肌色:',
        'ko': u':여자_역도_선수_연한_갈색_피부:',
        'pt': ':mulher_levantando_peso_pele_morena_clara:',
        'it': ':donna_che_solleva_pesi_carnagione_abbastanza_chiara:',
        'fa': u':وزنه_بردار_زن_پوست_روشن:',
        'id': ':wanita_mengangkat_beban_warna_kulit_cerah-sedang:',
        'zh': u':女生举重_中等浅肤色:'
    },
    u'\U0001F3CB\U0001F3FC\U0000200D\U00002640': { # 🏋🏼‍♀
        'en' : ':woman_lifting_weights_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheberin_mittelhelle_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_claro_medio:',
        'fr': u':femme_haltérophile_peau_moyennement_claire:',
        'ja': u':重量挙げをする女_やや薄い肌色:',
        'ko': u':여자_역도_선수_연한_갈색_피부:',
        'pt': ':mulher_levantando_peso_pele_morena_clara:',
        'it': ':donna_che_solleva_pesi_carnagione_abbastanza_chiara:',
        'fa': u':وزنه_بردار_زن_پوست_روشن:',
        'id': ':wanita_mengangkat_beban_warna_kulit_cerah-sedang:',
        'zh': u':女生举重_中等浅肤色:'
    },
    u'\U0001F3CB\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🏋🏽‍♀️
        'en' : ':woman_lifting_weights_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':gewichtheberin_mittlere_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_medio:',
        'fr': u':femme_haltérophile_peau_légèrement_mate:',
        'ja': u':重量挙げをする女_中間の肌色:',
        'ko': u':여자_역도_선수_갈색_피부:',
        'pt': ':mulher_levantando_peso_pele_morena:',
        'it': ':donna_che_solleva_pesi_carnagione_olivastra:',
        'fa': u':وزنه_بردار_زن_پوست_طلایی:',
        'id': ':wanita_mengangkat_beban_warna_kulit_sedang:',
        'zh': u':女生举重_中等肤色:'
    },
    u'\U0001F3CB\U0001F3FD\U0000200D\U00002640': { # 🏋🏽‍♀
        'en' : ':woman_lifting_weights_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':gewichtheberin_mittlere_hautfarbe:',
        'es': ':mujer_levantando_pesas_tono_de_piel_medio:',
        'fr': u':femme_haltérophile_peau_légèrement_mate:',
        'ja': u':重量挙げをする女_中間の肌色:',
        'ko': u':여자_역도_선수_갈색_피부:',
        'pt': ':mulher_levantando_peso_pele_morena:',
        'it': ':donna_che_solleva_pesi_carnagione_olivastra:',
        'fa': u':وزنه_بردار_زن_پوست_طلایی:',
        'id': ':wanita_mengangkat_beban_warna_kulit_sedang:',
        'zh': u':女生举重_中等肤色:'
    },
    u'\U0001F469\U0001F3FB': { # 👩🏻
        'en' : ':woman_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':frau_helle_hautfarbe:',
        'es': ':mujer_tono_de_piel_claro:',
        'fr': ':femme_peau_claire:',
        'ja': u':女性_薄い肌色:',
        'ko': u':여자_하얀_피부:',
        'pt': ':mulher_pele_clara:',
        'it': ':donna_carnagione_chiara:',
        'fa': u':زن_پوست_سفید:',
        'id': ':wanita_warna_kulit_cerah:',
        'zh': u':女人_较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F9B2': { # 👩🏻‍🦲
        'en' : ':woman_light_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_helle_hautfarbe,_glatze:',
        'es': ':mujer_tono_de_piel_claro_y_sin_pelo:',
        'fr': ':femme_peau_claire_et_chauve:',
        'ja': u':女性_薄い肌色_はげ頭:',
        'ko': u':여자_하얀_피부_대머리:',
        'pt': ':mulher_pele_clara_e_careca:',
        'it': ':donna_carnagione_chiara_e_calvo:',
        'fa': u':زن_پوست_سفید_تاس:',
        'id': ':wanita_warna_kulit_cerah_gundul:',
        'zh': u':女人_较浅肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧔🏻‍♀️
        'en' : ':woman_light_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':frau_helle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_claro_y_barba:',
        'fr': ':femme_barbue__peau_claire:',
        'ja': u':あごひげの女性_薄い肌色:',
        'ko': u':수염_난_여자_하얀_피부:',
        'pt': ':mulher_pele_clara_e_barba:',
        'it': ':donna_con_la_barba_carnagione_chiara:',
        'fa': u':زن_پوست_سفید_ریش:',
        'id': ':wanita_warna_kulit_cerah_janggut:',
        'zh': u':有络腮胡子的女人_较浅肤色:'
    },
    u'\U0001F9D4\U0001F3FB\U0000200D\U00002640': { # 🧔🏻‍♀
        'en' : ':woman_light_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':frau_helle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_claro_y_barba:',
        'fr': ':femme_barbue__peau_claire:',
        'ja': u':あごひげの女性_薄い肌色:',
        'ko': u':수염_난_여자_하얀_피부:',
        'pt': ':mulher_pele_clara_e_barba:',
        'it': ':donna_con_la_barba_carnagione_chiara:',
        'fa': u':زن_پوست_سفید_ریش:',
        'id': ':wanita_warna_kulit_cerah_janggut:',
        'zh': u':有络腮胡子的女人_较浅肤色:'
    },
    u'\U0001F471\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 👱🏻‍♀️
        'en' : ':woman_light_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_helle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_claro:',
        'fr': ':femme_blonde_peau_claire:',
        'ja': u':金髪の女性_薄い肌色:',
        'ko': u':금발_여자_하얀_피부:',
        'pt': ':mulher_pele_clara_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_chiara:',
        'fa': u':زن_پوست_سفید_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_cerah:',
        'zh': u':金发女_较浅肤色:'
    },
    u'\U0001F471\U0001F3FB\U0000200D\U00002640': { # 👱🏻‍♀
        'en' : ':woman_light_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_helle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_claro:',
        'fr': ':femme_blonde_peau_claire:',
        'ja': u':金髪の女性_薄い肌色:',
        'ko': u':금발_여자_하얀_피부:',
        'pt': ':mulher_pele_clara_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_chiara:',
        'fa': u':زن_پوست_سفید_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_cerah:',
        'zh': u':金发女_较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F9B1': { # 👩🏻‍🦱
        'en' : ':woman_light_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_helle_hautfarbe,_lockiges_haar:',
        'es': ':mujer_tono_de_piel_claro_y_pelo_rizado:',
        'fr': u':femme_peau_claire_et_cheveux_bouclés:',
        'ja': u':女性_薄い肌色_巻き毛:',
        'ko': u':여자_하얀_피부_곱슬머리:',
        'pt': ':mulher_pele_clara_e_cabelo_cacheado:',
        'it': ':donna_carnagione_chiara_e_capelli_ricci:',
        'fa': u':زن_پوست_سفید_موفرفری:',
        'id': ':wanita_warna_kulit_cerah_rambut_keriting:',
        'zh': u':女人_较浅肤色卷发:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F9B0': { # 👩🏻‍🦰
        'en' : ':woman_light_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_helle_hautfarbe,_rotes_haar:',
        'es': ':mujer_tono_de_piel_claro_y_pelo_pelirrojo:',
        'fr': ':femme_peau_claire_et_cheveux_roux:',
        'ja': u':女性_薄い肌色_赤毛:',
        'ko': u':여자_하얀_피부_빨간_머리:',
        'pt': ':mulher_pele_clara_e_cabelo_vermelho:',
        'it': ':donna_carnagione_chiara_e_capelli_rossi:',
        'fa': u':زن_پوست_سفید_موقرمز:',
        'id': ':wanita_warna_kulit_cerah_rambut_merah:',
        'zh': u':女人_较浅肤色红发:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F9B3': { # 👩🏻‍🦳
        'en' : ':woman_light_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':frau_helle_hautfarbe,_weißes_haar:',
        'es': ':mujer_tono_de_piel_claro_y_pelo_blanco:',
        'fr': ':femme_peau_claire_et_cheveux_blancs:',
        'ja': u':女性_薄い肌色_白髪:',
        'ko': u':여자_하얀_피부_백발:',
        'pt': ':mulher_pele_clara_e_cabelo_branco:',
        'it': ':donna_carnagione_chiara_e_capelli_bianchi:',
        'fa': u':زن_پوست_سفید_موسفید:',
        'id': ':wanita_warna_kulit_cerah_rambut_putih:',
        'zh': u':女人_较浅肤色白发:'
    },
    u'\U0001F9D9\U0000200D\U00002640\U0000FE0F': { # 🧙‍♀️
        'en' : ':woman_mage:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':mage_woman:'],
        'de': ':magierin:',
        'es': ':maga:',
        'fr': ':mage_femme:',
        'ja': u':女の魔法使い:',
        'ko': u':여자_마법사:',
        'pt': ':maga:',
        'it': ':maga:',
        'fa': u':ساحر_زن:',
        'id': ':magi_wanita:',
        'zh': u':女法师:'
    },
    u'\U0001F9D9\U0000200D\U00002640': { # 🧙‍♀
        'en' : ':woman_mage:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':mage_woman:'],
        'de': ':magierin:',
        'es': ':maga:',
        'fr': ':mage_femme:',
        'ja': u':女の魔法使い:',
        'ko': u':여자_마법사:',
        'pt': ':maga:',
        'it': ':maga:',
        'fa': u':ساحر_زن:',
        'id': ':magi_wanita:',
        'zh': u':女法师:'
    },
    u'\U0001F9D9\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧙🏿‍♀️
        'en' : ':woman_mage_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magierin_dunkle_hautfarbe:',
        'es': ':maga_tono_de_piel_oscuro:',
        'fr': u':mage_femme_peau_foncée:',
        'ja': u':女の魔法使い_濃い肌色:',
        'ko': u':여자_마법사_검은색_피부:',
        'pt': ':maga_pele_escura:',
        'it': ':maga_carnagione_scura:',
        'fa': u':ساحر_زن_پوست_آبنوسی:',
        'id': ':magi_wanita_warna_kulit_gelap:',
        'zh': u':女法师_较深肤色:'
    },
    u'\U0001F9D9\U0001F3FF\U0000200D\U00002640': { # 🧙🏿‍♀
        'en' : ':woman_mage_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magierin_dunkle_hautfarbe:',
        'es': ':maga_tono_de_piel_oscuro:',
        'fr': u':mage_femme_peau_foncée:',
        'ja': u':女の魔法使い_濃い肌色:',
        'ko': u':여자_마법사_검은색_피부:',
        'pt': ':maga_pele_escura:',
        'it': ':maga_carnagione_scura:',
        'fa': u':ساحر_زن_پوست_آبنوسی:',
        'id': ':magi_wanita_warna_kulit_gelap:',
        'zh': u':女法师_较深肤色:'
    },
    u'\U0001F9D9\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧙🏻‍♀️
        'en' : ':woman_mage_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magierin_helle_hautfarbe:',
        'es': ':maga_tono_de_piel_claro:',
        'fr': ':mage_femme_peau_claire:',
        'ja': u':女の魔法使い_薄い肌色:',
        'ko': u':여자_마법사_하얀_피부:',
        'pt': ':maga_pele_clara:',
        'it': ':maga_carnagione_chiara:',
        'fa': u':ساحر_زن_پوست_سفید:',
        'id': ':magi_wanita_warna_kulit_cerah:',
        'zh': u':女法师_较浅肤色:'
    },
    u'\U0001F9D9\U0001F3FB\U0000200D\U00002640': { # 🧙🏻‍♀
        'en' : ':woman_mage_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magierin_helle_hautfarbe:',
        'es': ':maga_tono_de_piel_claro:',
        'fr': ':mage_femme_peau_claire:',
        'ja': u':女の魔法使い_薄い肌色:',
        'ko': u':여자_마법사_하얀_피부:',
        'pt': ':maga_pele_clara:',
        'it': ':maga_carnagione_chiara:',
        'fa': u':ساحر_زن_پوست_سفید:',
        'id': ':magi_wanita_warna_kulit_cerah:',
        'zh': u':女法师_较浅肤色:'
    },
    u'\U0001F9D9\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧙🏾‍♀️
        'en' : ':woman_mage_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magierin_mitteldunkle_hautfarbe:',
        'es': ':maga_tono_de_piel_oscuro_medio:',
        'fr': ':mage_femme_peau_mate:',
        'ja': u':女の魔法使い_やや濃い肌色:',
        'ko': u':여자_마법사_진한_갈색_피부:',
        'pt': ':maga_pele_morena_escura:',
        'it': ':maga_carnagione_abbastanza_scura:',
        'fa': u':ساحر_زن_پوست_گندمی:',
        'id': ':magi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女法师_中等深肤色:'
    },
    u'\U0001F9D9\U0001F3FE\U0000200D\U00002640': { # 🧙🏾‍♀
        'en' : ':woman_mage_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magierin_mitteldunkle_hautfarbe:',
        'es': ':maga_tono_de_piel_oscuro_medio:',
        'fr': ':mage_femme_peau_mate:',
        'ja': u':女の魔法使い_やや濃い肌色:',
        'ko': u':여자_마법사_진한_갈색_피부:',
        'pt': ':maga_pele_morena_escura:',
        'it': ':maga_carnagione_abbastanza_scura:',
        'fa': u':ساحر_زن_پوست_گندمی:',
        'id': ':magi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女法师_中等深肤色:'
    },
    u'\U0001F9D9\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧙🏼‍♀️
        'en' : ':woman_mage_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magierin_mittelhelle_hautfarbe:',
        'es': ':maga_tono_de_piel_claro_medio:',
        'fr': ':mage_femme_peau_moyennement_claire:',
        'ja': u':女の魔法使い_やや薄い肌色:',
        'ko': u':여자_마법사_연한_갈색_피부:',
        'pt': ':maga_pele_morena_clara:',
        'it': ':maga_carnagione_abbastanza_chiara:',
        'fa': u':ساحر_زن_پوست_روشن:',
        'id': ':magi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女法师_中等浅肤色:'
    },
    u'\U0001F9D9\U0001F3FC\U0000200D\U00002640': { # 🧙🏼‍♀
        'en' : ':woman_mage_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magierin_mittelhelle_hautfarbe:',
        'es': ':maga_tono_de_piel_claro_medio:',
        'fr': ':mage_femme_peau_moyennement_claire:',
        'ja': u':女の魔法使い_やや薄い肌色:',
        'ko': u':여자_마법사_연한_갈색_피부:',
        'pt': ':maga_pele_morena_clara:',
        'it': ':maga_carnagione_abbastanza_chiara:',
        'fa': u':ساحر_زن_پوست_روشن:',
        'id': ':magi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女法师_中等浅肤色:'
    },
    u'\U0001F9D9\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧙🏽‍♀️
        'en' : ':woman_mage_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':magierin_mittlere_hautfarbe:',
        'es': ':maga_tono_de_piel_medio:',
        'fr': u':mage_femme_peau_légèrement_mate:',
        'ja': u':女の魔法使い_中間の肌色:',
        'ko': u':여자_마법사_갈색_피부:',
        'pt': ':maga_pele_morena:',
        'it': ':maga_carnagione_olivastra:',
        'fa': u':ساحر_زن_پوست_طلایی:',
        'id': ':magi_wanita_warna_kulit_sedang:',
        'zh': u':女法师_中等肤色:'
    },
    u'\U0001F9D9\U0001F3FD\U0000200D\U00002640': { # 🧙🏽‍♀
        'en' : ':woman_mage_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':magierin_mittlere_hautfarbe:',
        'es': ':maga_tono_de_piel_medio:',
        'fr': u':mage_femme_peau_légèrement_mate:',
        'ja': u':女の魔法使い_中間の肌色:',
        'ko': u':여자_마법사_갈색_피부:',
        'pt': ':maga_pele_morena:',
        'it': ':maga_carnagione_olivastra:',
        'fa': u':ساحر_زن_پوست_طلایی:',
        'id': ':magi_wanita_warna_kulit_sedang:',
        'zh': u':女法师_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F527': { # 👩‍🔧
        'en' : ':woman_mechanic:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechanikerin:',
        'es': u':profesional_de_la_mecánica_mujer:',
        'fr': u':mécanicienne:',
        'ja': u':女性の整備士:',
        'ko': u':여자_정비공:',
        'pt': u':mecânica:',
        'it': ':meccanico_donna:',
        'fa': u':تعمیرکار_زن:',
        'id': ':montir_wanita:',
        'zh': u':女技工:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F527': { # 👩🏿‍🔧
        'en' : ':woman_mechanic_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechanikerin_dunkle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_mujer_tono_de_piel_oscuro:',
        'fr': u':mécanicienne_peau_foncée:',
        'ja': u':女性の整備士_濃い肌色:',
        'ko': u':여자_정비공_검은색_피부:',
        'pt': u':mecânica_pele_escura:',
        'it': ':meccanico_donna_carnagione_scura:',
        'fa': u':تعمیرکار_زن_پوست_آبنوسی:',
        'id': ':montir_wanita_warna_kulit_gelap:',
        'zh': u':女技工_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F527': { # 👩🏻‍🔧
        'en' : ':woman_mechanic_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechanikerin_helle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_mujer_tono_de_piel_claro:',
        'fr': u':mécanicienne_peau_claire:',
        'ja': u':女性の整備士_薄い肌色:',
        'ko': u':여자_정비공_하얀_피부:',
        'pt': u':mecânica_pele_clara:',
        'it': ':meccanico_donna_carnagione_chiara:',
        'fa': u':تعمیرکار_زن_پوست_سفید:',
        'id': ':montir_wanita_warna_kulit_cerah:',
        'zh': u':女技工_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F527': { # 👩🏾‍🔧
        'en' : ':woman_mechanic_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechanikerin_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':mécanicienne_peau_mate:',
        'ja': u':女性の整備士_やや濃い肌色:',
        'ko': u':여자_정비공_진한_갈색_피부:',
        'pt': u':mecânica_pele_morena_escura:',
        'it': ':meccanico_donna_carnagione_abbastanza_scura:',
        'fa': u':تعمیرکار_زن_پوست_گندمی:',
        'id': ':montir_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女技工_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F527': { # 👩🏼‍🔧
        'en' : ':woman_mechanic_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechanikerin_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_mecánica_mujer_tono_de_piel_claro_medio:',
        'fr': u':mécanicienne_peau_moyennement_claire:',
        'ja': u':女性の整備士_やや薄い肌色:',
        'ko': u':여자_정비공_연한_갈색_피부:',
        'pt': u':mecânica_pele_morena_clara:',
        'it': ':meccanico_donna_carnagione_abbastanza_chiara:',
        'fa': u':تعمیرکار_زن_پوست_روشن:',
        'id': ':montir_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女技工_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F527': { # 👩🏽‍🔧
        'en' : ':woman_mechanic_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mechanikerin_mittlere_hautfarbe:',
        'es': u':profesional_de_la_mecánica_mujer_tono_de_piel_medio:',
        'fr': u':mécanicienne_peau_légèrement_mate:',
        'ja': u':女性の整備士_中間の肌色:',
        'ko': u':여자_정비공_갈색_피부:',
        'pt': u':mecânica_pele_morena:',
        'it': ':meccanico_donna_carnagione_olivastra:',
        'fa': u':تعمیرکار_زن_پوست_طلایی:',
        'id': ':montir_wanita_warna_kulit_sedang:',
        'zh': u':女技工_中等肤色:'
    },
    u'\U0001F469\U0001F3FE': { # 👩🏾
        'en' : ':woman_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_tono_de_piel_oscuro_medio:',
        'fr': ':femme_peau_mate:',
        'ja': u':女性_やや濃い肌色:',
        'ko': u':여자_진한_갈색_피부:',
        'pt': ':mulher_pele_morena_escura:',
        'it': ':donna_carnagione_abbastanza_scura:',
        'fa': u':زن_پوست_گندمی:',
        'id': ':wanita_warna_kulit_gelap-sedang:',
        'zh': u':女人_中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F9B2': { # 👩🏾‍🦲
        'en' : ':woman_medium-dark_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mitteldunkle_hautfarbe,_glatze:',
        'es': ':mujer_tono_de_piel_oscuro_medio_y_sin_pelo:',
        'fr': ':femme_peau_mate_et_chauve:',
        'ja': u':女性_やや濃い肌色_はげ頭:',
        'ko': u':여자_진한_갈색_피부_대머리:',
        'pt': ':mulher_pele_morena_escura_e_careca:',
        'it': ':donna_carnagione_abbastanza_scura_e_calvo:',
        'fa': u':زن_پوست_گندمی_تاس:',
        'id': ':wanita_warna_kulit_gelap-sedang_gundul:',
        'zh': u':女人_中等深肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧔🏾‍♀️
        'en' : ':woman_medium-dark_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':frau_mitteldunkle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_oscuro_medio_y_barba:',
        'fr': ':femme_barbue__peau_mate:',
        'ja': u':あごひげの女性_やや濃い肌色:',
        'ko': u':수염_난_여자_진한_갈색_피부:',
        'pt': ':mulher_pele_morena_escura_e_barba:',
        'it': ':donna_con_la_barba_carnagione_abbastanza_scura:',
        'fa': u':زن_پوست_گندمی_ریش:',
        'id': ':wanita_warna_kulit_gelap-sedang_janggut:',
        'zh': u':有络腮胡子的女人_中等深肤色:'
    },
    u'\U0001F9D4\U0001F3FE\U0000200D\U00002640': { # 🧔🏾‍♀
        'en' : ':woman_medium-dark_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':frau_mitteldunkle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_oscuro_medio_y_barba:',
        'fr': ':femme_barbue__peau_mate:',
        'ja': u':あごひげの女性_やや濃い肌色:',
        'ko': u':수염_난_여자_진한_갈색_피부:',
        'pt': ':mulher_pele_morena_escura_e_barba:',
        'it': ':donna_con_la_barba_carnagione_abbastanza_scura:',
        'fa': u':زن_پوست_گندمی_ریش:',
        'id': ':wanita_warna_kulit_gelap-sedang_janggut:',
        'zh': u':有络腮胡子的女人_中等深肤色:'
    },
    u'\U0001F471\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 👱🏾‍♀️
        'en' : ':woman_medium-dark_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mitteldunkle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_oscuro_medio:',
        'fr': ':femme_blonde_peau_mate:',
        'ja': u':金髪の女性_やや濃い肌色:',
        'ko': u':금발_여자_진한_갈색_피부:',
        'pt': ':mulher_pele_morena_escura_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_abbastanza_scura:',
        'fa': u':زن_پوست_گندمی_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_gelap-sedang:',
        'zh': u':金发女_中等深肤色:'
    },
    u'\U0001F471\U0001F3FE\U0000200D\U00002640': { # 👱🏾‍♀
        'en' : ':woman_medium-dark_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mitteldunkle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_oscuro_medio:',
        'fr': ':femme_blonde_peau_mate:',
        'ja': u':金髪の女性_やや濃い肌色:',
        'ko': u':금발_여자_진한_갈색_피부:',
        'pt': ':mulher_pele_morena_escura_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_abbastanza_scura:',
        'fa': u':زن_پوست_گندمی_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_gelap-sedang:',
        'zh': u':金发女_中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F9B1': { # 👩🏾‍🦱
        'en' : ':woman_medium-dark_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mitteldunkle_hautfarbe,_lockiges_haar:',
        'es': ':mujer_tono_de_piel_oscuro_medio_y_pelo_rizado:',
        'fr': u':femme_peau_mate_et_cheveux_bouclés:',
        'ja': u':女性_やや濃い肌色_巻き毛:',
        'ko': u':여자_진한_갈색_피부_곱슬머리:',
        'pt': ':mulher_pele_morena_escura_e_cabelo_cacheado:',
        'it': ':donna_carnagione_abbastanza_scura_e_capelli_ricci:',
        'fa': u':زن_پوست_گندمی_موفرفری:',
        'id': ':wanita_warna_kulit_gelap-sedang_rambut_keriting:',
        'zh': u':女人_中等深肤色卷发:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F9B0': { # 👩🏾‍🦰
        'en' : ':woman_medium-dark_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mitteldunkle_hautfarbe,_rotes_haar:',
        'es': ':mujer_tono_de_piel_oscuro_medio_y_pelo_pelirrojo:',
        'fr': ':femme_peau_mate_et_cheveux_roux:',
        'ja': u':女性_やや濃い肌色_赤毛:',
        'ko': u':여자_진한_갈색_피부_빨간_머리:',
        'pt': ':mulher_pele_morena_escura_e_cabelo_vermelho:',
        'it': ':donna_carnagione_abbastanza_scura_e_capelli_rossi:',
        'fa': u':زن_پوست_گندمی_موقرمز:',
        'id': ':wanita_warna_kulit_gelap-sedang_rambut_merah:',
        'zh': u':女人_中等深肤色红发:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F9B3': { # 👩🏾‍🦳
        'en' : ':woman_medium-dark_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':frau_mitteldunkle_hautfarbe,_weißes_haar:',
        'es': ':mujer_tono_de_piel_oscuro_medio_y_pelo_blanco:',
        'fr': ':femme_peau_mate_et_cheveux_blancs:',
        'ja': u':女性_やや濃い肌色_白髪:',
        'ko': u':여자_진한_갈색_피부_백발:',
        'pt': ':mulher_pele_morena_escura_e_cabelo_branco:',
        'it': ':donna_carnagione_abbastanza_scura_e_capelli_bianchi:',
        'fa': u':زن_پوست_گندمی_موسفید:',
        'id': ':wanita_warna_kulit_gelap-sedang_rambut_putih:',
        'zh': u':女人_中等深肤色白发:'
    },
    u'\U0001F469\U0001F3FC': { # 👩🏼
        'en' : ':woman_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':frau_mittelhelle_hautfarbe:',
        'es': ':mujer_tono_de_piel_claro_medio:',
        'fr': ':femme_peau_moyennement_claire:',
        'ja': u':女性_やや薄い肌色:',
        'ko': u':여자_연한_갈색_피부:',
        'pt': ':mulher_pele_morena_clara:',
        'it': ':donna_carnagione_abbastanza_chiara:',
        'fa': u':زن_پوست_روشن:',
        'id': ':wanita_warna_kulit_cerah-sedang:',
        'zh': u':女人_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F9B2': { # 👩🏼‍🦲
        'en' : ':woman_medium-light_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mittelhelle_hautfarbe,_glatze:',
        'es': ':mujer_tono_de_piel_claro_medio_y_sin_pelo:',
        'fr': ':femme_peau_moyennement_claire_et_chauve:',
        'ja': u':女性_やや薄い肌色_はげ頭:',
        'ko': u':여자_연한_갈색_피부_대머리:',
        'pt': ':mulher_pele_morena_clara_e_careca:',
        'it': ':donna_carnagione_abbastanza_chiara_e_calvo:',
        'fa': u':زن_پوست_روشن_تاس:',
        'id': ':wanita_warna_kulit_cerah-sedang_gundul:',
        'zh': u':女人_中等浅肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧔🏼‍♀️
        'en' : ':woman_medium-light_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':frau_mittelhelle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_claro_medio_y_barba:',
        'fr': ':femme_barbue__peau_moyennement_claire:',
        'ja': u':あごひげの女性_やや薄い肌色:',
        'ko': u':수염_난_여자_연한_갈색_피부:',
        'pt': ':mulher_pele_morena_clara_e_barba:',
        'it': ':donna_con_la_barba_carnagione_abbastanza_chiara:',
        'fa': u':زن_پوست_روشن_ریش:',
        'id': ':wanita_warna_kulit_cerah-sedang_janggut:',
        'zh': u':有络腮胡子的女人_中等浅肤色:'
    },
    u'\U0001F9D4\U0001F3FC\U0000200D\U00002640': { # 🧔🏼‍♀
        'en' : ':woman_medium-light_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':frau_mittelhelle_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_claro_medio_y_barba:',
        'fr': ':femme_barbue__peau_moyennement_claire:',
        'ja': u':あごひげの女性_やや薄い肌色:',
        'ko': u':수염_난_여자_연한_갈색_피부:',
        'pt': ':mulher_pele_morena_clara_e_barba:',
        'it': ':donna_con_la_barba_carnagione_abbastanza_chiara:',
        'fa': u':زن_پوست_روشن_ریش:',
        'id': ':wanita_warna_kulit_cerah-sedang_janggut:',
        'zh': u':有络腮胡子的女人_中等浅肤色:'
    },
    u'\U0001F471\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 👱🏼‍♀️
        'en' : ':woman_medium-light_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mittelhelle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_claro_medio:',
        'fr': ':femme_blonde_peau_moyennement_claire:',
        'ja': u':金髪の女性_やや薄い肌色:',
        'ko': u':금발_여자_연한_갈색_피부:',
        'pt': ':mulher_pele_morena_clara_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_abbastanza_chiara:',
        'fa': u':زن_پوست_روشن_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_cerah-sedang:',
        'zh': u':金发女_中等浅肤色:'
    },
    u'\U0001F471\U0001F3FC\U0000200D\U00002640': { # 👱🏼‍♀
        'en' : ':woman_medium-light_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mittelhelle_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_claro_medio:',
        'fr': ':femme_blonde_peau_moyennement_claire:',
        'ja': u':金髪の女性_やや薄い肌色:',
        'ko': u':금발_여자_연한_갈색_피부:',
        'pt': ':mulher_pele_morena_clara_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_abbastanza_chiara:',
        'fa': u':زن_پوست_روشن_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_cerah-sedang:',
        'zh': u':金发女_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F9B1': { # 👩🏼‍🦱
        'en' : ':woman_medium-light_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mittelhelle_hautfarbe,_lockiges_haar:',
        'es': ':mujer_tono_de_piel_claro_medio_y_pelo_rizado:',
        'fr': u':femme_peau_moyennement_claire_et_cheveux_bouclés:',
        'ja': u':女性_やや薄い肌色_巻き毛:',
        'ko': u':여자_연한_갈색_피부_곱슬머리:',
        'pt': ':mulher_pele_morena_clara_e_cabelo_cacheado:',
        'it': ':donna_carnagione_abbastanza_chiara_e_capelli_ricci:',
        'fa': u':زن_پوست_روشن_موفرفری:',
        'id': ':wanita_warna_kulit_cerah-sedang_rambut_keriting:',
        'zh': u':女人_中等浅肤色卷发:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F9B0': { # 👩🏼‍🦰
        'en' : ':woman_medium-light_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mittelhelle_hautfarbe,_rotes_haar:',
        'es': ':mujer_tono_de_piel_claro_medio_y_pelo_pelirrojo:',
        'fr': ':femme_peau_moyennement_claire_et_cheveux_roux:',
        'ja': u':女性_やや薄い肌色_赤毛:',
        'ko': u':여자_연한_갈색_피부_빨간_머리:',
        'pt': ':mulher_pele_morena_clara_e_cabelo_vermelho:',
        'it': ':donna_carnagione_abbastanza_chiara_e_capelli_rossi:',
        'fa': u':زن_پوست_روشن_موقرمز:',
        'id': ':wanita_warna_kulit_cerah-sedang_rambut_merah:',
        'zh': u':女人_中等浅肤色红发:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F9B3': { # 👩🏼‍🦳
        'en' : ':woman_medium-light_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':frau_mittelhelle_hautfarbe,_weißes_haar:',
        'es': ':mujer_tono_de_piel_claro_medio_y_pelo_blanco:',
        'fr': ':femme_peau_moyennement_claire_et_cheveux_blancs:',
        'ja': u':女性_やや薄い肌色_白髪:',
        'ko': u':여자_연한_갈색_피부_백발:',
        'pt': ':mulher_pele_morena_clara_e_cabelo_branco:',
        'it': ':donna_carnagione_abbastanza_chiara_e_capelli_bianchi:',
        'fa': u':زن_پوست_روشن_موسفید:',
        'id': ':wanita_warna_kulit_cerah-sedang_rambut_putih:',
        'zh': u':女人_中等浅肤色白发:'
    },
    u'\U0001F469\U0001F3FD': { # 👩🏽
        'en' : ':woman_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':frau_mittlere_hautfarbe:',
        'es': ':mujer_tono_de_piel_medio:',
        'fr': u':femme_peau_légèrement_mate:',
        'ja': u':女性_中間の肌色:',
        'ko': u':여자_갈색_피부:',
        'pt': ':mulher_pele_morena:',
        'it': ':donna_carnagione_olivastra:',
        'fa': u':زن_پوست_طلایی:',
        'id': ':wanita_warna_kulit_sedang:',
        'zh': u':女人_中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F9B2': { # 👩🏽‍🦲
        'en' : ':woman_medium_skin_tone_bald:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mittlere_hautfarbe,_glatze:',
        'es': ':mujer_tono_de_piel_medio_y_sin_pelo:',
        'fr': u':femme_peau_légèrement_mate_et_chauve:',
        'ja': u':女性_中間の肌色_はげ頭:',
        'ko': u':여자_갈색_피부_대머리:',
        'pt': ':mulher_pele_morena_e_careca:',
        'it': ':donna_carnagione_olivastra_e_calvo:',
        'fa': u':زن_پوست_طلایی_تاس:',
        'id': ':wanita_warna_kulit_sedang_gundul:',
        'zh': u':女人_中等肤色秃顶:'
    },
    u'\U0001F9D4\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧔🏽‍♀️
        'en' : ':woman_medium_skin_tone_beard:',
        'status' : fully_qualified,
        'E' : 13.1,
        'de': ':frau_mittlere_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_medio_y_barba:',
        'fr': u':femme_barbue__peau_légèrement_mate:',
        'ja': u':あごひげの女性_中間の肌色:',
        'ko': u':수염_난_여자_갈색_피부:',
        'pt': ':mulher_pele_morena_e_barba:',
        'it': ':donna_con_la_barba_carnagione_olivastra:',
        'fa': u':زن_پوست_طلایی_ریش:',
        'id': ':wanita_warna_kulit_sedang_janggut:',
        'zh': u':有络腮胡子的女人_中等肤色:'
    },
    u'\U0001F9D4\U0001F3FD\U0000200D\U00002640': { # 🧔🏽‍♀
        'en' : ':woman_medium_skin_tone_beard:',
        'status' : minimally_qualified,
        'E' : 13.1,
        'de': ':frau_mittlere_hautfarbe_bart:',
        'es': ':mujer_tono_de_piel_medio_y_barba:',
        'fr': u':femme_barbue__peau_légèrement_mate:',
        'ja': u':あごひげの女性_中間の肌色:',
        'ko': u':수염_난_여자_갈색_피부:',
        'pt': ':mulher_pele_morena_e_barba:',
        'it': ':donna_con_la_barba_carnagione_olivastra:',
        'fa': u':زن_پوست_طلایی_ریش:',
        'id': ':wanita_warna_kulit_sedang_janggut:',
        'zh': u':有络腮胡子的女人_中等肤色:'
    },
    u'\U0001F471\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 👱🏽‍♀️
        'en' : ':woman_medium_skin_tone_blond_hair:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mittlere_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_medio:',
        'fr': u':femme_blonde_peau_légèrement_mate:',
        'ja': u':金髪の女性_中間の肌色:',
        'ko': u':금발_여자_갈색_피부:',
        'pt': ':mulher_pele_morena_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_olivastra:',
        'fa': u':زن_پوست_طلایی_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_sedang:',
        'zh': u':金发女_中等肤色:'
    },
    u'\U0001F471\U0001F3FD\U0000200D\U00002640': { # 👱🏽‍♀
        'en' : ':woman_medium_skin_tone_blond_hair:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mittlere_hautfarbe,_blond:',
        'es': ':mujer_rubia_tono_de_piel_medio:',
        'fr': u':femme_blonde_peau_légèrement_mate:',
        'ja': u':金髪の女性_中間の肌色:',
        'ko': u':금발_여자_갈색_피부:',
        'pt': ':mulher_pele_morena_e_cabelo_loiro:',
        'it': ':donna_bionda_carnagione_olivastra:',
        'fa': u':زن_پوست_طلایی_موبور:',
        'id': ':wanita_berambut_pirang_warna_kulit_sedang:',
        'zh': u':金发女_中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F9B1': { # 👩🏽‍🦱
        'en' : ':woman_medium_skin_tone_curly_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mittlere_hautfarbe,_lockiges_haar:',
        'es': ':mujer_tono_de_piel_medio_y_pelo_rizado:',
        'fr': u':femme_peau_légèrement_mate_et_cheveux_bouclés:',
        'ja': u':女性_中間の肌色_巻き毛:',
        'ko': u':여자_갈색_피부_곱슬머리:',
        'pt': ':mulher_pele_morena_e_cabelo_cacheado:',
        'it': ':donna_carnagione_olivastra_e_capelli_ricci:',
        'fa': u':زن_پوست_طلایی_موفرفری:',
        'id': ':wanita_warna_kulit_sedang_rambut_keriting:',
        'zh': u':女人_中等肤色卷发:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F9B0': { # 👩🏽‍🦰
        'en' : ':woman_medium_skin_tone_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':frau_mittlere_hautfarbe,_rotes_haar:',
        'es': ':mujer_tono_de_piel_medio_y_pelo_pelirrojo:',
        'fr': u':femme_peau_légèrement_mate_et_cheveux_roux:',
        'ja': u':女性_中間の肌色_赤毛:',
        'ko': u':여자_갈색_피부_빨간_머리:',
        'pt': ':mulher_pele_morena_e_cabelo_vermelho:',
        'it': ':donna_carnagione_olivastra_e_capelli_rossi:',
        'fa': u':زن_پوست_طلایی_موقرمز:',
        'id': ':wanita_warna_kulit_sedang_rambut_merah:',
        'zh': u':女人_中等肤色红发:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F9B3': { # 👩🏽‍🦳
        'en' : ':woman_medium_skin_tone_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':frau_mittlere_hautfarbe,_weißes_haar:',
        'es': ':mujer_tono_de_piel_medio_y_pelo_blanco:',
        'fr': u':femme_peau_légèrement_mate_et_cheveux_blancs:',
        'ja': u':女性_中間の肌色_白髪:',
        'ko': u':여자_갈색_피부_백발:',
        'pt': ':mulher_pele_morena_e_cabelo_branco:',
        'it': ':donna_carnagione_olivastra_e_capelli_bianchi:',
        'fa': u':زن_پوست_طلایی_موسفید:',
        'id': ':wanita_warna_kulit_sedang_rambut_putih:',
        'zh': u':女人_中等肤色白发:'
    },
    u'\U0001F6B5\U0000200D\U00002640\U0000FE0F': { # 🚵‍♀️
        'en' : ':woman_mountain_biking:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':mountain_biking_woman:'],
        'de': ':mountainbikerin:',
        'es': u':mujer_en_bicicleta_de_montaña:',
        'fr': ':femme_en_vtt:',
        'ja': u':マウンテンバイクに乗る女:',
        'ko': u':산악_자전거_타는_여자:',
        'pt': ':mulher_fazendo_mountain_bike:',
        'it': ':ciclista_donna_di_mountain_bike:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان:',
        'id': ':wanita_bersepeda_gunung:',
        'zh': u':女生骑山地车:'
    },
    u'\U0001F6B5\U0000200D\U00002640': { # 🚵‍♀
        'en' : ':woman_mountain_biking:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':mountain_biking_woman:'],
        'de': ':mountainbikerin:',
        'es': u':mujer_en_bicicleta_de_montaña:',
        'fr': ':femme_en_vtt:',
        'ja': u':マウンテンバイクに乗る女:',
        'ko': u':산악_자전거_타는_여자:',
        'pt': ':mulher_fazendo_mountain_bike:',
        'it': ':ciclista_donna_di_mountain_bike:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان:',
        'id': ':wanita_bersepeda_gunung:',
        'zh': u':女生骑山地车:'
    },
    u'\U0001F6B5\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🚵🏿‍♀️
        'en' : ':woman_mountain_biking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbikerin_dunkle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_oscuro:',
        'fr': u':femme_en_vtt_peau_foncée:',
        'ja': u':マウンテンバイクに乗る女_濃い肌色:',
        'ko': u':산악_자전거_타는_여자_검은색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_escura:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_scura:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_آبنوسی:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_gelap:',
        'zh': u':女生骑山地车_较深肤色:'
    },
    u'\U0001F6B5\U0001F3FF\U0000200D\U00002640': { # 🚵🏿‍♀
        'en' : ':woman_mountain_biking_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbikerin_dunkle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_oscuro:',
        'fr': u':femme_en_vtt_peau_foncée:',
        'ja': u':マウンテンバイクに乗る女_濃い肌色:',
        'ko': u':산악_자전거_타는_여자_검은색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_escura:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_scura:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_آبنوسی:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_gelap:',
        'zh': u':女生骑山地车_较深肤色:'
    },
    u'\U0001F6B5\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🚵🏻‍♀️
        'en' : ':woman_mountain_biking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbikerin_helle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_claro:',
        'fr': ':femme_en_vtt_peau_claire:',
        'ja': u':マウンテンバイクに乗る女_薄い肌色:',
        'ko': u':산악_자전거_타는_여자_하얀_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_clara:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_chiara:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_سفید:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_cerah:',
        'zh': u':女生骑山地车_较浅肤色:'
    },
    u'\U0001F6B5\U0001F3FB\U0000200D\U00002640': { # 🚵🏻‍♀
        'en' : ':woman_mountain_biking_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbikerin_helle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_claro:',
        'fr': ':femme_en_vtt_peau_claire:',
        'ja': u':マウンテンバイクに乗る女_薄い肌色:',
        'ko': u':산악_자전거_타는_여자_하얀_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_clara:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_chiara:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_سفید:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_cerah:',
        'zh': u':女生骑山地车_较浅肤色:'
    },
    u'\U0001F6B5\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🚵🏾‍♀️
        'en' : ':woman_mountain_biking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbikerin_mitteldunkle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_oscuro_medio:',
        'fr': ':femme_en_vtt_peau_mate:',
        'ja': u':マウンテンバイクに乗る女_やや濃い肌色:',
        'ko': u':산악_자전거_타는_여자_진한_갈색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_morena_escura:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_abbastanza_scura:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_گندمی:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_gelap-sedang:',
        'zh': u':女生骑山地车_中等深肤色:'
    },
    u'\U0001F6B5\U0001F3FE\U0000200D\U00002640': { # 🚵🏾‍♀
        'en' : ':woman_mountain_biking_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbikerin_mitteldunkle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_oscuro_medio:',
        'fr': ':femme_en_vtt_peau_mate:',
        'ja': u':マウンテンバイクに乗る女_やや濃い肌色:',
        'ko': u':산악_자전거_타는_여자_진한_갈색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_morena_escura:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_abbastanza_scura:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_گندمی:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_gelap-sedang:',
        'zh': u':女生骑山地车_中等深肤色:'
    },
    u'\U0001F6B5\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🚵🏼‍♀️
        'en' : ':woman_mountain_biking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbikerin_mittelhelle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_claro_medio:',
        'fr': ':femme_en_vtt_peau_moyennement_claire:',
        'ja': u':マウンテンバイクに乗る女_やや薄い肌色:',
        'ko': u':산악_자전거_타는_여자_연한_갈색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_morena_clara:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_روشن:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_cerah-sedang:',
        'zh': u':女生骑山地车_中等浅肤色:'
    },
    u'\U0001F6B5\U0001F3FC\U0000200D\U00002640': { # 🚵🏼‍♀
        'en' : ':woman_mountain_biking_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbikerin_mittelhelle_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_claro_medio:',
        'fr': ':femme_en_vtt_peau_moyennement_claire:',
        'ja': u':マウンテンバイクに乗る女_やや薄い肌色:',
        'ko': u':산악_자전거_타는_여자_연한_갈색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_morena_clara:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_abbastanza_chiara:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_روشن:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_cerah-sedang:',
        'zh': u':女生骑山地车_中等浅肤色:'
    },
    u'\U0001F6B5\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🚵🏽‍♀️
        'en' : ':woman_mountain_biking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':mountainbikerin_mittlere_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_medio:',
        'fr': u':femme_en_vtt_peau_légèrement_mate:',
        'ja': u':マウンテンバイクに乗る女_中間の肌色:',
        'ko': u':산악_자전거_타는_여자_갈색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_morena:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_olivastra:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_طلایی:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_sedang:',
        'zh': u':女生骑山地车_中等肤色:'
    },
    u'\U0001F6B5\U0001F3FD\U0000200D\U00002640': { # 🚵🏽‍♀
        'en' : ':woman_mountain_biking_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':mountainbikerin_mittlere_hautfarbe:',
        'es': u':mujer_en_bicicleta_de_montaña_tono_de_piel_medio:',
        'fr': u':femme_en_vtt_peau_légèrement_mate:',
        'ja': u':マウンテンバイクに乗る女_中間の肌色:',
        'ko': u':산악_자전거_타는_여자_갈색_피부:',
        'pt': ':mulher_fazendo_mountain_bike_pele_morena:',
        'it': ':ciclista_donna_di_mountain_bike_carnagione_olivastra:',
        'fa': u':زن_و_دوچرخه_سواری_کوهستان_پوست_طلایی:',
        'id': ':wanita_bersepeda_gunung_warna_kulit_sedang:',
        'zh': u':女生骑山地车_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F4BC': { # 👩‍💼
        'en' : ':woman_office_worker:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellte:',
        'es': ':oficinista_mujer:',
        'fr': u':employée_de_bureau:',
        'ja': u':女性会社員:',
        'ko': u':여자_회사원:',
        'pt': u':funcionária_de_escritório:',
        'it': ':impiegata:',
        'fa': u':کارمند_زن:',
        'id': ':pekerja_kantor_wanita:',
        'zh': u':女白领:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F4BC': { # 👩🏿‍💼
        'en' : ':woman_office_worker_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellte_dunkle_hautfarbe:',
        'es': ':oficinista_mujer_tono_de_piel_oscuro:',
        'fr': u':employée_de_bureau_peau_foncée:',
        'ja': u':女性会社員_濃い肌色:',
        'ko': u':여자_회사원_검은색_피부:',
        'pt': u':funcionária_de_escritório_pele_escura:',
        'it': ':impiegata_carnagione_scura:',
        'fa': u':کارمند_زن_پوست_آبنوسی:',
        'id': ':pekerja_kantor_wanita_warna_kulit_gelap:',
        'zh': u':女白领_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F4BC': { # 👩🏻‍💼
        'en' : ':woman_office_worker_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellte_helle_hautfarbe:',
        'es': ':oficinista_mujer_tono_de_piel_claro:',
        'fr': u':employée_de_bureau_peau_claire:',
        'ja': u':女性会社員_薄い肌色:',
        'ko': u':여자_회사원_하얀_피부:',
        'pt': u':funcionária_de_escritório_pele_clara:',
        'it': ':impiegata_carnagione_chiara:',
        'fa': u':کارمند_زن_پوست_سفید:',
        'id': ':pekerja_kantor_wanita_warna_kulit_cerah:',
        'zh': u':女白领_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F4BC': { # 👩🏾‍💼
        'en' : ':woman_office_worker_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellte_mitteldunkle_hautfarbe:',
        'es': ':oficinista_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':employée_de_bureau_peau_mate:',
        'ja': u':女性会社員_やや濃い肌色:',
        'ko': u':여자_회사원_진한_갈색_피부:',
        'pt': u':funcionária_de_escritório_pele_morena_escura:',
        'it': ':impiegata_carnagione_abbastanza_scura:',
        'fa': u':کارمند_زن_پوست_گندمی:',
        'id': ':pekerja_kantor_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女白领_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F4BC': { # 👩🏼‍💼
        'en' : ':woman_office_worker_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellte_mittelhelle_hautfarbe:',
        'es': ':oficinista_mujer_tono_de_piel_claro_medio:',
        'fr': u':employée_de_bureau_peau_moyennement_claire:',
        'ja': u':女性会社員_やや薄い肌色:',
        'ko': u':여자_회사원_연한_갈색_피부:',
        'pt': u':funcionária_de_escritório_pele_morena_clara:',
        'it': ':impiegata_carnagione_abbastanza_chiara:',
        'fa': u':کارمند_زن_پوست_روشن:',
        'id': ':pekerja_kantor_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女白领_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F4BC': { # 👩🏽‍💼
        'en' : ':woman_office_worker_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':büroangestellte_mittlere_hautfarbe:',
        'es': ':oficinista_mujer_tono_de_piel_medio:',
        'fr': u':employée_de_bureau_peau_légèrement_mate:',
        'ja': u':女性会社員_中間の肌色:',
        'ko': u':여자_회사원_갈색_피부:',
        'pt': u':funcionária_de_escritório_pele_morena:',
        'it': ':impiegata_carnagione_olivastra:',
        'fa': u':کارمند_زن_پوست_طلایی:',
        'id': ':pekerja_kantor_wanita_warna_kulit_sedang:',
        'zh': u':女白领_中等肤色:'
    },
    u'\U0001F469\U0000200D\U00002708\U0000FE0F': { # 👩‍✈️
        'en' : ':woman_pilot:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilotin:',
        'es': ':piloto_mujer:',
        'fr': ':pilote_femme:',
        'ja': u':女性パイロット:',
        'ko': u':여자_기장:',
        'pt': u':piloto_de_avião_mulher:',
        'it': ':pilota_donna:',
        'fa': u':خلبان_زن:',
        'id': ':pilot_wanita:',
        'zh': u':女飞行员:'
    },
    u'\U0001F469\U0000200D\U00002708': { # 👩‍✈
        'en' : ':woman_pilot:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilotin:',
        'es': ':piloto_mujer:',
        'fr': ':pilote_femme:',
        'ja': u':女性パイロット:',
        'ko': u':여자_기장:',
        'pt': u':piloto_de_avião_mulher:',
        'it': ':pilota_donna:',
        'fa': u':خلبان_زن:',
        'id': ':pilot_wanita:',
        'zh': u':女飞行员:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002708\U0000FE0F': { # 👩🏿‍✈️
        'en' : ':woman_pilot_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilotin_dunkle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_oscuro:',
        'fr': u':pilote_femme_peau_foncée:',
        'ja': u':女性パイロット_濃い肌色:',
        'ko': u':여자_기장_검은색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_escura:',
        'it': ':pilota_donna_carnagione_scura:',
        'fa': u':خلبان_زن_پوست_آبنوسی:',
        'id': ':pilot_wanita_warna_kulit_gelap:',
        'zh': u':女飞行员_较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U00002708': { # 👩🏿‍✈
        'en' : ':woman_pilot_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilotin_dunkle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_oscuro:',
        'fr': u':pilote_femme_peau_foncée:',
        'ja': u':女性パイロット_濃い肌色:',
        'ko': u':여자_기장_검은색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_escura:',
        'it': ':pilota_donna_carnagione_scura:',
        'fa': u':خلبان_زن_پوست_آبنوسی:',
        'id': ':pilot_wanita_warna_kulit_gelap:',
        'zh': u':女飞行员_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002708\U0000FE0F': { # 👩🏻‍✈️
        'en' : ':woman_pilot_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilotin_helle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_claro:',
        'fr': ':pilote_femme_peau_claire:',
        'ja': u':女性パイロット_薄い肌色:',
        'ko': u':여자_기장_하얀_피부:',
        'pt': u':piloto_de_avião_mulher_pele_clara:',
        'it': ':pilota_donna_carnagione_chiara:',
        'fa': u':خلبان_زن_پوست_سفید:',
        'id': ':pilot_wanita_warna_kulit_cerah:',
        'zh': u':女飞行员_较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U00002708': { # 👩🏻‍✈
        'en' : ':woman_pilot_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilotin_helle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_claro:',
        'fr': ':pilote_femme_peau_claire:',
        'ja': u':女性パイロット_薄い肌色:',
        'ko': u':여자_기장_하얀_피부:',
        'pt': u':piloto_de_avião_mulher_pele_clara:',
        'it': ':pilota_donna_carnagione_chiara:',
        'fa': u':خلبان_زن_پوست_سفید:',
        'id': ':pilot_wanita_warna_kulit_cerah:',
        'zh': u':女飞行员_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002708\U0000FE0F': { # 👩🏾‍✈️
        'en' : ':woman_pilot_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilotin_mitteldunkle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':pilote_femme_peau_mate:',
        'ja': u':女性パイロット_やや濃い肌色:',
        'ko': u':여자_기장_진한_갈색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_morena_escura:',
        'it': ':pilota_donna_carnagione_abbastanza_scura:',
        'fa': u':خلبان_زن_پوست_گندمی:',
        'id': ':pilot_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女飞行员_中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U00002708': { # 👩🏾‍✈
        'en' : ':woman_pilot_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilotin_mitteldunkle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':pilote_femme_peau_mate:',
        'ja': u':女性パイロット_やや濃い肌色:',
        'ko': u':여자_기장_진한_갈색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_morena_escura:',
        'it': ':pilota_donna_carnagione_abbastanza_scura:',
        'fa': u':خلبان_زن_پوست_گندمی:',
        'id': ':pilot_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女飞行员_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002708\U0000FE0F': { # 👩🏼‍✈️
        'en' : ':woman_pilot_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilotin_mittelhelle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_claro_medio:',
        'fr': ':pilote_femme_peau_moyennement_claire:',
        'ja': u':女性パイロット_やや薄い肌色:',
        'ko': u':여자_기장_연한_갈색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_morena_clara:',
        'it': ':pilota_donna_carnagione_abbastanza_chiara:',
        'fa': u':خلبان_زن_پوست_روشن:',
        'id': ':pilot_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女飞行员_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U00002708': { # 👩🏼‍✈
        'en' : ':woman_pilot_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilotin_mittelhelle_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_claro_medio:',
        'fr': ':pilote_femme_peau_moyennement_claire:',
        'ja': u':女性パイロット_やや薄い肌色:',
        'ko': u':여자_기장_연한_갈색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_morena_clara:',
        'it': ':pilota_donna_carnagione_abbastanza_chiara:',
        'fa': u':خلبان_زن_پوست_روشن:',
        'id': ':pilot_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女飞行员_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002708\U0000FE0F': { # 👩🏽‍✈️
        'en' : ':woman_pilot_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':pilotin_mittlere_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_medio:',
        'fr': u':pilote_femme_peau_légèrement_mate:',
        'ja': u':女性パイロット_中間の肌色:',
        'ko': u':여자_기장_갈색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_morena:',
        'it': ':pilota_donna_carnagione_olivastra:',
        'fa': u':خلبان_زن_پوست_طلایی:',
        'id': ':pilot_wanita_warna_kulit_sedang:',
        'zh': u':女飞行员_中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U00002708': { # 👩🏽‍✈
        'en' : ':woman_pilot_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':pilotin_mittlere_hautfarbe:',
        'es': ':piloto_mujer_tono_de_piel_medio:',
        'fr': u':pilote_femme_peau_légèrement_mate:',
        'ja': u':女性パイロット_中間の肌色:',
        'ko': u':여자_기장_갈색_피부:',
        'pt': u':piloto_de_avião_mulher_pele_morena:',
        'it': ':pilota_donna_carnagione_olivastra:',
        'fa': u':خلبان_زن_پوست_طلایی:',
        'id': ':pilot_wanita_warna_kulit_sedang:',
        'zh': u':女飞行员_中等肤色:'
    },
    u'\U0001F93E\U0000200D\U00002640\U0000FE0F': { # 🤾‍♀️
        'en' : ':woman_playing_handball:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspielerin:',
        'es': ':mujer_jugando_al_balonmano:',
        'fr': ':handballeuse:',
        'ja': u':ハンドボールをする女:',
        'ko': u':핸드볼하는_여자:',
        'pt': ':jogadora_de_handebol:',
        'it': ':pallamanista_donna:',
        'fa': u':هندبالیست_زن:',
        'id': ':wanita_bermain_bola_tangan:',
        'zh': u':女生玩手球:'
    },
    u'\U0001F93E\U0000200D\U00002640': { # 🤾‍♀
        'en' : ':woman_playing_handball:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspielerin:',
        'es': ':mujer_jugando_al_balonmano:',
        'fr': ':handballeuse:',
        'ja': u':ハンドボールをする女:',
        'ko': u':핸드볼하는_여자:',
        'pt': ':jogadora_de_handebol:',
        'it': ':pallamanista_donna:',
        'fa': u':هندبالیست_زن:',
        'id': ':wanita_bermain_bola_tangan:',
        'zh': u':女生玩手球:'
    },
    u'\U0001F93E\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🤾🏿‍♀️
        'en' : ':woman_playing_handball_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspielerin_dunkle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_oscuro:',
        'fr': u':handballeuse_peau_foncée:',
        'ja': u':ハンドボールをする女_濃い肌色:',
        'ko': u':핸드볼하는_여자_검은색_피부:',
        'pt': ':jogadora_de_handebol_pele_escura:',
        'it': ':pallamanista_donna_carnagione_scura:',
        'fa': u':هندبالیست_زن_پوست_آبنوسی:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_gelap:',
        'zh': u':女生玩手球_较深肤色:'
    },
    u'\U0001F93E\U0001F3FF\U0000200D\U00002640': { # 🤾🏿‍♀
        'en' : ':woman_playing_handball_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspielerin_dunkle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_oscuro:',
        'fr': u':handballeuse_peau_foncée:',
        'ja': u':ハンドボールをする女_濃い肌色:',
        'ko': u':핸드볼하는_여자_검은색_피부:',
        'pt': ':jogadora_de_handebol_pele_escura:',
        'it': ':pallamanista_donna_carnagione_scura:',
        'fa': u':هندبالیست_زن_پوست_آبنوسی:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_gelap:',
        'zh': u':女生玩手球_较深肤色:'
    },
    u'\U0001F93E\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🤾🏻‍♀️
        'en' : ':woman_playing_handball_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspielerin_helle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_claro:',
        'fr': ':handballeuse_peau_claire:',
        'ja': u':ハンドボールをする女_薄い肌色:',
        'ko': u':핸드볼하는_여자_하얀_피부:',
        'pt': ':jogadora_de_handebol_pele_clara:',
        'it': ':pallamanista_donna_carnagione_chiara:',
        'fa': u':هندبالیست_زن_پوست_سفید:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_cerah:',
        'zh': u':女生玩手球_较浅肤色:'
    },
    u'\U0001F93E\U0001F3FB\U0000200D\U00002640': { # 🤾🏻‍♀
        'en' : ':woman_playing_handball_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspielerin_helle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_claro:',
        'fr': ':handballeuse_peau_claire:',
        'ja': u':ハンドボールをする女_薄い肌色:',
        'ko': u':핸드볼하는_여자_하얀_피부:',
        'pt': ':jogadora_de_handebol_pele_clara:',
        'it': ':pallamanista_donna_carnagione_chiara:',
        'fa': u':هندبالیست_زن_پوست_سفید:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_cerah:',
        'zh': u':女生玩手球_较浅肤色:'
    },
    u'\U0001F93E\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🤾🏾‍♀️
        'en' : ':woman_playing_handball_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspielerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_oscuro_medio:',
        'fr': ':handballeuse_peau_mate:',
        'ja': u':ハンドボールをする女_やや濃い肌色:',
        'ko': u':핸드볼하는_여자_진한_갈색_피부:',
        'pt': ':jogadora_de_handebol_pele_morena_escura:',
        'it': ':pallamanista_donna_carnagione_abbastanza_scura:',
        'fa': u':هندبالیست_زن_پوست_گندمی:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_gelap-sedang:',
        'zh': u':女生玩手球_中等深肤色:'
    },
    u'\U0001F93E\U0001F3FE\U0000200D\U00002640': { # 🤾🏾‍♀
        'en' : ':woman_playing_handball_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspielerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_oscuro_medio:',
        'fr': ':handballeuse_peau_mate:',
        'ja': u':ハンドボールをする女_やや濃い肌色:',
        'ko': u':핸드볼하는_여자_진한_갈색_피부:',
        'pt': ':jogadora_de_handebol_pele_morena_escura:',
        'it': ':pallamanista_donna_carnagione_abbastanza_scura:',
        'fa': u':هندبالیست_زن_پوست_گندمی:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_gelap-sedang:',
        'zh': u':女生玩手球_中等深肤色:'
    },
    u'\U0001F93E\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🤾🏼‍♀️
        'en' : ':woman_playing_handball_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspielerin_mittelhelle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_claro_medio:',
        'fr': ':handballeuse_peau_moyennement_claire:',
        'ja': u':ハンドボールをする女_やや薄い肌色:',
        'ko': u':핸드볼하는_여자_연한_갈색_피부:',
        'pt': ':jogadora_de_handebol_pele_morena_clara:',
        'it': ':pallamanista_donna_carnagione_abbastanza_chiara:',
        'fa': u':هندبالیست_زن_پوست_روشن:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_cerah-sedang:',
        'zh': u':女生玩手球_中等浅肤色:'
    },
    u'\U0001F93E\U0001F3FC\U0000200D\U00002640': { # 🤾🏼‍♀
        'en' : ':woman_playing_handball_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspielerin_mittelhelle_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_claro_medio:',
        'fr': ':handballeuse_peau_moyennement_claire:',
        'ja': u':ハンドボールをする女_やや薄い肌色:',
        'ko': u':핸드볼하는_여자_연한_갈색_피부:',
        'pt': ':jogadora_de_handebol_pele_morena_clara:',
        'it': ':pallamanista_donna_carnagione_abbastanza_chiara:',
        'fa': u':هندبالیست_زن_پوست_روشن:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_cerah-sedang:',
        'zh': u':女生玩手球_中等浅肤色:'
    },
    u'\U0001F93E\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🤾🏽‍♀️
        'en' : ':woman_playing_handball_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':handballspielerin_mittlere_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_medio:',
        'fr': u':handballeuse_peau_légèrement_mate:',
        'ja': u':ハンドボールをする女_中間の肌色:',
        'ko': u':핸드볼하는_여자_갈색_피부:',
        'pt': ':jogadora_de_handebol_pele_morena:',
        'it': ':pallamanista_donna_carnagione_olivastra:',
        'fa': u':هندبالیست_زن_پوست_طلایی:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_sedang:',
        'zh': u':女生玩手球_中等肤色:'
    },
    u'\U0001F93E\U0001F3FD\U0000200D\U00002640': { # 🤾🏽‍♀
        'en' : ':woman_playing_handball_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':handballspielerin_mittlere_hautfarbe:',
        'es': ':mujer_jugando_al_balonmano_tono_de_piel_medio:',
        'fr': u':handballeuse_peau_légèrement_mate:',
        'ja': u':ハンドボールをする女_中間の肌色:',
        'ko': u':핸드볼하는_여자_갈색_피부:',
        'pt': ':jogadora_de_handebol_pele_morena:',
        'it': ':pallamanista_donna_carnagione_olivastra:',
        'fa': u':هندبالیست_زن_پوست_طلایی:',
        'id': ':wanita_bermain_bola_tangan_warna_kulit_sedang:',
        'zh': u':女生玩手球_中等肤色:'
    },
    u'\U0001F93D\U0000200D\U00002640\U0000FE0F': { # 🤽‍♀️
        'en' : ':woman_playing_water_polo:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspielerin:',
        'es': ':mujer_jugando_al_waterpolo:',
        'fr': ':joueuse_de_water-polo:',
        'ja': u':水球をする女:',
        'ko': u':수구하는_여자:',
        'pt': u':mulher_jogando_polo_aquático:',
        'it': ':pallanuotista_donna:',
        'fa': u':واترپلو_زنان:',
        'id': ':wanita_bermain_polo_air:',
        'zh': u':女生玩水球:'
    },
    u'\U0001F93D\U0000200D\U00002640': { # 🤽‍♀
        'en' : ':woman_playing_water_polo:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspielerin:',
        'es': ':mujer_jugando_al_waterpolo:',
        'fr': ':joueuse_de_water-polo:',
        'ja': u':水球をする女:',
        'ko': u':수구하는_여자:',
        'pt': u':mulher_jogando_polo_aquático:',
        'it': ':pallanuotista_donna:',
        'fa': u':واترپلو_زنان:',
        'id': ':wanita_bermain_polo_air:',
        'zh': u':女生玩水球:'
    },
    u'\U0001F93D\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🤽🏿‍♀️
        'en' : ':woman_playing_water_polo_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_dunkle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_oscuro:',
        'fr': u':joueuse_de_water-polo_peau_foncée:',
        'ja': u':水球をする女_濃い肌色:',
        'ko': u':수구하는_여자_검은색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_escura:',
        'it': ':pallanuotista_donna_carnagione_scura:',
        'fa': u':واترپلو_زنان_پوست_آبنوسی:',
        'id': ':wanita_bermain_polo_air_warna_kulit_gelap:',
        'zh': u':女生玩水球_较深肤色:'
    },
    u'\U0001F93D\U0001F3FF\U0000200D\U00002640': { # 🤽🏿‍♀
        'en' : ':woman_playing_water_polo_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_dunkle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_oscuro:',
        'fr': u':joueuse_de_water-polo_peau_foncée:',
        'ja': u':水球をする女_濃い肌色:',
        'ko': u':수구하는_여자_검은색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_escura:',
        'it': ':pallanuotista_donna_carnagione_scura:',
        'fa': u':واترپلو_زنان_پوست_آبنوسی:',
        'id': ':wanita_bermain_polo_air_warna_kulit_gelap:',
        'zh': u':女生玩水球_较深肤色:'
    },
    u'\U0001F93D\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🤽🏻‍♀️
        'en' : ':woman_playing_water_polo_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_helle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_claro:',
        'fr': ':joueuse_de_water-polo_peau_claire:',
        'ja': u':水球をする女_薄い肌色:',
        'ko': u':수구하는_여자_하얀_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_clara:',
        'it': ':pallanuotista_donna_carnagione_chiara:',
        'fa': u':واترپلو_زنان_پوست_سفید:',
        'id': ':wanita_bermain_polo_air_warna_kulit_cerah:',
        'zh': u':女生玩水球_较浅肤色:'
    },
    u'\U0001F93D\U0001F3FB\U0000200D\U00002640': { # 🤽🏻‍♀
        'en' : ':woman_playing_water_polo_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_helle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_claro:',
        'fr': ':joueuse_de_water-polo_peau_claire:',
        'ja': u':水球をする女_薄い肌色:',
        'ko': u':수구하는_여자_하얀_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_clara:',
        'it': ':pallanuotista_donna_carnagione_chiara:',
        'fa': u':واترپلو_زنان_پوست_سفید:',
        'id': ':wanita_bermain_polo_air_warna_kulit_cerah:',
        'zh': u':女生玩水球_较浅肤色:'
    },
    u'\U0001F93D\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🤽🏾‍♀️
        'en' : ':woman_playing_water_polo_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_oscuro_medio:',
        'fr': ':joueuse_de_water-polo_peau_mate:',
        'ja': u':水球をする女_やや濃い肌色:',
        'ko': u':수구하는_여자_진한_갈색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_morena_escura:',
        'it': ':pallanuotista_donna_carnagione_abbastanza_scura:',
        'fa': u':واترپلو_زنان_پوست_گندمی:',
        'id': ':wanita_bermain_polo_air_warna_kulit_gelap-sedang:',
        'zh': u':女生玩水球_中等深肤色:'
    },
    u'\U0001F93D\U0001F3FE\U0000200D\U00002640': { # 🤽🏾‍♀
        'en' : ':woman_playing_water_polo_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_oscuro_medio:',
        'fr': ':joueuse_de_water-polo_peau_mate:',
        'ja': u':水球をする女_やや濃い肌色:',
        'ko': u':수구하는_여자_진한_갈색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_morena_escura:',
        'it': ':pallanuotista_donna_carnagione_abbastanza_scura:',
        'fa': u':واترپلو_زنان_پوست_گندمی:',
        'id': ':wanita_bermain_polo_air_warna_kulit_gelap-sedang:',
        'zh': u':女生玩水球_中等深肤色:'
    },
    u'\U0001F93D\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🤽🏼‍♀️
        'en' : ':woman_playing_water_polo_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_mittelhelle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_claro_medio:',
        'fr': ':joueuse_de_water-polo_peau_moyennement_claire:',
        'ja': u':水球をする女_やや薄い肌色:',
        'ko': u':수구하는_여자_연한_갈색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_morena_clara:',
        'it': ':pallanuotista_donna_carnagione_abbastanza_chiara:',
        'fa': u':واترپلو_زنان_پوست_روشن:',
        'id': ':wanita_bermain_polo_air_warna_kulit_cerah-sedang:',
        'zh': u':女生玩水球_中等浅肤色:'
    },
    u'\U0001F93D\U0001F3FC\U0000200D\U00002640': { # 🤽🏼‍♀
        'en' : ':woman_playing_water_polo_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_mittelhelle_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_claro_medio:',
        'fr': ':joueuse_de_water-polo_peau_moyennement_claire:',
        'ja': u':水球をする女_やや薄い肌色:',
        'ko': u':수구하는_여자_연한_갈색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_morena_clara:',
        'it': ':pallanuotista_donna_carnagione_abbastanza_chiara:',
        'fa': u':واترپلو_زنان_پوست_روشن:',
        'id': ':wanita_bermain_polo_air_warna_kulit_cerah-sedang:',
        'zh': u':女生玩水球_中等浅肤色:'
    },
    u'\U0001F93D\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🤽🏽‍♀️
        'en' : ':woman_playing_water_polo_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_mittlere_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_medio:',
        'fr': u':joueuse_de_water-polo_peau_légèrement_mate:',
        'ja': u':水球をする女_中間の肌色:',
        'ko': u':수구하는_여자_갈색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_morena:',
        'it': ':pallanuotista_donna_carnagione_olivastra:',
        'fa': u':واترپلو_زنان_پوست_طلایی:',
        'id': ':wanita_bermain_polo_air_warna_kulit_sedang:',
        'zh': u':女生玩水球_中等肤色:'
    },
    u'\U0001F93D\U0001F3FD\U0000200D\U00002640': { # 🤽🏽‍♀
        'en' : ':woman_playing_water_polo_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':wasserballspielerin_mittlere_hautfarbe:',
        'es': ':mujer_jugando_al_waterpolo_tono_de_piel_medio:',
        'fr': u':joueuse_de_water-polo_peau_légèrement_mate:',
        'ja': u':水球をする女_中間の肌色:',
        'ko': u':수구하는_여자_갈색_피부:',
        'pt': u':mulher_jogando_polo_aquático_pele_morena:',
        'it': ':pallanuotista_donna_carnagione_olivastra:',
        'fa': u':واترپلو_زنان_پوست_طلایی:',
        'id': ':wanita_bermain_polo_air_warna_kulit_sedang:',
        'zh': u':女生玩水球_中等肤色:'
    },
    u'\U0001F46E\U0000200D\U00002640\U0000FE0F': { # 👮‍♀️
        'en' : ':woman_police_officer:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':policewoman:'],
        'de': ':polizistin:',
        'es': u':agente_de_policía_mujer:',
        'fr': u':policière:',
        'ja': u':女性警察官:',
        'ko': u':여자_경찰관:',
        'pt': ':policial_mulher:',
        'it': ':poliziotta:',
        'fa': u':پلیس_زن:',
        'id': ':polisi_wanita:',
        'zh': u':女警察:'
    },
    u'\U0001F46E\U0000200D\U00002640': { # 👮‍♀
        'en' : ':woman_police_officer:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':policewoman:'],
        'de': ':polizistin:',
        'es': u':agente_de_policía_mujer:',
        'fr': u':policière:',
        'ja': u':女性警察官:',
        'ko': u':여자_경찰관:',
        'pt': ':policial_mulher:',
        'it': ':poliziotta:',
        'fa': u':پلیس_زن:',
        'id': ':polisi_wanita:',
        'zh': u':女警察:'
    },
    u'\U0001F46E\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 👮🏿‍♀️
        'en' : ':woman_police_officer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizistin_dunkle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_oscuro:',
        'fr': u':policière_peau_foncée:',
        'ja': u':女性警察官_濃い肌色:',
        'ko': u':여자_경찰관_검은색_피부:',
        'pt': ':policial_mulher_pele_escura:',
        'it': ':poliziotta_carnagione_scura:',
        'fa': u':پلیس_زن_پوست_آبنوسی:',
        'id': ':polisi_wanita_warna_kulit_gelap:',
        'zh': u':女警察_较深肤色:'
    },
    u'\U0001F46E\U0001F3FF\U0000200D\U00002640': { # 👮🏿‍♀
        'en' : ':woman_police_officer_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizistin_dunkle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_oscuro:',
        'fr': u':policière_peau_foncée:',
        'ja': u':女性警察官_濃い肌色:',
        'ko': u':여자_경찰관_검은색_피부:',
        'pt': ':policial_mulher_pele_escura:',
        'it': ':poliziotta_carnagione_scura:',
        'fa': u':پلیس_زن_پوست_آبنوسی:',
        'id': ':polisi_wanita_warna_kulit_gelap:',
        'zh': u':女警察_较深肤色:'
    },
    u'\U0001F46E\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 👮🏻‍♀️
        'en' : ':woman_police_officer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizistin_helle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_claro:',
        'fr': u':policière_peau_claire:',
        'ja': u':女性警察官_薄い肌色:',
        'ko': u':여자_경찰관_하얀_피부:',
        'pt': ':policial_mulher_pele_clara:',
        'it': ':poliziotta_carnagione_chiara:',
        'fa': u':پلیس_زن_پوست_سفید:',
        'id': ':polisi_wanita_warna_kulit_cerah:',
        'zh': u':女警察_较浅肤色:'
    },
    u'\U0001F46E\U0001F3FB\U0000200D\U00002640': { # 👮🏻‍♀
        'en' : ':woman_police_officer_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizistin_helle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_claro:',
        'fr': u':policière_peau_claire:',
        'ja': u':女性警察官_薄い肌色:',
        'ko': u':여자_경찰관_하얀_피부:',
        'pt': ':policial_mulher_pele_clara:',
        'it': ':poliziotta_carnagione_chiara:',
        'fa': u':پلیس_زن_پوست_سفید:',
        'id': ':polisi_wanita_warna_kulit_cerah:',
        'zh': u':女警察_较浅肤色:'
    },
    u'\U0001F46E\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 👮🏾‍♀️
        'en' : ':woman_police_officer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizistin_mitteldunkle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':policière_peau_mate:',
        'ja': u':女性警察官_やや濃い肌色:',
        'ko': u':여자_경찰관_진한_갈색_피부:',
        'pt': ':policial_mulher_pele_morena_escura:',
        'it': ':poliziotta_carnagione_abbastanza_scura:',
        'fa': u':پلیس_زن_پوست_گندمی:',
        'id': ':polisi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女警察_中等深肤色:'
    },
    u'\U0001F46E\U0001F3FE\U0000200D\U00002640': { # 👮🏾‍♀
        'en' : ':woman_police_officer_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizistin_mitteldunkle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':policière_peau_mate:',
        'ja': u':女性警察官_やや濃い肌色:',
        'ko': u':여자_경찰관_진한_갈색_피부:',
        'pt': ':policial_mulher_pele_morena_escura:',
        'it': ':poliziotta_carnagione_abbastanza_scura:',
        'fa': u':پلیس_زن_پوست_گندمی:',
        'id': ':polisi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女警察_中等深肤色:'
    },
    u'\U0001F46E\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 👮🏼‍♀️
        'en' : ':woman_police_officer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizistin_mittelhelle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_claro_medio:',
        'fr': u':policière_peau_moyennement_claire:',
        'ja': u':女性警察官_やや薄い肌色:',
        'ko': u':여자_경찰관_연한_갈색_피부:',
        'pt': ':policial_mulher_pele_morena_clara:',
        'it': ':poliziotta_carnagione_abbastanza_chiara:',
        'fa': u':پلیس_زن_پوست_روشن:',
        'id': ':polisi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女警察_中等浅肤色:'
    },
    u'\U0001F46E\U0001F3FC\U0000200D\U00002640': { # 👮🏼‍♀
        'en' : ':woman_police_officer_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizistin_mittelhelle_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_claro_medio:',
        'fr': u':policière_peau_moyennement_claire:',
        'ja': u':女性警察官_やや薄い肌色:',
        'ko': u':여자_경찰관_연한_갈색_피부:',
        'pt': ':policial_mulher_pele_morena_clara:',
        'it': ':poliziotta_carnagione_abbastanza_chiara:',
        'fa': u':پلیس_زن_پوست_روشن:',
        'id': ':polisi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女警察_中等浅肤色:'
    },
    u'\U0001F46E\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 👮🏽‍♀️
        'en' : ':woman_police_officer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':polizistin_mittlere_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_medio:',
        'fr': u':policière_peau_légèrement_mate:',
        'ja': u':女性警察官_中間の肌色:',
        'ko': u':여자_경찰관_갈색_피부:',
        'pt': ':policial_mulher_pele_morena:',
        'it': ':poliziotta_carnagione_olivastra:',
        'fa': u':پلیس_زن_پوست_طلایی:',
        'id': ':polisi_wanita_warna_kulit_sedang:',
        'zh': u':女警察_中等肤色:'
    },
    u'\U0001F46E\U0001F3FD\U0000200D\U00002640': { # 👮🏽‍♀
        'en' : ':woman_police_officer_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':polizistin_mittlere_hautfarbe:',
        'es': u':agente_de_policía_mujer_tono_de_piel_medio:',
        'fr': u':policière_peau_légèrement_mate:',
        'ja': u':女性警察官_中間の肌色:',
        'ko': u':여자_경찰관_갈색_피부:',
        'pt': ':policial_mulher_pele_morena:',
        'it': ':poliziotta_carnagione_olivastra:',
        'fa': u':پلیس_زن_پوست_طلایی:',
        'id': ':polisi_wanita_warna_kulit_sedang:',
        'zh': u':女警察_中等肤色:'
    },
    u'\U0001F64E\U0000200D\U00002640\U0000FE0F': { # 🙎‍♀️
        'en' : ':woman_pouting:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':pouting_woman:'],
        'de': ':schmollende_frau:',
        'es': ':mujer_haciendo_pucheros:',
        'fr': ':femme_qui_boude:',
        'ja': u':不機嫌な女:',
        'ko': u':뾰로통한_여자:',
        'pt': ':mulher_fazendo_bico:',
        'it': ':donna_imbronciata:',
        'fa': u':زن_اخم_وتخم_می_کند:',
        'id': ':wanita_tidak_senang:',
        'zh': u':撅嘴女:'
    },
    u'\U0001F64E\U0000200D\U00002640': { # 🙎‍♀
        'en' : ':woman_pouting:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':pouting_woman:'],
        'de': ':schmollende_frau:',
        'es': ':mujer_haciendo_pucheros:',
        'fr': ':femme_qui_boude:',
        'ja': u':不機嫌な女:',
        'ko': u':뾰로통한_여자:',
        'pt': ':mulher_fazendo_bico:',
        'it': ':donna_imbronciata:',
        'fa': u':زن_اخم_وتخم_می_کند:',
        'id': ':wanita_tidak_senang:',
        'zh': u':撅嘴女:'
    },
    u'\U0001F64E\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🙎🏿‍♀️
        'en' : ':woman_pouting_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollende_frau_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_oscuro:',
        'fr': u':femme_qui_boude_peau_foncée:',
        'ja': u':不機嫌な女_濃い肌色:',
        'ko': u':뾰로통한_여자_검은색_피부:',
        'pt': ':mulher_fazendo_bico_pele_escura:',
        'it': ':donna_imbronciata_carnagione_scura:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_آبنوسی:',
        'id': ':wanita_tidak_senang_warna_kulit_gelap:',
        'zh': u':撅嘴女_较深肤色:'
    },
    u'\U0001F64E\U0001F3FF\U0000200D\U00002640': { # 🙎🏿‍♀
        'en' : ':woman_pouting_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollende_frau_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_oscuro:',
        'fr': u':femme_qui_boude_peau_foncée:',
        'ja': u':不機嫌な女_濃い肌色:',
        'ko': u':뾰로통한_여자_검은색_피부:',
        'pt': ':mulher_fazendo_bico_pele_escura:',
        'it': ':donna_imbronciata_carnagione_scura:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_آبنوسی:',
        'id': ':wanita_tidak_senang_warna_kulit_gelap:',
        'zh': u':撅嘴女_较深肤色:'
    },
    u'\U0001F64E\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🙎🏻‍♀️
        'en' : ':woman_pouting_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollende_frau_helle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_claro:',
        'fr': ':femme_qui_boude_peau_claire:',
        'ja': u':不機嫌な女_薄い肌色:',
        'ko': u':뾰로통한_여자_하얀_피부:',
        'pt': ':mulher_fazendo_bico_pele_clara:',
        'it': ':donna_imbronciata_carnagione_chiara:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_سفید:',
        'id': ':wanita_tidak_senang_warna_kulit_cerah:',
        'zh': u':撅嘴女_较浅肤色:'
    },
    u'\U0001F64E\U0001F3FB\U0000200D\U00002640': { # 🙎🏻‍♀
        'en' : ':woman_pouting_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollende_frau_helle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_claro:',
        'fr': ':femme_qui_boude_peau_claire:',
        'ja': u':不機嫌な女_薄い肌色:',
        'ko': u':뾰로통한_여자_하얀_피부:',
        'pt': ':mulher_fazendo_bico_pele_clara:',
        'it': ':donna_imbronciata_carnagione_chiara:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_سفید:',
        'id': ':wanita_tidak_senang_warna_kulit_cerah:',
        'zh': u':撅嘴女_较浅肤色:'
    },
    u'\U0001F64E\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🙎🏾‍♀️
        'en' : ':woman_pouting_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_boude_peau_mate:',
        'ja': u':不機嫌な女_やや濃い肌色:',
        'ko': u':뾰로통한_여자_진한_갈색_피부:',
        'pt': ':mulher_fazendo_bico_pele_morena_escura:',
        'it': ':donna_imbronciata_carnagione_abbastanza_scura:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_گندمی:',
        'id': ':wanita_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':撅嘴女_中等深肤色:'
    },
    u'\U0001F64E\U0001F3FE\U0000200D\U00002640': { # 🙎🏾‍♀
        'en' : ':woman_pouting_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_boude_peau_mate:',
        'ja': u':不機嫌な女_やや濃い肌色:',
        'ko': u':뾰로통한_여자_진한_갈색_피부:',
        'pt': ':mulher_fazendo_bico_pele_morena_escura:',
        'it': ':donna_imbronciata_carnagione_abbastanza_scura:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_گندمی:',
        'id': ':wanita_tidak_senang_warna_kulit_gelap-sedang:',
        'zh': u':撅嘴女_中等深肤色:'
    },
    u'\U0001F64E\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🙎🏼‍♀️
        'en' : ':woman_pouting_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_boude_peau_moyennement_claire:',
        'ja': u':不機嫌な女_やや薄い肌色:',
        'ko': u':뾰로통한_여자_연한_갈색_피부:',
        'pt': ':mulher_fazendo_bico_pele_morena_clara:',
        'it': ':donna_imbronciata_carnagione_abbastanza_chiara:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_روشن:',
        'id': ':wanita_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':撅嘴女_中等浅肤色:'
    },
    u'\U0001F64E\U0001F3FC\U0000200D\U00002640': { # 🙎🏼‍♀
        'en' : ':woman_pouting_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_boude_peau_moyennement_claire:',
        'ja': u':不機嫌な女_やや薄い肌色:',
        'ko': u':뾰로통한_여자_연한_갈색_피부:',
        'pt': ':mulher_fazendo_bico_pele_morena_clara:',
        'it': ':donna_imbronciata_carnagione_abbastanza_chiara:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_روشن:',
        'id': ':wanita_tidak_senang_warna_kulit_cerah-sedang:',
        'zh': u':撅嘴女_中等浅肤色:'
    },
    u'\U0001F64E\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🙎🏽‍♀️
        'en' : ':woman_pouting_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schmollende_frau_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_medio:',
        'fr': u':femme_qui_boude_peau_légèrement_mate:',
        'ja': u':不機嫌な女_中間の肌色:',
        'ko': u':뾰로통한_여자_갈색_피부:',
        'pt': ':mulher_fazendo_bico_pele_morena:',
        'it': ':donna_imbronciata_carnagione_olivastra:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_طلایی:',
        'id': ':wanita_tidak_senang_warna_kulit_sedang:',
        'zh': u':撅嘴女_中等肤色:'
    },
    u'\U0001F64E\U0001F3FD\U0000200D\U00002640': { # 🙎🏽‍♀
        'en' : ':woman_pouting_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schmollende_frau_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_pucheros_tono_de_piel_medio:',
        'fr': u':femme_qui_boude_peau_légèrement_mate:',
        'ja': u':不機嫌な女_中間の肌色:',
        'ko': u':뾰로통한_여자_갈색_피부:',
        'pt': ':mulher_fazendo_bico_pele_morena:',
        'it': ':donna_imbronciata_carnagione_olivastra:',
        'fa': u':زن_اخم_وتخم_می_کند_پوست_طلایی:',
        'id': ':wanita_tidak_senang_warna_kulit_sedang:',
        'zh': u':撅嘴女_中等肤色:'
    },
    u'\U0001F64B\U0000200D\U00002640\U0000FE0F': { # 🙋‍♀️
        'en' : ':woman_raising_hand:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':raising_hand_woman:'],
        'de': ':frau_mit_erhobenem_arm:',
        'es': ':mujer_con_la_mano_levantada:',
        'fr': u':femme_qui_lève_la_main:',
        'ja': u':手を挙げる女:',
        'ko': u':한_손_든_여자:',
        'pt': u':mulher_levantando_a_mão:',
        'it': ':donna_con_mano_alzata:',
        'fa': u':زن_دستش_را_بالا_می_برد:',
        'id': ':wanita_mengangkat_tangan:',
        'zh': u':女生举手:'
    },
    u'\U0001F64B\U0000200D\U00002640': { # 🙋‍♀
        'en' : ':woman_raising_hand:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':raising_hand_woman:'],
        'de': ':frau_mit_erhobenem_arm:',
        'es': ':mujer_con_la_mano_levantada:',
        'fr': u':femme_qui_lève_la_main:',
        'ja': u':手を挙げる女:',
        'ko': u':한_손_든_여자:',
        'pt': u':mulher_levantando_a_mão:',
        'it': ':donna_con_mano_alzata:',
        'fa': u':زن_دستش_را_بالا_می_برد:',
        'id': ':wanita_mengangkat_tangan:',
        'zh': u':女生举手:'
    },
    u'\U0001F64B\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🙋🏿‍♀️
        'en' : ':woman_raising_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_dunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_oscuro:',
        'fr': u':femme_qui_lève_la_main_peau_foncée:',
        'ja': u':手を挙げる女_濃い肌色:',
        'ko': u':한_손_든_여자_검은색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_escura:',
        'it': ':donna_con_mano_alzata_carnagione_scura:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_آبنوسی:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_gelap:',
        'zh': u':女生举手_较深肤色:'
    },
    u'\U0001F64B\U0001F3FF\U0000200D\U00002640': { # 🙋🏿‍♀
        'en' : ':woman_raising_hand_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_dunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_oscuro:',
        'fr': u':femme_qui_lève_la_main_peau_foncée:',
        'ja': u':手を挙げる女_濃い肌色:',
        'ko': u':한_손_든_여자_검은색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_escura:',
        'it': ':donna_con_mano_alzata_carnagione_scura:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_آبنوسی:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_gelap:',
        'zh': u':女生举手_较深肤色:'
    },
    u'\U0001F64B\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🙋🏻‍♀️
        'en' : ':woman_raising_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_helle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_claro:',
        'fr': u':femme_qui_lève_la_main_peau_claire:',
        'ja': u':手を挙げる女_薄い肌色:',
        'ko': u':한_손_든_여자_하얀_피부:',
        'pt': u':mulher_levantando_a_mão_pele_clara:',
        'it': ':donna_con_mano_alzata_carnagione_chiara:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_سفید:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_cerah:',
        'zh': u':女生举手_较浅肤色:'
    },
    u'\U0001F64B\U0001F3FB\U0000200D\U00002640': { # 🙋🏻‍♀
        'en' : ':woman_raising_hand_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_helle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_claro:',
        'fr': u':femme_qui_lève_la_main_peau_claire:',
        'ja': u':手を挙げる女_薄い肌色:',
        'ko': u':한_손_든_여자_하얀_피부:',
        'pt': u':mulher_levantando_a_mão_pele_clara:',
        'it': ':donna_con_mano_alzata_carnagione_chiara:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_سفید:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_cerah:',
        'zh': u':女生举手_较浅肤色:'
    },
    u'\U0001F64B\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🙋🏾‍♀️
        'en' : ':woman_raising_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_oscuro_medio:',
        'fr': u':femme_qui_lève_la_main_peau_mate:',
        'ja': u':手を挙げる女_やや濃い肌色:',
        'ko': u':한_손_든_여자_진한_갈색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_morena_escura:',
        'it': ':donna_con_mano_alzata_carnagione_abbastanza_scura:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_گندمی:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':女生举手_中等深肤色:'
    },
    u'\U0001F64B\U0001F3FE\U0000200D\U00002640': { # 🙋🏾‍♀
        'en' : ':woman_raising_hand_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_oscuro_medio:',
        'fr': u':femme_qui_lève_la_main_peau_mate:',
        'ja': u':手を挙げる女_やや濃い肌色:',
        'ko': u':한_손_든_여자_진한_갈색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_morena_escura:',
        'it': ':donna_con_mano_alzata_carnagione_abbastanza_scura:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_گندمی:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_gelap-sedang:',
        'zh': u':女生举手_中等深肤色:'
    },
    u'\U0001F64B\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🙋🏼‍♀️
        'en' : ':woman_raising_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_mittelhelle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_claro_medio:',
        'fr': u':femme_qui_lève_la_main_peau_moyennement_claire:',
        'ja': u':手を挙げる女_やや薄い肌色:',
        'ko': u':한_손_든_여자_연한_갈색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_morena_clara:',
        'it': ':donna_con_mano_alzata_carnagione_abbastanza_chiara:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_روشن:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':女生举手_中等浅肤色:'
    },
    u'\U0001F64B\U0001F3FC\U0000200D\U00002640': { # 🙋🏼‍♀
        'en' : ':woman_raising_hand_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_mittelhelle_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_claro_medio:',
        'fr': u':femme_qui_lève_la_main_peau_moyennement_claire:',
        'ja': u':手を挙げる女_やや薄い肌色:',
        'ko': u':한_손_든_여자_연한_갈색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_morena_clara:',
        'it': ':donna_con_mano_alzata_carnagione_abbastanza_chiara:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_روشن:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_cerah-sedang:',
        'zh': u':女生举手_中等浅肤色:'
    },
    u'\U0001F64B\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🙋🏽‍♀️
        'en' : ':woman_raising_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_mittlere_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_medio:',
        'fr': u':femme_qui_lève_la_main_peau_légèrement_mate:',
        'ja': u':手を挙げる女_中間の肌色:',
        'ko': u':한_손_든_여자_갈색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_morena:',
        'it': ':donna_con_mano_alzata_carnagione_olivastra:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_طلایی:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_sedang:',
        'zh': u':女生举手_中等肤色:'
    },
    u'\U0001F64B\U0001F3FD\U0000200D\U00002640': { # 🙋🏽‍♀
        'en' : ':woman_raising_hand_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_erhobenem_arm_mittlere_hautfarbe:',
        'es': ':mujer_con_la_mano_levantada_tono_de_piel_medio:',
        'fr': u':femme_qui_lève_la_main_peau_légèrement_mate:',
        'ja': u':手を挙げる女_中間の肌色:',
        'ko': u':한_손_든_여자_갈색_피부:',
        'pt': u':mulher_levantando_a_mão_pele_morena:',
        'it': ':donna_con_mano_alzata_carnagione_olivastra:',
        'fa': u':زن_دستش_را_بالا_می_برد_پوست_طلایی:',
        'id': ':wanita_mengangkat_tangan_warna_kulit_sedang:',
        'zh': u':女生举手_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F9B0': { # 👩‍🦰
        'en' : ':woman_red_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':red_haired_woman:'],
        'de': ':frau_rotes_haar:',
        'es': ':mujer_pelo_pelirrojo:',
        'fr': ':femme_cheveux_roux:',
        'ja': u':女性_赤毛:',
        'ko': u':여자_빨간_머리:',
        'pt': ':mulher_cabelo_vermelho:',
        'it': ':donna_capelli_rossi:',
        'fa': u':زن_موقرمز:',
        'id': ':wanita_rambut_merah:',
        'zh': u':女人_红发:'
    },
    u'\U0001F6A3\U0000200D\U00002640\U0000FE0F': { # 🚣‍♀️
        'en' : ':woman_rowing_boat:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':rowing_woman:'],
        'de': ':frau_im_ruderboot:',
        'es': ':mujer_remando_en_un_bote:',
        'fr': ':rameuse_dans_une_barque:',
        'ja': u':ボートをこぐ女:',
        'ko': u':노젓는_여자:',
        'pt': ':mulher_remando:',
        'it': ':donna_in_barca_a_remi:',
        'fa': u':پاروزن_زن:',
        'id': ':wanita_mendayung_perahu:',
        'zh': u':女生划船:'
    },
    u'\U0001F6A3\U0000200D\U00002640': { # 🚣‍♀
        'en' : ':woman_rowing_boat:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':rowing_woman:'],
        'de': ':frau_im_ruderboot:',
        'es': ':mujer_remando_en_un_bote:',
        'fr': ':rameuse_dans_une_barque:',
        'ja': u':ボートをこぐ女:',
        'ko': u':노젓는_여자:',
        'pt': ':mulher_remando:',
        'it': ':donna_in_barca_a_remi:',
        'fa': u':پاروزن_زن:',
        'id': ':wanita_mendayung_perahu:',
        'zh': u':女生划船:'
    },
    u'\U0001F6A3\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🚣🏿‍♀️
        'en' : ':woman_rowing_boat_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_dunkle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_oscuro:',
        'fr': u':rameuse_dans_une_barque_peau_foncée:',
        'ja': u':ボートをこぐ女_濃い肌色:',
        'ko': u':노젓는_여자_검은색_피부:',
        'pt': ':mulher_remando_pele_escura:',
        'it': ':donna_in_barca_a_remi_carnagione_scura:',
        'fa': u':پاروزن_زن_پوست_آبنوسی:',
        'id': ':wanita_mendayung_perahu_warna_kulit_gelap:',
        'zh': u':女生划船_较深肤色:'
    },
    u'\U0001F6A3\U0001F3FF\U0000200D\U00002640': { # 🚣🏿‍♀
        'en' : ':woman_rowing_boat_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_dunkle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_oscuro:',
        'fr': u':rameuse_dans_une_barque_peau_foncée:',
        'ja': u':ボートをこぐ女_濃い肌色:',
        'ko': u':노젓는_여자_검은색_피부:',
        'pt': ':mulher_remando_pele_escura:',
        'it': ':donna_in_barca_a_remi_carnagione_scura:',
        'fa': u':پاروزن_زن_پوست_آبنوسی:',
        'id': ':wanita_mendayung_perahu_warna_kulit_gelap:',
        'zh': u':女生划船_较深肤色:'
    },
    u'\U0001F6A3\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🚣🏻‍♀️
        'en' : ':woman_rowing_boat_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_helle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_claro:',
        'fr': ':rameuse_dans_une_barque_peau_claire:',
        'ja': u':ボートをこぐ女_薄い肌色:',
        'ko': u':노젓는_여자_하얀_피부:',
        'pt': ':mulher_remando_pele_clara:',
        'it': ':donna_in_barca_a_remi_carnagione_chiara:',
        'fa': u':پاروزن_زن_پوست_سفید:',
        'id': ':wanita_mendayung_perahu_warna_kulit_cerah:',
        'zh': u':女生划船_较浅肤色:'
    },
    u'\U0001F6A3\U0001F3FB\U0000200D\U00002640': { # 🚣🏻‍♀
        'en' : ':woman_rowing_boat_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_helle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_claro:',
        'fr': ':rameuse_dans_une_barque_peau_claire:',
        'ja': u':ボートをこぐ女_薄い肌色:',
        'ko': u':노젓는_여자_하얀_피부:',
        'pt': ':mulher_remando_pele_clara:',
        'it': ':donna_in_barca_a_remi_carnagione_chiara:',
        'fa': u':پاروزن_زن_پوست_سفید:',
        'id': ':wanita_mendayung_perahu_warna_kulit_cerah:',
        'zh': u':女生划船_较浅肤色:'
    },
    u'\U0001F6A3\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🚣🏾‍♀️
        'en' : ':woman_rowing_boat_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_mitteldunkle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_oscuro_medio:',
        'fr': ':rameuse_dans_une_barque_peau_mate:',
        'ja': u':ボートをこぐ女_やや濃い肌色:',
        'ko': u':노젓는_여자_진한_갈색_피부:',
        'pt': ':mulher_remando_pele_morena_escura:',
        'it': ':donna_in_barca_a_remi_carnagione_abbastanza_scura:',
        'fa': u':پاروزن_زن_پوست_گندمی:',
        'id': ':wanita_mendayung_perahu_warna_kulit_gelap-sedang:',
        'zh': u':女生划船_中等深肤色:'
    },
    u'\U0001F6A3\U0001F3FE\U0000200D\U00002640': { # 🚣🏾‍♀
        'en' : ':woman_rowing_boat_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_mitteldunkle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_oscuro_medio:',
        'fr': ':rameuse_dans_une_barque_peau_mate:',
        'ja': u':ボートをこぐ女_やや濃い肌色:',
        'ko': u':노젓는_여자_진한_갈색_피부:',
        'pt': ':mulher_remando_pele_morena_escura:',
        'it': ':donna_in_barca_a_remi_carnagione_abbastanza_scura:',
        'fa': u':پاروزن_زن_پوست_گندمی:',
        'id': ':wanita_mendayung_perahu_warna_kulit_gelap-sedang:',
        'zh': u':女生划船_中等深肤色:'
    },
    u'\U0001F6A3\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🚣🏼‍♀️
        'en' : ':woman_rowing_boat_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_mittelhelle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_claro_medio:',
        'fr': ':rameuse_dans_une_barque_peau_moyennement_claire:',
        'ja': u':ボートをこぐ女_やや薄い肌色:',
        'ko': u':노젓는_여자_연한_갈색_피부:',
        'pt': ':mulher_remando_pele_morena_clara:',
        'it': ':donna_in_barca_a_remi_carnagione_abbastanza_chiara:',
        'fa': u':پاروزن_زن_پوست_روشن:',
        'id': ':wanita_mendayung_perahu_warna_kulit_cerah-sedang:',
        'zh': u':女生划船_中等浅肤色:'
    },
    u'\U0001F6A3\U0001F3FC\U0000200D\U00002640': { # 🚣🏼‍♀
        'en' : ':woman_rowing_boat_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_mittelhelle_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_claro_medio:',
        'fr': ':rameuse_dans_une_barque_peau_moyennement_claire:',
        'ja': u':ボートをこぐ女_やや薄い肌色:',
        'ko': u':노젓는_여자_연한_갈색_피부:',
        'pt': ':mulher_remando_pele_morena_clara:',
        'it': ':donna_in_barca_a_remi_carnagione_abbastanza_chiara:',
        'fa': u':پاروزن_زن_پوست_روشن:',
        'id': ':wanita_mendayung_perahu_warna_kulit_cerah-sedang:',
        'zh': u':女生划船_中等浅肤色:'
    },
    u'\U0001F6A3\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🚣🏽‍♀️
        'en' : ':woman_rowing_boat_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_mittlere_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_medio:',
        'fr': u':rameuse_dans_une_barque_peau_légèrement_mate:',
        'ja': u':ボートをこぐ女_中間の肌色:',
        'ko': u':노젓는_여자_갈색_피부:',
        'pt': ':mulher_remando_pele_morena:',
        'it': ':donna_in_barca_a_remi_carnagione_olivastra:',
        'fa': u':پاروزن_زن_پوست_طلایی:',
        'id': ':wanita_mendayung_perahu_warna_kulit_sedang:',
        'zh': u':女生划船_中等肤色:'
    },
    u'\U0001F6A3\U0001F3FD\U0000200D\U00002640': { # 🚣🏽‍♀
        'en' : ':woman_rowing_boat_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_im_ruderboot_mittlere_hautfarbe:',
        'es': ':mujer_remando_en_un_bote_tono_de_piel_medio:',
        'fr': u':rameuse_dans_une_barque_peau_légèrement_mate:',
        'ja': u':ボートをこぐ女_中間の肌色:',
        'ko': u':노젓는_여자_갈색_피부:',
        'pt': ':mulher_remando_pele_morena:',
        'it': ':donna_in_barca_a_remi_carnagione_olivastra:',
        'fa': u':پاروزن_زن_پوست_طلایی:',
        'id': ':wanita_mendayung_perahu_warna_kulit_sedang:',
        'zh': u':女生划船_中等肤色:'
    },
    u'\U0001F3C3\U0000200D\U00002640\U0000FE0F': { # 🏃‍♀️
        'en' : ':woman_running:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':running_woman:'],
        'de': ':laufende_frau:',
        'es': ':mujer_corriendo:',
        'fr': ':femme_qui_court:',
        'ja': u':走る女:',
        'ko': u':뛰는_여자:',
        'pt': ':mulher_correndo:',
        'it': ':donna_che_corre:',
        'fa': u':زن_دونده:',
        'id': ':wanita_berlari:',
        'zh': u':女生跑步:'
    },
    u'\U0001F3C3\U0000200D\U00002640': { # 🏃‍♀
        'en' : ':woman_running:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':running_woman:'],
        'de': ':laufende_frau:',
        'es': ':mujer_corriendo:',
        'fr': ':femme_qui_court:',
        'ja': u':走る女:',
        'ko': u':뛰는_여자:',
        'pt': ':mulher_correndo:',
        'it': ':donna_che_corre:',
        'fa': u':زن_دونده:',
        'id': ':wanita_berlari:',
        'zh': u':女生跑步:'
    },
    u'\U0001F3C3\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🏃🏿‍♀️
        'en' : ':woman_running_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufende_frau_dunkle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_oscuro:',
        'fr': u':femme_qui_court_peau_foncée:',
        'ja': u':走る女_濃い肌色:',
        'ko': u':뛰는_여자_검은색_피부:',
        'pt': ':mulher_correndo_pele_escura:',
        'it': ':donna_che_corre_carnagione_scura:',
        'fa': u':زن_دونده_پوست_آبنوسی:',
        'id': ':wanita_berlari_warna_kulit_gelap:',
        'zh': u':女生跑步_较深肤色:'
    },
    u'\U0001F3C3\U0001F3FF\U0000200D\U00002640': { # 🏃🏿‍♀
        'en' : ':woman_running_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufende_frau_dunkle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_oscuro:',
        'fr': u':femme_qui_court_peau_foncée:',
        'ja': u':走る女_濃い肌色:',
        'ko': u':뛰는_여자_검은색_피부:',
        'pt': ':mulher_correndo_pele_escura:',
        'it': ':donna_che_corre_carnagione_scura:',
        'fa': u':زن_دونده_پوست_آبنوسی:',
        'id': ':wanita_berlari_warna_kulit_gelap:',
        'zh': u':女生跑步_较深肤色:'
    },
    u'\U0001F3C3\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🏃🏻‍♀️
        'en' : ':woman_running_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufende_frau_helle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_claro:',
        'fr': ':femme_qui_court_peau_claire:',
        'ja': u':走る女_薄い肌色:',
        'ko': u':뛰는_여자_하얀_피부:',
        'pt': ':mulher_correndo_pele_clara:',
        'it': ':donna_che_corre_carnagione_chiara:',
        'fa': u':زن_دونده_پوست_سفید:',
        'id': ':wanita_berlari_warna_kulit_cerah:',
        'zh': u':女生跑步_较浅肤色:'
    },
    u'\U0001F3C3\U0001F3FB\U0000200D\U00002640': { # 🏃🏻‍♀
        'en' : ':woman_running_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufende_frau_helle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_claro:',
        'fr': ':femme_qui_court_peau_claire:',
        'ja': u':走る女_薄い肌色:',
        'ko': u':뛰는_여자_하얀_피부:',
        'pt': ':mulher_correndo_pele_clara:',
        'it': ':donna_che_corre_carnagione_chiara:',
        'fa': u':زن_دونده_پوست_سفید:',
        'id': ':wanita_berlari_warna_kulit_cerah:',
        'zh': u':女生跑步_较浅肤色:'
    },
    u'\U0001F3C3\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🏃🏾‍♀️
        'en' : ':woman_running_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_court_peau_mate:',
        'ja': u':走る女_やや濃い肌色:',
        'ko': u':뛰는_여자_진한_갈색_피부:',
        'pt': ':mulher_correndo_pele_morena_escura:',
        'it': ':donna_che_corre_carnagione_abbastanza_scura:',
        'fa': u':زن_دونده_پوست_گندمی:',
        'id': ':wanita_berlari_warna_kulit_gelap-sedang:',
        'zh': u':女生跑步_中等深肤色:'
    },
    u'\U0001F3C3\U0001F3FE\U0000200D\U00002640': { # 🏃🏾‍♀
        'en' : ':woman_running_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_court_peau_mate:',
        'ja': u':走る女_やや濃い肌色:',
        'ko': u':뛰는_여자_진한_갈색_피부:',
        'pt': ':mulher_correndo_pele_morena_escura:',
        'it': ':donna_che_corre_carnagione_abbastanza_scura:',
        'fa': u':زن_دونده_پوست_گندمی:',
        'id': ':wanita_berlari_warna_kulit_gelap-sedang:',
        'zh': u':女生跑步_中等深肤色:'
    },
    u'\U0001F3C3\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🏃🏼‍♀️
        'en' : ':woman_running_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_court_peau_moyennement_claire:',
        'ja': u':走る女_やや薄い肌色:',
        'ko': u':뛰는_여자_연한_갈색_피부:',
        'pt': ':mulher_correndo_pele_morena_clara:',
        'it': ':donna_che_corre_carnagione_abbastanza_chiara:',
        'fa': u':زن_دونده_پوست_روشن:',
        'id': ':wanita_berlari_warna_kulit_cerah-sedang:',
        'zh': u':女生跑步_中等浅肤色:'
    },
    u'\U0001F3C3\U0001F3FC\U0000200D\U00002640': { # 🏃🏼‍♀
        'en' : ':woman_running_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_court_peau_moyennement_claire:',
        'ja': u':走る女_やや薄い肌色:',
        'ko': u':뛰는_여자_연한_갈색_피부:',
        'pt': ':mulher_correndo_pele_morena_clara:',
        'it': ':donna_che_corre_carnagione_abbastanza_chiara:',
        'fa': u':زن_دونده_پوست_روشن:',
        'id': ':wanita_berlari_warna_kulit_cerah-sedang:',
        'zh': u':女生跑步_中等浅肤色:'
    },
    u'\U0001F3C3\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🏃🏽‍♀️
        'en' : ':woman_running_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':laufende_frau_mittlere_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_medio:',
        'fr': u':femme_qui_court_peau_légèrement_mate:',
        'ja': u':走る女_中間の肌色:',
        'ko': u':뛰는_여자_갈색_피부:',
        'pt': ':mulher_correndo_pele_morena:',
        'it': ':donna_che_corre_carnagione_olivastra:',
        'fa': u':زن_دونده_پوست_طلایی:',
        'id': ':wanita_berlari_warna_kulit_sedang:',
        'zh': u':女生跑步_中等肤色:'
    },
    u'\U0001F3C3\U0001F3FD\U0000200D\U00002640': { # 🏃🏽‍♀
        'en' : ':woman_running_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':laufende_frau_mittlere_hautfarbe:',
        'es': ':mujer_corriendo_tono_de_piel_medio:',
        'fr': u':femme_qui_court_peau_légèrement_mate:',
        'ja': u':走る女_中間の肌色:',
        'ko': u':뛰는_여자_갈색_피부:',
        'pt': ':mulher_correndo_pele_morena:',
        'it': ':donna_che_corre_carnagione_olivastra:',
        'fa': u':زن_دونده_پوست_طلایی:',
        'id': ':wanita_berlari_warna_kulit_sedang:',
        'zh': u':女生跑步_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F52C': { # 👩‍🔬
        'en' : ':woman_scientist:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftlerin:',
        'es': ':profesional_de_la_ciencia_mujer:',
        'fr': ':scientifique_femme:',
        'ja': u':女性科学者:',
        'ko': u':여자_과학자:',
        'pt': ':cientista_mulher:',
        'it': ':scienziata:',
        'fa': u':دانشمند_زن:',
        'id': ':ilmuwan_wanita:',
        'zh': u':女科学家:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F52C': { # 👩🏿‍🔬
        'en' : ':woman_scientist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftlerin_dunkle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_mujer_tono_de_piel_oscuro:',
        'fr': u':scientifique_femme_peau_foncée:',
        'ja': u':女性科学者_濃い肌色:',
        'ko': u':여자_과학자_검은색_피부:',
        'pt': ':cientista_mulher_pele_escura:',
        'it': ':scienziata_carnagione_scura:',
        'fa': u':دانشمند_زن_پوست_آبنوسی:',
        'id': ':ilmuwan_wanita_warna_kulit_gelap:',
        'zh': u':女科学家_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F52C': { # 👩🏻‍🔬
        'en' : ':woman_scientist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftlerin_helle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_mujer_tono_de_piel_claro:',
        'fr': ':scientifique_femme_peau_claire:',
        'ja': u':女性科学者_薄い肌色:',
        'ko': u':여자_과학자_하얀_피부:',
        'pt': ':cientista_mulher_pele_clara:',
        'it': ':scienziata_carnagione_chiara:',
        'fa': u':دانشمند_زن_پوست_سفید:',
        'id': ':ilmuwan_wanita_warna_kulit_cerah:',
        'zh': u':女科学家_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F52C': { # 👩🏾‍🔬
        'en' : ':woman_scientist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftlerin_mitteldunkle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':scientifique_femme_peau_mate:',
        'ja': u':女性科学者_やや濃い肌色:',
        'ko': u':여자_과학자_진한_갈색_피부:',
        'pt': ':cientista_mulher_pele_morena_escura:',
        'it': ':scienziata_carnagione_abbastanza_scura:',
        'fa': u':دانشمند_زن_پوست_گندمی:',
        'id': ':ilmuwan_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女科学家_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F52C': { # 👩🏼‍🔬
        'en' : ':woman_scientist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftlerin_mittelhelle_hautfarbe:',
        'es': ':profesional_de_la_ciencia_mujer_tono_de_piel_claro_medio:',
        'fr': ':scientifique_femme_peau_moyennement_claire:',
        'ja': u':女性科学者_やや薄い肌色:',
        'ko': u':여자_과학자_연한_갈색_피부:',
        'pt': ':cientista_mulher_pele_morena_clara:',
        'it': ':scienziata_carnagione_abbastanza_chiara:',
        'fa': u':دانشمند_زن_پوست_روشن:',
        'id': ':ilmuwan_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女科学家_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F52C': { # 👩🏽‍🔬
        'en' : ':woman_scientist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':wissenschaftlerin_mittlere_hautfarbe:',
        'es': ':profesional_de_la_ciencia_mujer_tono_de_piel_medio:',
        'fr': u':scientifique_femme_peau_légèrement_mate:',
        'ja': u':女性科学者_中間の肌色:',
        'ko': u':여자_과학자_갈색_피부:',
        'pt': ':cientista_mulher_pele_morena:',
        'it': ':scienziata_carnagione_olivastra:',
        'fa': u':دانشمند_زن_پوست_طلایی:',
        'id': ':ilmuwan_wanita_warna_kulit_sedang:',
        'zh': u':女科学家_中等肤色:'
    },
    u'\U0001F937\U0000200D\U00002640\U0000FE0F': { # 🤷‍♀️
        'en' : ':woman_shrugging:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau:',
        'es': ':mujer_encogida_de_hombros:',
        'fr': u':femme_qui_hausse_les_épaules:',
        'ja': u':お手上げする女:',
        'ko': u':어깨를_으쓱하는_여자:',
        'pt': ':mulher_dando_de_ombros:',
        'it': ':donna_che_scrolla_le_spalle:',
        'fa': u':زن_شانه_بالا_می_اندازد:',
        'id': ':wanita_mengangkat_bahu:',
        'zh': u':女生耸肩:'
    },
    u'\U0001F937\U0000200D\U00002640': { # 🤷‍♀
        'en' : ':woman_shrugging:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau:',
        'es': ':mujer_encogida_de_hombros:',
        'fr': u':femme_qui_hausse_les_épaules:',
        'ja': u':お手上げする女:',
        'ko': u':어깨를_으쓱하는_여자:',
        'pt': ':mulher_dando_de_ombros:',
        'it': ':donna_che_scrolla_le_spalle:',
        'fa': u':زن_شانه_بالا_می_اندازد:',
        'id': ':wanita_mengangkat_bahu:',
        'zh': u':女生耸肩:'
    },
    u'\U0001F937\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🤷🏿‍♀️
        'en' : ':woman_shrugging_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_dunkle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_oscuro:',
        'fr': u':femme_qui_hausse_les_épaules_peau_foncée:',
        'ja': u':お手上げする女_濃い肌色:',
        'ko': u':어깨를_으쓱하는_여자_검은색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_escura:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_scura:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_آبنوسی:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_gelap:',
        'zh': u':女生耸肩_较深肤色:'
    },
    u'\U0001F937\U0001F3FF\U0000200D\U00002640': { # 🤷🏿‍♀
        'en' : ':woman_shrugging_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_dunkle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_oscuro:',
        'fr': u':femme_qui_hausse_les_épaules_peau_foncée:',
        'ja': u':お手上げする女_濃い肌色:',
        'ko': u':어깨를_으쓱하는_여자_검은색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_escura:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_scura:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_آبنوسی:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_gelap:',
        'zh': u':女生耸肩_较深肤色:'
    },
    u'\U0001F937\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🤷🏻‍♀️
        'en' : ':woman_shrugging_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_helle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_claro:',
        'fr': u':femme_qui_hausse_les_épaules_peau_claire:',
        'ja': u':お手上げする女_薄い肌色:',
        'ko': u':어깨를_으쓱하는_여자_하얀_피부:',
        'pt': ':mulher_dando_de_ombros_pele_clara:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_chiara:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_سفید:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_cerah:',
        'zh': u':女生耸肩_较浅肤色:'
    },
    u'\U0001F937\U0001F3FB\U0000200D\U00002640': { # 🤷🏻‍♀
        'en' : ':woman_shrugging_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_helle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_claro:',
        'fr': u':femme_qui_hausse_les_épaules_peau_claire:',
        'ja': u':お手上げする女_薄い肌色:',
        'ko': u':어깨를_으쓱하는_여자_하얀_피부:',
        'pt': ':mulher_dando_de_ombros_pele_clara:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_chiara:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_سفید:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_cerah:',
        'zh': u':女生耸肩_较浅肤色:'
    },
    u'\U0001F937\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🤷🏾‍♀️
        'en' : ':woman_shrugging_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_oscuro_medio:',
        'fr': u':femme_qui_hausse_les_épaules_peau_mate:',
        'ja': u':お手上げする女_やや濃い肌色:',
        'ko': u':어깨를_으쓱하는_여자_진한_갈색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_morena_escura:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_abbastanza_scura:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_گندمی:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_gelap-sedang:',
        'zh': u':女生耸肩_中等深肤色:'
    },
    u'\U0001F937\U0001F3FE\U0000200D\U00002640': { # 🤷🏾‍♀
        'en' : ':woman_shrugging_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_oscuro_medio:',
        'fr': u':femme_qui_hausse_les_épaules_peau_mate:',
        'ja': u':お手上げする女_やや濃い肌色:',
        'ko': u':어깨를_으쓱하는_여자_진한_갈색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_morena_escura:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_abbastanza_scura:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_گندمی:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_gelap-sedang:',
        'zh': u':女生耸肩_中等深肤色:'
    },
    u'\U0001F937\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🤷🏼‍♀️
        'en' : ':woman_shrugging_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_claro_medio:',
        'fr': u':femme_qui_hausse_les_épaules_peau_moyennement_claire:',
        'ja': u':お手上げする女_やや薄い肌色:',
        'ko': u':어깨를_으쓱하는_여자_연한_갈색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_morena_clara:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_abbastanza_chiara:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_روشن:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_cerah-sedang:',
        'zh': u':女生耸肩_中等浅肤色:'
    },
    u'\U0001F937\U0001F3FC\U0000200D\U00002640': { # 🤷🏼‍♀
        'en' : ':woman_shrugging_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_claro_medio:',
        'fr': u':femme_qui_hausse_les_épaules_peau_moyennement_claire:',
        'ja': u':お手上げする女_やや薄い肌色:',
        'ko': u':어깨를_으쓱하는_여자_연한_갈색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_morena_clara:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_abbastanza_chiara:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_روشن:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_cerah-sedang:',
        'zh': u':女生耸肩_中等浅肤色:'
    },
    u'\U0001F937\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🤷🏽‍♀️
        'en' : ':woman_shrugging_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_mittlere_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_medio:',
        'fr': u':femme_qui_hausse_les_épaules_peau_légèrement_mate:',
        'ja': u':お手上げする女_中間の肌色:',
        'ko': u':어깨를_으쓱하는_여자_갈색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_morena:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_olivastra:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_طلایی:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_sedang:',
        'zh': u':女生耸肩_中等肤色:'
    },
    u'\U0001F937\U0001F3FD\U0000200D\U00002640': { # 🤷🏽‍♀
        'en' : ':woman_shrugging_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schulterzuckende_frau_mittlere_hautfarbe:',
        'es': ':mujer_encogida_de_hombros_tono_de_piel_medio:',
        'fr': u':femme_qui_hausse_les_épaules_peau_légèrement_mate:',
        'ja': u':お手上げする女_中間の肌色:',
        'ko': u':어깨를_으쓱하는_여자_갈색_피부:',
        'pt': ':mulher_dando_de_ombros_pele_morena:',
        'it': ':donna_che_scrolla_le_spalle_carnagione_olivastra:',
        'fa': u':زن_شانه_بالا_می_اندازد_پوست_طلایی:',
        'id': ':wanita_mengangkat_bahu_warna_kulit_sedang:',
        'zh': u':女生耸肩_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F3A4': { # 👩‍🎤
        'en' : ':woman_singer:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sängerin:',
        'es': ':cantante_mujer:',
        'fr': ':chanteuse:',
        'ja': u':女性歌手:',
        'ko': u':여자_가수:',
        'pt': ':cantora:',
        'it': ':cantante_donna:',
        'fa': u':خواننده_زن:',
        'id': ':penyanyi_wanita:',
        'zh': u':女歌手:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F3A4': { # 👩🏿‍🎤
        'en' : ':woman_singer_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sängerin_dunkle_hautfarbe:',
        'es': ':cantante_mujer_tono_de_piel_oscuro:',
        'fr': u':chanteuse_peau_foncée:',
        'ja': u':女性歌手_濃い肌色:',
        'ko': u':여자_가수_검은색_피부:',
        'pt': ':cantora_pele_escura:',
        'it': ':cantante_donna_carnagione_scura:',
        'fa': u':خواننده_زن_پوست_آبنوسی:',
        'id': ':penyanyi_wanita_warna_kulit_gelap:',
        'zh': u':女歌手_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F3A4': { # 👩🏻‍🎤
        'en' : ':woman_singer_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sängerin_helle_hautfarbe:',
        'es': ':cantante_mujer_tono_de_piel_claro:',
        'fr': ':chanteuse_peau_claire:',
        'ja': u':女性歌手_薄い肌色:',
        'ko': u':여자_가수_하얀_피부:',
        'pt': ':cantora_pele_clara:',
        'it': ':cantante_donna_carnagione_chiara:',
        'fa': u':خواننده_زن_پوست_سفید:',
        'id': ':penyanyi_wanita_warna_kulit_cerah:',
        'zh': u':女歌手_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F3A4': { # 👩🏾‍🎤
        'en' : ':woman_singer_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sängerin_mitteldunkle_hautfarbe:',
        'es': ':cantante_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':chanteuse_peau_mate:',
        'ja': u':女性歌手_やや濃い肌色:',
        'ko': u':여자_가수_진한_갈색_피부:',
        'pt': ':cantora_pele_morena_escura:',
        'it': ':cantante_donna_carnagione_abbastanza_scura:',
        'fa': u':خواننده_زن_پوست_گندمی:',
        'id': ':penyanyi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女歌手_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F3A4': { # 👩🏼‍🎤
        'en' : ':woman_singer_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sängerin_mittelhelle_hautfarbe:',
        'es': ':cantante_mujer_tono_de_piel_claro_medio:',
        'fr': ':chanteuse_peau_moyennement_claire:',
        'ja': u':女性歌手_やや薄い肌色:',
        'ko': u':여자_가수_연한_갈색_피부:',
        'pt': ':cantora_pele_morena_clara:',
        'it': ':cantante_donna_carnagione_abbastanza_chiara:',
        'fa': u':خواننده_زن_پوست_روشن:',
        'id': ':penyanyi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女歌手_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F3A4': { # 👩🏽‍🎤
        'en' : ':woman_singer_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':sängerin_mittlere_hautfarbe:',
        'es': ':cantante_mujer_tono_de_piel_medio:',
        'fr': u':chanteuse_peau_légèrement_mate:',
        'ja': u':女性歌手_中間の肌色:',
        'ko': u':여자_가수_갈색_피부:',
        'pt': ':cantora_pele_morena:',
        'it': ':cantante_donna_carnagione_olivastra:',
        'fa': u':خواننده_زن_پوست_طلایی:',
        'id': ':penyanyi_wanita_warna_kulit_sedang:',
        'zh': u':女歌手_中等肤色:'
    },
    u'\U0001F9CD\U0000200D\U00002640\U0000FE0F': { # 🧍‍♀️
        'en' : ':woman_standing:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':standing_woman:'],
        'de': ':stehende_frau:',
        'es': ':mujer_de_pie:',
        'fr': ':femme_debout:',
        'ja': u':立つ女:',
        'ko': u':서_있는_여자:',
        'pt': u':mulher_em_pé:',
        'it': ':donna_in_piedi:',
        'fa': u':زن_ایستاده:',
        'id': ':wanita_berdiri:',
        'zh': u':站立的女人:'
    },
    u'\U0001F9CD\U0000200D\U00002640': { # 🧍‍♀
        'en' : ':woman_standing:',
        'status' : minimally_qualified,
        'E' : 12,
        'alias' : [':standing_woman:'],
        'de': ':stehende_frau:',
        'es': ':mujer_de_pie:',
        'fr': ':femme_debout:',
        'ja': u':立つ女:',
        'ko': u':서_있는_여자:',
        'pt': u':mulher_em_pé:',
        'it': ':donna_in_piedi:',
        'fa': u':زن_ایستاده:',
        'id': ':wanita_berdiri:',
        'zh': u':站立的女人:'
    },
    u'\U0001F9CD\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧍🏿‍♀️
        'en' : ':woman_standing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_frau_dunkle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_oscuro:',
        'fr': u':femme_debout_peau_foncée:',
        'ja': u':立つ女_濃い肌色:',
        'ko': u':서_있는_여자_검은색_피부:',
        'pt': u':mulher_em_pé_pele_escura:',
        'it': ':donna_in_piedi_carnagione_scura:',
        'fa': u':زن_ایستاده_پوست_آبنوسی:',
        'id': ':wanita_berdiri_warna_kulit_gelap:',
        'zh': u':站立的女人_较深肤色:'
    },
    u'\U0001F9CD\U0001F3FF\U0000200D\U00002640': { # 🧍🏿‍♀
        'en' : ':woman_standing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehende_frau_dunkle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_oscuro:',
        'fr': u':femme_debout_peau_foncée:',
        'ja': u':立つ女_濃い肌色:',
        'ko': u':서_있는_여자_검은색_피부:',
        'pt': u':mulher_em_pé_pele_escura:',
        'it': ':donna_in_piedi_carnagione_scura:',
        'fa': u':زن_ایستاده_پوست_آبنوسی:',
        'id': ':wanita_berdiri_warna_kulit_gelap:',
        'zh': u':站立的女人_较深肤色:'
    },
    u'\U0001F9CD\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧍🏻‍♀️
        'en' : ':woman_standing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_frau_helle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_claro:',
        'fr': ':femme_debout_peau_claire:',
        'ja': u':立つ女_薄い肌色:',
        'ko': u':서_있는_여자_하얀_피부:',
        'pt': u':mulher_em_pé_pele_clara:',
        'it': ':donna_in_piedi_carnagione_chiara:',
        'fa': u':زن_ایستاده_پوست_سفید:',
        'id': ':wanita_berdiri_warna_kulit_cerah:',
        'zh': u':站立的女人_较浅肤色:'
    },
    u'\U0001F9CD\U0001F3FB\U0000200D\U00002640': { # 🧍🏻‍♀
        'en' : ':woman_standing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehende_frau_helle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_claro:',
        'fr': ':femme_debout_peau_claire:',
        'ja': u':立つ女_薄い肌色:',
        'ko': u':서_있는_여자_하얀_피부:',
        'pt': u':mulher_em_pé_pele_clara:',
        'it': ':donna_in_piedi_carnagione_chiara:',
        'fa': u':زن_ایستاده_پوست_سفید:',
        'id': ':wanita_berdiri_warna_kulit_cerah:',
        'zh': u':站立的女人_较浅肤色:'
    },
    u'\U0001F9CD\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧍🏾‍♀️
        'en' : ':woman_standing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_oscuro_medio:',
        'fr': ':femme_debout_peau_mate:',
        'ja': u':立つ女_やや濃い肌色:',
        'ko': u':서_있는_여자_진한_갈색_피부:',
        'pt': u':mulher_em_pé_pele_morena_escura:',
        'it': ':donna_in_piedi_carnagione_abbastanza_scura:',
        'fa': u':زن_ایستاده_پوست_گندمی:',
        'id': ':wanita_berdiri_warna_kulit_gelap-sedang:',
        'zh': u':站立的女人_中等深肤色:'
    },
    u'\U0001F9CD\U0001F3FE\U0000200D\U00002640': { # 🧍🏾‍♀
        'en' : ':woman_standing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehende_frau_mitteldunkle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_oscuro_medio:',
        'fr': ':femme_debout_peau_mate:',
        'ja': u':立つ女_やや濃い肌色:',
        'ko': u':서_있는_여자_진한_갈색_피부:',
        'pt': u':mulher_em_pé_pele_morena_escura:',
        'it': ':donna_in_piedi_carnagione_abbastanza_scura:',
        'fa': u':زن_ایستاده_پوست_گندمی:',
        'id': ':wanita_berdiri_warna_kulit_gelap-sedang:',
        'zh': u':站立的女人_中等深肤色:'
    },
    u'\U0001F9CD\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧍🏼‍♀️
        'en' : ':woman_standing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_claro_medio:',
        'fr': ':femme_debout_peau_moyennement_claire:',
        'ja': u':立つ女_やや薄い肌色:',
        'ko': u':서_있는_여자_연한_갈색_피부:',
        'pt': u':mulher_em_pé_pele_morena_clara:',
        'it': ':donna_in_piedi_carnagione_abbastanza_chiara:',
        'fa': u':زن_ایستاده_پوست_روشن:',
        'id': ':wanita_berdiri_warna_kulit_cerah-sedang:',
        'zh': u':站立的女人_中等浅肤色:'
    },
    u'\U0001F9CD\U0001F3FC\U0000200D\U00002640': { # 🧍🏼‍♀
        'en' : ':woman_standing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehende_frau_mittelhelle_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_claro_medio:',
        'fr': ':femme_debout_peau_moyennement_claire:',
        'ja': u':立つ女_やや薄い肌色:',
        'ko': u':서_있는_여자_연한_갈색_피부:',
        'pt': u':mulher_em_pé_pele_morena_clara:',
        'it': ':donna_in_piedi_carnagione_abbastanza_chiara:',
        'fa': u':زن_ایستاده_پوست_روشن:',
        'id': ':wanita_berdiri_warna_kulit_cerah-sedang:',
        'zh': u':站立的女人_中等浅肤色:'
    },
    u'\U0001F9CD\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧍🏽‍♀️
        'en' : ':woman_standing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':stehende_frau_mittlere_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_medio:',
        'fr': u':femme_debout_peau_légèrement_mate:',
        'ja': u':立つ女_中間の肌色:',
        'ko': u':서_있는_여자_갈색_피부:',
        'pt': u':mulher_em_pé_pele_morena:',
        'it': ':donna_in_piedi_carnagione_olivastra:',
        'fa': u':زن_ایستاده_پوست_طلایی:',
        'id': ':wanita_berdiri_warna_kulit_sedang:',
        'zh': u':站立的女人_中等肤色:'
    },
    u'\U0001F9CD\U0001F3FD\U0000200D\U00002640': { # 🧍🏽‍♀
        'en' : ':woman_standing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 12,
        'de': ':stehende_frau_mittlere_hautfarbe:',
        'es': ':mujer_de_pie_tono_de_piel_medio:',
        'fr': u':femme_debout_peau_légèrement_mate:',
        'ja': u':立つ女_中間の肌色:',
        'ko': u':서_있는_여자_갈색_피부:',
        'pt': u':mulher_em_pé_pele_morena:',
        'it': ':donna_in_piedi_carnagione_olivastra:',
        'fa': u':زن_ایستاده_پوست_طلایی:',
        'id': ':wanita_berdiri_warna_kulit_sedang:',
        'zh': u':站立的女人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F393': { # 👩‍🎓
        'en' : ':woman_student:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':studentin:',
        'es': ':estudiante_mujer:',
        'fr': u':étudiante:',
        'ja': u':女子学生:',
        'ko': u':여학생:',
        'pt': ':aluna:',
        'it': ':studentessa:',
        'fa': u':دانشجوی_زن:',
        'id': ':sarjana_wanita:',
        'zh': u':女学生:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F393': { # 👩🏿‍🎓
        'en' : ':woman_student_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':studentin_dunkle_hautfarbe:',
        'es': ':estudiante_mujer_tono_de_piel_oscuro:',
        'fr': u':étudiante_peau_foncée:',
        'ja': u':女子学生_濃い肌色:',
        'ko': u':여학생_검은색_피부:',
        'pt': ':aluna_pele_escura:',
        'it': ':studentessa_carnagione_scura:',
        'fa': u':دانشجوی_زن_پوست_آبنوسی:',
        'id': ':sarjana_wanita_warna_kulit_gelap:',
        'zh': u':女学生_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F393': { # 👩🏻‍🎓
        'en' : ':woman_student_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':studentin_helle_hautfarbe:',
        'es': ':estudiante_mujer_tono_de_piel_claro:',
        'fr': u':étudiante_peau_claire:',
        'ja': u':女子学生_薄い肌色:',
        'ko': u':여학생_하얀_피부:',
        'pt': ':aluna_pele_clara:',
        'it': ':studentessa_carnagione_chiara:',
        'fa': u':دانشجوی_زن_پوست_سفید:',
        'id': ':sarjana_wanita_warna_kulit_cerah:',
        'zh': u':女学生_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F393': { # 👩🏾‍🎓
        'en' : ':woman_student_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':studentin_mitteldunkle_hautfarbe:',
        'es': ':estudiante_mujer_tono_de_piel_oscuro_medio:',
        'fr': u':étudiante_peau_mate:',
        'ja': u':女子学生_やや濃い肌色:',
        'ko': u':여학생_진한_갈색_피부:',
        'pt': ':aluna_pele_morena_escura:',
        'it': ':studentessa_carnagione_abbastanza_scura:',
        'fa': u':دانشجوی_زن_پوست_گندمی:',
        'id': ':sarjana_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女学生_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F393': { # 👩🏼‍🎓
        'en' : ':woman_student_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':studentin_mittelhelle_hautfarbe:',
        'es': ':estudiante_mujer_tono_de_piel_claro_medio:',
        'fr': u':étudiante_peau_moyennement_claire:',
        'ja': u':女子学生_やや薄い肌色:',
        'ko': u':여학생_연한_갈색_피부:',
        'pt': ':aluna_pele_morena_clara:',
        'it': ':studentessa_carnagione_abbastanza_chiara:',
        'fa': u':دانشجوی_زن_پوست_روشن:',
        'id': ':sarjana_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女学生_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F393': { # 👩🏽‍🎓
        'en' : ':woman_student_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':studentin_mittlere_hautfarbe:',
        'es': ':estudiante_mujer_tono_de_piel_medio:',
        'fr': u':étudiante_peau_légèrement_mate:',
        'ja': u':女子学生_中間の肌色:',
        'ko': u':여학생_갈색_피부:',
        'pt': ':aluna_pele_morena:',
        'it': ':studentessa_carnagione_olivastra:',
        'fa': u':دانشجوی_زن_پوست_طلایی:',
        'id': ':sarjana_wanita_warna_kulit_sedang:',
        'zh': u':女学生_中等肤色:'
    },
    u'\U0001F9B8\U0000200D\U00002640\U0000FE0F': { # 🦸‍♀️
        'en' : ':woman_superhero:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':superhero_woman:'],
        'de': ':heldin:',
        'es': u':superheroína:',
        'fr': u':super-héroïne:',
        'ja': u':女性のスーパーヒーロー:',
        'ko': u':여자_히어로:',
        'pt': u':super-heroína:',
        'it': ':supereroina:',
        'fa': u':ابرقهرمان_زن:',
        'id': ':pahlawan_super_wanita:',
        'zh': u':女超级英雄:'
    },
    u'\U0001F9B8\U0000200D\U00002640': { # 🦸‍♀
        'en' : ':woman_superhero:',
        'status' : minimally_qualified,
        'E' : 11,
        'alias' : [':superhero_woman:'],
        'de': ':heldin:',
        'es': u':superheroína:',
        'fr': u':super-héroïne:',
        'ja': u':女性のスーパーヒーロー:',
        'ko': u':여자_히어로:',
        'pt': u':super-heroína:',
        'it': ':supereroina:',
        'fa': u':ابرقهرمان_زن:',
        'id': ':pahlawan_super_wanita:',
        'zh': u':女超级英雄:'
    },
    u'\U0001F9B8\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🦸🏿‍♀️
        'en' : ':woman_superhero_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':heldin_dunkle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_oscuro:',
        'fr': u':super-héroïne_peau_foncée:',
        'ja': u':女性のスーパーヒーロー_濃い肌色:',
        'ko': u':여자_히어로_검은색_피부:',
        'pt': u':super-heroína_pele_escura:',
        'it': ':supereroina_carnagione_scura:',
        'fa': u':ابرقهرمان_زن_پوست_آبنوسی:',
        'id': ':pahlawan_super_wanita_warna_kulit_gelap:',
        'zh': u':女超级英雄_较深肤色:'
    },
    u'\U0001F9B8\U0001F3FF\U0000200D\U00002640': { # 🦸🏿‍♀
        'en' : ':woman_superhero_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':heldin_dunkle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_oscuro:',
        'fr': u':super-héroïne_peau_foncée:',
        'ja': u':女性のスーパーヒーロー_濃い肌色:',
        'ko': u':여자_히어로_검은색_피부:',
        'pt': u':super-heroína_pele_escura:',
        'it': ':supereroina_carnagione_scura:',
        'fa': u':ابرقهرمان_زن_پوست_آبنوسی:',
        'id': ':pahlawan_super_wanita_warna_kulit_gelap:',
        'zh': u':女超级英雄_较深肤色:'
    },
    u'\U0001F9B8\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🦸🏻‍♀️
        'en' : ':woman_superhero_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':heldin_helle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_claro:',
        'fr': u':super-héroïne_peau_claire:',
        'ja': u':女性のスーパーヒーロー_薄い肌色:',
        'ko': u':여자_히어로_하얀_피부:',
        'pt': u':super-heroína_pele_clara:',
        'it': ':supereroina_carnagione_chiara:',
        'fa': u':ابرقهرمان_زن_پوست_سفید:',
        'id': ':pahlawan_super_wanita_warna_kulit_cerah:',
        'zh': u':女超级英雄_较浅肤色:'
    },
    u'\U0001F9B8\U0001F3FB\U0000200D\U00002640': { # 🦸🏻‍♀
        'en' : ':woman_superhero_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':heldin_helle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_claro:',
        'fr': u':super-héroïne_peau_claire:',
        'ja': u':女性のスーパーヒーロー_薄い肌色:',
        'ko': u':여자_히어로_하얀_피부:',
        'pt': u':super-heroína_pele_clara:',
        'it': ':supereroina_carnagione_chiara:',
        'fa': u':ابرقهرمان_زن_پوست_سفید:',
        'id': ':pahlawan_super_wanita_warna_kulit_cerah:',
        'zh': u':女超级英雄_较浅肤色:'
    },
    u'\U0001F9B8\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🦸🏾‍♀️
        'en' : ':woman_superhero_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':heldin_mitteldunkle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_oscuro_medio:',
        'fr': u':super-héroïne_peau_mate:',
        'ja': u':女性のスーパーヒーロー_やや濃い肌色:',
        'ko': u':여자_히어로_진한_갈색_피부:',
        'pt': u':super-heroína_pele_morena_escura:',
        'it': ':supereroina_carnagione_abbastanza_scura:',
        'fa': u':ابرقهرمان_زن_پوست_گندمی:',
        'id': ':pahlawan_super_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女超级英雄_中等深肤色:'
    },
    u'\U0001F9B8\U0001F3FE\U0000200D\U00002640': { # 🦸🏾‍♀
        'en' : ':woman_superhero_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':heldin_mitteldunkle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_oscuro_medio:',
        'fr': u':super-héroïne_peau_mate:',
        'ja': u':女性のスーパーヒーロー_やや濃い肌色:',
        'ko': u':여자_히어로_진한_갈색_피부:',
        'pt': u':super-heroína_pele_morena_escura:',
        'it': ':supereroina_carnagione_abbastanza_scura:',
        'fa': u':ابرقهرمان_زن_پوست_گندمی:',
        'id': ':pahlawan_super_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女超级英雄_中等深肤色:'
    },
    u'\U0001F9B8\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🦸🏼‍♀️
        'en' : ':woman_superhero_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':heldin_mittelhelle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_claro_medio:',
        'fr': u':super-héroïne_peau_moyennement_claire:',
        'ja': u':女性のスーパーヒーロー_やや薄い肌色:',
        'ko': u':여자_히어로_연한_갈색_피부:',
        'pt': u':super-heroína_pele_morena_clara:',
        'it': ':supereroina_carnagione_abbastanza_chiara:',
        'fa': u':ابرقهرمان_زن_پوست_روشن:',
        'id': ':pahlawan_super_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女超级英雄_中等浅肤色:'
    },
    u'\U0001F9B8\U0001F3FC\U0000200D\U00002640': { # 🦸🏼‍♀
        'en' : ':woman_superhero_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':heldin_mittelhelle_hautfarbe:',
        'es': u':superheroína_tono_de_piel_claro_medio:',
        'fr': u':super-héroïne_peau_moyennement_claire:',
        'ja': u':女性のスーパーヒーロー_やや薄い肌色:',
        'ko': u':여자_히어로_연한_갈색_피부:',
        'pt': u':super-heroína_pele_morena_clara:',
        'it': ':supereroina_carnagione_abbastanza_chiara:',
        'fa': u':ابرقهرمان_زن_پوست_روشن:',
        'id': ':pahlawan_super_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女超级英雄_中等浅肤色:'
    },
    u'\U0001F9B8\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🦸🏽‍♀️
        'en' : ':woman_superhero_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':heldin_mittlere_hautfarbe:',
        'es': u':superheroína_tono_de_piel_medio:',
        'fr': u':super-héroïne_peau_légèrement_mate:',
        'ja': u':女性のスーパーヒーロー_中間の肌色:',
        'ko': u':여자_히어로_갈색_피부:',
        'pt': u':super-heroína_pele_morena:',
        'it': ':supereroina_carnagione_olivastra:',
        'fa': u':ابرقهرمان_زن_پوست_طلایی:',
        'id': ':pahlawan_super_wanita_warna_kulit_sedang:',
        'zh': u':女超级英雄_中等肤色:'
    },
    u'\U0001F9B8\U0001F3FD\U0000200D\U00002640': { # 🦸🏽‍♀
        'en' : ':woman_superhero_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': ':heldin_mittlere_hautfarbe:',
        'es': u':superheroína_tono_de_piel_medio:',
        'fr': u':super-héroïne_peau_légèrement_mate:',
        'ja': u':女性のスーパーヒーロー_中間の肌色:',
        'ko': u':여자_히어로_갈색_피부:',
        'pt': u':super-heroína_pele_morena:',
        'it': ':supereroina_carnagione_olivastra:',
        'fa': u':ابرقهرمان_زن_پوست_طلایی:',
        'id': ':pahlawan_super_wanita_warna_kulit_sedang:',
        'zh': u':女超级英雄_中等肤色:'
    },
    u'\U0001F9B9\U0000200D\U00002640\U0000FE0F': { # 🦹‍♀️
        'en' : ':woman_supervillain:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':supervillain_woman:'],
        'de': u':weiblicher_bösewicht:',
        'es': ':supervillana:',
        'fr': ':super-vilain_femme:',
        'ja': u':女性の悪役:',
        'ko': u':여자_슈퍼_악당:',
        'pt': u':supervilã:',
        'it': ':supercattiva:',
        'fa': u':ابرشرور_زن:',
        'id': ':penjahat_super_wanita:',
        'zh': u':女超级大坏蛋:'
    },
    u'\U0001F9B9\U0000200D\U00002640': { # 🦹‍♀
        'en' : ':woman_supervillain:',
        'status' : minimally_qualified,
        'E' : 11,
        'alias' : [':supervillain_woman:'],
        'de': u':weiblicher_bösewicht:',
        'es': ':supervillana:',
        'fr': ':super-vilain_femme:',
        'ja': u':女性の悪役:',
        'ko': u':여자_슈퍼_악당:',
        'pt': u':supervilã:',
        'it': ':supercattiva:',
        'fa': u':ابرشرور_زن:',
        'id': ':penjahat_super_wanita:',
        'zh': u':女超级大坏蛋:'
    },
    u'\U0001F9B9\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🦹🏿‍♀️
        'en' : ':woman_supervillain_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_dunkle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_oscuro:',
        'fr': u':super-vilain_femme_peau_foncée:',
        'ja': u':女性の悪役_濃い肌色:',
        'ko': u':여자_슈퍼_악당_검은색_피부:',
        'pt': u':supervilã_pele_escura:',
        'it': ':supercattiva_carnagione_scura:',
        'fa': u':ابرشرور_زن_پوست_آبنوسی:',
        'id': ':penjahat_super_wanita_warna_kulit_gelap:',
        'zh': u':女超级大坏蛋_较深肤色:'
    },
    u'\U0001F9B9\U0001F3FF\U0000200D\U00002640': { # 🦹🏿‍♀
        'en' : ':woman_supervillain_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_dunkle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_oscuro:',
        'fr': u':super-vilain_femme_peau_foncée:',
        'ja': u':女性の悪役_濃い肌色:',
        'ko': u':여자_슈퍼_악당_검은색_피부:',
        'pt': u':supervilã_pele_escura:',
        'it': ':supercattiva_carnagione_scura:',
        'fa': u':ابرشرور_زن_پوست_آبنوسی:',
        'id': ':penjahat_super_wanita_warna_kulit_gelap:',
        'zh': u':女超级大坏蛋_较深肤色:'
    },
    u'\U0001F9B9\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🦹🏻‍♀️
        'en' : ':woman_supervillain_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_helle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_claro:',
        'fr': ':super-vilain_femme_peau_claire:',
        'ja': u':女性の悪役_薄い肌色:',
        'ko': u':여자_슈퍼_악당_하얀_피부:',
        'pt': u':supervilã_pele_clara:',
        'it': ':supercattiva_carnagione_chiara:',
        'fa': u':ابرشرور_زن_پوست_سفید:',
        'id': ':penjahat_super_wanita_warna_kulit_cerah:',
        'zh': u':女超级大坏蛋_较浅肤色:'
    },
    u'\U0001F9B9\U0001F3FB\U0000200D\U00002640': { # 🦹🏻‍♀
        'en' : ':woman_supervillain_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_helle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_claro:',
        'fr': ':super-vilain_femme_peau_claire:',
        'ja': u':女性の悪役_薄い肌色:',
        'ko': u':여자_슈퍼_악당_하얀_피부:',
        'pt': u':supervilã_pele_clara:',
        'it': ':supercattiva_carnagione_chiara:',
        'fa': u':ابرشرور_زن_پوست_سفید:',
        'id': ':penjahat_super_wanita_warna_kulit_cerah:',
        'zh': u':女超级大坏蛋_较浅肤色:'
    },
    u'\U0001F9B9\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🦹🏾‍♀️
        'en' : ':woman_supervillain_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_mitteldunkle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_oscuro_medio:',
        'fr': ':super-vilain_femme_peau_mate:',
        'ja': u':女性の悪役_やや濃い肌色:',
        'ko': u':여자_슈퍼_악당_진한_갈색_피부:',
        'pt': u':supervilã_pele_morena_escura:',
        'it': ':supercattiva_carnagione_abbastanza_scura:',
        'fa': u':ابرشرور_زن_پوست_گندمی:',
        'id': ':penjahat_super_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女超级大坏蛋_中等深肤色:'
    },
    u'\U0001F9B9\U0001F3FE\U0000200D\U00002640': { # 🦹🏾‍♀
        'en' : ':woman_supervillain_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_mitteldunkle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_oscuro_medio:',
        'fr': ':super-vilain_femme_peau_mate:',
        'ja': u':女性の悪役_やや濃い肌色:',
        'ko': u':여자_슈퍼_악당_진한_갈색_피부:',
        'pt': u':supervilã_pele_morena_escura:',
        'it': ':supercattiva_carnagione_abbastanza_scura:',
        'fa': u':ابرشرور_زن_پوست_گندمی:',
        'id': ':penjahat_super_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女超级大坏蛋_中等深肤色:'
    },
    u'\U0001F9B9\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🦹🏼‍♀️
        'en' : ':woman_supervillain_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_mittelhelle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_claro_medio:',
        'fr': ':super-vilain_femme_peau_moyennement_claire:',
        'ja': u':女性の悪役_やや薄い肌色:',
        'ko': u':여자_슈퍼_악당_연한_갈색_피부:',
        'pt': u':supervilã_pele_morena_clara:',
        'it': ':supercattiva_carnagione_abbastanza_chiara:',
        'fa': u':ابرشرور_زن_پوست_روشن:',
        'id': ':penjahat_super_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女超级大坏蛋_中等浅肤色:'
    },
    u'\U0001F9B9\U0001F3FC\U0000200D\U00002640': { # 🦹🏼‍♀
        'en' : ':woman_supervillain_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_mittelhelle_hautfarbe:',
        'es': ':supervillana_tono_de_piel_claro_medio:',
        'fr': ':super-vilain_femme_peau_moyennement_claire:',
        'ja': u':女性の悪役_やや薄い肌色:',
        'ko': u':여자_슈퍼_악당_연한_갈색_피부:',
        'pt': u':supervilã_pele_morena_clara:',
        'it': ':supercattiva_carnagione_abbastanza_chiara:',
        'fa': u':ابرشرور_زن_پوست_روشن:',
        'id': ':penjahat_super_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女超级大坏蛋_中等浅肤色:'
    },
    u'\U0001F9B9\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🦹🏽‍♀️
        'en' : ':woman_supervillain_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_mittlere_hautfarbe:',
        'es': ':supervillana_tono_de_piel_medio:',
        'fr': u':super-vilain_femme_peau_légèrement_mate:',
        'ja': u':女性の悪役_中間の肌色:',
        'ko': u':여자_슈퍼_악당_갈색_피부:',
        'pt': u':supervilã_pele_morena:',
        'it': ':supercattiva_carnagione_olivastra:',
        'fa': u':ابرشرور_زن_پوست_طلایی:',
        'id': ':penjahat_super_wanita_warna_kulit_sedang:',
        'zh': u':女超级大坏蛋_中等肤色:'
    },
    u'\U0001F9B9\U0001F3FD\U0000200D\U00002640': { # 🦹🏽‍♀
        'en' : ':woman_supervillain_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 11,
        'de': u':weiblicher_bösewicht_mittlere_hautfarbe:',
        'es': ':supervillana_tono_de_piel_medio:',
        'fr': u':super-vilain_femme_peau_légèrement_mate:',
        'ja': u':女性の悪役_中間の肌色:',
        'ko': u':여자_슈퍼_악당_갈색_피부:',
        'pt': u':supervilã_pele_morena:',
        'it': ':supercattiva_carnagione_olivastra:',
        'fa': u':ابرشرور_زن_پوست_طلایی:',
        'id': ':penjahat_super_wanita_warna_kulit_sedang:',
        'zh': u':女超级大坏蛋_中等肤色:'
    },
    u'\U0001F3C4\U0000200D\U00002640\U0000FE0F': { # 🏄‍♀️
        'en' : ':woman_surfing:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':surfing_woman:'],
        'de': ':surferin:',
        'es': ':mujer_haciendo_surf:',
        'fr': ':surfeuse:',
        'ja': u':サーフィンする女:',
        'ko': u':서핑하는_여자:',
        'pt': ':mulher_surfista:',
        'it': ':surfista_donna:',
        'fa': u':موج_سوار_زن:',
        'id': ':wanita_berselancar:',
        'zh': u':女生冲浪:'
    },
    u'\U0001F3C4\U0000200D\U00002640': { # 🏄‍♀
        'en' : ':woman_surfing:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':surfing_woman:'],
        'de': ':surferin:',
        'es': ':mujer_haciendo_surf:',
        'fr': ':surfeuse:',
        'ja': u':サーフィンする女:',
        'ko': u':서핑하는_여자:',
        'pt': ':mulher_surfista:',
        'it': ':surfista_donna:',
        'fa': u':موج_سوار_زن:',
        'id': ':wanita_berselancar:',
        'zh': u':女生冲浪:'
    },
    u'\U0001F3C4\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🏄🏿‍♀️
        'en' : ':woman_surfing_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surferin_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_oscuro:',
        'fr': u':surfeuse_peau_foncée:',
        'ja': u':サーフィンする女_濃い肌色:',
        'ko': u':서핑하는_여자_검은색_피부:',
        'pt': ':mulher_surfista_pele_escura:',
        'it': ':surfista_donna_carnagione_scura:',
        'fa': u':موج_سوار_زن_پوست_آبنوسی:',
        'id': ':wanita_berselancar_warna_kulit_gelap:',
        'zh': u':女生冲浪_较深肤色:'
    },
    u'\U0001F3C4\U0001F3FF\U0000200D\U00002640': { # 🏄🏿‍♀
        'en' : ':woman_surfing_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surferin_dunkle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_oscuro:',
        'fr': u':surfeuse_peau_foncée:',
        'ja': u':サーフィンする女_濃い肌色:',
        'ko': u':서핑하는_여자_검은색_피부:',
        'pt': ':mulher_surfista_pele_escura:',
        'it': ':surfista_donna_carnagione_scura:',
        'fa': u':موج_سوار_زن_پوست_آبنوسی:',
        'id': ':wanita_berselancar_warna_kulit_gelap:',
        'zh': u':女生冲浪_较深肤色:'
    },
    u'\U0001F3C4\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🏄🏻‍♀️
        'en' : ':woman_surfing_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surferin_helle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_claro:',
        'fr': ':surfeuse_peau_claire:',
        'ja': u':サーフィンする女_薄い肌色:',
        'ko': u':서핑하는_여자_하얀_피부:',
        'pt': ':mulher_surfista_pele_clara:',
        'it': ':surfista_donna_carnagione_chiara:',
        'fa': u':موج_سوار_زن_پوست_سفید:',
        'id': ':wanita_berselancar_warna_kulit_cerah:',
        'zh': u':女生冲浪_较浅肤色:'
    },
    u'\U0001F3C4\U0001F3FB\U0000200D\U00002640': { # 🏄🏻‍♀
        'en' : ':woman_surfing_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surferin_helle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_claro:',
        'fr': ':surfeuse_peau_claire:',
        'ja': u':サーフィンする女_薄い肌色:',
        'ko': u':서핑하는_여자_하얀_피부:',
        'pt': ':mulher_surfista_pele_clara:',
        'it': ':surfista_donna_carnagione_chiara:',
        'fa': u':موج_سوار_زن_پوست_سفید:',
        'id': ':wanita_berselancar_warna_kulit_cerah:',
        'zh': u':女生冲浪_较浅肤色:'
    },
    u'\U0001F3C4\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🏄🏾‍♀️
        'en' : ':woman_surfing_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surferin_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_oscuro_medio:',
        'fr': ':surfeuse_peau_mate:',
        'ja': u':サーフィンする女_やや濃い肌色:',
        'ko': u':서핑하는_여자_진한_갈색_피부:',
        'pt': ':mulher_surfista_pele_morena_escura:',
        'it': ':surfista_donna_carnagione_abbastanza_scura:',
        'fa': u':موج_سوار_زن_پوست_گندمی:',
        'id': ':wanita_berselancar_warna_kulit_gelap-sedang:',
        'zh': u':女生冲浪_中等深肤色:'
    },
    u'\U0001F3C4\U0001F3FE\U0000200D\U00002640': { # 🏄🏾‍♀
        'en' : ':woman_surfing_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surferin_mitteldunkle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_oscuro_medio:',
        'fr': ':surfeuse_peau_mate:',
        'ja': u':サーフィンする女_やや濃い肌色:',
        'ko': u':서핑하는_여자_진한_갈색_피부:',
        'pt': ':mulher_surfista_pele_morena_escura:',
        'it': ':surfista_donna_carnagione_abbastanza_scura:',
        'fa': u':موج_سوار_زن_پوست_گندمی:',
        'id': ':wanita_berselancar_warna_kulit_gelap-sedang:',
        'zh': u':女生冲浪_中等深肤色:'
    },
    u'\U0001F3C4\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🏄🏼‍♀️
        'en' : ':woman_surfing_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surferin_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_claro_medio:',
        'fr': ':surfeuse_peau_moyennement_claire:',
        'ja': u':サーフィンする女_やや薄い肌色:',
        'ko': u':서핑하는_여자_연한_갈색_피부:',
        'pt': ':mulher_surfista_pele_morena_clara:',
        'it': ':surfista_donna_carnagione_abbastanza_chiara:',
        'fa': u':موج_سوار_زن_پوست_روشن:',
        'id': ':wanita_berselancar_warna_kulit_cerah-sedang:',
        'zh': u':女生冲浪_中等浅肤色:'
    },
    u'\U0001F3C4\U0001F3FC\U0000200D\U00002640': { # 🏄🏼‍♀
        'en' : ':woman_surfing_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surferin_mittelhelle_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_claro_medio:',
        'fr': ':surfeuse_peau_moyennement_claire:',
        'ja': u':サーフィンする女_やや薄い肌色:',
        'ko': u':서핑하는_여자_연한_갈색_피부:',
        'pt': ':mulher_surfista_pele_morena_clara:',
        'it': ':surfista_donna_carnagione_abbastanza_chiara:',
        'fa': u':موج_سوار_زن_پوست_روشن:',
        'id': ':wanita_berselancar_warna_kulit_cerah-sedang:',
        'zh': u':女生冲浪_中等浅肤色:'
    },
    u'\U0001F3C4\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🏄🏽‍♀️
        'en' : ':woman_surfing_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':surferin_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_medio:',
        'fr': u':surfeuse_peau_légèrement_mate:',
        'ja': u':サーフィンする女_中間の肌色:',
        'ko': u':서핑하는_여자_갈색_피부:',
        'pt': ':mulher_surfista_pele_morena:',
        'it': ':surfista_donna_carnagione_olivastra:',
        'fa': u':موج_سوار_زن_پوست_طلایی:',
        'id': ':wanita_berselancar_warna_kulit_sedang:',
        'zh': u':女生冲浪_中等肤色:'
    },
    u'\U0001F3C4\U0001F3FD\U0000200D\U00002640': { # 🏄🏽‍♀
        'en' : ':woman_surfing_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':surferin_mittlere_hautfarbe:',
        'es': ':mujer_haciendo_surf_tono_de_piel_medio:',
        'fr': u':surfeuse_peau_légèrement_mate:',
        'ja': u':サーフィンする女_中間の肌色:',
        'ko': u':서핑하는_여자_갈색_피부:',
        'pt': ':mulher_surfista_pele_morena:',
        'it': ':surfista_donna_carnagione_olivastra:',
        'fa': u':موج_سوار_زن_پوست_طلایی:',
        'id': ':wanita_berselancar_warna_kulit_sedang:',
        'zh': u':女生冲浪_中等肤色:'
    },
    u'\U0001F3CA\U0000200D\U00002640\U0000FE0F': { # 🏊‍♀️
        'en' : ':woman_swimming:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':swimming_woman:'],
        'de': ':schwimmerin:',
        'es': ':mujer_nadando:',
        'fr': ':nageuse:',
        'ja': u':泳ぐ女:',
        'ko': u':수영하는_여자:',
        'pt': ':mulher_nadando:',
        'it': ':nuotatrice:',
        'fa': u':شناگر_زن:',
        'id': ':wanita_berenang:',
        'zh': u':女生游泳:'
    },
    u'\U0001F3CA\U0000200D\U00002640': { # 🏊‍♀
        'en' : ':woman_swimming:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':swimming_woman:'],
        'de': ':schwimmerin:',
        'es': ':mujer_nadando:',
        'fr': ':nageuse:',
        'ja': u':泳ぐ女:',
        'ko': u':수영하는_여자:',
        'pt': ':mulher_nadando:',
        'it': ':nuotatrice:',
        'fa': u':شناگر_زن:',
        'id': ':wanita_berenang:',
        'zh': u':女生游泳:'
    },
    u'\U0001F3CA\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🏊🏿‍♀️
        'en' : ':woman_swimming_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmerin_dunkle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_oscuro:',
        'fr': u':nageuse_peau_foncée:',
        'ja': u':泳ぐ女_濃い肌色:',
        'ko': u':수영하는_여자_검은색_피부:',
        'pt': ':mulher_nadando_pele_escura:',
        'it': ':nuotatrice_carnagione_scura:',
        'fa': u':شناگر_زن_پوست_آبنوسی:',
        'id': ':wanita_berenang_warna_kulit_gelap:',
        'zh': u':女生游泳_较深肤色:'
    },
    u'\U0001F3CA\U0001F3FF\U0000200D\U00002640': { # 🏊🏿‍♀
        'en' : ':woman_swimming_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmerin_dunkle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_oscuro:',
        'fr': u':nageuse_peau_foncée:',
        'ja': u':泳ぐ女_濃い肌色:',
        'ko': u':수영하는_여자_검은색_피부:',
        'pt': ':mulher_nadando_pele_escura:',
        'it': ':nuotatrice_carnagione_scura:',
        'fa': u':شناگر_زن_پوست_آبنوسی:',
        'id': ':wanita_berenang_warna_kulit_gelap:',
        'zh': u':女生游泳_较深肤色:'
    },
    u'\U0001F3CA\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🏊🏻‍♀️
        'en' : ':woman_swimming_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmerin_helle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_claro:',
        'fr': ':nageuse_peau_claire:',
        'ja': u':泳ぐ女_薄い肌色:',
        'ko': u':수영하는_여자_하얀_피부:',
        'pt': ':mulher_nadando_pele_clara:',
        'it': ':nuotatrice_carnagione_chiara:',
        'fa': u':شناگر_زن_پوست_سفید:',
        'id': ':wanita_berenang_warna_kulit_cerah:',
        'zh': u':女生游泳_较浅肤色:'
    },
    u'\U0001F3CA\U0001F3FB\U0000200D\U00002640': { # 🏊🏻‍♀
        'en' : ':woman_swimming_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmerin_helle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_claro:',
        'fr': ':nageuse_peau_claire:',
        'ja': u':泳ぐ女_薄い肌色:',
        'ko': u':수영하는_여자_하얀_피부:',
        'pt': ':mulher_nadando_pele_clara:',
        'it': ':nuotatrice_carnagione_chiara:',
        'fa': u':شناگر_زن_پوست_سفید:',
        'id': ':wanita_berenang_warna_kulit_cerah:',
        'zh': u':女生游泳_较浅肤色:'
    },
    u'\U0001F3CA\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🏊🏾‍♀️
        'en' : ':woman_swimming_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_oscuro_medio:',
        'fr': ':nageuse_peau_mate:',
        'ja': u':泳ぐ女_やや濃い肌色:',
        'ko': u':수영하는_여자_진한_갈색_피부:',
        'pt': ':mulher_nadando_pele_morena_escura:',
        'it': ':nuotatrice_carnagione_abbastanza_scura:',
        'fa': u':شناگر_زن_پوست_گندمی:',
        'id': ':wanita_berenang_warna_kulit_gelap-sedang:',
        'zh': u':女生游泳_中等深肤色:'
    },
    u'\U0001F3CA\U0001F3FE\U0000200D\U00002640': { # 🏊🏾‍♀
        'en' : ':woman_swimming_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_oscuro_medio:',
        'fr': ':nageuse_peau_mate:',
        'ja': u':泳ぐ女_やや濃い肌色:',
        'ko': u':수영하는_여자_진한_갈색_피부:',
        'pt': ':mulher_nadando_pele_morena_escura:',
        'it': ':nuotatrice_carnagione_abbastanza_scura:',
        'fa': u':شناگر_زن_پوست_گندمی:',
        'id': ':wanita_berenang_warna_kulit_gelap-sedang:',
        'zh': u':女生游泳_中等深肤色:'
    },
    u'\U0001F3CA\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🏊🏼‍♀️
        'en' : ':woman_swimming_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmerin_mittelhelle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_claro_medio:',
        'fr': ':nageuse_peau_moyennement_claire:',
        'ja': u':泳ぐ女_やや薄い肌色:',
        'ko': u':수영하는_여자_연한_갈색_피부:',
        'pt': ':mulher_nadando_pele_morena_clara:',
        'it': ':nuotatrice_carnagione_abbastanza_chiara:',
        'fa': u':شناگر_زن_پوست_روشن:',
        'id': ':wanita_berenang_warna_kulit_cerah-sedang:',
        'zh': u':女生游泳_中等浅肤色:'
    },
    u'\U0001F3CA\U0001F3FC\U0000200D\U00002640': { # 🏊🏼‍♀
        'en' : ':woman_swimming_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmerin_mittelhelle_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_claro_medio:',
        'fr': ':nageuse_peau_moyennement_claire:',
        'ja': u':泳ぐ女_やや薄い肌色:',
        'ko': u':수영하는_여자_연한_갈색_피부:',
        'pt': ':mulher_nadando_pele_morena_clara:',
        'it': ':nuotatrice_carnagione_abbastanza_chiara:',
        'fa': u':شناگر_زن_پوست_روشن:',
        'id': ':wanita_berenang_warna_kulit_cerah-sedang:',
        'zh': u':女生游泳_中等浅肤色:'
    },
    u'\U0001F3CA\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🏊🏽‍♀️
        'en' : ':woman_swimming_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':schwimmerin_mittlere_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_medio:',
        'fr': u':nageuse_peau_légèrement_mate:',
        'ja': u':泳ぐ女_中間の肌色:',
        'ko': u':수영하는_여자_갈색_피부:',
        'pt': ':mulher_nadando_pele_morena:',
        'it': ':nuotatrice_carnagione_olivastra:',
        'fa': u':شناگر_زن_پوست_طلایی:',
        'id': ':wanita_berenang_warna_kulit_sedang:',
        'zh': u':女生游泳_中等肤色:'
    },
    u'\U0001F3CA\U0001F3FD\U0000200D\U00002640': { # 🏊🏽‍♀
        'en' : ':woman_swimming_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':schwimmerin_mittlere_hautfarbe:',
        'es': ':mujer_nadando_tono_de_piel_medio:',
        'fr': u':nageuse_peau_légèrement_mate:',
        'ja': u':泳ぐ女_中間の肌色:',
        'ko': u':수영하는_여자_갈색_피부:',
        'pt': ':mulher_nadando_pele_morena:',
        'it': ':nuotatrice_carnagione_olivastra:',
        'fa': u':شناگر_زن_پوست_طلایی:',
        'id': ':wanita_berenang_warna_kulit_sedang:',
        'zh': u':女生游泳_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F3EB': { # 👩‍🏫
        'en' : ':woman_teacher:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrerin:',
        'es': ':docente_mujer:',
        'fr': ':enseignante:',
        'ja': u':女性の教師:',
        'ko': u':여교사:',
        'pt': ':professora:',
        'it': ':professoressa:',
        'fa': u':آموزگار_زن:',
        'id': ':pengajar_wanita:',
        'zh': u':女老师:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F3EB': { # 👩🏿‍🏫
        'en' : ':woman_teacher_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrerin_dunkle_hautfarbe:',
        'es': ':docente_mujer_tono_de_piel_oscuro:',
        'fr': u':enseignante_peau_foncée:',
        'ja': u':女性の教師_濃い肌色:',
        'ko': u':여교사_검은색_피부:',
        'pt': ':professora_pele_escura:',
        'it': ':professoressa_carnagione_scura:',
        'fa': u':آموزگار_زن_پوست_آبنوسی:',
        'id': ':pengajar_wanita_warna_kulit_gelap:',
        'zh': u':女老师_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F3EB': { # 👩🏻‍🏫
        'en' : ':woman_teacher_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrerin_helle_hautfarbe:',
        'es': ':docente_mujer_tono_de_piel_claro:',
        'fr': ':enseignante_peau_claire:',
        'ja': u':女性の教師_薄い肌色:',
        'ko': u':여교사_하얀_피부:',
        'pt': ':professora_pele_clara:',
        'it': ':professoressa_carnagione_chiara:',
        'fa': u':آموزگار_زن_پوست_سفید:',
        'id': ':pengajar_wanita_warna_kulit_cerah:',
        'zh': u':女老师_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F3EB': { # 👩🏾‍🏫
        'en' : ':woman_teacher_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrerin_mitteldunkle_hautfarbe:',
        'es': ':docente_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':enseignante_peau_mate:',
        'ja': u':女性の教師_やや濃い肌色:',
        'ko': u':여교사_진한_갈색_피부:',
        'pt': ':professora_pele_morena_escura:',
        'it': ':professoressa_carnagione_abbastanza_scura:',
        'fa': u':آموزگار_زن_پوست_گندمی:',
        'id': ':pengajar_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女老师_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F3EB': { # 👩🏼‍🏫
        'en' : ':woman_teacher_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrerin_mittelhelle_hautfarbe:',
        'es': ':docente_mujer_tono_de_piel_claro_medio:',
        'fr': ':enseignante_peau_moyennement_claire:',
        'ja': u':女性の教師_やや薄い肌色:',
        'ko': u':여교사_연한_갈색_피부:',
        'pt': ':professora_pele_morena_clara:',
        'it': ':professoressa_carnagione_abbastanza_chiara:',
        'fa': u':آموزگار_زن_پوست_روشن:',
        'id': ':pengajar_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女老师_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F3EB': { # 👩🏽‍🏫
        'en' : ':woman_teacher_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':lehrerin_mittlere_hautfarbe:',
        'es': ':docente_mujer_tono_de_piel_medio:',
        'fr': u':enseignante_peau_légèrement_mate:',
        'ja': u':女性の教師_中間の肌色:',
        'ko': u':여교사_갈색_피부:',
        'pt': ':professora_pele_morena:',
        'it': ':professoressa_carnagione_olivastra:',
        'fa': u':آموزگار_زن_پوست_طلایی:',
        'id': ':pengajar_wanita_warna_kulit_sedang:',
        'zh': u':女老师_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F4BB': { # 👩‍💻
        'en' : ':woman_technologist:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-expertin:',
        'es': u':profesional_de_la_tecnología_mujer:',
        'fr': ':informaticienne:',
        'ja': u':女性技術者:',
        'ko': u':여자_기술_전문가:',
        'pt': u':tecnóloga:',
        'it': ':tecnologa:',
        'fa': u':کارشناس_فناوری_زن:',
        'id': ':ahli_teknologi_wanita:',
        'zh': u':女程序员:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F4BB': { # 👩🏿‍💻
        'en' : ':woman_technologist_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-expertin_dunkle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_mujer_tono_de_piel_oscuro:',
        'fr': u':informaticienne_peau_foncée:',
        'ja': u':女性技術者_濃い肌色:',
        'ko': u':여자_기술_전문가_검은색_피부:',
        'pt': u':tecnóloga_pele_escura:',
        'it': ':tecnologa_carnagione_scura:',
        'fa': u':کارشناس_فناوری_زن_پوست_آبنوسی:',
        'id': ':ahli_teknologi_wanita_warna_kulit_gelap:',
        'zh': u':女程序员_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F4BB': { # 👩🏻‍💻
        'en' : ':woman_technologist_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-expertin_helle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_mujer_tono_de_piel_claro:',
        'fr': ':informaticienne_peau_claire:',
        'ja': u':女性技術者_薄い肌色:',
        'ko': u':여자_기술_전문가_하얀_피부:',
        'pt': u':tecnóloga_pele_clara:',
        'it': ':tecnologa_carnagione_chiara:',
        'fa': u':کارشناس_فناوری_زن_پوست_سفید:',
        'id': ':ahli_teknologi_wanita_warna_kulit_cerah:',
        'zh': u':女程序员_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F4BB': { # 👩🏾‍💻
        'en' : ':woman_technologist_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-expertin_mitteldunkle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_mujer_tono_de_piel_oscuro_medio:',
        'fr': ':informaticienne_peau_mate:',
        'ja': u':女性技術者_やや濃い肌色:',
        'ko': u':여자_기술_전문가_진한_갈색_피부:',
        'pt': u':tecnóloga_pele_morena_escura:',
        'it': ':tecnologa_carnagione_abbastanza_scura:',
        'fa': u':کارشناس_فناوری_زن_پوست_گندمی:',
        'id': ':ahli_teknologi_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女程序员_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F4BB': { # 👩🏼‍💻
        'en' : ':woman_technologist_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-expertin_mittelhelle_hautfarbe:',
        'es': u':profesional_de_la_tecnología_mujer_tono_de_piel_claro_medio:',
        'fr': ':informaticienne_peau_moyennement_claire:',
        'ja': u':女性技術者_やや薄い肌色:',
        'ko': u':여자_기술_전문가_연한_갈색_피부:',
        'pt': u':tecnóloga_pele_morena_clara:',
        'it': ':tecnologa_carnagione_abbastanza_chiara:',
        'fa': u':کارشناس_فناوری_زن_پوست_روشن:',
        'id': ':ahli_teknologi_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女程序员_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F4BB': { # 👩🏽‍💻
        'en' : ':woman_technologist_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':it-expertin_mittlere_hautfarbe:',
        'es': u':profesional_de_la_tecnología_mujer_tono_de_piel_medio:',
        'fr': u':informaticienne_peau_légèrement_mate:',
        'ja': u':女性技術者_中間の肌色:',
        'ko': u':여자_기술_전문가_갈색_피부:',
        'pt': u':tecnóloga_pele_morena:',
        'it': ':tecnologa_carnagione_olivastra:',
        'fa': u':کارشناس_فناوری_زن_پوست_طلایی:',
        'id': ':ahli_teknologi_wanita_warna_kulit_sedang:',
        'zh': u':女程序员_中等肤色:'
    },
    u'\U0001F481\U0000200D\U00002640\U0000FE0F': { # 💁‍♀️
        'en' : ':woman_tipping_hand:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':sassy_woman:', ':tipping_hand_woman:'],
        'de': ':infoschalter-mitarbeiterin:',
        'es': u':empleada_de_mostrador_de_información:',
        'fr': ':femme_paume_vers_le_haut:',
        'ja': u':案内する女:',
        'ko': u':손바닥_꺾은_여자:',
        'pt': ':mulher_com_a_palma_virada_para_cima:',
        'it': ':donna_con_suggerimento:',
        'fa': u':زن_کمک_می_کند:',
        'id': ':wanita_menengadahkan_tangan:',
        'zh': u':前台女:'
    },
    u'\U0001F481\U0000200D\U00002640': { # 💁‍♀
        'en' : ':woman_tipping_hand:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':sassy_woman:', ':tipping_hand_woman:'],
        'de': ':infoschalter-mitarbeiterin:',
        'es': u':empleada_de_mostrador_de_información:',
        'fr': ':femme_paume_vers_le_haut:',
        'ja': u':案内する女:',
        'ko': u':손바닥_꺾은_여자:',
        'pt': ':mulher_com_a_palma_virada_para_cima:',
        'it': ':donna_al_punto_informazioni:',
        'fa': u':زن_کمک_می_کند:',
        'id': ':wanita_menengadahkan_tangan:',
        'zh': u':前台女:'
    },
    u'\U0001F481\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 💁🏿‍♀️
        'en' : ':woman_tipping_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_dunkle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_oscuro:',
        'fr': u':femme_paume_vers_le_haut_peau_foncée:',
        'ja': u':案内する女_濃い肌色:',
        'ko': u':손바닥_꺾은_여자_검은색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_escura:',
        'it': ':donna_con_suggerimento_carnagione_scura:',
        'fa': u':زن_کمک_می_کند_پوست_آبنوسی:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_gelap:',
        'zh': u':前台女_较深肤色:'
    },
    u'\U0001F481\U0001F3FF\U0000200D\U00002640': { # 💁🏿‍♀
        'en' : ':woman_tipping_hand_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_dunkle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_oscuro:',
        'fr': u':femme_paume_vers_le_haut_peau_foncée:',
        'ja': u':案内する女_濃い肌色:',
        'ko': u':손바닥_꺾은_여자_검은색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_escura:',
        'it': ':donna_con_suggerimento_carnagione_scura:',
        'fa': u':زن_کمک_می_کند_پوست_آبنوسی:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_gelap:',
        'zh': u':前台女_较深肤色:'
    },
    u'\U0001F481\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 💁🏻‍♀️
        'en' : ':woman_tipping_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_helle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_claro:',
        'fr': ':femme_paume_vers_le_haut_peau_claire:',
        'ja': u':案内する女_薄い肌色:',
        'ko': u':손바닥_꺾은_여자_하얀_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_clara:',
        'it': ':donna_con_suggerimento_carnagione_chiara:',
        'fa': u':زن_کمک_می_کند_پوست_سفید:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_cerah:',
        'zh': u':前台女_较浅肤色:'
    },
    u'\U0001F481\U0001F3FB\U0000200D\U00002640': { # 💁🏻‍♀
        'en' : ':woman_tipping_hand_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_helle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_claro:',
        'fr': ':femme_paume_vers_le_haut_peau_claire:',
        'ja': u':案内する女_薄い肌色:',
        'ko': u':손바닥_꺾은_여자_하얀_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_clara:',
        'it': ':donna_con_suggerimento_carnagione_chiara:',
        'fa': u':زن_کمک_می_کند_پوست_سفید:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_cerah:',
        'zh': u':前台女_较浅肤色:'
    },
    u'\U0001F481\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 💁🏾‍♀️
        'en' : ':woman_tipping_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_mitteldunkle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_oscuro_medio:',
        'fr': ':femme_paume_vers_le_haut_peau_mate:',
        'ja': u':案内する女_やや濃い肌色:',
        'ko': u':손바닥_꺾은_여자_진한_갈색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_morena_escura:',
        'it': ':donna_con_suggerimento_carnagione_abbastanza_scura:',
        'fa': u':زن_کمک_می_کند_پوست_گندمی:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_gelap-sedang:',
        'zh': u':前台女_中等深肤色:'
    },
    u'\U0001F481\U0001F3FE\U0000200D\U00002640': { # 💁🏾‍♀
        'en' : ':woman_tipping_hand_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_mitteldunkle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_oscuro_medio:',
        'fr': ':femme_paume_vers_le_haut_peau_mate:',
        'ja': u':案内する女_やや濃い肌色:',
        'ko': u':손바닥_꺾은_여자_진한_갈색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_morena_escura:',
        'it': ':donna_con_suggerimento_carnagione_abbastanza_scura:',
        'fa': u':زن_کمک_می_کند_پوست_گندمی:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_gelap-sedang:',
        'zh': u':前台女_中等深肤色:'
    },
    u'\U0001F481\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 💁🏼‍♀️
        'en' : ':woman_tipping_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_mittelhelle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_claro_medio:',
        'fr': ':femme_paume_vers_le_haut_peau_moyennement_claire:',
        'ja': u':案内する女_やや薄い肌色:',
        'ko': u':손바닥_꺾은_여자_연한_갈색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_morena_clara:',
        'it': ':donna_con_suggerimento_carnagione_abbastanza_chiara:',
        'fa': u':زن_کمک_می_کند_پوست_روشن:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_cerah-sedang:',
        'zh': u':前台女_中等浅肤色:'
    },
    u'\U0001F481\U0001F3FC\U0000200D\U00002640': { # 💁🏼‍♀
        'en' : ':woman_tipping_hand_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_mittelhelle_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_claro_medio:',
        'fr': ':femme_paume_vers_le_haut_peau_moyennement_claire:',
        'ja': u':案内する女_やや薄い肌色:',
        'ko': u':손바닥_꺾은_여자_연한_갈색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_morena_clara:',
        'it': ':donna_con_suggerimento_carnagione_abbastanza_chiara:',
        'fa': u':زن_کمک_می_کند_پوست_روشن:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_cerah-sedang:',
        'zh': u':前台女_中等浅肤色:'
    },
    u'\U0001F481\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 💁🏽‍♀️
        'en' : ':woman_tipping_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_mittlere_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_medio:',
        'fr': u':femme_paume_vers_le_haut_peau_légèrement_mate:',
        'ja': u':案内する女_中間の肌色:',
        'ko': u':손바닥_꺾은_여자_갈색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_morena:',
        'it': ':donna_con_suggerimento_carnagione_olivastra:',
        'fa': u':زن_کمک_می_کند_پوست_طلایی:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_sedang:',
        'zh': u':前台女_中等肤色:'
    },
    u'\U0001F481\U0001F3FD\U0000200D\U00002640': { # 💁🏽‍♀
        'en' : ':woman_tipping_hand_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':infoschalter-mitarbeiterin_mittlere_hautfarbe:',
        'es': u':empleada_de_mostrador_de_información_tono_de_piel_medio:',
        'fr': u':femme_paume_vers_le_haut_peau_légèrement_mate:',
        'ja': u':案内する女_中間の肌色:',
        'ko': u':손바닥_꺾은_여자_갈색_피부:',
        'pt': ':mulher_com_a_palma_virada_para_cima_pele_morena:',
        'it': ':donna_con_suggerimento_carnagione_olivastra:',
        'fa': u':زن_کمک_می_کند_پوست_طلایی:',
        'id': ':wanita_menengadahkan_tangan_warna_kulit_sedang:',
        'zh': u':前台女_中等肤色:'
    },
    u'\U0001F9DB\U0000200D\U00002640\U0000FE0F': { # 🧛‍♀️
        'en' : ':woman_vampire:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':vampire_woman:'],
        'de': ':weiblicher_vampir:',
        'es': ':vampiresa:',
        'fr': ':vampire_femme:',
        'ja': u':女の吸血鬼:',
        'ko': u':여자_뱀파이어:',
        'pt': ':mulher_vampira:',
        'it': ':vampira:',
        'fa': u':دراکولای_زن:',
        'id': ':vampir_wanita:',
        'zh': u':女吸血鬼:'
    },
    u'\U0001F9DB\U0000200D\U00002640': { # 🧛‍♀
        'en' : ':woman_vampire:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':vampire_woman:'],
        'de': ':weiblicher_vampir:',
        'es': ':vampiresa:',
        'fr': ':vampire_femme:',
        'ja': u':女の吸血鬼:',
        'ko': u':여자_뱀파이어:',
        'pt': ':mulher_vampira:',
        'it': ':vampira:',
        'fa': u':دراکولای_زن:',
        'id': ':vampir_wanita:',
        'zh': u':女吸血鬼:'
    },
    u'\U0001F9DB\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🧛🏿‍♀️
        'en' : ':woman_vampire_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_dunkle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_oscuro:',
        'fr': u':vampire_femme_peau_foncée:',
        'ja': u':女の吸血鬼_濃い肌色:',
        'ko': u':여자_뱀파이어_검은색_피부:',
        'pt': ':mulher_vampira_pele_escura:',
        'it': ':vampira_carnagione_scura:',
        'fa': u':دراکولای_زن_پوست_آبنوسی:',
        'id': ':vampir_wanita_warna_kulit_gelap:',
        'zh': u':女吸血鬼_较深肤色:'
    },
    u'\U0001F9DB\U0001F3FF\U0000200D\U00002640': { # 🧛🏿‍♀
        'en' : ':woman_vampire_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_dunkle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_oscuro:',
        'fr': u':vampire_femme_peau_foncée:',
        'ja': u':女の吸血鬼_濃い肌色:',
        'ko': u':여자_뱀파이어_검은색_피부:',
        'pt': ':mulher_vampira_pele_escura:',
        'it': ':vampira_carnagione_scura:',
        'fa': u':دراکولای_زن_پوست_آبنوسی:',
        'id': ':vampir_wanita_warna_kulit_gelap:',
        'zh': u':女吸血鬼_较深肤色:'
    },
    u'\U0001F9DB\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🧛🏻‍♀️
        'en' : ':woman_vampire_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_helle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_claro:',
        'fr': ':vampire_femme_peau_claire:',
        'ja': u':女の吸血鬼_薄い肌色:',
        'ko': u':여자_뱀파이어_하얀_피부:',
        'pt': ':mulher_vampira_pele_clara:',
        'it': ':vampira_carnagione_chiara:',
        'fa': u':دراکولای_زن_پوست_سفید:',
        'id': ':vampir_wanita_warna_kulit_cerah:',
        'zh': u':女吸血鬼_较浅肤色:'
    },
    u'\U0001F9DB\U0001F3FB\U0000200D\U00002640': { # 🧛🏻‍♀
        'en' : ':woman_vampire_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_helle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_claro:',
        'fr': ':vampire_femme_peau_claire:',
        'ja': u':女の吸血鬼_薄い肌色:',
        'ko': u':여자_뱀파이어_하얀_피부:',
        'pt': ':mulher_vampira_pele_clara:',
        'it': ':vampira_carnagione_chiara:',
        'fa': u':دراکولای_زن_پوست_سفید:',
        'id': ':vampir_wanita_warna_kulit_cerah:',
        'zh': u':女吸血鬼_较浅肤色:'
    },
    u'\U0001F9DB\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🧛🏾‍♀️
        'en' : ':woman_vampire_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_mitteldunkle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_oscuro_medio:',
        'fr': ':vampire_femme_peau_mate:',
        'ja': u':女の吸血鬼_やや濃い肌色:',
        'ko': u':여자_뱀파이어_진한_갈색_피부:',
        'pt': ':mulher_vampira_pele_morena_escura:',
        'it': ':vampira_carnagione_abbastanza_scura:',
        'fa': u':دراکولای_زن_پوست_گندمی:',
        'id': ':vampir_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女吸血鬼_中等深肤色:'
    },
    u'\U0001F9DB\U0001F3FE\U0000200D\U00002640': { # 🧛🏾‍♀
        'en' : ':woman_vampire_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_mitteldunkle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_oscuro_medio:',
        'fr': ':vampire_femme_peau_mate:',
        'ja': u':女の吸血鬼_やや濃い肌色:',
        'ko': u':여자_뱀파이어_진한_갈색_피부:',
        'pt': ':mulher_vampira_pele_morena_escura:',
        'it': ':vampira_carnagione_abbastanza_scura:',
        'fa': u':دراکولای_زن_پوست_گندمی:',
        'id': ':vampir_wanita_warna_kulit_gelap-sedang:',
        'zh': u':女吸血鬼_中等深肤色:'
    },
    u'\U0001F9DB\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🧛🏼‍♀️
        'en' : ':woman_vampire_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_mittelhelle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_claro_medio:',
        'fr': ':vampire_femme_peau_moyennement_claire:',
        'ja': u':女の吸血鬼_やや薄い肌色:',
        'ko': u':여자_뱀파이어_연한_갈색_피부:',
        'pt': ':mulher_vampira_pele_morena_clara:',
        'it': ':vampira_carnagione_abbastanza_chiara:',
        'fa': u':دراکولای_زن_پوست_روشن:',
        'id': ':vampir_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女吸血鬼_中等浅肤色:'
    },
    u'\U0001F9DB\U0001F3FC\U0000200D\U00002640': { # 🧛🏼‍♀
        'en' : ':woman_vampire_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_mittelhelle_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_claro_medio:',
        'fr': ':vampire_femme_peau_moyennement_claire:',
        'ja': u':女の吸血鬼_やや薄い肌色:',
        'ko': u':여자_뱀파이어_연한_갈색_피부:',
        'pt': ':mulher_vampira_pele_morena_clara:',
        'it': ':vampira_carnagione_abbastanza_chiara:',
        'fa': u':دراکولای_زن_پوست_روشن:',
        'id': ':vampir_wanita_warna_kulit_cerah-sedang:',
        'zh': u':女吸血鬼_中等浅肤色:'
    },
    u'\U0001F9DB\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🧛🏽‍♀️
        'en' : ':woman_vampire_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_mittlere_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_medio:',
        'fr': u':vampire_femme_peau_légèrement_mate:',
        'ja': u':女の吸血鬼_中間の肌色:',
        'ko': u':여자_뱀파이어_갈색_피부:',
        'pt': ':mulher_vampira_pele_morena:',
        'it': ':vampira_carnagione_olivastra:',
        'fa': u':دراکولای_زن_پوست_طلایی:',
        'id': ':vampir_wanita_warna_kulit_sedang:',
        'zh': u':女吸血鬼_中等肤色:'
    },
    u'\U0001F9DB\U0001F3FD\U0000200D\U00002640': { # 🧛🏽‍♀
        'en' : ':woman_vampire_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 5,
        'de': ':weiblicher_vampir_mittlere_hautfarbe:',
        'es': ':vampiresa_tono_de_piel_medio:',
        'fr': u':vampire_femme_peau_légèrement_mate:',
        'ja': u':女の吸血鬼_中間の肌色:',
        'ko': u':여자_뱀파이어_갈색_피부:',
        'pt': ':mulher_vampira_pele_morena:',
        'it': ':vampira_carnagione_olivastra:',
        'fa': u':دراکولای_زن_پوست_طلایی:',
        'id': ':vampir_wanita_warna_kulit_sedang:',
        'zh': u':女吸血鬼_中等肤色:'
    },
    u'\U0001F6B6\U0000200D\U00002640\U0000FE0F': { # 🚶‍♀️
        'en' : ':woman_walking:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':walking_woman:'],
        'de': u':fußgängerin:',
        'es': ':mujer_caminando:',
        'fr': ':femme_qui_marche:',
        'ja': u':歩く女:',
        'ko': u':걷는_여자:',
        'pt': ':mulher_andando:',
        'it': ':donna_che_cammina:',
        'fa': u':زن_پیاده_روی_می_کند:',
        'id': ':wanita_berjalan_kaki:',
        'zh': u':女行人:'
    },
    u'\U0001F6B6\U0000200D\U00002640': { # 🚶‍♀
        'en' : ':woman_walking:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':walking_woman:'],
        'de': u':fußgängerin:',
        'es': ':mujer_caminando:',
        'fr': ':femme_qui_marche:',
        'ja': u':歩く女:',
        'ko': u':걷는_여자:',
        'pt': ':mulher_andando:',
        'it': ':donna_che_cammina:',
        'fa': u':زن_پیاده_روی_می_کند:',
        'id': ':wanita_berjalan_kaki:',
        'zh': u':女行人:'
    },
    u'\U0001F6B6\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 🚶🏿‍♀️
        'en' : ':woman_walking_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgängerin_dunkle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_oscuro:',
        'fr': u':femme_qui_marche_peau_foncée:',
        'ja': u':歩く女_濃い肌色:',
        'ko': u':걷는_여자_검은색_피부:',
        'pt': ':mulher_andando_pele_escura:',
        'it': ':donna_che_cammina_carnagione_scura:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_آبنوسی:',
        'id': ':wanita_berjalan_kaki_warna_kulit_gelap:',
        'zh': u':女行人_较深肤色:'
    },
    u'\U0001F6B6\U0001F3FF\U0000200D\U00002640': { # 🚶🏿‍♀
        'en' : ':woman_walking_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgängerin_dunkle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_oscuro:',
        'fr': u':femme_qui_marche_peau_foncée:',
        'ja': u':歩く女_濃い肌色:',
        'ko': u':걷는_여자_검은색_피부:',
        'pt': ':mulher_andando_pele_escura:',
        'it': ':donna_che_cammina_carnagione_scura:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_آبنوسی:',
        'id': ':wanita_berjalan_kaki_warna_kulit_gelap:',
        'zh': u':女行人_较深肤色:'
    },
    u'\U0001F6B6\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 🚶🏻‍♀️
        'en' : ':woman_walking_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgängerin_helle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_claro:',
        'fr': ':femme_qui_marche_peau_claire:',
        'ja': u':歩く女_薄い肌色:',
        'ko': u':걷는_여자_하얀_피부:',
        'pt': ':mulher_andando_pele_clara:',
        'it': ':donna_che_cammina_carnagione_chiara:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_سفید:',
        'id': ':wanita_berjalan_kaki_warna_kulit_cerah:',
        'zh': u':女行人_较浅肤色:'
    },
    u'\U0001F6B6\U0001F3FB\U0000200D\U00002640': { # 🚶🏻‍♀
        'en' : ':woman_walking_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgängerin_helle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_claro:',
        'fr': ':femme_qui_marche_peau_claire:',
        'ja': u':歩く女_薄い肌色:',
        'ko': u':걷는_여자_하얀_피부:',
        'pt': ':mulher_andando_pele_clara:',
        'it': ':donna_che_cammina_carnagione_chiara:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_سفید:',
        'id': ':wanita_berjalan_kaki_warna_kulit_cerah:',
        'zh': u':女行人_较浅肤色:'
    },
    u'\U0001F6B6\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 🚶🏾‍♀️
        'en' : ':woman_walking_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgängerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_marche_peau_mate:',
        'ja': u':歩く女_やや濃い肌色:',
        'ko': u':걷는_여자_진한_갈색_피부:',
        'pt': ':mulher_andando_pele_morena_escura:',
        'it': ':donna_che_cammina_carnagione_abbastanza_scura:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_گندمی:',
        'id': ':wanita_berjalan_kaki_warna_kulit_gelap-sedang:',
        'zh': u':女行人_中等深肤色:'
    },
    u'\U0001F6B6\U0001F3FE\U0000200D\U00002640': { # 🚶🏾‍♀
        'en' : ':woman_walking_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgängerin_mitteldunkle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_oscuro_medio:',
        'fr': ':femme_qui_marche_peau_mate:',
        'ja': u':歩く女_やや濃い肌色:',
        'ko': u':걷는_여자_진한_갈색_피부:',
        'pt': ':mulher_andando_pele_morena_escura:',
        'it': ':donna_che_cammina_carnagione_abbastanza_scura:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_گندمی:',
        'id': ':wanita_berjalan_kaki_warna_kulit_gelap-sedang:',
        'zh': u':女行人_中等深肤色:'
    },
    u'\U0001F6B6\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 🚶🏼‍♀️
        'en' : ':woman_walking_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgängerin_mittelhelle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_marche_peau_moyennement_claire:',
        'ja': u':歩く女_やや薄い肌色:',
        'ko': u':걷는_여자_연한_갈색_피부:',
        'pt': ':mulher_andando_pele_morena_clara:',
        'it': ':donna_che_cammina_carnagione_abbastanza_chiara:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_روشن:',
        'id': ':wanita_berjalan_kaki_warna_kulit_cerah-sedang:',
        'zh': u':女行人_中等浅肤色:'
    },
    u'\U0001F6B6\U0001F3FC\U0000200D\U00002640': { # 🚶🏼‍♀
        'en' : ':woman_walking_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgängerin_mittelhelle_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_claro_medio:',
        'fr': ':femme_qui_marche_peau_moyennement_claire:',
        'ja': u':歩く女_やや薄い肌色:',
        'ko': u':걷는_여자_연한_갈색_피부:',
        'pt': ':mulher_andando_pele_morena_clara:',
        'it': ':donna_che_cammina_carnagione_abbastanza_chiara:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_روشن:',
        'id': ':wanita_berjalan_kaki_warna_kulit_cerah-sedang:',
        'zh': u':女行人_中等浅肤色:'
    },
    u'\U0001F6B6\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 🚶🏽‍♀️
        'en' : ':woman_walking_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': u':fußgängerin_mittlere_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_medio:',
        'fr': u':femme_qui_marche_peau_légèrement_mate:',
        'ja': u':歩く女_中間の肌色:',
        'ko': u':걷는_여자_갈색_피부:',
        'pt': ':mulher_andando_pele_morena:',
        'it': ':donna_che_cammina_carnagione_olivastra:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_طلایی:',
        'id': ':wanita_berjalan_kaki_warna_kulit_sedang:',
        'zh': u':女行人_中等肤色:'
    },
    u'\U0001F6B6\U0001F3FD\U0000200D\U00002640': { # 🚶🏽‍♀
        'en' : ':woman_walking_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': u':fußgängerin_mittlere_hautfarbe:',
        'es': ':mujer_caminando_tono_de_piel_medio:',
        'fr': u':femme_qui_marche_peau_légèrement_mate:',
        'ja': u':歩く女_中間の肌色:',
        'ko': u':걷는_여자_갈색_피부:',
        'pt': ':mulher_andando_pele_morena:',
        'it': ':donna_che_cammina_carnagione_olivastra:',
        'fa': u':زن_پیاده_روی_می_کند_پوست_طلایی:',
        'id': ':wanita_berjalan_kaki_warna_kulit_sedang:',
        'zh': u':女行人_中等肤色:'
    },
    u'\U0001F473\U0000200D\U00002640\U0000FE0F': { # 👳‍♀️
        'en' : ':woman_wearing_turban:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':woman_with_turban:'],
        'de': ':frau_mit_turban:',
        'es': ':mujer_con_turbante:',
        'fr': ':femme_en_turban:',
        'ja': u':ターバンの女性:',
        'ko': u':터번을_쓰고_있는_여자:',
        'pt': ':mulher_com_turbante:',
        'it': ':donna_con_turbante:',
        'fa': u':زن_با_دستار:',
        'id': ':wanita_mengenakan_serban:',
        'zh': u':戴头巾的女人:'
    },
    u'\U0001F473\U0000200D\U00002640': { # 👳‍♀
        'en' : ':woman_wearing_turban:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':woman_with_turban:'],
        'de': ':frau_mit_turban:',
        'es': ':mujer_con_turbante:',
        'fr': ':femme_en_turban:',
        'ja': u':ターバンの女性:',
        'ko': u':터번을_쓰고_있는_여자:',
        'pt': ':mulher_com_turbante:',
        'it': ':donna_con_turbante:',
        'fa': u':زن_با_دستار:',
        'id': ':wanita_mengenakan_serban:',
        'zh': u':戴头巾的女人:'
    },
    u'\U0001F473\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 👳🏿‍♀️
        'en' : ':woman_wearing_turban_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_dunkle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_oscuro:',
        'fr': u':femme_en_turban_peau_foncée:',
        'ja': u':ターバンの女性_濃い肌色:',
        'ko': u':터번을_쓰고_있는_여자_검은색_피부:',
        'pt': ':mulher_com_turbante_pele_escura:',
        'it': ':donna_con_turbante_carnagione_scura:',
        'fa': u':زن_با_دستار_پوست_آبنوسی:',
        'id': ':wanita_mengenakan_serban_warna_kulit_gelap:',
        'zh': u':戴头巾的女人_较深肤色:'
    },
    u'\U0001F473\U0001F3FF\U0000200D\U00002640': { # 👳🏿‍♀
        'en' : ':woman_wearing_turban_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_dunkle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_oscuro:',
        'fr': u':femme_en_turban_peau_foncée:',
        'ja': u':ターバンの女性_濃い肌色:',
        'ko': u':터번을_쓰고_있는_여자_검은색_피부:',
        'pt': ':mulher_com_turbante_pele_escura:',
        'it': ':donna_con_turbante_carnagione_scura:',
        'fa': u':زن_با_دستار_پوست_آبنوسی:',
        'id': ':wanita_mengenakan_serban_warna_kulit_gelap:',
        'zh': u':戴头巾的女人_较深肤色:'
    },
    u'\U0001F473\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 👳🏻‍♀️
        'en' : ':woman_wearing_turban_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_helle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_claro:',
        'fr': ':femme_en_turban_peau_claire:',
        'ja': u':ターバンの女性_薄い肌色:',
        'ko': u':터번을_쓰고_있는_여자_하얀_피부:',
        'pt': ':mulher_com_turbante_pele_clara:',
        'it': ':donna_con_turbante_carnagione_chiara:',
        'fa': u':زن_با_دستار_پوست_سفید:',
        'id': ':wanita_mengenakan_serban_warna_kulit_cerah:',
        'zh': u':戴头巾的女人_较浅肤色:'
    },
    u'\U0001F473\U0001F3FB\U0000200D\U00002640': { # 👳🏻‍♀
        'en' : ':woman_wearing_turban_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_helle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_claro:',
        'fr': ':femme_en_turban_peau_claire:',
        'ja': u':ターバンの女性_薄い肌色:',
        'ko': u':터번을_쓰고_있는_여자_하얀_피부:',
        'pt': ':mulher_com_turbante_pele_clara:',
        'it': ':donna_con_turbante_carnagione_chiara:',
        'fa': u':زن_با_دستار_پوست_سفید:',
        'id': ':wanita_mengenakan_serban_warna_kulit_cerah:',
        'zh': u':戴头巾的女人_较浅肤色:'
    },
    u'\U0001F473\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 👳🏾‍♀️
        'en' : ':woman_wearing_turban_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_oscuro_medio:',
        'fr': ':femme_en_turban_peau_mate:',
        'ja': u':ターバンの女性_やや濃い肌色:',
        'ko': u':터번을_쓰고_있는_여자_진한_갈색_피부:',
        'pt': ':mulher_com_turbante_pele_morena_escura:',
        'it': ':donna_con_turbante_carnagione_abbastanza_scura:',
        'fa': u':زن_با_دستار_پوست_گندمی:',
        'id': ':wanita_mengenakan_serban_warna_kulit_gelap-sedang:',
        'zh': u':戴头巾的女人_中等深肤色:'
    },
    u'\U0001F473\U0001F3FE\U0000200D\U00002640': { # 👳🏾‍♀
        'en' : ':woman_wearing_turban_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_oscuro_medio:',
        'fr': ':femme_en_turban_peau_mate:',
        'ja': u':ターバンの女性_やや濃い肌色:',
        'ko': u':터번을_쓰고_있는_여자_진한_갈색_피부:',
        'pt': ':mulher_com_turbante_pele_morena_escura:',
        'it': ':donna_con_turbante_carnagione_abbastanza_scura:',
        'fa': u':زن_با_دستار_پوست_گندمی:',
        'id': ':wanita_mengenakan_serban_warna_kulit_gelap-sedang:',
        'zh': u':戴头巾的女人_中等深肤色:'
    },
    u'\U0001F473\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 👳🏼‍♀️
        'en' : ':woman_wearing_turban_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_mittelhelle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_claro_medio:',
        'fr': ':femme_en_turban_peau_moyennement_claire:',
        'ja': u':ターバンの女性_やや薄い肌色:',
        'ko': u':터번을_쓰고_있는_여자_연한_갈색_피부:',
        'pt': ':mulher_com_turbante_pele_morena_clara:',
        'it': ':donna_con_turbante_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_دستار_پوست_روشن:',
        'id': ':wanita_mengenakan_serban_warna_kulit_cerah-sedang:',
        'zh': u':戴头巾的女人_中等浅肤色:'
    },
    u'\U0001F473\U0001F3FC\U0000200D\U00002640': { # 👳🏼‍♀
        'en' : ':woman_wearing_turban_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_mittelhelle_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_claro_medio:',
        'fr': ':femme_en_turban_peau_moyennement_claire:',
        'ja': u':ターバンの女性_やや薄い肌色:',
        'ko': u':터번을_쓰고_있는_여자_연한_갈색_피부:',
        'pt': ':mulher_com_turbante_pele_morena_clara:',
        'it': ':donna_con_turbante_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_دستار_پوست_روشن:',
        'id': ':wanita_mengenakan_serban_warna_kulit_cerah-sedang:',
        'zh': u':戴头巾的女人_中等浅肤色:'
    },
    u'\U0001F473\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 👳🏽‍♀️
        'en' : ':woman_wearing_turban_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_mittlere_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_medio:',
        'fr': u':femme_en_turban_peau_légèrement_mate:',
        'ja': u':ターバンの女性_中間の肌色:',
        'ko': u':터번을_쓰고_있는_여자_갈색_피부:',
        'pt': ':mulher_com_turbante_pele_morena:',
        'it': ':donna_con_turbante_carnagione_olivastra:',
        'fa': u':زن_با_دستار_پوست_طلایی:',
        'id': ':wanita_mengenakan_serban_warna_kulit_sedang:',
        'zh': u':戴头巾的女人_中等肤色:'
    },
    u'\U0001F473\U0001F3FD\U0000200D\U00002640': { # 👳🏽‍♀
        'en' : ':woman_wearing_turban_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':frau_mit_turban_mittlere_hautfarbe:',
        'es': ':mujer_con_turbante_tono_de_piel_medio:',
        'fr': u':femme_en_turban_peau_légèrement_mate:',
        'ja': u':ターバンの女性_中間の肌色:',
        'ko': u':터번을_쓰고_있는_여자_갈색_피부:',
        'pt': ':mulher_com_turbante_pele_morena:',
        'it': ':donna_con_turbante_carnagione_olivastra:',
        'fa': u':زن_با_دستار_پوست_طلایی:',
        'id': ':wanita_mengenakan_serban_warna_kulit_sedang:',
        'zh': u':戴头巾的女人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F9B3': { # 👩‍🦳
        'en' : ':woman_white_hair:',
        'status' : fully_qualified,
        'E' : 11,
        'alias' : [':white_haired_woman:'],
        'de': u':frau_weißes_haar:',
        'es': ':mujer_pelo_blanco:',
        'fr': ':femme_cheveux_blancs:',
        'ja': u':女性_白髪:',
        'ko': u':여자_백발:',
        'pt': ':mulher_cabelo_branco:',
        'it': ':donna_capelli_bianchi:',
        'fa': u':زن_موسفید:',
        'id': ':wanita_rambut_putih:',
        'zh': u':女人_白发:'
    },
    u'\U0001F9D5': { # 🧕
        'en' : ':woman_with_headscarf:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_mit_kopftuch:',
        'es': ':mujer_con_hiyab:',
        'fr': ':femme_avec_foulard:',
        'ja': u':スカーフの女性:',
        'ko': u':머리에_스카프를_두른_여자:',
        'pt': u':mulher_com_véu:',
        'it': ':donna_con_velo:',
        'fa': u':زن_با_روسری:',
        'id': ':wanita_dengan_kerudung:',
        'zh': u':带头饰的女人:'
    },
    u'\U0001F9D5\U0001F3FF': { # 🧕🏿
        'en' : ':woman_with_headscarf_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_mit_kopftuch_dunkle_hautfarbe:',
        'es': ':mujer_con_hiyab_tono_de_piel_oscuro:',
        'fr': u':femme_avec_foulard_peau_foncée:',
        'ja': u':スカーフの女性_濃い肌色:',
        'ko': u':머리에_스카프를_두른_여자_검은색_피부:',
        'pt': u':mulher_com_véu_pele_escura:',
        'it': ':donna_con_velo_carnagione_scura:',
        'fa': u':زن_با_روسری_پوست_آبنوسی:',
        'id': ':wanita_dengan_kerudung_warna_kulit_gelap:',
        'zh': u':带头饰的女人_较深肤色:'
    },
    u'\U0001F9D5\U0001F3FB': { # 🧕🏻
        'en' : ':woman_with_headscarf_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_mit_kopftuch_helle_hautfarbe:',
        'es': ':mujer_con_hiyab_tono_de_piel_claro:',
        'fr': ':femme_avec_foulard_peau_claire:',
        'ja': u':スカーフの女性_薄い肌色:',
        'ko': u':머리에_스카프를_두른_여자_하얀_피부:',
        'pt': u':mulher_com_véu_pele_clara:',
        'it': ':donna_con_velo_carnagione_chiara:',
        'fa': u':زن_با_روسری_پوست_سفید:',
        'id': ':wanita_dengan_kerudung_warna_kulit_cerah:',
        'zh': u':带头饰的女人_较浅肤色:'
    },
    u'\U0001F9D5\U0001F3FE': { # 🧕🏾
        'en' : ':woman_with_headscarf_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_mit_kopftuch_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_hiyab_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_foulard_peau_mate:',
        'ja': u':スカーフの女性_やや濃い肌色:',
        'ko': u':머리에_스카프를_두른_여자_진한_갈색_피부:',
        'pt': u':mulher_com_véu_pele_morena_escura:',
        'it': ':donna_con_velo_carnagione_abbastanza_scura:',
        'fa': u':زن_با_روسری_پوست_گندمی:',
        'id': ':wanita_dengan_kerudung_warna_kulit_gelap-sedang:',
        'zh': u':带头饰的女人_中等深肤色:'
    },
    u'\U0001F9D5\U0001F3FC': { # 🧕🏼
        'en' : ':woman_with_headscarf_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_mit_kopftuch_mittelhelle_hautfarbe:',
        'es': ':mujer_con_hiyab_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_foulard_peau_moyennement_claire:',
        'ja': u':スカーフの女性_やや薄い肌色:',
        'ko': u':머리에_스카프를_두른_여자_연한_갈색_피부:',
        'pt': u':mulher_com_véu_pele_morena_clara:',
        'it': ':donna_con_velo_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_روسری_پوست_روشن:',
        'id': ':wanita_dengan_kerudung_warna_kulit_cerah-sedang:',
        'zh': u':带头饰的女人_中等浅肤色:'
    },
    u'\U0001F9D5\U0001F3FD': { # 🧕🏽
        'en' : ':woman_with_headscarf_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':frau_mit_kopftuch_mittlere_hautfarbe:',
        'es': ':mujer_con_hiyab_tono_de_piel_medio:',
        'fr': u':femme_avec_foulard_peau_légèrement_mate:',
        'ja': u':スカーフの女性_中間の肌色:',
        'ko': u':머리에_스카프를_두른_여자_갈색_피부:',
        'pt': u':mulher_com_véu_pele_morena:',
        'it': ':donna_con_velo_carnagione_olivastra:',
        'fa': u':زن_با_روسری_پوست_طلایی:',
        'id': ':wanita_dengan_kerudung_warna_kulit_sedang:',
        'zh': u':带头饰的女人_中等肤色:'
    },
    u'\U0001F470\U0000200D\U00002640\U0000FE0F': { # 👰‍♀️
        'en' : ':woman_with_veil:',
        'status' : fully_qualified,
        'E' : 13,
        'alias' : [':bride_with_veil:'],
        'de': ':frau_mit_schleier:',
        'es': ':mujer_con_velo:',
        'fr': ':femme_avec_voile:',
        'ja': u':ベールの女性:',
        'ko': u':면사포를_쓴_여자:',
        'pt': u':noiva_com_véu:',
        'it': ':sposa_con_velo:',
        'fa': u':زن_با_تور_عروس:',
        'id': ':wanita_berpenutup_kepala:',
        'zh': u':戴头纱的女人:'
    },
    u'\U0001F470\U0000200D\U00002640': { # 👰‍♀
        'en' : ':woman_with_veil:',
        'status' : minimally_qualified,
        'E' : 13,
        'alias' : [':bride_with_veil:'],
        'de': ':frau_mit_schleier:',
        'es': ':mujer_con_velo:',
        'fr': ':femme_avec_voile:',
        'ja': u':ベールの女性:',
        'ko': u':면사포를_쓴_여자:',
        'pt': u':noiva_com_véu:',
        'it': ':sposa_con_velo:',
        'fa': u':زن_با_تور_عروس:',
        'id': ':wanita_berpenutup_kepala:',
        'zh': u':戴头纱的女人:'
    },
    u'\U0001F470\U0001F3FF\U0000200D\U00002640\U0000FE0F': { # 👰🏿‍♀️
        'en' : ':woman_with_veil_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_dunkle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_oscuro:',
        'fr': u':femme_avec_voile_peau_foncée:',
        'ja': u':ベールの女性_濃い肌色:',
        'ko': u':면사포를_쓴_여자_검은색_피부:',
        'pt': u':noiva_com_véu_pele_escura:',
        'it': ':sposa_con_velo_carnagione_scura:',
        'fa': u':زن_با_تور_عروس_پوست_آبنوسی:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_gelap:',
        'zh': u':戴头纱的女人_较深肤色:'
    },
    u'\U0001F470\U0001F3FF\U0000200D\U00002640': { # 👰🏿‍♀
        'en' : ':woman_with_veil_dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_dunkle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_oscuro:',
        'fr': u':femme_avec_voile_peau_foncée:',
        'ja': u':ベールの女性_濃い肌色:',
        'ko': u':면사포를_쓴_여자_검은색_피부:',
        'pt': u':noiva_com_véu_pele_escura:',
        'it': ':sposa_con_velo_carnagione_scura:',
        'fa': u':زن_با_تور_عروس_پوست_آبنوسی:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_gelap:',
        'zh': u':戴头纱的女人_较深肤色:'
    },
    u'\U0001F470\U0001F3FB\U0000200D\U00002640\U0000FE0F': { # 👰🏻‍♀️
        'en' : ':woman_with_veil_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_helle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_claro:',
        'fr': ':femme_avec_voile_peau_claire:',
        'ja': u':ベールの女性_薄い肌色:',
        'ko': u':면사포를_쓴_여자_하얀_피부:',
        'pt': u':noiva_com_véu_pele_clara:',
        'it': ':sposa_con_velo_carnagione_chiara:',
        'fa': u':زن_با_تور_عروس_پوست_سفید:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_cerah:',
        'zh': u':戴头纱的女人_较浅肤色:'
    },
    u'\U0001F470\U0001F3FB\U0000200D\U00002640': { # 👰🏻‍♀
        'en' : ':woman_with_veil_light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_helle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_claro:',
        'fr': ':femme_avec_voile_peau_claire:',
        'ja': u':ベールの女性_薄い肌色:',
        'ko': u':면사포를_쓴_여자_하얀_피부:',
        'pt': u':noiva_com_véu_pele_clara:',
        'it': ':sposa_con_velo_carnagione_chiara:',
        'fa': u':زن_با_تور_عروس_پوست_سفید:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_cerah:',
        'zh': u':戴头纱的女人_较浅肤色:'
    },
    u'\U0001F470\U0001F3FE\U0000200D\U00002640\U0000FE0F': { # 👰🏾‍♀️
        'en' : ':woman_with_veil_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_voile_peau_mate:',
        'ja': u':ベールの女性_やや濃い肌色:',
        'ko': u':면사포를_쓴_여자_진한_갈색_피부:',
        'pt': u':noiva_com_véu_pele_morena_escura:',
        'it': ':sposa_con_velo_carnagione_abbastanza_scura:',
        'fa': u':زن_با_تور_عروس_پوست_گندمی:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_gelap-sedang:',
        'zh': u':戴头纱的女人_中等深肤色:'
    },
    u'\U0001F470\U0001F3FE\U0000200D\U00002640': { # 👰🏾‍♀
        'en' : ':woman_with_veil_medium-dark_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_mitteldunkle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_voile_peau_mate:',
        'ja': u':ベールの女性_やや濃い肌色:',
        'ko': u':면사포를_쓴_여자_진한_갈색_피부:',
        'pt': u':noiva_com_véu_pele_morena_escura:',
        'it': ':sposa_con_velo_carnagione_abbastanza_scura:',
        'fa': u':زن_با_تور_عروس_پوست_گندمی:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_gelap-sedang:',
        'zh': u':戴头纱的女人_中等深肤色:'
    },
    u'\U0001F470\U0001F3FC\U0000200D\U00002640\U0000FE0F': { # 👰🏼‍♀️
        'en' : ':woman_with_veil_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_mittelhelle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_voile_peau_moyennement_claire:',
        'ja': u':ベールの女性_やや薄い肌色:',
        'ko': u':면사포를_쓴_여자_연한_갈색_피부:',
        'pt': u':noiva_com_véu_pele_morena_clara:',
        'it': ':sposa_con_velo_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_تور_عروس_پوست_روشن:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_cerah-sedang:',
        'zh': u':戴头纱的女人_中等浅肤色:'
    },
    u'\U0001F470\U0001F3FC\U0000200D\U00002640': { # 👰🏼‍♀
        'en' : ':woman_with_veil_medium-light_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_mittelhelle_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_voile_peau_moyennement_claire:',
        'ja': u':ベールの女性_やや薄い肌色:',
        'ko': u':면사포를_쓴_여자_연한_갈색_피부:',
        'pt': u':noiva_com_véu_pele_morena_clara:',
        'it': ':sposa_con_velo_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_تور_عروس_پوست_روشن:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_cerah-sedang:',
        'zh': u':戴头纱的女人_中等浅肤色:'
    },
    u'\U0001F470\U0001F3FD\U0000200D\U00002640\U0000FE0F': { # 👰🏽‍♀️
        'en' : ':woman_with_veil_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_mittlere_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_medio:',
        'fr': u':femme_avec_voile_peau_légèrement_mate:',
        'ja': u':ベールの女性_中間の肌色:',
        'ko': u':면사포를_쓴_여자_갈색_피부:',
        'pt': u':noiva_com_véu_pele_morena:',
        'it': ':sposa_con_velo_carnagione_olivastra:',
        'fa': u':زن_با_تور_عروس_پوست_طلایی:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_sedang:',
        'zh': u':戴头纱的女人_中等肤色:'
    },
    u'\U0001F470\U0001F3FD\U0000200D\U00002640': { # 👰🏽‍♀
        'en' : ':woman_with_veil_medium_skin_tone:',
        'status' : minimally_qualified,
        'E' : 13,
        'de': ':frau_mit_schleier_mittlere_hautfarbe:',
        'es': ':mujer_con_velo_tono_de_piel_medio:',
        'fr': u':femme_avec_voile_peau_légèrement_mate:',
        'ja': u':ベールの女性_中間の肌色:',
        'ko': u':면사포를_쓴_여자_갈색_피부:',
        'pt': u':noiva_com_véu_pele_morena:',
        'it': ':sposa_con_velo_carnagione_olivastra:',
        'fa': u':زن_با_تور_عروس_پوست_طلایی:',
        'id': ':wanita_berpenutup_kepala_warna_kulit_sedang:',
        'zh': u':戴头纱的女人_中等肤色:'
    },
    u'\U0001F469\U0000200D\U0001F9AF': { # 👩‍🦯
        'en' : ':woman_with_white_cane:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':woman_with_probing_cane:'],
        'de': ':frau_mit_langstock:',
        'es': u':mujer_con_bastón:',
        'fr': ':femme_avec_canne_blanche:',
        'ja': u':杖をついた女性:',
        'ko': u':지팡이를_든_여자:',
        'pt': ':mulher_com_bengala_para_cego:',
        'it': ':donna_con_bastone_bianco_di_orientamento:',
        'fa': u':زن_با_عصای_سفید:',
        'id': ':wanita_dengan_tongkat:',
        'zh': u':拄盲杖的女人:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F9AF': { # 👩🏿‍🦯
        'en' : ':woman_with_white_cane_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_mit_gehstock_dunkle_hautfarbe:',
        'es': u':mujer_con_bastón_tono_de_piel_oscuro:',
        'fr': u':femme_avec_canne_blanche_peau_foncée:',
        'ja': u':杖をついた女性_濃い肌色:',
        'ko': u':지팡이를_든_여자_검은색_피부:',
        'pt': ':mulher_com_bengala_para_cego_pele_escura:',
        'it': ':donna_con_bastone_bianco_di_orientamento_carnagione_scura:',
        'fa': u':زن_با_عصای_سفید_پوست_آبنوسی:',
        'id': ':wanita_dengan_tongkat_warna_kulit_gelap:',
        'zh': u':拄盲杖的女人_较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F9AF': { # 👩🏻‍🦯
        'en' : ':woman_with_white_cane_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_mit_gehstock_helle_hautfarbe:',
        'es': u':mujer_con_bastón_tono_de_piel_claro:',
        'fr': ':femme_avec_canne_blanche_peau_claire:',
        'ja': u':杖をついた女性_薄い肌色:',
        'ko': u':지팡이를_든_여자_하얀_피부:',
        'pt': ':mulher_com_bengala_para_cego_pele_clara:',
        'it': ':donna_con_bastone_bianco_di_orientamento_carnagione_chiara:',
        'fa': u':زن_با_عصای_سفید_پوست_سفید:',
        'id': ':wanita_dengan_tongkat_warna_kulit_cerah:',
        'zh': u':拄盲杖的女人_较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F9AF': { # 👩🏾‍🦯
        'en' : ':woman_with_white_cane_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_mit_gehstock_mitteldunkle_hautfarbe:',
        'es': u':mujer_con_bastón_tono_de_piel_oscuro_medio:',
        'fr': ':femme_avec_canne_blanche_peau_mate:',
        'ja': u':杖をついた女性_やや濃い肌色:',
        'ko': u':지팡이를_든_여자_진한_갈색_피부:',
        'pt': ':mulher_com_bengala_para_cego_pele_morena_escura:',
        'it': ':donna_con_bastone_bianco_di_orientamento_carnagione_abbastanza_scura:',
        'fa': u':زن_با_عصای_سفید_پوست_گندمی:',
        'id': ':wanita_dengan_tongkat_warna_kulit_gelap-sedang:',
        'zh': u':拄盲杖的女人_中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F9AF': { # 👩🏼‍🦯
        'en' : ':woman_with_white_cane_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_mit_gehstock_mittelhelle_hautfarbe:',
        'es': u':mujer_con_bastón_tono_de_piel_claro_medio:',
        'fr': ':femme_avec_canne_blanche_peau_moyennement_claire:',
        'ja': u':杖をついた女性_やや薄い肌色:',
        'ko': u':지팡이를_든_여자_연한_갈색_피부:',
        'pt': ':mulher_com_bengala_para_cego_pele_morena_clara:',
        'it': ':donna_con_bastone_bianco_di_orientamento_carnagione_abbastanza_chiara:',
        'fa': u':زن_با_عصای_سفید_پوست_روشن:',
        'id': ':wanita_dengan_tongkat_warna_kulit_cerah-sedang:',
        'zh': u':拄盲杖的女人_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F9AF': { # 👩🏽‍🦯
        'en' : ':woman_with_white_cane_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':frau_mit_gehstock_mittlere_hautfarbe:',
        'es': u':mujer_con_bastón_tono_de_piel_medio:',
        'fr': u':femme_avec_canne_blanche_peau_légèrement_mate:',
        'ja': u':杖をついた女性_中間の肌色:',
        'ko': u':지팡이를_든_여자_갈색_피부:',
        'pt': ':mulher_com_bengala_para_cego_pele_morena:',
        'it': ':donna_con_bastone_bianco_di_orientamento_carnagione_olivastra:',
        'fa': u':زن_با_عصای_سفید_پوست_طلایی:',
        'id': ':wanita_dengan_tongkat_warna_kulit_sedang:',
        'zh': u':拄盲杖的女人_中等肤色:'
    },
    u'\U0001F9DF\U0000200D\U00002640\U0000FE0F': { # 🧟‍♀️
        'en' : ':woman_zombie:',
        'status' : fully_qualified,
        'E' : 5,
        'alias' : [':zombie_woman:'],
        'de': ':weiblicher_zombie:',
        'es': ':zombi_mujer:',
        'fr': ':zombie_femme:',
        'ja': u':女のゾンビ:',
        'ko': u':여자_좀비:',
        'pt': ':mulher_zumbi:',
        'it': ':zombie_donna:',
        'fa': u':مرده_متحرک_زن:',
        'id': ':zombi_wanita:',
        'zh': u':女僵尸:'
    },
    u'\U0001F9DF\U0000200D\U00002640': { # 🧟‍♀
        'en' : ':woman_zombie:',
        'status' : minimally_qualified,
        'E' : 5,
        'alias' : [':zombie_woman:'],
        'de': ':weiblicher_zombie:',
        'es': ':zombi_mujer:',
        'fr': ':zombie_femme:',
        'ja': u':女のゾンビ:',
        'ko': u':여자_좀비:',
        'pt': ':mulher_zumbi:',
        'it': ':zombie_donna:',
        'fa': u':مرده_متحرک_زن:',
        'id': ':zombi_wanita:',
        'zh': u':女僵尸:'
    },
    u'\U0001F462': { # 👢
        'en' : u':woman’s_boot:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':boot:'],
        'de': ':damenstiefel:',
        'es': ':bota_de_mujer:',
        'fr': ':botte_de_femme:',
        'ja': u':ブーツ:',
        'ko': u':부츠:',
        'pt': ':bota_feminina:',
        'it': ':stivale_da_donna:',
        'fa': u':پوتین_زنانه:',
        'id': ':sepatu_bot_wanita:',
        'zh': u':女靴:'
    },
    u'\U0001F45A': { # 👚
        'en' : u':woman’s_clothes:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':womans_clothes:'],
        'de': ':bluse:',
        'es': ':ropa_de_mujer:',
        'fr': u':vêtements_de_femme:',
        'ja': u':婦人服:',
        'ko': u':여성복:',
        'pt': ':roupas_femininas:',
        'it': ':maglietta_da_donna:',
        'fa': u':لباس_زنانه:',
        'id': ':pakaian_wanita:',
        'zh': u':女装:'
    },
    u'\U0001F452': { # 👒
        'en' : u':woman’s_hat:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':womans_hat:'],
        'de': ':damenhut:',
        'es': ':sombrero_de_mujer:',
        'fr': ':chapeau_de_femme:',
        'ja': u':婦人帽子:',
        'ko': u':여성용_모자:',
        'pt': u':chapéu_feminino:',
        'it': ':cappello_da_donna:',
        'fa': u':کلاه_زنانه:',
        'id': ':topi_wanita:',
        'zh': u':女帽:'
    },
    u'\U0001F461': { # 👡
        'en' : u':woman’s_sandal:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':sandal:'],
        'de': ':damensandale:',
        'es': ':sandalia_de_mujer:',
        'fr': ':sandale_de_femme:',
        'ja': u':サンダル:',
        'ko': u':샌들:',
        'pt': u':sandália_feminina:',
        'it': ':sandalo_da_donna:',
        'fa': u':صندل_زنانه:',
        'id': ':sandal_wanita:',
        'zh': u':女式凉鞋:'
    },
    u'\U0001F46D': { # 👭
        'en' : ':women_holding_hands:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':two_women_holding_hands:'],
        'de': u':händchen_haltende_frauen:',
        'es': ':mujeres_de_la_mano:',
        'fr': ':deux_femmes_se_tenant_la_main:',
        'ja': u':手をつなぐ女性:',
        'ko': u':손을_잡고_있는_두_명의_여자:',
        'pt': u':duas_mulheres_de_mãos_dadas:',
        'it': ':due_donne_che_si_tengono_per_mano:',
        'fa': u':دو_زن_دست_در_دست:',
        'id': ':dua_wanita_bergandengan:',
        'zh': u':手拉手的两个女人:'
    },
    u'\U0001F46D\U0001F3FF': { # 👭🏿
        'en' : ':women_holding_hands_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_dunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_foncée:',
        'ja': u':手をつなぐ女性_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_검은색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_آبنوسی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap:',
        'zh': u':手拉手的两个女人_较深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FB': { # 👩🏿‍🤝‍👩🏻
        'en' : ':women_holding_hands_dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_dunkle_hautfarbe,_helle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_foncée_et_peau_claire:',
        'ja': u':手をつなぐ女性_濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_검은색_피부_하얀_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_escura_e_pele_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_scura_e_carnagione_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_آبنوسی_پوست_سفید:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap_warna_kulit_cerah:',
        'zh': u':手拉手的两个女人_较深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FE': { # 👩🏿‍🤝‍👩🏾
        'en' : ':women_holding_hands_dark_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_dunkle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_oscuro_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_foncée_et_peau_mate:',
        'ja': u':手をつなぐ女性_濃い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_검은색_피부_진한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_escura_e_pele_morena_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_آبنوسی_پوست_گندمی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个女人_较深肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FC': { # 👩🏿‍🤝‍👩🏼
        'en' : ':women_holding_hands_dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_dunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_claro_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_foncée_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ女性_濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_검은색_피부_연한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_escura_e_pele_morena_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_آبنوسی_پوست_روشن:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个女人_较深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FF\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FD': { # 👩🏿‍🤝‍👩🏽
        'en' : ':women_holding_hands_dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_dunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_y_tono_de_piel_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_foncée_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ女性_濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_검은색_피부_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_escura_e_pele_morena:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_scura_e_carnagione_olivastra:',
        'fa': u':دو_زن_دست_در_دست_پوست_آبنوسی_پوست_طلایی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap_warna_kulit_sedang:',
        'zh': u':手拉手的两个女人_较深肤色中等肤色:'
    },
    u'\U0001F46D\U0001F3FB': { # 👭🏻
        'en' : ':women_holding_hands_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_helle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_claire:',
        'ja': u':手をつなぐ女性_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_하얀_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_سفید:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah:',
        'zh': u':手拉手的两个女人_较浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FF': { # 👩🏻‍🤝‍👩🏿
        'en' : ':women_holding_hands_light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_helle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_claire_et_peau_foncée:',
        'ja': u':手をつなぐ女性_薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_하얀_피부_검은색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_clara_e_pele_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_سفید_پوست_آبنوسی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah_warna_kulit_gelap:',
        'zh': u':手拉手的两个女人_较浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FE': { # 👩🏻‍🤝‍👩🏾
        'en' : ':women_holding_hands_light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_helle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_oscuro_medio:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_claire_et_peau_mate:',
        'ja': u':手をつなぐ女性_薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_하얀_피부_진한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_clara_e_pele_morena_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_سفید_پوست_گندمی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个女人_较浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FC': { # 👩🏻‍🤝‍👩🏼
        'en' : ':women_holding_hands_light_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_helle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_claro_medio:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_claire_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ女性_薄い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_하얀_피부_연한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_clara_e_pele_morena_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_سفید_پوست_روشن:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个女人_较浅肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FB\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FD': { # 👩🏻‍🤝‍👩🏽
        'en' : ':women_holding_hands_light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_helle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_y_tono_de_piel_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ女性_薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_하얀_피부_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_clara_e_pele_morena:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_chiara_e_carnagione_olivastra:',
        'fa': u':دو_زن_دست_در_دست_پوست_سفید_پوست_طلایی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah_warna_kulit_sedang:',
        'zh': u':手拉手的两个女人_较浅肤色中等肤色:'
    },
    u'\U0001F46D\U0001F3FE': { # 👭🏾
        'en' : ':women_holding_hands_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mitteldunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_medio:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_mate:',
        'ja': u':手をつなぐ女性_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_진한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_گندمی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个女人_中等深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FF': { # 👩🏾‍🤝‍👩🏿
        'en' : ':women_holding_hands_medium-dark_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_mitteldunkle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_mate_et_peau_foncée:',
        'ja': u':手をつなぐ女性_やや濃い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_진한_갈색_피부_검은색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_escura_e_pele_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_گندمی_پوست_آبنوسی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个女人_中等深肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FB': { # 👩🏾‍🤝‍👩🏻
        'en' : ':women_holding_hands_medium-dark_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mitteldunkle_hautfarbe,_helle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_mate_et_peau_claire:',
        'ja': u':手をつなぐ女性_やや濃い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_진한_갈색_피부_하얀_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_escura_e_pele_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_گندمی_پوست_سفید:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个女人_中等深肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FC': { # 👩🏾‍🤝‍👩🏼
        'en' : ':women_holding_hands_medium-dark_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mitteldunkle_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_claro_medio:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ女性_やや濃い肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_진한_갈색_피부_연한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_escura_e_pele_morena_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_گندمی_پوست_روشن:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个女人_中等深肤色中等浅肤色:'
    },
    u'\U0001F469\U0001F3FE\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FD': { # 👩🏾‍🤝‍👩🏽
        'en' : ':women_holding_hands_medium-dark_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mitteldunkle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_oscuro_medio_y_tono_de_piel_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_mate_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ女性_やや濃い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_진한_갈색_피부_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_escura_e_pele_morena:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_scura_e_carnagione_olivastra:',
        'fa': u':دو_زن_دست_در_دست_پوست_گندمی_پوست_طلایی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_gelap-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的两个女人_中等深肤色中等肤色:'
    },
    u'\U0001F46D\U0001F3FC': { # 👭🏼
        'en' : ':women_holding_hands_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mittelhelle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_medio:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_moyennement_claire:',
        'ja': u':手をつなぐ女性_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_연한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_روشن:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个女人_中等浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FF': { # 👩🏼‍🤝‍👩🏿
        'en' : ':women_holding_hands_medium-light_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_mittelhelle_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_moyennement_claire_et_peau_foncée:',
        'ja': u':手をつなぐ女性_やや薄い肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_연한_갈색_피부_검은색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_clara_e_pele_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_روشن_پوست_آبنوسی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个女人_中等浅肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FB': { # 👩🏼‍🤝‍👩🏻
        'en' : ':women_holding_hands_medium-light_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mittelhelle_hautfarbe,_helle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_claro:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_moyennement_claire_et_peau_claire:',
        'ja': u':手をつなぐ女性_やや薄い肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_연한_갈색_피부_하얀_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_clara_e_pele_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_روشن_پوست_سفید:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个女人_中等浅肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FE': { # 👩🏼‍🤝‍👩🏾
        'en' : ':women_holding_hands_medium-light_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_mittelhelle_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_oscuro_medio:',
        'fr': ':deux_femmes_se_tenant_la_main_peau_moyennement_claire_et_peau_mate:',
        'ja': u':手をつなぐ女性_やや薄い肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_연한_갈색_피부_진한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_clara_e_pele_morena_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_abbastanza_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_روشن_پوست_گندمی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个女人_中等浅肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FC\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FD': { # 👩🏼‍🤝‍👩🏽
        'en' : ':women_holding_hands_medium-light_skin_tone_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_mittelhelle_hautfarbe,_mittlere_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_claro_medio_y_tono_de_piel_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_moyennement_claire_et_peau_légèrement_mate:',
        'ja': u':手をつなぐ女性_やや薄い肌色_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_연한_갈색_피부_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_clara_e_pele_morena:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_abbastanza_chiara_e_carnagione_olivastra:',
        'fa': u':دو_زن_دست_در_دست_پوست_روشن_پوست_طلایی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_cerah-sedang_warna_kulit_sedang:',
        'zh': u':手拉手的两个女人_中等浅肤色中等肤色:'
    },
    u'\U0001F46D\U0001F3FD': { # 👭🏽
        'en' : ':women_holding_hands_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mittlere_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_légèrement_mate:',
        'ja': u':手をつなぐ女性_中間の肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_olivastra:',
        'fa': u':دو_زن_دست_در_دست_پوست_طلایی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_sedang:',
        'zh': u':手拉手的两个女人_中等肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FF': { # 👩🏽‍🤝‍👩🏿
        'en' : ':women_holding_hands_medium_skin_tone_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_mittlere_hautfarbe,_dunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_légèrement_mate_et_peau_foncée:',
        'ja': u':手をつなぐ女性_中間の肌色_濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_갈색_피부_검은색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_e_pele_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_طلایی_پوست_آبنوسی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_sedang_warna_kulit_gelap:',
        'zh': u':手拉手的两个女人_中等肤色较深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FB': { # 👩🏽‍🤝‍👩🏻
        'en' : ':women_holding_hands_medium_skin_tone_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mittlere_hautfarbe,_helle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_claro:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_légèrement_mate_et_peau_claire:',
        'ja': u':手をつなぐ女性_中間の肌色_薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_갈색_피부_하얀_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_e_pele_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_طلایی_پوست_سفید:',
        'id': ':dua_wanita_bergandengan_warna_kulit_sedang_warna_kulit_cerah:',
        'zh': u':手拉手的两个女人_中等肤色较浅肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FE': { # 👩🏽‍🤝‍👩🏾
        'en' : ':women_holding_hands_medium_skin_tone_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 12.1,
        'de': u':händchenhaltende_frauen_mittlere_hautfarbe,_mitteldunkle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_oscuro_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_légèrement_mate_et_peau_mate:',
        'ja': u':手をつなぐ女性_中間の肌色_やや濃い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_갈색_피부_진한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_e_pele_morena_escura:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_scura:',
        'fa': u':دو_زن_دست_در_دست_پوست_طلایی_پوست_گندمی:',
        'id': ':dua_wanita_bergandengan_warna_kulit_sedang_warna_kulit_gelap-sedang:',
        'zh': u':手拉手的两个女人_中等肤色中等深肤色:'
    },
    u'\U0001F469\U0001F3FD\U0000200D\U0001F91D\U0000200D\U0001F469\U0001F3FC': { # 👩🏽‍🤝‍👩🏼
        'en' : ':women_holding_hands_medium_skin_tone_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':händchenhaltende_frauen_mittlere_hautfarbe,_mittelhelle_hautfarbe:',
        'es': ':mujeres_de_la_mano_tono_de_piel_medio_y_tono_de_piel_claro_medio:',
        'fr': u':deux_femmes_se_tenant_la_main_peau_légèrement_mate_et_peau_moyennement_claire:',
        'ja': u':手をつなぐ女性_中間の肌色_やや薄い肌色:',
        'ko': u':손을_잡고_있는_두_명의_여자_갈색_피부_연한_갈색_피부:',
        'pt': u':duas_mulheres_de_mãos_dadas_pele_morena_e_pele_morena_clara:',
        'it': ':due_donne_che_si_tengono_per_mano_carnagione_olivastra_e_carnagione_abbastanza_chiara:',
        'fa': u':دو_زن_دست_در_دست_پوست_طلایی_پوست_روشن:',
        'id': ':dua_wanita_bergandengan_warna_kulit_sedang_warna_kulit_cerah-sedang:',
        'zh': u':手拉手的两个女人_中等肤色中等浅肤色:'
    },
    u'\U0001F46F\U0000200D\U00002640\U0000FE0F': { # 👯‍♀️
        'en' : ':women_with_bunny_ears:',
        'status' : fully_qualified,
        'E' : 4,
        'alias' : [':dancing_women:'],
        'de': ':frauen_mit_hasenohren:',
        'es': ':mujeres_con_orejas_de_conejo:',
        'fr': ':femmes_avec_des_oreilles_de_lapin:',
        'ja': u':バニーガール:',
        'ko': u':토끼_귀를_쓰고_춤추는_여자들:',
        'pt': ':mulheres_com_orelhas_de_coelho:',
        'it': ':donne_con_orecchie_da_coniglio:',
        'fa': u':زنان_در_پارتی:',
        'id': ':wanita_dengan_telinga_kelinci:',
        'zh': u':兔女郎:'
    },
    u'\U0001F46F\U0000200D\U00002640': { # 👯‍♀
        'en' : ':women_with_bunny_ears:',
        'status' : minimally_qualified,
        'E' : 4,
        'alias' : [':dancing_women:'],
        'de': ':frauen_mit_hasenohren:',
        'es': ':mujeres_con_orejas_de_conejo:',
        'fr': ':femmes_avec_des_oreilles_de_lapin:',
        'ja': u':バニーガール:',
        'ko': u':토끼_귀를_쓰고_춤추는_여자들:',
        'pt': ':mulheres_com_orelhas_de_coelho:',
        'it': ':donne_con_orecchie_da_coniglio:',
        'fa': u':زنان_در_پارتی:',
        'id': ':wanita_dengan_telinga_kelinci:',
        'zh': u':兔女郎:'
    },
    u'\U0001F93C\U0000200D\U00002640\U0000FE0F': { # 🤼‍♀️
        'en' : ':women_wrestling:',
        'status' : fully_qualified,
        'E' : 4,
        'de': ':ringende_frauen:',
        'es': ':mujeres_luchando:',
        'fr': ':lutteuses:',
        'ja': u':レスリングする女:',
        'ko': u':레슬링하는_여자:',
        'pt': ':mulheres_lutando:',
        'it': ':lottatrici:',
        'fa': u':کُشتی_گیر_زن:',
        'id': ':wanita_bergulat:',
        'zh': u':女生摔跤:'
    },
    u'\U0001F93C\U0000200D\U00002640': { # 🤼‍♀
        'en' : ':women_wrestling:',
        'status' : minimally_qualified,
        'E' : 4,
        'de': ':ringende_frauen:',
        'es': ':mujeres_luchando:',
        'fr': ':lutteuses:',
        'ja': u':レスリングする女:',
        'ko': u':레슬링하는_여자:',
        'pt': ':mulheres_lutando:',
        'it': ':lottatrici:',
        'fa': u':کُشتی_گیر_زن:',
        'id': ':wanita_bergulat:',
        'zh': u':女生摔跤:'
    },
    u'\U0001F6BA': { # 🚺
        'en' : u':women’s_room:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':womens:'],
        'variant': True,
        'de': ':damen:',
        'es': u':señal_de_aseo_para_mujeres:',
        'fr': ':symbole_toilettes_femmes:',
        'ja': u':女子トイレ:',
        'ko': u':여자_화장실:',
        'pt': ':banheiro_feminino:',
        'it': ':simbolo_del_bagno_delle_donne:',
        'fa': u':توالت_زنانه:',
        'id': ':toilet_wanita:',
        'zh': u':女厕:'
    },
    u'\U0001FAB5': { # 🪵
        'en' : ':wood:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':holz:',
        'es': ':madera:',
        'fr': ':bois:',
        'ja': u':丸太:',
        'ko': u':목재:',
        'pt': ':madeira:',
        'it': ':legna:',
        'fa': u':چوب:',
        'id': ':kayu:',
        'zh': u':木头:'
    },
    u'\U0001F974': { # 🥴
        'en' : ':woozy_face:',
        'status' : fully_qualified,
        'E' : 11,
        'de': ':schwindeliges_gesicht:',
        'es': ':cara_de_grogui:',
        'fr': u':visage_éméché:',
        'ja': u':ふらふらの顔:',
        'ko': u':헤롱헤롱_얼굴:',
        'pt': ':rosto_embriagado:',
        'it': ':faccina_stordita:',
        'fa': u':نشئه:',
        'id': ':wajah_pusing_karena_mabuk:',
        'zh': u':头昏眼花:'
    },
    u'\U0001F5FA\U0000FE0F': { # 🗺️
        'en' : ':world_map:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':weltkarte:',
        'es': ':mapa_mundial:',
        'fr': ':carte_du_monde:',
        'ja': u':世界地図:',
        'ko': u':세계_지도:',
        'pt': u':mapa-múndi:',
        'it': ':mappa_mondiale:',
        'fa': u':نقشه_جهان:',
        'id': ':peta_dunia:',
        'zh': u':世界地图:'
    },
    u'\U0001F5FA': { # 🗺
        'en' : ':world_map:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':weltkarte:',
        'es': ':mapa_mundial:',
        'fr': ':carte_du_monde:',
        'ja': u':世界地図:',
        'ko': u':세계_지도:',
        'pt': u':mapa-múndi:',
        'it': ':mappa_mondiale:',
        'fa': u':نقشهٔ_جهان:',
        'id': ':peta_dunia:',
        'zh': u':世界地图:'
    },
    u'\U0001FAB1': { # 🪱
        'en' : ':worm:',
        'status' : fully_qualified,
        'E' : 13,
        'de': ':wurm:',
        'es': ':gusano:',
        'fr': ':lombric:',
        'ja': u':ミミズ:',
        'ko': u':지렁이:',
        'pt': ':minhoca:',
        'it': ':verme:',
        'fa': u':کرم:',
        'id': ':cacing:',
        'zh': u':蠕虫:'
    },
    u'\U0001F61F': { # 😟
        'en' : ':worried_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':worried:'],
        'de': ':besorgtes_gesicht:',
        'es': ':cara_preocupada:',
        'fr': ':visage_inquiet:',
        'ja': u':悩む顔:',
        'ko': u':걱정스러운_얼굴:',
        'pt': ':rosto_preocupado:',
        'it': ':faccina_preoccupata:',
        'fa': u':چهره_نگران:',
        'id': ':wajah_cemas:',
        'zh': u':担心:'
    },
    u'\U0001F381': { # 🎁
        'en' : ':wrapped_gift:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':gift:'],
        'de': ':geschenk:',
        'es': ':regalo:',
        'fr': ':cadeau:',
        'ja': u':プレゼント:',
        'ko': u':선물:',
        'pt': ':presente:',
        'it': ':regalo:',
        'fa': u':هدیهٔ_کادوشده:',
        'id': ':kado:',
        'zh': u':礼物:'
    },
    u'\U0001F527': { # 🔧
        'en' : ':wrench:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': u':schraubenschlüssel:',
        'es': ':llave_inglesa:',
        'fr': u':clé_à_molette:',
        'ja': u':レンチ:',
        'ko': u':렌치:',
        'pt': ':chave_inglesa:',
        'it': ':chiave_inglese:',
        'fa': u':آچار:',
        'id': ':kunci_inggris:',
        'zh': u':扳手:'
    },
    u'\U0000270D\U0000FE0F': { # ✍️
        'en' : ':writing_hand:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schreibende_hand:',
        'es': ':mano_escribiendo:',
        'fr': u':main_qui_écrit:',
        'ja': u':書いている手:',
        'ko': u':글을_쓰고_있는_손:',
        'pt': u':escrevendo_à_mão:',
        'it': ':mano_che_scrive:',
        'fa': u':نوشتن_با_دست:',
        'id': ':tangan_menulis:',
        'zh': u':写字:'
    },
    u'\U0000270D': { # ✍
        'en' : ':writing_hand:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':schreibende_hand:',
        'es': ':mano_escribiendo:',
        'fr': u':main_qui_écrit:',
        'ja': u':書いている手:',
        'ko': u':글을_쓰고_있는_손:',
        'pt': u':escrevendo_à_mão:',
        'it': ':mano_che_scrive:',
        'fa': u':نوشتن_با_دست:',
        'id': ':tangan_menulis:',
        'zh': u':写字:'
    },
    u'\U0000270D\U0001F3FF': { # ✍🏿
        'en' : ':writing_hand_dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schreibende_hand_dunkle_hautfarbe:',
        'es': ':mano_escribiendo_tono_de_piel_oscuro:',
        'fr': u':main_qui_écrit_peau_foncée:',
        'ja': u':書いている手_濃い肌色:',
        'ko': u':글을_쓰고_있는_손_검은색_피부:',
        'pt': u':escrevendo_à_mão_pele_escura:',
        'it': ':mano_che_scrive_carnagione_scura:',
        'fa': u':نوشتن_با_دست_پوست_آبنوسی:',
        'id': ':tangan_menulis_warna_kulit_gelap:',
        'zh': u':写字_较深肤色:'
    },
    u'\U0000270D\U0001F3FB': { # ✍🏻
        'en' : ':writing_hand_light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schreibende_hand_helle_hautfarbe:',
        'es': ':mano_escribiendo_tono_de_piel_claro:',
        'fr': u':main_qui_écrit_peau_claire:',
        'ja': u':書いている手_薄い肌色:',
        'ko': u':글을_쓰고_있는_손_하얀_피부:',
        'pt': u':escrevendo_à_mão_pele_clara:',
        'it': ':mano_che_scrive_carnagione_chiara:',
        'fa': u':نوشتن_با_دست_پوست_سفید:',
        'id': ':tangan_menulis_warna_kulit_cerah:',
        'zh': u':写字_较浅肤色:'
    },
    u'\U0000270D\U0001F3FE': { # ✍🏾
        'en' : ':writing_hand_medium-dark_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schreibende_hand_mitteldunkle_hautfarbe:',
        'es': ':mano_escribiendo_tono_de_piel_oscuro_medio:',
        'fr': u':main_qui_écrit_peau_mate:',
        'ja': u':書いている手_やや濃い肌色:',
        'ko': u':글을_쓰고_있는_손_진한_갈색_피부:',
        'pt': u':escrevendo_à_mão_pele_morena_escura:',
        'it': ':mano_che_scrive_carnagione_abbastanza_scura:',
        'fa': u':نوشتن_با_دست_پوست_گندمی:',
        'id': ':tangan_menulis_warna_kulit_gelap-sedang:',
        'zh': u':写字_中等深肤色:'
    },
    u'\U0000270D\U0001F3FC': { # ✍🏼
        'en' : ':writing_hand_medium-light_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schreibende_hand_mittelhelle_hautfarbe:',
        'es': ':mano_escribiendo_tono_de_piel_claro_medio:',
        'fr': u':main_qui_écrit_peau_moyennement_claire:',
        'ja': u':書いている手_やや薄い肌色:',
        'ko': u':글을_쓰고_있는_손_연한_갈색_피부:',
        'pt': u':escrevendo_à_mão_pele_morena_clara:',
        'it': ':mano_che_scrive_carnagione_abbastanza_chiara:',
        'fa': u':نوشتن_با_دست_پوست_روشن:',
        'id': ':tangan_menulis_warna_kulit_cerah-sedang:',
        'zh': u':写字_中等浅肤色:'
    },
    u'\U0000270D\U0001F3FD': { # ✍🏽
        'en' : ':writing_hand_medium_skin_tone:',
        'status' : fully_qualified,
        'E' : 1,
        'de': ':schreibende_hand_mittlere_hautfarbe:',
        'es': ':mano_escribiendo_tono_de_piel_medio:',
        'fr': u':main_qui_écrit_peau_légèrement_mate:',
        'ja': u':書いている手_中間の肌色:',
        'ko': u':글을_쓰고_있는_손_갈색_피부:',
        'pt': u':escrevendo_à_mão_pele_morena:',
        'it': ':mano_che_scrive_carnagione_olivastra:',
        'fa': u':نوشتن_با_دست_پوست_طلایی:',
        'id': ':tangan_menulis_warna_kulit_sedang:',
        'zh': u':写字_中等肤色:'
    },
    u'\U0001FA7B': { # 🩻
        'en' : ':x-ray:',
        'status' : fully_qualified,
        'E' : 14,
        'de': u':röntgenbild:',
        'es': u':radiografía:',
        'fr': ':radiographie:',
        'ja': u':x線:',
        'ko': u':엑스레이:',
        'pt': ':raio_x:',
        'it': ':radiografia:',
        'fa': u':اشعه_ایکس:',
        'id': ':sinar-x:',
        'zh': u':X射线:'
    },
    u'\U0001F9F6': { # 🧶
        'en' : ':yarn:',
        'status' : fully_qualified,
        'E' : 11,
        'de': u':wollknäuel:',
        'es': ':ovillo:',
        'fr': ':fil:',
        'ja': u':毛糸:',
        'ko': u':실뭉치:',
        'pt': ':novelo:',
        'it': ':gomitolo:',
        'fa': u':نخ_بافندگی:',
        'id': ':gulungan_benang:',
        'zh': u':毛线:'
    },
    u'\U0001F971': { # 🥱
        'en' : ':yawning_face:',
        'status' : fully_qualified,
        'E' : 12,
        'de': u':gähnendes_gesicht:',
        'es': ':cara_de_bostezo:',
        'fr': u':visage_bâillant:',
        'ja': u':あくびした顔:',
        'ko': u':하품하는_얼굴:',
        'pt': ':rosto_bocejando:',
        'it': ':faccina_che_sbadiglia:',
        'fa': u':صورت_خمیازه_کش:',
        'id': ':wajah_menguap:',
        'zh': u':打呵欠:'
    },
    u'\U0001F7E1': { # 🟡
        'en' : ':yellow_circle:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':gelber_punkt:',
        'es': u':círculo_amarillo:',
        'fr': ':disque_jaune:',
        'ja': u':黄色い丸:',
        'ko': u':노란색_원:',
        'pt': u':círculo_amarelo:',
        'it': ':cerchio_giallo:',
        'fa': u':دایره_زرد:',
        'id': ':lingkaran_kuning:',
        'zh': u':黄色圆:'
    },
    u'\U0001F49B': { # 💛
        'en' : ':yellow_heart:',
        'status' : fully_qualified,
        'E' : 0.6,
        'de': ':gelbes_herz:',
        'es': u':corazón_amarillo:',
        'fr': u':cœur_jaune:',
        'ja': u':黄色のハート:',
        'ko': u':노란색_하트:',
        'pt': u':coração_amarelo:',
        'it': ':cuore_giallo:',
        'fa': u':قلب_زرد:',
        'id': ':hati_kuning:',
        'zh': u':黄心:'
    },
    u'\U0001F7E8': { # 🟨
        'en' : ':yellow_square:',
        'status' : fully_qualified,
        'E' : 12,
        'de': ':gelbes_quadrat:',
        'es': ':cuadrado_amarillo:',
        'fr': u':carré_jaune:',
        'ja': u':黄色い四角:',
        'ko': u':노란색_사각형:',
        'pt': ':quadrado_amarelo:',
        'it': ':quadrato_giallo:',
        'fa': u':مربع_زرد:',
        'id': ':persegi_kuning:',
        'zh': u':黄色方块:'
    },
    u'\U0001F4B4': { # 💴
        'en' : ':yen_banknote:',
        'status' : fully_qualified,
        'E' : 0.6,
        'alias' : [':yen:'],
        'de': ':yen-banknote:',
        'es': ':billete_de_yen:',
        'fr': ':billet_en_yens:',
        'ja': u':円札:',
        'ko': u':엔:',
        'pt': ':nota_de_iene:',
        'it': ':banconota_yen:',
        'fa': u':اسکناس_ین:',
        'id': ':uang_kertas_yen:',
        'zh': u':日元:'
    },
    u'\U0000262F\U0000FE0F': { # ☯️
        'en' : ':yin_yang:',
        'status' : fully_qualified,
        'E' : 0.7,
        'variant': True,
        'de': ':yin_und_yang:',
        'es': ':yin_yang:',
        'fr': ':yin_yang:',
        'ja': u':陰陽:',
        'ko': u':음양:',
        'pt': ':yin_yang:',
        'it': ':yin_e_yang:',
        'fa': u':یین_و_ینگ:',
        'id': ':yin_yang:',
        'zh': u':阴阳:'
    },
    u'\U0000262F': { # ☯
        'en' : ':yin_yang:',
        'status' : unqualified,
        'E' : 0.7,
        'variant': True,
        'de': ':yin_und_yang:',
        'es': ':yin_yang:',
        'fr': ':yin_yang:',
        'ja': u':陰陽:',
        'ko': u':음양:',
        'pt': ':yin_yang:',
        'it': ':yin_e_yang:',
        'fa': u':یین_و_ینگ:',
        'id': ':yin_yang:',
        'zh': u':阴阳:'
    },
    u'\U0001FA80': { # 🪀
        'en' : ':yo-yo:',
        'status' : fully_qualified,
        'E' : 12,
        'alias' : [':yo_yo:'],
        'de': ':jo-jo:',
        'es': u':yoyó:',
        'fr': ':yoyo:',
        'ja': u':ヨーヨー:',
        'ko': u':요요:',
        'pt': u':ioiô:',
        'it': ':yo-yo:',
        'fa': u':یویو:',
        'id': ':yo-yo:',
        'zh': u':悠悠球:'
    },
    u'\U0001F92A': { # 🤪
        'en' : ':zany_face:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':irres_gesicht:',
        'es': ':cara_de_loco:',
        'fr': u':tête_de_fou:',
        'ja': u':ふざけた顔:',
        'ko': u':괴짜_얼굴:',
        'pt': ':rosto_bizarro:',
        'it': ':faccina_impazzita:',
        'fa': u':دیوانه:',
        'id': ':wajah_konyol:',
        'zh': u':滑稽:'
    },
    u'\U0001F993': { # 🦓
        'en' : ':zebra:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':zebra:',
        'es': ':cebra:',
        'fr': u':zèbre:',
        'ja': u':シマウマ:',
        'ko': u':얼룩말:',
        'pt': ':zebra:',
        'it': ':zebra:',
        'fa': u':گورخر:',
        'id': ':zebra:',
        'zh': u':斑马:'
    },
    u'\U0001F910': { # 🤐
        'en' : ':zipper-mouth_face:',
        'status' : fully_qualified,
        'E' : 1,
        'alias' : [':zipper__mouth_face:', ':zipper_mouth_face:'],
        'de': u':gesicht_mit_reißverschlussmund:',
        'es': ':cara_con_la_boca_cerrada_con_cremallera:',
        'fr': u':visage_avec_bouche_fermeture_éclair:',
        'ja': u':口チャック:',
        'ko': u':지퍼로_입을_잠근_얼굴:',
        'pt': u':rosto_com_boca_de_zíper:',
        'it': ':faccina_con_bocca_con_cerniera:',
        'fa': u':دهان_چفت:',
        'id': ':wajah_dengan_mulut_tertutup_rapat:',
        'zh': u':闭嘴:'
    },
    u'\U0001F9DF': { # 🧟
        'en' : ':zombie:',
        'status' : fully_qualified,
        'E' : 5,
        'de': ':zombie:',
        'es': ':zombi:',
        'fr': ':zombie:',
        'ja': u':ゾンビ:',
        'ko': u':좀비:',
        'pt': ':zumbi:',
        'it': ':zombie:',
        'fa': u':مرده_متحرک:',
        'id': ':zombi:',
        'zh': u':僵尸:'
    },
    u'\U0001F1E6\U0001F1FD': { # 🇦🇽
        'en' : u':Åland_Islands:',
        'status' : fully_qualified,
        'E' : 2,
        'alias' : [u':flag_for_Åland_Islands:', ':aland_islands:'],
        'de': u':flagge_ålandinseln:',
        'es': ':bandera_islas_?_land:',
        'fr': u':drapeau_îles_åland:',
        'ja': u':旗_オーランド諸島:',
        'ko': u':깃발_올란드_제도:',
        'pt': ':bandeira_ilhas_aland:',
        'it': u':bandiera_isole_åland:',
        'fa': u':پرچم_جزایر_آلاند:',
        'id': ':bendera_kepulauan_aland:',
        'zh': u':奥兰群岛:'
    },
}
